

%macro data_creation;
/* Control tables */

	%include "Data/bisdata/code/control/control_create_table_scripts.sas";
	%include "Data/bisdata/code/control/data_dictionary.sas";
	%include "Data/bisdata/code/control/validation_grade.sas";


/*Parameter Tables*/
	%if(%sysfunc(exist(custpara.parameter))) = 0 %then %do;	      
		%include "Data/bisdata/code/parameter/parameter.sas";
	%end;

	%if(%sysfunc(exist(custpara.parameter_x_category))) = 0 %then %do;	    
		%include "Data/bisdata/code/parameter/parameter_x_category.sas";
	%end;

	%if(%sysfunc(exist(custpara.parameter_category))) = 0 %then %do;	    
		%include "Data/bisdata/code/parameter/parameter_category.sas";
	%end;

/*ABT Framework Tables*/
	%include "Data/bisdata/code/frame_work_script/abt_frame_work_create_table_scripts_crs.sas";

/* List of tables to create reference table formats */
%include "Data/bisdata/code/format/fmtref.sas";

/* Foundation Mart job dependency */
%include "Data/bisdata/code/foundation_job_dependency/foundation_job_dependency.sas";

/* Credit Scoring Additons Mart job dependency */
%include "Data/bisdata/code/foundation_job_dependency/star_credit_scoring_job_dependency.sas";


/* Pooling Functionality */
%include "Data/bisdata/code/pooling_script/pooling_create_table_scripts.sas";
%include "Data/bisdata/code/pooling_script/pool_menu_items.sas";

/**************************************************************************** 
************************SAMPLE DATA FOR POOLING******************************
****************************************************************************/
%include "Data/bisdata/code/pooling_script/master_scale_defn.sas";
%include "Data/bisdata/code/pooling_script/pool_scheme_defn.sas";
%include "Data/bisdata/code/pooling_script/_300_pd_200303.sas";
%include "Data/bisdata/code/pooling_script/_400_lgd_200303.sas";
%include "Data/bisdata/code/pooling_script/_500_ccf_200303.sas";

%include "Data/bisdata/code/longrun/_lng_300_pd.sas";
%include "Data/bisdata/code/longrun/_lng_300_pd_lgdyrs.sas";
%include "Data/bisdata/code/longrun/_lng_400_lgd.sas";
/**************************************************************************** 
**********************END OF SAMPLE DATA FOR POOLING*************************
****************************************************************************/

/* Required dimensions for ETL jobs. Note: These dimensions should have data */
%include "Data/bisdata/code/foundation_script/dimension/dim_create_table_script.sas";
%include "Data/bisdata/code/foundation_script/dimension/time_dim_code.sas";
%include "Data/bisdata/code/foundation_script/modelmart/model_input.sas";

/* Model Monitoring Reports and Business Reports */
/**************************************************************************** 
********SAMPLE DATA FOR MODEL MONITORING REPORTS AND BUSINESS REPORTS********
****************************************************************************/
/* Dimensions */
	%include "Data/bisdata/code/foundation_script/dimension/account_dim.sas";

	%include "Data/bisdata/code/foundation_script/dimension/analytical_model_dim.sas";

	%include "Data/bisdata/code/foundation_script/dimension/applicant_dim.sas";

	%include "Data/bisdata/code/foundation_script/dimension/application_dim.sas";

	%include "Data/bisdata/code/foundation_script/dimension/customer_dim.sas";

	%include "Data/bisdata/code/foundation_script/dimension/delinquency_range_dim.sas";


	%include "Data/bisdata/code/foundation_script/dimension/financial_product_dim.sas";


	%include "Data/bisdata/code/foundation_script/dimension/internal_org_dim.sas";


	%include "Data/bisdata/code/foundation_script/dimension/measure_dim.sas";


	%include "Data/bisdata/code/foundation_script/dimension/pool_dim.sas";

	%include "Data/bisdata/code/foundation_script/dimension/pool_scheme.sas";

	%include "Data/bisdata/code/foundation_script/dimension/score_card_dim.sas";

	%include "Data/bisdata/code/foundation_script/dimension/score_card_variable_dim.sas";

	%include "Data/bisdata/code/foundation_script/dimension/country_dim.sas";

	%include "Data/bisdata/code/foundation_script/dimension/channel_dim.sas";

	%include "Data/bisdata/code/foundation_script/dimension/age_range_dim.sas";

	%include "Data/bisdata/code/foundation_script/dimension/tenure_range_dim.sas";

/* Facts */
%include "Data/bisdata/code/foundation_script/fact/fact_create_table_script.sas";
%include "Data/bisdata/code/foundation_script/fact/account_ccf_fact.sas";
%include "Data/bisdata/code/foundation_script/fact/account_lgd_fact.sas";
%include "Data/bisdata/code/foundation_script/fact/account_pd_fact.sas";
%include "Data/bisdata/code/foundation_script/fact/account_snapshot.sas";
%include "Data/bisdata/code/foundation_script/fact/application_analysis_fact.sas";
/*%include "Data/bisdata/code/foundation_script/fact/model_dev_appl_fact.sas";*/
%include "Data/bisdata/code/foundation_script/fact/model_dev_fact.sas";
%include "Data/bisdata/code/foundation_script/fact/model_measure_fact.sas";
%include "Data/bisdata/code/foundation_script/fact/score_range_fact.sas";
%include "Data/bisdata/code/foundation_script/fact/score_card_variable_fact.sas";


%macro run_partitioned_fact_scripts;
%let out_lib=fact;
%let file_path=Data/bisdata/code/foundation_script/fact;
%let fact_list=account_ccf_fact~500 account_lgd_fact~400~401 account_pd_fact~300~301~302~303 appl_pd_fact~200~201 score_card_fact~300~301;
%let cnt=1;
%let token=%qscan(&fact_list,&cnt);
%do %while(&token ne %str());
	%let tab_nm=%qscan(&token,1,'~');
	%let ind=2;
	%let model=%qscan(&token,&ind,'~');
	%do %while(&model ne %str());
		%do time = 13 %to 27;
			%let table_nm=&tab_nm._&model._&time.;
			%let file_nm=&table_nm..sas;
			%let file_p=&file_path./&file_nm;
			%include "&file_p";
		%end;
		%let ind=%eval(&ind+1);
		%let model=%qscan(&token,&ind,'~');
	%end;
	%let cnt=%eval(&cnt+1);
	%let token=%qscan(&fact_list,&cnt);
%end;
%mend run_partitioned_fact_scripts;
%run_partitioned_fact_scripts;

/* Bridge */
%include "Data/bisdata/code/foundation_script/fact/fact_create_table_index_script.sas";
%include "Data/bisdata/code/foundation_script/bridge/model_x_pool.sas";

/* Sample data for Enterprise Miner models */
libname lgd "Data/bisdata/lgd_sample_model/DataSources";
%include "Data/bisdata/code/sample_data_for_models/lgd_model/defaults.sas";
%include "Data/bisdata/code/sample_data_for_models/lgd_model/non_defaults.sas";
%include "Data/bisdata/code/sample_data_for_models/lgd_model/score.sas";

libname ccf "Data/bisdata/ccf_sample_model/DataSources";
%include "Data/bisdata/code/sample_data_for_models/ccf_model/ccf_abt.sas";
%include "Data/bisdata/code/sample_data_for_models/ccf_model/ccf_score.sas";

libname beh "Data/bisdata/pd_behavior_sample_model/DataSources";
%include "Data/bisdata/code/sample_data_for_models/behavioral_pd_model/beh_pd_abt.sas";
%include "Data/bisdata/code/sample_data_for_models/behavioral_pd_model/beh_pd_score.sas";

libname appl "Data/bisdata/pd_application_sample_model/DataSources";
%include "Data/bisdata/code/sample_data_for_models/application_pd_model/appl_pd_rejects.sas";
%include "Data/bisdata/code/sample_data_for_models/application_pd_model/appl_pd_score.sas";
%include "Data/bisdata/code/sample_data_for_models/application_pd_model/pd_appl_abt.sas";
/***********************************************************************************
********END OF SAMPLE DATA FOR MODEL MONITORING REPORTS AND BUSINESS REPORTS********
***********************************************************************************/

%let CCD_PRD_TYPE='CCD';
%let COR_PRD_TYPE='COR';
%let CHECK_FLAG_TRUE='Y';
/* The following 3 macro variables are required for vw_acctsnpsht_ccf view*/
/* Views: Note - Views will be created only if there is data in the facts */
%include "Data/bisdata/code/foundation_script/dimension/view/vw_acctsnpsht_ccf.sas";
%include "Data/bisdata/code/foundation_script/dimension/view/vw_delinq_tmp.sas";
%include "Data/bisdata/code/foundation_script/dimension/view/vw_delinquency.sas";
%include "Data/bisdata/code/foundation_script/dimension/view/vw_pool_lgd_tmp.sas";
%include "Data/bisdata/code/foundation_script/dimension/view/vw_pool_lgd.sas";
%include "Data/bisdata/code/foundation_script/dimension/view/vw_pool_pd_tmp.sas";
%include "Data/bisdata/code/foundation_script/dimension/view/vw_pool_pd.sas";
%include "Data/bisdata/code/foundation_script/dimension/view/vw_vintage_analysis.sas";
/* Call to create smd dataset used in Internationalization */	

%if(%sysfunc(exist(control.LOAD_CONTROL))) = 0 %then %do;	    	
	proc sql;
		create table control.LOAD_CONTROL
		  (
		   LOAD_MTH_YR_CD char(10) format=$10. informat=$10. label='Load Month And Year',
		   LOAD_START_DTTM num format=NLDATM21. informat=NLDATM21. label='Load Start Datetime',
		   LOAD_END_DTTM num format=NLDATM21. informat=NLDATM21. label='Load End Datetime',
		   LOAD_FLG char(1) format=$1. informat=$1. label='Load Flag',
		   RUN_STATUS char(10) label='Run status'
		  );
	quit;
%end;


%mend data_creation;

%data_creation;



