/****************************************************************************** 
 * Job:           ACCOUNT_SNAPSHOT_PRE_FACT                 A52B3KFO.BP00005K * 
 * Description:   This job picks up data from FA_CUSD_LKP  for the            * 
 *                 ACCOUNT_SNAPSHOT pre-fact table.                           * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A52B3KFO * 
 * Server:        SASMain                                   A52B3KFO.AT000001 * 
 *                                                                            * 
 * Source Table:  FA_CUSD_LKP - martscr.FA_CUSD_LKP         A52B3KFO.BH0000XO * 
 * Target Table:  ACCOUNT_SNAPSHOT_PRE_FACT -               A52B3KFO.BH0000XK * 
 *                 martscr.ACCOUNT_SNAPSHOT_PRE_FACT                          * 
 *                                                                            * 
 * Generated on:  Wednesday, June 11, 2008 9:30:08 AM IST                     * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * ACCOUNT_SNAPSHOT_PRE_FACT                                                  * 
 * Job Name: ACCOUNT_SNAPSHOT_PRE_FACTJob Desc Pre Process: a) Creating       * 
 * formats to obtain AGE_RANGE_SK, TENURE_RANGE_SK and DELINQUENCY_RANGE_SK   * 
 * from the tables AGE_RANGE_DIM, TENURE_RANGE_DIM and                        * 
 * DELINQUENCY_RANGE_DIM respectively.Main: a) To obtain cross sell count     * 
 * and age, tenure and delinquency surrogate keys using                       * 
 * formats.CROSS_SELL_ACCOUNT_CNT is obtained by applying the condition       * 
 * that is CUSTOMER_ACTIVE_CD is active, i.e. in the user defined parameter   * 
 * CUS_STATUS_ACT and FIRST_ACCOUNT_OPEN_DT is less that OPEN_DT the count    * 
 * is 1 else it is 0.Post Process: NoneParameters: a) CUS_STATUS_ACT: This    * 
 * parameter is used to check whether the customer is active.b) DUMMY_SK,     * 
 * DUMMY_RK : For Age_Range, Tenure_Range formats, if the underlying          * 
 * columns have null values available, the DUMMY_SK will be used. Similarly   * 
 * for Employee_rk, if the value is null, DUMMY_RK will be used.Developed     * 
 *  by: singupReviewed by:Tested by:                                          * 
 ******************************************************************************/ 



%let jobID = %quote(A52B3KFO.BP00005K);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = ACCOUNT_SNAPSHOT_PRE_FACT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A52B3KFO.AY0001PZ * 
 *                                                                            * 
 * User Written:  Format creation for age, tenure and       A52B3KFO.AF0009SS * 
 *                 delinquency                                                * 
 *                Format creation for age, tenure and delinquency             * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/* This code is to be removed 
and replaced by including the sas file for creating format */
/* Format creation for tenure range*/
data work.ntmp_tr;
set dim.TENURE_RANGE_DIM;
rangecol = catx('-',TENURE_RANGE_START_VALUE,TENURE_RANGE_END_VALUE);
keep rangecol TENURE_RANGE_SK;
run;

filename  ten_fmt 'Data/bisdata/format/cust_tr.sas' ;
data _null_;
file ten_fmt;
set work.ntmp_tr end=last;
if _n_=1 then do;
 put 'proc format;';
 put 'invalue TNRFMT'; 
end;
put rangecol @;
put '='@;
put TENURE_RANGE_SK;
if last then do;
 put 'other=.;';
 put 'run;';
end;
run;

/* Format creation for age range*/
data work.ntmp_age;
set dim.AGE_RANGE_DIM;
rangecol = catx('-',AGE_RANGE_START_VALUE,AGE_RANGE_END_VALUE);
keep rangecol AGE_RANGE_SK;
run;

filename  age_fmt 'Data/bisdata/format/cust_age.sas' ;
data _null_;
file age_fmt;
set work.ntmp_age end=last;
if _n_=1 then do;
 put 'proc format;';
 put 'invalue AGEFMT'; 
end;
put rangecol @;
put '='@;
put AGE_RANGE_SK;
if last then do;
 put 'other=.;';
 put 'run;';
end;
run;

/* Format creation for delinquency range*/
data work.ntmp_dlq;
set dim.DELINQUENCY_RANGE_DIM;
rangecol = catx('-',DELINQUENCY_RANGE_FROM,DELINQUENCY_RANGE_TO);
keep rangecol DELINQUENCY_RANGE_SK;
run;

filename dlq_fmt 'Data/bisdata/format/cust_dlq.sas';
data _null_;
file dlq_fmt;
set work.ntmp_dlq end=last;
if _n_=1 then do;
 put 'proc format;';
 put 'invalue DLQFMT'; 
end;
put rangecol @;
put '='@;
put DELINQUENCY_RANGE_SK;
if last then do;
 put 'other=.;';
 put 'run;';
end;
run;

%include ten_fmt;
%include age_fmt;
%include dlq_fmt;

/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          To obtain Cross sell count                A52B3KFO.BQ0000CB * 
 * Transform:     Extract                                                     * 
 * Description:   To obtain cross sell count and age, tenure and delinquency  * 
 *                 surrogate keys using formats                               * 
 *                                                                            * 
 * Source Table:  FA_CUSD_LKP - martscr.FA_CUSD_LKP         A52B3KFO.BH0000XO * 
 * Target Table:  Extract Target -                          A52B3KFO.BR000063 * 
 *                 martscr.ACCOUNT_SNAPSHOT_PRE_FACT                          * 
 *============================================================================*/ 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let SYSLAST = %nrquote(martscr.FA_CUSD_LKP); 

%let transformID = %quote(A52B3KFO.BQ0000CB); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete ACCOUNT_SNAPSHOT_PRE_FACT;
quit;

proc sql; 
   create table martscr.ACCOUNT_SNAPSHOT_PRE_FACT as 
      select (DATEPART(LOAD_END_DTTM )) as CAL_MONTH_LAST_DT length = 8 format = NLDATE10. informat = NLDATE10.,
             LOAD_END_DTTM length = 8 label = 'Load End Datetime',
             CUSTOMER_SK length = 8,
             (COALESCE(EMPLOYEE_RK , &DUMMY_RK.)) as EMPLOYEE_RK length = 8 format = 12. informat = 12.,
             ACCOUNT_RK length = 8 label = 'Account Key',
             PRODUCT_RK length = 8 label = 'Product Key',
             OWNED_BY_INTERNAL_ORG_RK length = 8 label = 'Internal Organization Retained Key',
             (COALESCE(INPUT(PUT(INTCK('MONTH', FIRST_ACCOUNT_OPEN_DT, datepart(LOAD_END_DTTM)) ,12.), TNRFMT.), &DUMMY_SK.)) as CUSTOMER_TENURE_RANGE_SK length = 8,
             (COALESCE(INPUT(PUT(INTCK('YEAR', BIRTH_DT, datepart(LOAD_END_DTTM))  ,12.), AGEFMT.), &DUMMY_SK.)) as AGE_RANGE_SK length = 8 format = 12. informat = 12.,
             (COALESCE(INPUT(PUT(DAYS_PAYMENT_PAST_DUE_CNT ,12.), DLQFMT.), &DUMMY_SK.)) as DELINQUENCY_RANGE_SK length = 8 format = 12. informat = 12.,
             BILLED_AMT length = 8 label = 'Billed Amount',
             CURRENT_BILL_AMT length = 8 label = 'Current Bill Amount',
             BALANCE_AMT length = 8 label = 'Balance Amount',
             INTEREST_EXPECTED_AMT length = 8 label = 'Interest Balance Amount',
             PRINCIPAL_BALANCE_AMT length = 8 label = 'Principal Balance Amount',
             PAST_DUE_AMT length = 8 label = 'Past Due Amount',
             DAYS_PAYMENT_PAST_DUE_CNT length = 8 label = 'No of Days Payment Past Due',
             AVERAGE_DAILY_BALANCE_AMT length = 8 label = 'Average Daily Balance Amount',
             MAX_ACCOUNT_VALUE_AMT length = 8 label = 'Maximum Account Value Amount',
             MIN_ACCOUNT_VALUE_AMT length = 8 label = 'Minimum Account Value Amount',
             MIN_BILLING_AMT length = 8 label = 'Minimum Due Amount',
             FEES_AMT length = 8 label = 'Fees Amount',
             CURTAILMENT_AMT length = 8 label = 'Curtailment Amount',
             LAST_STATEMENT_DT length = 8 label = 'Statement Date',
             LATE_PAYMENT_CNT length = 8 label = 'Number of late payment transactions, performed by all the Sks.',
             CCD_TOT_POINTS_EARNED length = 8 label = 'Total No Points Earned',
             CCD_TOT_POINTS_REDEEMED length = 8 label = 'Total No Points Redeemed',
             CCD_POINTS_BALANCE length = 8 label = 'Credit Card Points Balance',
             LAST_PAYMENT_STATUS_CD length = 3,
             OPENING_CHANNEL_CD length = 3,
             ACTIVE_ACCOUNT_CNT length = 8,
             INACTIVE_ACCOUNT_CNT length = 8,
             CLOSED_ACCOUNT_CNT length = 8,
             OPEN_ACCOUNT_CNT length = 8,
             DELINQUENCY_CNT length = 8,
             DIFFER_PAYMENT_CNT length = 8,
             DEFAULT_CNT length = 8,
             NEW_ACCOUNT_CNT length = 8,
             (CASE WHEN CUSTOMER_ACTIVE_CD  IN (&CUS_STATUS_ACT) AND FIRST_ACCOUNT_OPEN_DT  < OPEN_DT  THEN 1 ELSE 0 END) as CROSS_SELL_ACCOUNT_CNT length = 8,
             CROSS_SELL_CAMPAIGN_IND length = 8,
             ESCROW_AMT length = 8 label = 'Escrow Amount',
             UP_SELL_ACCOUNT_CNT length = 8,
             CLEARED_BALANCE_AMT length = 8 label = 'Cleared Balance Amount',
             NEXT_INTEREST_PAYMENT_DT length = 8 label = 'Next Interest Payment Date',
             TOTAL_SUSPENSIONS_CNT length = 8,
             TOTAL_BALANCE_AMT length = 8 label = 'Total Balance Amount',
             OVERDRAFT_CURRENT_AMT length = 8 label = 'Overdraft Current Amount'
         from &SYSLAST; 
quit;

%let SYSLAST = martscr.ACCOUNT_SNAPSHOT_PRE_FACT; 

%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Dummy Loader                              A52B3KFO.BQ0000CA * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  Extract Target -                          A52B3KFO.BR000063 * 
 *                 martscr.ACCOUNT_SNAPSHOT_PRE_FACT                          * 
 * Target Table:  ACCOUNT_SNAPSHOT_PRE_FACT -               A52B3KFO.BH0000XK * 
 *                 martscr.ACCOUNT_SNAPSHOT_PRE_FACT                          * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
