/****************************************************************************** 
 * Job:           ACC_DEF_RCV_CURR_LKP                      A52B3KFO.BP00021M * 
 * Description:   This job picks up the data from RECOVERY_FACT_EXT_CURR      * 
 *                 ,ACCOUNT_DIM and  RECOVERY_FROM_TYPE_DIM.                  * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A52B3KFO * 
 * Server:        SASMain                                   A52B3KFO.AT000001 * 
 *                                                                            * 
 * Source Tables: RECOVERY_FROM_TYPE_DIM -                  A52B3KFO.BH0000W4 * 
 *                 dim.RECOVERY_FROM_TYPE_DIM                                 * 
 *                RECOVERY_FACT_EXT_CURR -                  A52B3KFO.BH000134 * 
 *                 abtscr.RECOVERY_FACT_EXT_CURR                              * 
 *                ACCOUNT_DIM - dim.account_dim             A52B3KFO.BH0000VE * 
 *                                                                            * 
 * Generated on:  Wednesday, June 11, 2008 4:21:00 PM IST                     * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************/ 

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = ACC_DEF_RCV_CURR_LKP;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          Finding account key                       A52B3KFO.BQ0004N6 * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Finding the account information for the recovery.Finding    * 
 *                the account information for the recovery. From inner        * 
 *                joining table RECOVERY_FACT_EXT_CURR and ACCOUNT_DIM on     * 
 *                 ACCOUNT_SK.                                                * 
 *                                                                            * 
 * Source Tables: RECOVERY_FACT_EXT_CURR -                  A52B3KFO.BH000134 * 
 *                 abtscr.RECOVERY_FACT_EXT_CURR                              * 
 *                ACCOUNT_DIM - dim.account_dim             A52B3KFO.BH0000VE * 
 * Target Table:  SQL Target -                              A52B3KFO.BR0002BO * 
 *                 abtscr.ACC_DEF_RCV_CURR_LKP_TEMP                           * 
 *============================================================================*/ 

/* Access the data for Scratch for ABT  */ 
LIBNAME abtscr BASE "Data/bisdata/scratch/abt" ;
%rcSet(&syslibrc); 

/* Access the data for Dimensions  */ 
LIBNAME dim BASE "Data/bisdata/dim" ;
%rcSet(&syslibrc); 

%let trans_rc = 0; 

proc datasets lib = abtscr nolist nowarn memtype = (data view);
   delete ACC_DEF_RCV_CURR_LKP_TEMP;
quit;

proc sql;
   create table abtscr.ACC_DEF_RCV_CURR_LKP_TEMP as
      select
         account_dim.ACCOUNT_RK length = 8
                                format = 12.
                                informat = 12.
                                label = "_RKorSK",
         RECOVERY_FACT_EXT_CURR.TIME_SK length = 8
                                        format = 12.
                                        informat = 12.
                                        label = "_RKorSK",
         RECOVERY_FACT_EXT_CURR.RECOVERY_COST_AMT length = 8
                                                  format = NLNUM18.5
                                                  informat = NLNUM18.5
                                                  label = "_AMT",
         RECOVERY_FACT_EXT_CURR.RECOVERY_FROM_TYPE_SK length = 8
                                                      format = 12.
                                                      informat = 12.
                                                      label = "_RKorSK",
         account_dim.PRIMARY_CUSTOMER_RK length = 8,
         account_dim.ACCOUNT_TYPE_CD length = 3
                                     format = $3.
                                     informat = $3.
                                     label = "_CD",
         account_dim.ACCOUNT_SUB_TYPE_CD length = 3
                                         format = $3.
                                         informat = $3.
                                         label = "_CD",
         account_dim.COLLATERAL_CD length = 3
                                   format = $3.
                                   informat = $3.
                                   label = "_CD",
         account_dim.ACCOUNT_STATUS_CD length = 3
                                       format = $3.
                                       informat = $3.
                                       label = "_CD",
         RECOVERY_FACT_EXT_CURR.VALUE_REALIZED_AMT length = 8
                                                   format = NLNUM18.5
                                                   informat = NLNUM18.5
                                                   label = "_AMT",
         RECOVERY_FACT_EXT_CURR.LOAD_ABT_USER_INPUT_DTTM length = 8
                                                         format = NLDATM21.
                                                         informat = NLDATM21.,
         RECOVERY_FACT_EXT_CURR.LOAD_ABT_USER_INPUT_DATE length = 8
                                                         format = NLDATE10.
                                                         informat = NLDATE10.,
         RECOVERY_FACT_EXT_CURR.CURR_TIME_SK length = 8,
         RECOVERY_FACT_EXT_CURR.BACK_12M_TIME_SK length = 8
      from
         abtscr.RECOVERY_FACT_EXT_CURR, 
         dim.account_dim
      where
         RECOVERY_FACT_EXT_CURR.ACCOUNT_SK = account_dim.ACCOUNT_SK
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Recovery Type Code Lookup                 A52B3KFO.BQ0004N5 * 
 * Transform:     Lookup                                                      * 
 * Description:   Recovery Type Code Lookup on table RECOVERY_FROM_TYPE_DIM.  * 
 *                                                                            * 
 * Source Tables: RECOVERY_FROM_TYPE_DIM -                  A52B3KFO.BH0000W4 * 
 *                 dim.RECOVERY_FROM_TYPE_DIM                                 * 
 *                SQL Target -                              A52B3KFO.BR0002BO * 
 *                 abtscr.ACC_DEF_RCV_CURR_LKP_TEMP                           * 
 * Target Table:  Lookup Target -                           A52B3KFO.BR0002BM * 
 *                 abtscr.ACC_DEF_RCV_CURR_LKP                                * 
 *============================================================================*/ 

%let trans_rc = 0; 

/* make the runTime macro variable to store the run time of the job  */ 
%let runTime = %sysfunc(datetime(), ); 

proc datasets lib = abtscr nolist nowarn memtype = (data view);
   delete ACC_DEF_RCV_CURR_LKP;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  abtscr.ACC_DEF_RCV_CURR_LKP
         (keep = ACCOUNT_RK TIME_SK RECOVERY_COST_AMT RECOVERY_FROM_TYPE_CD 
                 PRIMARY_CUSTOMER_RK ACCOUNT_TYPE_CD ACCOUNT_SUB_TYPE_CD 
                 COLLATERAL_CD ACCOUNT_STATUS_CD VALUE_REALIZED_AMT 
                 LOAD_ABT_USER_INPUT_DTTM LOAD_ABT_USER_INPUT_DATE CURR_TIME_SK 
                 BACK_12M_TIME_SK)
      ; 
   
   attrib ACCOUNT_RK length=8 format=12. label="_RKorSK"
          TIME_SK length=8 format=12. label="_RKorSK"
          RECOVERY_COST_AMT length=8 format=NLNUM18.5 label="_AMT"
          RECOVERY_FROM_TYPE_CD length=$3 format=$3. label="_Id"
          PRIMARY_CUSTOMER_RK length=8
          ACCOUNT_TYPE_CD length=$3 format=$3. label="_CD"
          ACCOUNT_SUB_TYPE_CD length=$3 format=$3. label="_CD"
          COLLATERAL_CD length=$3 format=$3. label="_CD"
          ACCOUNT_STATUS_CD length=$3 format=$3. label="_CD"
          VALUE_REALIZED_AMT length=8 format=NLNUM18.5 label="_AMT"
          LOAD_ABT_USER_INPUT_DTTM length=8 format=NLDATM21.
          LOAD_ABT_USER_INPUT_DATE length=8 format=NLDATE10.
          CURR_TIME_SK length=8
          BACK_12M_TIME_SK length=8
          ; 
   
   length RECOVERY_FROM_TYPE_SK 8 ; 
   
   retain missing0 0 ; 
   
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table dim.RECOVERY_FROM_TYPE_DIM */ 
      nlobs = .; 
      dsid = open("dim.RECOVERY_FROM_TYPE_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "dim.RECOVERY_FROM_TYPE_DIM", hashexp: exponent);
            h0.defineKey( "RECOVERY_FROM_TYPE_SK");
            h0.defineData( "RECOVERY_FROM_TYPE_CD");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: dim.RECOVERY_FROM_TYPE_DIM";
                  missing0 = 98; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: dim.RECOVERY_FROM_TYPE_DIM";
            missing0 = 98; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " dim.RECOVERY_FROM_TYPE_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " dim.RECOVERY_FROM_TYPE_DIM";
         
         abort 3; 
      end; 
      
      call missing (RECOVERY_FROM_TYPE_SK, RECOVERY_FROM_TYPE_CD); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set abtscr.ACC_DEF_RCV_CURR_LKP_TEMP end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   if (missing0 < 1) then 
   do; 
      rc0 = h0.find();
   end; 
   else 
      rc0 = missing0; 
      
   
   /* Examine success of lookups  */ 
   if (rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output abtscr.ACC_DEF_RCV_CURR_LKP; 
      return; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         if (rc0 = 98) then 
         do; 
            /* Check: Lookup table has no rows-Write exception row  */ 
            /* Check: Lookup table has no rows-Set target columns to value  */ 
         end; 
         
         else 
         do; 
            /* Check: Lookup value not found-Skip the record  */ 
            return; 
         end; 
      end; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "NOTE: Source records with errors: error_total ; ";
      put "NOTE: Total lookup exceptions: exception_total ; ";
   end; 

run; 

%rcSet(&syserr); 

/*============================================================================* 
 * Step:          Call the macro acc_def_recv_abt           A52B3KFO.BQ0004N4 * 
 * Transform:     User Written Code                                           * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  Lookup Target -                           A52B3KFO.BR0002BM * 
 *                 abtscr.ACC_DEF_RCV_CURR_LKP                                * 
 * Target Table:  ACC_DEF_RCV_CURR_ABT - work.              A52B3KFO.BR0002BN * 
 *                                                                            * 
 * User Written:  Macro call: acc_def_recv_abt              A52B3KFO.AF000OR3 * 
 *                Macro call  to populate the table ACC_DEF_RCV_CURR_ABT      * 
 *============================================================================*/ 

%let SYSLAST = %nrquote(abtscr.ACC_DEF_RCV_CURR_LKP); 

%let trans_rc = 0; 

%let _OUTPUT = %nrquote(work.A52B3KFO_BR0002BN); 

/*---- Start of User Written Code  ----*/ 

/*Macro Name :acc_def_recv_abt
Parameters: 
a) PERIOD: Period for which the historical calculation/summarization is
 to be done .
b) INPUT_TABLE: This is the input table to the macro which will be used for 
  historical calculation/summarization. 

Output: 
Table-1: ACC_DEF_RCV_CURR_ABT 
 */
/*%let CURR_TIME_SK=7;*/
/*%let BACK_12M_TIME_SK=9;*/
/*%LET PCU_RECOVERY_FROM_TYPE ='PCU';*/
/*%LET PCL_RECOVERY_FROM_TYPE ='PCL'; */
/*%LET GUR_RECOVERY_FROM_TYPE ='GUR';*/
/*%LET INC_RECOVERY_FROM_TYPE ='INC';*/
/*%LET SRD_RECOVERY_FROM_TYPE ='SRD';*/
%acc_def_recv_abt(PERIOD=1, INPUT_TABLE=ACC_DEF_RCV_CURR_LKP);
PROC SQL ;
/*Creating simple index on table for current months*/
CREATE INDEX ACCOUNT_TYPE_CD ON ABTAGG.ACC_DEF_RCV_CURR_ABT(ACCOUNT_TYPE_CD);
CREATE INDEX COLLATERAL_CD ON ABTAGG.ACC_DEF_RCV_CURR_ABT(COLLATERAL_CD);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

