/****************************************************************************** 
 * Job:           ACC_SNAP_TIME_LTD_ABT                     A52B3KFO.BP00022X * 
 * Description:   This job picks up data from ACC_SNAP_LTD_ABT and TIME_DIM   * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A52B3KFO * 
 * Server:        SASMain                                   A52B3KFO.AT000001 * 
 *                                                                            * 
 * Source Table:  ACC_SNAP_LTD_ABT -                        A52B3KFO.BH00015C * 
 *                 abtagg.ACC_SNAP_LTD_ABT                                    * 
 * Target Table:  ACC_SNAP_TIME_LTD_ABT -                   A52B3KFO.BH00015E * 
 *                 abtagg.ACC_SNAP_TIME_LTD_ABT                               * 
 *                                                                            * 
 * Generated on:  Thursday, June 12, 2008 10:21:31 AM IST                     * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************/ 



%let jobID = %quote(A52B3KFO.BP00022X);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = ACC_SNAP_TIME_LTD_ABT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A52B3KFO.AY0002CA * 
 *                                                                            * 
 * User Written:  Format to obtain CAL_YYYYMM               A52B3KFO.AF000P24 * 
 *                Format to obtain CAL_YYYYMM                                 * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/* Creating a dataset WORK.FMTLIST containing the table name and
 column names on which the formats is to be created. 
 For more details on the columns in WORK.FMTLIST, please refer to
 the macro fmt_gen in Data/bisdata/macro. */
DATA WORK.FMTLIST;
INFILE CARDS DLM=',';
INPUT WC $ GENYN $ LIBN $ DSN $ STARTCOL : $32. LABELCOL : $32. FMTNAME : $32. TYPE $;

CARDS;
 ,1,DIM,TIME_DIM,TIME_SK,CAL_YYYYMM,CALENDAR_YYYYMM,N
;
RUN;

/* The macro fmt_gen is called to create the formats $CALENDAR_YYYYMM */
%fmt_gen(
libraryname=WORK,
dsname=FMTLIST,
work=WORK,
for_lib=WORK,
generate_log=N
);

/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          To obtain the date of highest and lowest  A52B3KFO.BQ0004Q6 * 
 *                 ever balance                                               * 
 * Transform:     Extract                                                     * 
 * Description:   To obtain the date of highest and lowest ever balance by    * 
 *                 applying format CALENDAR_YYYYMM on the respective sk's.    * 
 *                                                                            * 
 * Source Table:  ACC_SNAP_LTD_ABT -                        A52B3KFO.BH00015C * 
 *                 abtagg.ACC_SNAP_LTD_ABT                                    * 
 * Target Table:  Extract Target -                          A52B3KFO.BR0002DW * 
 *                 abtagg.ACC_SNAP_TIME_LTD_ABT                               * 
 *============================================================================*/ 

/* Access the data for ABT Aggregate Tables  */ 
LIBNAME abtagg BASE "Data/bisdata/abt_agg_table" ;
%rcSet(&syslibrc); 

%let SYSLAST = %nrquote(abtagg.ACC_SNAP_LTD_ABT); 

%let transformID = %quote(A52B3KFO.BQ0004Q6); 

%let trans_rc = 0; 

proc datasets lib = abtagg nolist nowarn memtype = (data view);
   delete ACC_SNAP_TIME_LTD_ABT;
quit;

proc sql; 
   create table abtagg.ACC_SNAP_TIME_LTD_ABT as 
      select CUSTOMER_RK length = 8 label = '_RKorSK',
             ACCOUNT_RK length = 8 label = '_RKorSK',
             ACC_DLQ_LTD_MTH_CNT length = 8,
             (PUT(ACC_MAX_OUT_BAL_LTD_MTH_SK, CALENDAR_YYYYMM.)) as ACC_MAX_OUT_BAL_LTD_MTH_NO length = 6 format = $6. informat = $6.,
             (PUT(ACC_MIN_OUT_BAL_LTD_MTH_SK,  CALENDAR_YYYYMM.)) as ACC_MIN_OUT_BAL_LTD_MTH_NO length = 6 format = $6. informat = $6.,
             ACC_DFT_2NOR_LTD_MTH_CNT length = 8,
             ACC_PAY_DLD_2NOR_LTD_MTH_CNT length = 8,
             ACC_DLQ_2NOR_LTD_MTH_CNT length = 8,
             ACC_MAX_OUT_BAL_LTD_AMT length = 8,
             ACC_MIN_OUT_BAL_LTD_AMT length = 8,
             ACC_SNC_ZERO_BAL_MTH_CNT length = 8,
             ACC_NIL_BAL_LTD_MTH_CNT length = 8
         from &SYSLAST; 
quit;

%let SYSLAST = abtagg.ACC_SNAP_TIME_LTD_ABT; 

%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Dummy Loader                              A52B3KFO.BQ0004Q5 * 
 * Transform:     Table Loader (Version 2)                                    * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  Extract Target -                          A52B3KFO.BR0002DW * 
 *                 abtagg.ACC_SNAP_TIME_LTD_ABT                               * 
 * Target Table:  ACC_SNAP_TIME_LTD_ABT -                   A52B3KFO.BH00015E * 
 *                 abtagg.ACC_SNAP_TIME_LTD_ABT                               * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

