/****************************************************************************** 
 * Job:           AM_EXT                                    A5MS6GQF.BP0002BI * 
 * Description:   This job builds the AM_EXT table by picking up data from    * 
 *                 ANALYTICAL_MODEL table.                                    * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5MS6GQF * 
 * Server:        SASMain                                   A5MS6GQF.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5MS6GQF.BH0002BD * 
 *                ANALYTICAL_MODEL - DDS.ANALYTICAL_MODEL   A5MS6GQF.BH000004 * 
 * Target Table:  AM_EXT - martscr.AM_EXT                   A5MS6GQF.BH0000HT * 
 *                                                                            * 
 * Generated on:  Tuesday, December 4, 2007 10:15:28 AM IST                   * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * AM_EXT                                                                     * 
 * Job Name: AM_EXTJob Desc Pre Process: NoneMain:a) Extract and load data    * 
 * from ANALYTICAL_MODEL using SQL Join on LOAD_CONTROL based on              * 
 * conditionsLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUEand                       * 
 * LOAD_CONTROL.RUN_STATUS = RUNNING_STATUSand LOAD_CONTROL.LOAD_END_DTTM     * 
 * between ANALYTICAL_MODEL.VALID_FROM_DTTM and                               * 
 * ANALYTICAL_MODEL.VALID_TO_DTTMPost Process: An index is created on the     * 
 * MODEL_RK andLOAD_END_DTTM field in the AM_EXT table.Parameters:            * 
 * CHECK_FLAG_TRUE and RUNNING_STATUS are the user defined parameters.        * 
 * CHECK_FLAG_TRUE is set to 'Y' and RUNNING_STATUS is to 'Running' for       * 
 *  each month of data load.Developed by: singupReviewed by:Tested by:        * 
 ******************************************************************************/ 



%let jobID = %quote(A5MS6GQF.BP0002BI);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = AM_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          Extraction of data as per the loading     A5MS6GQF.BQ0004MR * 
 *                 period                                                     * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Extract and load data based on load period mentioned in     * 
 *                 LOAD_CONTROL table                                         * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5MS6GQF.BH0002BD * 
 *                ANALYTICAL_MODEL - DDS.ANALYTICAL_MODEL   A5MS6GQF.BH000004 * 
 * Target Table:  SQL Target - martscr.AM_EXT               A5MS6GQF.BR000336 * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5MS6GQF.BQ0004MR); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete AM_EXT;
quit;

proc sql;
   create table martscr.AM_EXT as
      select
         ANALYTICAL_MODEL.MODEL_RK length = 8
                                   format = 12.
                                   informat = 12.
                                   label = "Model Key",
         intnx('DTMONTH',datetime(),0,'END') as LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         ANALYTICAL_MODEL.MODEL_ID length = 32
                                   label = "Model Id",
         ANALYTICAL_MODEL.MODEL_NM length = 40
                                   label = "Model Name",
         ANALYTICAL_MODEL.VERSION_NO length = 20
                                     label = "Version No",
         ANALYTICAL_MODEL.MODEL_CREATION_DT length = 8
                                            format = NLDATE10.
                                            informat = NLDATE10.
                                            label = "Model Creation Date",
         ANALYTICAL_MODEL.MODEL_DEPLOYMENT_CD length = 3
                                              label = "Contact Type Code",
         ANALYTICAL_MODEL.MODEL_DESC length = 250
                                     label = "Model Description",
         ANALYTICAL_MODEL.MODEL_TYPE_CD length = 3
                                        label = "Model Type Description",
         ANALYTICAL_MODEL.TARGET_PERIOD_MTHS_CNT length = 8
                                                 format = NLNUM6.2
                                                 informat = NLNUM6.2
                                                 label = "Target Period in Months",
         ANALYTICAL_MODEL.EFFECTIVE_FROM_DTTM length = 8
                                              format = NLDATM21.
                                              informat = NLDATM21.
                                              label = "Effective From Datetime",
         ANALYTICAL_MODEL.EFFECTIVE_TO_DTTM length = 8
                                            format = NLDATM21.
                                            informat = NLDATM21.
                                            label = "Effective To Datetime",
         ANALYTICAL_MODEL.CR_MITIGANT_ADJUSTED_FLG length = 1
                                                   label = "Credit Mitigant Adjusted Flag",
         ANALYTICAL_MODEL.MODEL_PRODUCT_TYPE_CD length = 3
                                                label = "Financial Product Type Code",
         ANALYTICAL_MODEL.FACTOR_RT length = 8
                                    format = NLNUM9.4
                                    informat = NLNUM9.4
                                    label = "Conversion factor",
         ANALYTICAL_MODEL.CUT_OFF_SCORE_NO length = 8
                                           label = "Cut off score number",
         ANALYTICAL_MODEL.OFFSET_RT length = 8
                                    format = NLNUM9.4
                                    informat = NLNUM9.4
                                    label = "Conversion Offset"
      from
         control.LOAD_CONTROL, 
         DDS.ANALYTICAL_MODEL
      where
	  	 datetime() >= ANALYTICAL_MODEL.VALID_FROM_DTTM
         and datetime() <= ANALYTICAL_MODEL.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify AM_EXT;
         ic create not null (MODEL_RK);
         ic create not null (LOAD_END_DTTM);
         ic create not null (MODEL_ID);
   quit;
   
   %rcSet(&syserr); 
   
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5MS6GQF.BQ0003VE * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.AM_EXT               A5MS6GQF.BR000336 * 
 * Target Table:  AM_EXT - martscr.AM_EXT                   A5MS6GQF.BH0000HT * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*============================================================================* 
 * Post-Process code for the job                            A5MS6GQF.AY0001JO * 
 *                                                                            * 
 * User Written:  Index creation code on MODEL_RK &         A5MS6GQF.AF000HRC * 
 *                 LOAD_END_DTTM                                              * 
 *                Index creation code on MODEL_RK & LOAD_END_DTTM             * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on MODEL_RK & LOAD_END_DTTM columns */
PROC SQL NOPRINT;
           CREATE INDEX MODEL_RK_LOAD_END_DTTM
            ON martscr.AM_EXT (MODEL_RK,LOAD_END_DTTM); 
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

