/****************************************************************************** 
 * Job:           CAS_EXT                                   A52B3KFO.BP00000N * 
 * Description:   This job picks up data from CUSTOMER_ACCOUNT_SCORE          * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A52B3KFO * 
 * Server:        SASMain                                   A52B3KFO.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A52B3KFO.BH0000RW * 
 *                CUSTOMER_ACCOUNT_SCORE -                  A52B3KFO.BH00001R * 
 *                 DDS.CUSTOMER_ACCOUNT_SCORE                                 * 
 * Target Table:  CAS_EXT - martscr.CAS_EXT                 A52B3KFO.BH0000SH * 
 *                                                                            * 
 * Generated on:  Tuesday, June 10, 2008 2:46:10 PM IST                       * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * CAS_EXT                                                                    * 
 * Job Name: CAS_EXTJob Desc Pre Process: NoneMain:a)This job extracts and    * 
 * loads data from CUSTOMER_ACCOUNT_SCORE with SQL join on LOAD_CONTROL       * 
 * based on conditions:LOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUEand             * 
 * LOAD_CONTROL.RUN_STATUS = RUNNING_STATUSand                                * 
 * CUSTOMER_ACCOUNT_SCORE.SCORE_DT between                                    * 
 * datepart(LOAD_CONTROL.LOAD_START_DTTM) and                                 * 
 * datepart(LOAD_CONTROL.LOAD_END_DTTM)b) There is an having clause to load   * 
 * data for the maximum score date of that month. The assumption is that      * 
 * any application will be scored by same model only once in a day.Post       * 
 * Process: Creating index on MODEL_RK column and LOAD_END_DTTM.Parameters:   * 
 * CHECK_FLAG_TRUE and RUNNING_STATUS are the user defined parameters.        * 
 * CHECK_FLAG_TRUE is set to 'Y' and RUNNING_STATUS is to 'Running' for       * 
 *  each month of data load.Developed by: singupReviewed by:Tested by:        * 
 ******************************************************************************/ 



%let jobID = %quote(A52B3KFO.BP00000N);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = CAS_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          Extraction of data as per the loading     A52B3KFO.BQ00001A * 
 *                 period                                                     * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Extract and load data based on load period mentioned in     * 
 *                 LOAD_CONTROL table                                         * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A52B3KFO.BH0000RW * 
 *                CUSTOMER_ACCOUNT_SCORE -                  A52B3KFO.BH00001R * 
 *                 DDS.CUSTOMER_ACCOUNT_SCORE                                 * 
 * Target Table:  SQL Target - martscr.CAS_EXT              A52B3KFO.BR00000R * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A52B3KFO.BQ00001A); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete CAS_EXT;
quit;

proc sql;
   create table martscr.CAS_EXT as
      select
         CUSTOMER_ACCOUNT_SCORE.ACCOUNT_RK length = 8
                                           format = 12.
                                           informat = 12.
                                           label = "Account Key",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         CUSTOMER_ACCOUNT_SCORE.SCORE_DT length = 8
                                         format = NLDATE10.
                                         informat = NLDATE10.
                                         label = "Score Date",
         CUSTOMER_ACCOUNT_SCORE.MODEL_RK length = 8
                                         format = 12.
                                         informat = 12.
                                         label = "Model Key",
         CUSTOMER_ACCOUNT_SCORE.CUSTOMER_ACCOUNT_SCORE_NO length = 8
                                                          format = NLNUM12.8
                                                          informat = NLNUM12.8
                                                          label = "Customer Account Score No",
         CUSTOMER_ACCOUNT_SCORE.SCORE_POINTS_NO length = 8
                                                label = "Score Points No",
         CUSTOMER_ACCOUNT_SCORE.CR_MITIGANT_ADJUSTED_FLG length = 1
                                                         label = "Cr Mitigant Adjusted Flag",
         CUSTOMER_ACCOUNT_SCORE.PRINCIPAL_ONLY_FLG length = 1
                                                   label = "Principal Only Flag",
         CUSTOMER_ACCOUNT_SCORE.ESTIMATED_RT length = 8
                                             format = NLNUM9.4
                                             informat = NLNUM9.4
                                             label = "Estimated Rate"
      from
         control.LOAD_CONTROL, 
         DDS.CUSTOMER_ACCOUNT_SCORE
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and CUSTOMER_ACCOUNT_SCORE.SCORE_DT >= datepart(LOAD_CONTROL.LOAD_START_DTTM)
         and CUSTOMER_ACCOUNT_SCORE.SCORE_DT <= datepart(LOAD_CONTROL.LOAD_END_DTTM)
      group by
         CUSTOMER_ACCOUNT_SCORE.ACCOUNT_RK, 
         CUSTOMER_ACCOUNT_SCORE.MODEL_RK, 
         LOAD_CONTROL.LOAD_END_DTTM
      having
         CUSTOMER_ACCOUNT_SCORE.SCORE_DT = MAX(CUSTOMER_ACCOUNT_SCORE.SCORE_DT )
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A52B3KFO.BQ00001B * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.CAS_EXT              A52B3KFO.BR00000R * 
 * Target Table:  CAS_EXT - martscr.CAS_EXT                 A52B3KFO.BH0000SH * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A52B3KFO.AY0001KB * 
 *                                                                            * 
 * User Written:  Creating index on MODEL_RK &              A52B3KFO.AF00086O * 
 *                 LOAD_END_DTTM column .                                     * 
 *                Creating index on MODEL_RK & LOAD_END_DTTM column .         * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*Creating index on MODEL_RK and on LOAD_END_DTTM column */
PROC SQL NOPRINT;
  CREATE INDEX  MODEL_RK_LOAD_END_DTTM
   ON martscr.CAS_EXT(MODEL_RK,LOAD_END_DTTM);

QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

