/****************************************************************************** 
 * Job:           CUS_ACC_SNAP_LST_12M_ABT                  A52B3KFO.BP0001T7 * 
 * Description:   This job picks up the data from ACC_SNAP_LST_12M_ABT table  * 
 *                 for customer consolidation.                                * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A52B3KFO * 
 * Server:        SASMain                                   A52B3KFO.AT000001 * 
 *                                                                            * 
 * Source Table:  ACC_SNAP_LST_12M_ABT -                    A52B3KFO.BH000159 * 
 *                 abtagg.ACC_SNAP_LST_12M_ABT                                * 
 * Target Table:  CUS_ACC_SNAP_LST_12M_ABT -                A52B3KFO.BH0002O3 * 
 *                 abtagg.CUS_ACC_SNAP_LST_12M_ABT                            * 
 *                                                                            * 
 * Generated on:  Tuesday, June 10, 2008 2:53:12 PM IST                       * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************/ 

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = CUS_ACC_SNAP_LST_12M_ABT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          Customer consolidation                    A52B3KFO.BQ0003PG * 
 * Transform:     Extract                                                     * 
 * Description:   Customer consolidation obtained from the table              * 
 *                ACC_SNAP_LST_12M_ABT by grouping on CUSTOMER_RK where       * 
 *                account type is Mortgage, Loan, Credit card and Core and    * 
 *                 account status is open.                                    * 
 *                                                                            * 
 * Source Table:  ACC_SNAP_LST_12M_ABT -                    A52B3KFO.BH000159 * 
 *                 abtagg.ACC_SNAP_LST_12M_ABT                                * 
 * Target Table:  Extract Target -                          A52B3KFO.BR0001WP * 
 *                 abtagg.CUS_ACC_SNAP_LST_12M_ABT                            * 
 *============================================================================*/ 

/* Access the data for ABT Aggregate Tables  */ 
LIBNAME abtagg BASE "Data/bisdata/abt_agg_table" ;
%rcSet(&syslibrc); 

%let SYSLAST = %nrquote(abtagg.ACC_SNAP_LST_12M_ABT); 

%let trans_rc = 0; 

proc datasets lib = abtagg nolist nowarn memtype = (data view);
   delete CUS_ACC_SNAP_LST_12M_ABT;
quit;

proc sql; 
   create table abtagg.CUS_ACC_SNAP_LST_12M_ABT as 
      select CUSTOMER_RK length = 8 label = '_RKorSK',
             (SUM(ACC_1_30DLQ_LST_12M_CNT)) as CUS_1_30DLQ_LST_12M_CNT length = 8,
             (SUM(ACC_31_60DLQ_LST_12M_CNT)) as CUS_31_60DLQ_LST_12M_CNT length = 8,
             (SUM(ACC_61_90DLQ_LST_12M_CNT)) as CUS_61_90DLQ_LST_12M_CNT length = 8,
             (SUM(ACC_91_120DLQ_LST_12M_CNT)) as CUS_91_120DLQ_LST_12M_CNT length = 8,
             (SUM(ACC_120PDLQ_LST_12M_CNT)) as CUS_120PDLQ_LST_12M_CNT length = 8
         from &SYSLAST
            where ACCOUNT_TYPE_CD IN (&MTG_ACCOUNT_TYPE, &LON_ACCOUNT_TYPE, &CCD_ACCOUNT_TYPE,   
                  &COR_ACCOUNT_TYPE) AND ACCOUNT_STATUS_CD IN (&ACCT_STATUS_OPN)
         group by CUSTOMER_RK; 
quit;

%let SYSLAST = abtagg.CUS_ACC_SNAP_LST_12M_ABT; 

%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Dummy Loader                              A52B3KFO.BQ0003PF * 
 * Transform:     Table Loader (Version 2)                                    * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  Extract Target -                          A52B3KFO.BR0001WP * 
 *                 abtagg.CUS_ACC_SNAP_LST_12M_ABT                            * 
 * Target Table:  CUS_ACC_SNAP_LST_12M_ABT -                A52B3KFO.BH0002O3 * 
 *                 abtagg.CUS_ACC_SNAP_LST_12M_ABT                            * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

