/****************************************************************************** 
 * Job:           OTC_RCV_PER_LGD_ABT                       A52B3KFO.BP0001V7 * 
 * Description:   This job picks up data from ACC_DEF_EVENT_X_ACC_DIM and     * 
 *                 RECOVERY_FACT.                                             * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A52B3KFO * 
 * Server:        SASMain                                   A52B3KFO.AT000001 * 
 *                                                                            * 
 * Source Tables: ACCOUNT_DIM - dim.account_dim             A52B3KFO.BH0000VE * 
 *                ACC_DEF_EVENT_X_ACC_DIM -                 A52B3KFO.BH00010U * 
 *                 abtscr.ACC_DEF_EVENT_X_ACC_DIM                             * 
 *                RECOVERY_FACT - fact.RECOVERY_FACT        A52B3KFO.BH0000YS * 
 * Target Table:  OTC_RCV_PER_LGD_ABT -                     A52B3KFO.BH0002QB * 
 *                 abtagg.OTC_RCV_PER_LGD_ABT                                 * 
 *                                                                            * 
 * Generated on:  Thursday, June 12, 2008 10:41:00 AM IST                     * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************/ 

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = OTC_RCV_PER_LGD_ABT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          SQL Join                                  A52B3KFO.BQ0004RY * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Tables: ACCOUNT_DIM - dim.account_dim             A52B3KFO.BH0000VE * 
 *                ACC_DEF_EVENT_X_ACC_DIM -                 A52B3KFO.BH00010U * 
 *                 abtscr.ACC_DEF_EVENT_X_ACC_DIM                             * 
 *                RECOVERY_FACT - fact.RECOVERY_FACT        A52B3KFO.BH0000YS * 
 * Target Table:  SQL Target - work.W5IKDCER                A52B3KFO.BR0002FB * 
 *============================================================================*/ 

/* Access the data for Dimensions  */ 
LIBNAME dim BASE "Data/bisdata/dim" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for ABT  */ 
LIBNAME abtscr BASE "Data/bisdata/scratch/abt" ;
%rcSet(&syslibrc); 

/* Access the data for Facts  */ 
LIBNAME fact BASE "Data/bisdata/fact" ;
%rcSet(&syslibrc); 

%let trans_rc = 0; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5IKDCER;
quit;

proc sql;
   create view work.W5IKDCER as
      select
         AVG(ACC_DEF_EVENT_X_ACC_DIM.EXPOSURE_AT_DEFAULT_AMT) as EXPOSURE_AT_DEFAULT_AMT length = 8
                                                                                         format = NLNUM18.5
                                                                                         informat = NLNUM18.5,
         SUM(RECOVERY_FACT.RECOVERY_COST_AMT) as RECOVERY_COST_AMT length = 8
                                                                   format = NLNUM18.5
                                                                   informat = NLNUM18.5
                                                                   label = "_AMT",
         SUM(RECOVERY_FACT.VALUE_AT_RECOVERY_AMT) as VALUE_AT_RECOVERY_AMT length = 8
                                                                           format = NLNUM18.5
                                                                           informat = NLNUM18.5
                                                                           label = "_AMT",
         account_dim.ACCOUNT_RK length = 8
                                format = 12.
                                informat = 12.
                                label = "_RKorSK"
      from
         dim.account_dim, 
         abtscr.ACC_DEF_EVENT_X_ACC_DIM, 
         fact.RECOVERY_FACT
      where
         account_dim.ACCOUNT_RK = ACC_DEF_EVENT_X_ACC_DIM.ACCOUNT_RK
         and account_dim.ACCOUNT_SK = RECOVERY_FACT.ACCOUNT_SK
         and (input(put(RECOVERY_FACT.TIME_SK,12.),CALENDER_LAST_MTH_DT.) >= ACC_DEF_EVENT_X_ACC_DIM.DEFAULT_DT 
         and input(put(RECOVERY_FACT.TIME_SK,12.),CALENDER_LAST_MTH_DT.) <= INTNX('MONTH',ACC_DEF_EVENT_X_ACC_DIM.DEFAULT_DT,&RCV_PERIOD_MONTH_CNT,'END')) 
      ;
quit;

%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Calculation of Actual LGD and Actual Loss A52B3KFO.BQ0004RZ * 
 * Transform:     Extract                                                     * 
 * Description:   Calculation of Actual LGD and Actual Loss                   * 
 *                                                                            * 
 * Source Table:  SQL Target - work.W5IKDCER                A52B3KFO.BR0002FB * 
 * Target Table:  Extract Target -                          A52B3KFO.BR0002FA * 
 *                 abtagg.OTC_RCV_PER_LGD_ABT                                 * 
 *============================================================================*/ 

/* Access the data for ABT Aggregate Tables  */ 
LIBNAME abtagg BASE "Data/bisdata/abt_agg_table" ;
%rcSet(&syslibrc); 

%let SYSLAST = %nrquote(work.W5IKDCER); 

%let trans_rc = 0; 

proc datasets lib = abtagg nolist nowarn memtype = (data view);
   delete OTC_RCV_PER_LGD_ABT;
quit;

proc sql; 
   create table abtagg.OTC_RCV_PER_LGD_ABT as 
      select ACCOUNT_RK length = 8 label = '_RKorSK',
             ((EXPOSURE_AT_DEFAULT_AMT  + RECOVERY_COST_AMT  - VALUE_AT_RECOVERY_AMT) / EXPOSURE_AT_DEFAULT_AMT * 100) as ACTUAL_LGD length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (CASE WHEN (EXPOSURE_AT_DEFAULT_AMT  + RECOVERY_COST_AMT  - VALUE_AT_RECOVERY_AMT) > 0 THEN 1 ELSE 0 END) as LOSS_FLG length = 8
         from &SYSLAST; 
quit;

%let SYSLAST = abtagg.OTC_RCV_PER_LGD_ABT; 

%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Dummy Loader                              A52B3KFO.BQ0004RX * 
 * Transform:     Table Loader (Version 2)                                    * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  Extract Target -                          A52B3KFO.BR0002FA * 
 *                 abtagg.OTC_RCV_PER_LGD_ABT                                 * 
 * Target Table:  OTC_RCV_PER_LGD_ABT -                     A52B3KFO.BH0002QB * 
 *                 abtagg.OTC_RCV_PER_LGD_ABT                                 * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
