/****************************************************************************** 
 * Job:           PRP_EXT                                   A52B3KFO.BP0002C3 * 
 * Description:   This job builds the PRP_EXT table by picking up data from   * 
 *                 PROPERTY table in DDS.                                     * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A52B3KFO * 
 * Server:        SASMain                                   A52B3KFO.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A52B3KFO.BH0000RW * 
 *                PROPERTY - DDS.PROPERTY                   A52B3KFO.BH000057 * 
 * Target Table:  PRP_EXT - martscr.PRP_EXT                 A52B3KFO.BH0003UX * 
 *                                                                            * 
 * Generated on:  Wednesday, June 11, 2008 10:48:49 AM IST                    * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * PRP_EXT                                                                    * 
 * Job Name: PRP_EXTJob Desc Pre Process: NoneMain:Extract and load data      * 
 * from PROPERTY using a SQL join with table LOAD_CONTROL based on            * 
 * conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE                           * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS                                * 
 * andLOAD_CONTROL.LOAD_END_DTTM betweenVALID_FROM_DTTM and                   * 
 * VALID_TO_DTTMPost Process: Creating a simple index on PROPERTY_RK and      * 
 * LOAD_END_DTTMParameters: a)CHECK_FLAG_TRUE and RUNNING_STATUS are the      * 
 * user defined parameters. CHECK_FLAG_TRUE is set to 'Y' and                 * 
 * RUNNING_STATUS is to 'Running' for each month of data load.Developed by:   * 
 *  sindpcReviewed by:Tested by:                                              * 
 ******************************************************************************/ 



%let jobID = %quote(A52B3KFO.BP0002C3);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = PRP_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          Extraction of data as per the loading     A52B3KFO.BQ0004SO * 
 *                 period                                                     * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Extract and load data based on load period mentioned in     * 
 *                 LOAD_CONTROL table                                         * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A52B3KFO.BH0000RW * 
 *                PROPERTY - DDS.PROPERTY                   A52B3KFO.BH000057 * 
 * Target Table:  SQL Target - martscr.PRP_EXT              A52B3KFO.BR0002FP * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A52B3KFO.BQ0004SO); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete PRP_EXT;
quit;

proc sql;
   create table martscr.PRP_EXT as
      select
         PROPERTY.PROPERTY_RK length = 8
                              format = 12.
                              informat = 12.
                              label = "Property Key",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         PROPERTY.APPRAISED_VALUE_AMT length = 8
                                      format = NLNUM18.5
                                      informat = NLNUM18.5
                                      label = "Appraised Value Amount"
      from
         control.LOAD_CONTROL, 
         DDS.PROPERTY
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= PROPERTY.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= PROPERTY.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A52B3KFO.BQ0004SQ * 
 * Transform:     Table Loader (Version 2)                                    * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.PRP_EXT              A52B3KFO.BR0002FP * 
 * Target Table:  PRP_EXT - martscr.PRP_EXT                 A52B3KFO.BH0003UX * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*============================================================================* 
 * Post-Process code for the job                            A52B3KFO.AY0002CS * 
 *                                                                            * 
 * User Written:  Index creation code on PROPERTY_RK &      A52B3KFO.AF000PAO * 
 *                 LOAD_END_DTTM                                              * 
 *                Index creation code on PROPERTY_RK & LOAD_END_DTTM          * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on PROPERTY_RK & LOAD_END_DTTM columns */
PROC SQL NOPRINT;
           CREATE INDEX PROPERTY_RK_LOAD_END_DTTM
            ON martscr.PRP_EXT (PROPERTY_RK,LOAD_END_DTTM); 
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

