/****************************************************************************** 
 * Job:           ULN_ACC_SNAP_6M_BCK_ABT                   A52B3KFO.BP0000V9 * 
 * Description:   This job picks up data from ACC_SNAP_6M_BCK_ABT  for        * 
 *                 unsecured loan consolidation.                              * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A52B3KFO * 
 * Server:        SASMain                                   A52B3KFO.AT000001 * 
 *                                                                            * 
 * Source Table:  ACC_SNAP_6M_BCK_ABT -                     A52B3KFO.BH000157 * 
 *                 abtagg.ACC_SNAP_6M_BCK_ABT                                 * 
 * Target Table:  ULN_ACC_SNAP_6M_BCK_ABT -                 A52B3KFO.BH0001Q5 * 
 *                 abtagg.ULN_ACC_SNAP_6M_BCK_ABT                             * 
 *                                                                            * 
 * Generated on:  Tuesday, June 10, 2008 2:54:48 PM IST                       * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************/ 

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = ULN_ACC_SNAP_6M_BCK_ABT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          Unsecured Loan consolidation              A52B3KFO.BQ0001TI * 
 * Transform:     Extract                                                     * 
 * Description:   Unsecured Loan consolidation obtained from the table        * 
 *                ACC_SNAP_6M_BCK_ABT by grouping on CUSTOMER_RK where        * 
 *                 account type is loan and collateral code is null.          * 
 *                                                                            * 
 * Source Table:  ACC_SNAP_6M_BCK_ABT -                     A52B3KFO.BH000157 * 
 *                 abtagg.ACC_SNAP_6M_BCK_ABT                                 * 
 * Target Table:  Extract Target -                          A52B3KFO.BR0000YQ * 
 *                 abtagg.ULN_ACC_SNAP_6M_BCK_ABT                             * 
 *============================================================================*/ 

/* Access the data for ABT Aggregate Tables  */ 
LIBNAME abtagg BASE "Data/bisdata/abt_agg_table" ;
%rcSet(&syslibrc); 

%let SYSLAST = %nrquote(abtagg.ACC_SNAP_6M_BCK_ABT); 

%let trans_rc = 0; 

proc datasets lib = abtagg nolist nowarn memtype = (data view);
   delete ULN_ACC_SNAP_6M_BCK_ABT;
quit;

proc sql; 
   create table abtagg.ULN_ACC_SNAP_6M_BCK_ABT as 
      select CUSTOMER_RK length = 8 label = '_RKorSK',
             (SUM(CASE WHEN DELINQUENCY_CNT = 1 AND DAYS_PAYMENT_PAST_DUE_CNT BETWEEN 1 AND 30 THEN 1 ELSE 0 END)) as ULN_1_30DLQ_6M_BCK_ACC_CNT length = 8,
             (SUM(CASE WHEN DELINQUENCY_CNT = 1 AND DAYS_PAYMENT_PAST_DUE_CNT BETWEEN 31 AND 60 THEN 1 ELSE 0 END)) as ULN_31_60DLQ_6M_BCK_ACC_CNT length = 8,
             (SUM(CASE WHEN DELINQUENCY_CNT = 1 AND DAYS_PAYMENT_PAST_DUE_CNT BETWEEN 61 AND 90 THEN 1 ELSE 0 END)) as ULN_61_90DLQ_6M_BCK_ACC_CNT length = 8,
             (SUM(CASE WHEN DELINQUENCY_CNT = 1 AND DAYS_PAYMENT_PAST_DUE_CNT BETWEEN 91 AND 120 THEN 1 ELSE 0 END)) as ULN_91_120DLQ_6M_BCK_ACC_CNT length = 8,
             (SUM(CASE WHEN DELINQUENCY_CNT = 1 AND DAYS_PAYMENT_PAST_DUE_CNT > 120  THEN 1 ELSE 0 END)) as ULN_120PDLQ_6M_BCK_ACC_CNT length = 8,
             (SUM(ACC_31_60DLQ_6M_BCK_AMT)) as ULN_1_30DLQ_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (SUM(ACC_31_60DLQ_6M_BCK_AMT)) as ULN_31_60DLQ_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (SUM(ACC_61_90DLQ_6M_BCK_AMT)) as ULN_61_90DLQ_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (SUM(ACC_91_120DLQ_6M_BCK_AMT)) as ULN_91_120DLQ_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (SUM(ACC_120PDLQ_6M_BCK_AMT)) as ULN_120PDLQ_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (SUM( ACC_OUT_FEE_6M_BCK_AMT)) as ULN_OUT_FEE_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (MAX(ACC_OUT_FEE_6M_BCK_AMT)) as ULN_MAX_OUT_FEE_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (MIN(ACC_OUT_FEE_6M_BCK_AMT)) as ULN_MIN_OUT_FEE_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (SUM( ACC_OUT_BAL_6M_BCK_AMT)) as ULN_BAL_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (MAX(ACC_OUT_BAL_6M_BCK_AMT)) as ULN_MAX_BAL_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (MIN(ACC_OUT_BAL_6M_BCK_AMT)) as ULN_MIN_BAL_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (AVG(ACC_AVG_DLY_BAL_6M_BCK_AMT)) as ULN_AVG_DLY_BAL_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (SUM(ACC_OUT_PPL_6M_BCK_AMT)) as ULN_OUT_PPL_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (MAX( ACC_OUT_PPL_6M_BCK_AMT)) as ULN_MAX_OUT_PPL_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (MIN( ACC_OUT_PPL_6M_BCK_AMT)) as ULN_MIN_OUT_PPL_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (SUM(ACC_OUT_INT_6M_BCK_AMT)) as ULN_OUT_INT_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (MAX(ACC_OUT_INT_6M_BCK_AMT)) as ULN_MAX_OUT_INT_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5,
             (MIN(ACC_OUT_INT_6M_BCK_AMT)) as ULN_MIN_OUT_INT_6M_BCK_AMT length = 8 format = NLNUM18.5 informat = NLNUM18.5
         from &SYSLAST
            where ACCOUNT_TYPE_CD IN (&LON_ACCOUNT_TYPE)  AND  (COLLATERAL_CD IS NULL) AND ACCOUNT_STATUS_CD IN (&ACCT_STATUS_OPN)
         group by CUSTOMER_RK; 
quit;

%let SYSLAST = abtagg.ULN_ACC_SNAP_6M_BCK_ABT; 

%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Dummy Loader                              A52B3KFO.BQ0001TJ * 
 * Transform:     Table Loader (Version 2)                                    * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  Extract Target -                          A52B3KFO.BR0000YQ * 
 *                 abtagg.ULN_ACC_SNAP_6M_BCK_ABT                             * 
 * Target Table:  ULN_ACC_SNAP_6M_BCK_ABT -                 A52B3KFO.BH0001Q5 * 
 *                 abtagg.ULN_ACC_SNAP_6M_BCK_ABT                             * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

