/* The input to this macro is the 
1) PERIOD: (1(Current Month), 3, 6, 12, 24) for which the variables have
to be aggregated.
If PERIOD=1, then aggregation for current month will be calculated and stored in,
ACC_BANK_CURR_ABT.
If PERIOD=3, then aggregation for current month and last 3 months will be calculated 
and stored in,ACC_BANK_CURR_ABT, ACC_BANK_LST_3M_ABT.
If PERIOD=6, then aggregation for current month, last 3 & 6 months will be calculated and 
stored in,ACC_BANK_CURR_ABT, ACC_BANK_LST_3M_ABT, ACC_BANK_LST_6M_ABT. 
If PERIOD=12, then aggregation for current month, last 3, 6 & 12 months will be calculated 
and stored in,ACC_BANK_CURR_ABT, ACC_BANK_LST_3M_ABT, ACC_BANK_LST_6M_ABT,ACC_BANK_LST_12M_ABT. 
If PERIOD=24, then aggregation for last 13-24 months will be calculated and stored in,
ACC_BANK_LST_13_24M_ABT . 
2) INPUT_TABLE: The input table which is already filtered for the PERIOD 
(1(Current Month), 3, 6, 12, 13-24).
*/


%macro acc_bank_card_lst_abt(PERIOD=, INPUT_TABLE=);
/*Sort the input data BY ACCOUNT_RK in ascending order 
and BY TIME_SK in descending order */

PROC SORT DATA=ABTSCR.&INPUT_TABLE.;
	BY ACCOUNT_RK BANK_CARD_TYPE_CD DESCENDING VALID_START_DTTM;
RUN;

/*The data step begins here. The data step reads the sorted input data set
& outputs aggregation tables based on the PERIOD*/
%LET HIGH_DTTM=%SYSFUNC(datepart(&VALID_HIGH_DTTM.));
data 
/*If PERIOD = 1, then call the macro having the keep statement for current months */
%if &PERIOD. = 1 %then %do; 
	ABTAGG.ACC_BANK_CURR_ABT(KEEP= ACCOUNT_RK  ACC_ATM_LOST_CURR_MTH_CNT LOAD_ABT_USER_INPUT_DTTM
									LOAD_ABT_USER_INPUT_DATE) ; %end;
/*If PERIOD = 3, then call the macro having the keep statement for last 3 months */
%else %if &PERIOD. = 3 %then %do; 
	ABTAGG.ACC_BANK_CURR_ABT(KEEP= ACCOUNT_RK  ACC_ATM_LOST_CURR_MTH_CNT LOAD_ABT_USER_INPUT_DTTM
							LOAD_ABT_USER_INPUT_DATE) 
 	ABTAGG.ACC_BANK_LST_3M_ABT (KEEP= ACCOUNT_RK ACC_ATM_LOST_LST_3M_CNT LOAD_ABT_USER_INPUT_DTTM
							LOAD_ABT_USER_INPUT_DATE) ; %end;
/*If PERIOD = 6, then call the macro having the keep statement for last 3,6 months */
%else %if &PERIOD. = 6 %then 
	%do ; 
	 ABTAGG.ACC_BANK_CURR_ABT(KEEP= ACCOUNT_RK  ACC_ATM_LOST_CURR_MTH_CNT LOAD_ABT_USER_INPUT_DTTM
								LOAD_ABT_USER_INPUT_DATE) 
	 ABTAGG.ACC_BANK_LST_3M_ABT (KEEP= ACCOUNT_RK ACC_ATM_LOST_LST_3M_CNT LOAD_ABT_USER_INPUT_DTTM
								LOAD_ABT_USER_INPUT_DATE)
	 ABTAGG.ACC_BANK_LST_6M_ABT (KEEP= ACCOUNT_RK ACC_ATM_LOST_LST_6M_CNT LOAD_ABT_USER_INPUT_DTTM
								LOAD_ABT_USER_INPUT_DATE);
	%end;
/*If PERIOD = 12, then call the macro having the keep statement for last 3,6,12 months */
%else %if &PERIOD. = 12 %then 
	%do; 
	ABTAGG.ACC_BANK_CURR_ABT(KEEP= ACCOUNT_RK  ACC_ATM_LOST_CURR_MTH_CNT LOAD_ABT_USER_INPUT_DTTM
								LOAD_ABT_USER_INPUT_DATE) 
	ABTAGG.ACC_BANK_LST_3M_ABT (KEEP= ACCOUNT_RK ACC_ATM_LOST_LST_3M_CNT LOAD_ABT_USER_INPUT_DTTM
									LOAD_ABT_USER_INPUT_DATE)
	ABTAGG.ACC_BANK_LST_6M_ABT (KEEP= ACCOUNT_RK ACC_ATM_LOST_LST_6M_CNT LOAD_ABT_USER_INPUT_DTTM
									LOAD_ABT_USER_INPUT_DATE)
 	ABTAGG.ACC_BANK_LST_12M_ABT (KEEP= ACCOUNT_RK ACC_ATM_LOST_LST_12M_CNT LOAD_ABT_USER_INPUT_DTTM
									LOAD_ABT_USER_INPUT_DATE);
	%end;
/*If PERIOD =24, then call the macro having the keep statement for last 13-24 months */
%else %if &PERIOD. = 24 %then 
	%do; /*If PERIOD = 24,for 13 to 24 month.*/
		 	ABTAGG.ACC_BANK_13_24M_ABT (KEEP= ACCOUNT_RK ACC_ATM_LOST_13_24M_CNT LOAD_ABT_USER_INPUT_DTTM
										LOAD_ABT_USER_INPUT_DATE);
	%end;

/* Set the input table for reading */
SET ABTSCR.&INPUT_TABLE.;
BY ACCOUNT_RK BANK_CARD_TYPE_CD DESCENDING VALID_START_DTTM;

/* List of variables to be retained */
RETAIN  ACC_ATM_LOST_CURR_MTH_CNT 0 
		ACC_ATM_LOST_LST_3M_CNT 0 
		ACC_ATM_LOST_LST_6M_CNT 0 
		ACC_ATM_LOST_LST_12M_CNT 0
		ACC_ATM_LOST_13_24M_CNT 0;

%if &PERIOD. = 1 %then 
	%do; 
		IF LOSS_DT  > INTNX('MONTH', LOAD_ABT_USER_INPUT_DATE, 0, 'B') AND LOSS_DT  <= LOAD_ABT_USER_INPUT_DATE THEN DO;
				ACC_ATM_LOST_CURR_MTH_CNT = SUM(ACC_ATM_LOST_CURR_MTH_CNT, 1);	 END;
	%end;
/*If PERIOD = 3, then call the macro having the keep statement for last 3 months */
%else %if &PERIOD. = 3 %then 
	%do; 
		IF LOSS_DT  > INTNX('MONTH', LOAD_ABT_USER_INPUT_DATE, 0, 'B') AND LOSS_DT  <= LOAD_ABT_USER_INPUT_DATE THEN 
			DO;
				ACC_ATM_LOST_CURR_MTH_CNT = SUM(ACC_ATM_LOST_CURR_MTH_CNT, 1);	
				ACC_ATM_LOST_LST_3M_CNT = ACC_ATM_LOST_CURR_MTH_CNT; 
			END;
		ELSE IF LOSS_DT  > LOAD_ABT_3M_BCK_DATE  AND LOSS_DT  <= INTNX('MONTH', LOAD_ABT_USER_INPUT_DATE, -1, 'E')   THEN DO;
					ACC_ATM_LOST_LST_3M_CNT = SUM(ACC_ATM_LOST_LST_3M_CNT, 1); END;		
	%end;
/*If PERIOD = 6, then call the macro having the keep statement for last 3,6 months */
%else %if &PERIOD. = 6 %then 
	%do ; 
		IF LOSS_DT  > INTNX('MONTH', LOAD_ABT_USER_INPUT_DATE, 0, 'B') AND LOSS_DT  <= LOAD_ABT_USER_INPUT_DATE THEN 
			DO;
				ACC_ATM_LOST_CURR_MTH_CNT = SUM(ACC_ATM_LOST_CURR_MTH_CNT, 1);	
				ACC_ATM_LOST_LST_3M_CNT = ACC_ATM_LOST_CURR_MTH_CNT; 
				ACC_ATM_LOST_LST_6M_CNT = ACC_ATM_LOST_LST_3M_CNT;
			END;
		ELSE IF LOSS_DT  > LOAD_ABT_3M_BCK_DATE  AND LOSS_DT  <= INTNX('MONTH', LOAD_ABT_USER_INPUT_DATE, -1, 'E')   THEN 
				DO;
					ACC_ATM_LOST_LST_3M_CNT = SUM(ACC_ATM_LOST_LST_3M_CNT, 1); 
					ACC_ATM_LOST_LST_6M_CNT = ACC_ATM_LOST_LST_3M_CNT;
				END;		
		ELSE IF LOSS_DT  > LOAD_ABT_6M_BCK_DATE  AND LOSS_DT  <= LOAD_ABT_3M_BCK_DATE THEN DO;
				ACC_ATM_LOST_LST_6M_CNT = SUM(ACC_ATM_LOST_LST_6M_CNT, 1); END;
	%end;
/*If PERIOD = 12, then call the macro having the keep statement for last 3,6,12 months */
%else %if &PERIOD. = 12 %then 
	%do; 
		IF LOSS_DT  > INTNX('MONTH', LOAD_ABT_USER_INPUT_DATE, 0, 'B') AND LOSS_DT  <= LOAD_ABT_USER_INPUT_DATE THEN 
			DO;
				ACC_ATM_LOST_CURR_MTH_CNT = SUM(ACC_ATM_LOST_CURR_MTH_CNT, 1);	
				ACC_ATM_LOST_LST_3M_CNT = ACC_ATM_LOST_CURR_MTH_CNT; 
				ACC_ATM_LOST_LST_6M_CNT = ACC_ATM_LOST_LST_3M_CNT;
				ACC_ATM_LOST_LST_12M_CNT = ACC_ATM_LOST_CURR_MTH_CNT;
			END;
		ELSE IF LOSS_DT  > LOAD_ABT_3M_BCK_DATE  AND LOSS_DT  <= INTNX('MONTH', LOAD_ABT_USER_INPUT_DATE, -1, 'E')   THEN 
				DO;
					ACC_ATM_LOST_LST_3M_CNT = SUM(ACC_ATM_LOST_LST_3M_CNT, 1); 
					ACC_ATM_LOST_LST_6M_CNT = ACC_ATM_LOST_LST_3M_CNT;
					ACC_ATM_LOST_LST_12M_CNT = ACC_ATM_LOST_LST_3M_CNT;
				END;		
		ELSE IF LOSS_DT  > LOAD_ABT_6M_BCK_DATE  AND LOSS_DT  <= LOAD_ABT_3M_BCK_DATE THEN DO;
					ACC_ATM_LOST_LST_6M_CNT = SUM(ACC_ATM_LOST_LST_6M_CNT, 1);
					ACC_ATM_LOST_LST_12M_CNT = ACC_ATM_LOST_LST_6M_CNT; 
				END;
		ELSE IF LOSS_DT  > LOAD_ABT_12M_BCK_DATE AND LOSS_DT  <= LOAD_ABT_6M_BCK_DATE  THEN DO;
				ACC_ATM_LOST_LST_12M_CNT = SUM(ACC_ATM_LOST_LST_12M_CNT, 1); END;
	%end;
/*If PERIOD =24, then call the macro having the keep statement for last 13-24 months */
%else %if &PERIOD. = 24 %then 
	%do; /*If PERIOD = 24,for 13 to 24 month.*/
		 IF LOSS_DT  > INTNX('MONTH', LOAD_ABT_24M_BCK_DATE, 0, 'B') AND LOSS_DT  <= LOAD_ABT_12M_BCK_DATE THEN DO;
				ACC_ATM_LOST_13_24M_CNT = SUM(ACC_ATM_LOST_13_24M_CNT, 1); END;
	%end;
 

IF LAST.ACCOUNT_RK THEN
	DO;
		/*Output the data set */ 		
		OUTPUT; 
		/* Reset all the retain variables for the next account group */
		ACC_ATM_LOST_CURR_MTH_CNT=0;
		ACC_ATM_LOST_LST_3M_CNT=0;
		ACC_ATM_LOST_LST_6M_CNT=0;
		ACC_ATM_LOST_LST_12M_CNT=0;
		ACC_ATM_LOST_13_24M_CNT=0;
	END;
run;

%mend; 
 
 
  
