/*  The input to this macro is the 
1) PERIOD:  (3, 6, 12, 24 and 100(LTD ABT)) for which the variables have
			to be aggregated. 
			If PERIOD=3, then aggregation for last 3 months will be calculated and stored in,
			ACC_BASIC_LST_3M_ABT.
			If PERIOD=6, then aggregation for last 3 & 6 months will be calculated and stored in,
			ACC_BASIC_LST_3M_ABT,ACC_BASIC_LST_6M_ABT. 
			If PERIOD=12, then aggregation for last 3, 6 & 12 months will be calculated and 
			stored in,ACC_BASIC_LST_3M_ABT,ACC_BASIC_LST_6M_ABT,ACC_BASIC_LST_12M_ABT. 
			If PERIOD=24, then aggregation for last 13-24 months will be calculated and stored in,
			ACC_BASIC_13_24M_ABT. 
			If PERIOD=100,then aggregation for last 3, 6 , 12 & Life to date  will be calculated 
			and stored in,ACC_BASIC_LST_3M_ABT,ACC_BASIC_LST_6M_ABT,ACC_BASIC_LST_12M_ABT,
			ACC_BASIC_13_24M_ABT and ACC_BASIC_LTD_ABT.
2) INPUT_TABLE: The input table which is already filter for the 
				PERIOD (3, 6, 12, 13-24).
				For PERIOD 100 the table account_dim is used which will be filtered in the 
				macro itself.
*/
%macro acc_basic_lst_macro(PERIOD= ,INPUT_TABLE= );

/*%if &PERIOD.=100 %then */
/*	%do;*/
	 /* Filtering Account_dim in order to pick records which are relevant for ABT building.
		For e.g. If the table has the data from  JAN 00 to DEC 00 and we want to calculate 
		ABT as of APRIL 00 then first filter the data such that it has data since JAN 00 till 
		APRIL 00 and then build the ABT. */
/*		PROC SORT DATA=dim.account_dim OUT=ABTSCR.&INPUT_TABLE.;*/
/*			BY ACCOUNT_RK DESCENDING VALID_START_DTTM;*/
/*			WHERE VALID_START_DTTM <=&LOAD_ABT_USER_INPUT_DTTM.; */
/*		RUN;*/
/*	%end;*/
/*%else */
/*	%do;*/
		PROC SORT DATA=ABTSCR.&INPUT_TABLE.   ;
			BY ACCOUNT_RK DESCENDING VALID_START_DTTM;
		RUN;
/*	%end;*/

data 
		/*If PERIOD = 3, then call the macro having the keep statement for last 3 months */
		%if &PERIOD. = 3 %then %do; 
			%acc_basic_lst_3m_keep;
		%end;
		/*If PERIOD = 6, then call the macro having the keep statement for last 3,6 months */
		%else %if &PERIOD. = 6 %then %do ;  
			%acc_basic_lst_3m_keep 
			%acc_basic_lst_6m_keep;
		%end;
		/*If PERIOD = 12, then call the macro having the keep statement for last 3,6,12 months */
		%else %if &PERIOD. = 12 %then %do; 
			%acc_basic_lst_3m_keep
			%acc_basic_lst_6m_keep
			%acc_basic_lst_12m_keep;
		%end;
		/*If PERIOD =24, then call the macro having the keep statement for last 13-24 months */
		%else %if &PERIOD. = 24 %then %do;  
			%acc_basic_13_24m_keep;
		%end;
		/*If PERIOD = 100, then call the macro having the keep statement for last 3,6,12,13-24,
		  LTD months*/
		%else %if &PERIOD. = 100 %then %do; /* If PERIOD = 100 ,for life to date ABT*/
			%acc_basic_lst_3m_keep
			%acc_basic_lst_6m_keep
			%acc_basic_lst_12m_keep
			%acc_basic_13_24m_keep
			%acc_basic_ltd_abt_keep;			 
		%end;

SET  ABTSCR.&INPUT_TABLE.;
BY ACCOUNT_RK DESCENDING VALID_START_DTTM;

/*Set of retain statements. Retain variables will be initialized by the call of 
following macro */
RETAIN  %acc_basic_lst_retain

/*General retain variables are declared here*/
%if &PERIOD. = 24 %then %do;
	RETAIN VALID_END_TEMP  COUNT;
	VALID_END_TEMP = LOAD_ABT_12M_BCK_DTTM;
	COUNT = 12;
%end;
%else %do;
	RETAIN VALID_END_TEMP COUNT COUNT_TEMP;
	VALID_END_TEMP = LOAD_ABT_USER_INPUT_DTTM;
	COUNT = 0;
%end;

COUNT_TEMP=COUNT;

/*These are temporary constants for storing max & min value, which will be used
in the code as a reference for finding max, min for the variables
The value of max & min can be changed as per the need of the implementation team
*/
min_value=&min_value.;
max_value=&max_value.;
/*Common variables to retained, applicable for all datasets.*/ 
LENGTH   ACCOUNT_TYPE_CD ACCOUNT_STATUS_CD COLLATERAL_CD ACC_CLS_TYP_CD 
		 ACCOUNT_SUB_TYPE_CD CLOSE_REASON_CD $3
		 ALLOW_OVERDRAFT_FLG $1;

RETAIN PRIMARY_CUSTOMER_RK_RET ACC_CLS_DT_RET ACC_OPEN_DT_RET ACCOUNT_TYPE_CD_RET 
		ACCOUNT_STATUS_CD_RET COLLATERAL_CD_RET ACC_CLS_TYP_CD_RET ACCOUNT_SUB_TYPE_CD_RET
		ALLOW_OVERDRAFT_FLG_RET;  

/*Bijoy: Do we need to check for count here */
IF (COUNT EQ 3 OR (COUNT_TEMP<= 3 AND COUNT > 3))  THEN 
	DO;
			%acc_basic_abt_assign_3_to_6; 

	END;
IF (COUNT EQ 6 OR (COUNT_TEMP<= 6 AND COUNT > 6)) THEN 
	DO;
	 		%acc_basic_abt_assign_6_to_12;
	END;

/*While building 13-24 month ABT variables, TEMP_CREDT_AMT_13_24 and TEMP_OVER_DRFT_AMT_13_24 
  are captured on first.account_rk. If PERIOD=24 and first.account_rk is not true then 
  TEMP_CREDT_AMT_13_24 and TEMP_OVER_DRFT_AMT_13_24 will have missing value. In this case, 
  Value of TEMP_CREDT_AMT_13_24 and TEMP_OVER_DRFT_AMT_13_24 is set to TEMP_CREDT_AMT_12 
  and TEMP_OVER_DRFT_AMT_12 respectively.*/
IF (COUNT EQ 12 OR (COUNT_TEMP<= 12 AND COUNT > 12))  AND &PERIOD. NE 24 THEN 	
	DO;
			TEMP_CREDT_AMT_13_24 = TEMP_CREDT_AMT_12;
			TEMP_OVER_DRFT_AMT_13_24 = TEMP_OVER_DRFT_AMT_12; 
	END;

  

 /*Assign the value of following variables to the retained variables.These 
   variables will be written to the data set at last observation of ACCOUNT_RK.
 */
IF FIRST.ACCOUNT_RK THEN
	DO;
		PRIMARY_CUSTOMER_RK_RET=PRIMARY_CUSTOMER_RK; 
		ACC_CLS_DT_RET=CLOSE_DT; 
		ACC_OPEN_DT_RET=OPEN_DT; 
		ACCOUNT_TYPE_CD_RET=ACCOUNT_TYPE_CD; 
		ACCOUNT_STATUS_CD_RET=ACCOUNT_STATUS_CD; 
		COLLATERAL_CD_RET=COLLATERAL_CD; 
		ACC_CLS_TYP_CD_RET=CLOSE_REASON_CD; 
		ACCOUNT_SUB_TYPE_CD_RET=ACCOUNT_SUB_TYPE_CD;
		ALLOW_OVERDRAFT_FLG_RET=ALLOW_OVERDRAFT_FLG; 
	END;
 /*If COUNT < 3, viz. the iteration is for last 3 months */ 
   	 IF (COUNT < 3) THEN 
	 	DO;
			/*Counting how many times the account status was active in last 3 months.*/
			IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_ACT.) THEN DO;
					ACC_ACT_STS_LST_3M_CNT=SUM(ACC_ACT_STS_LST_3M_CNT,1); END;
			/*Counting  how many times the account status was inactive in last 3 months.*/
			ELSE IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_INA.) THEN DO;
					ACC_INA_STS_LST_3M_CNT=SUM(ACC_INA_STS_LST_3M_CNT,1); END; 

			/*Bijoy: This variable is deleted from the metedata, however the follwing 
			  derivation is kept for future use.*/
			IF CALLABLE_FACILITY_USED_FLG IN (&CHECK_FLAG_TRUE.) THEN DO;
					ACC_CALL_USE_LST_3M_CNT=SUM(ACC_CALL_USE_LST_3M_CNT,1);	END;
  
			IF FIRST.ACCOUNT_RK  THEN 
				DO;
			/*Assign the current_limit_amt & overdraft_limit_amt to a temporary 
			  retained variable.*/
				   TEMP_CREDT_AMT_3=CURRENT_LIMIT_AMT; 
				   TEMP_OVER_DRFT_AMT_3=OVERDRAFT_LIMIT_AMT; 
				END;
			ELSE 
				DO; 
			/*Variable to hold number of time the current limit amount decreased in last 
			  three month.*/
					IF (COALESCE(CURRENT_LIMIT_AMT,min_value) > COALESCE(TEMP_CREDT_AMT_3,min_value)) THEN  	
						DO;						
				   			ACC_LMT_DEC_LST_3M_CNT =SUM(ACC_LMT_DEC_LST_3M_CNT,1);
							TEMP_CREDT_AMT_3=CURRENT_LIMIT_AMT;                			
						END;
			/*Variable to hold number of time the current limit amount increased in last 
			  three month.*/
					 ELSE IF (COALESCE(CURRENT_LIMIT_AMT,max_value) < COALESCE(TEMP_CREDT_AMT_3,max_value))THEN 
						DO; 	
							ACC_LMT_INR_LST_3M_CNT=SUM(ACC_LMT_INR_LST_3M_CNT,1);
							TEMP_CREDT_AMT_3=CURRENT_LIMIT_AMT; 
						END;	
			/*Variable to hold number of time the overdraft limit amount increased in last 
			  three month.*/				 
			 	    IF  (COALESCE(OVERDRAFT_LIMIT_AMT,min_value) <  COALESCE(TEMP_OVER_DRFT_AMT_3,min_value))THEN  	
						DO;	 			 		
							ACC_ODLMT_INR_LST_3M_CNT=SUM(ACC_ODLMT_INR_LST_3M_CNT,1);
							TEMP_OVER_DRFT_AMT_3=OVERDRAFT_LIMIT_AMT;							
						END;
			/*If the temporary variable TEMP_OVER_DRFT_AMT_3, holds  amount less then or 
		      equal to the overdraft limit amount then current value of the overdraft limit 
			  amount gets assigned to the temporary variable.*/
					 ELSE DO; 
						 TEMP_OVER_DRFT_AMT_3=OVERDRAFT_LIMIT_AMT; END;
				END;   
		/*Accumulating the current limit amount for last 3 months*/
				ACC_LMT_LST_3M_AMT=SUM(ACC_LMT_LST_3M_AMT,CURRENT_LIMIT_AMT);
		/*Variable to hold the maximum value of current limit amount in last 3 months*/
			IF (CURRENT_LIMIT_AMT > COALESCE(ACC_MAX_LMT_LST_3M_AMT,min_value)) THEN DO;
				ACC_MAX_LMT_LST_3M_AMT = CURRENT_LIMIT_AMT; END;	
		/*Variable to hold the minimum value of current limit amount in last 3 months*/	
			IF (CURRENT_LIMIT_AMT < COALESCE(ACC_MIN_LMT_LST_3M_AMT,max_value)) THEN DO;								 	 
				ACC_MIN_LMT_LST_3M_AMT = CURRENT_LIMIT_AMT; END;
		/*Variable to hold the average value of current limit amount for last 3 months */
			IF CURRENT_LIMIT_AMT NE . THEN DO;				
					COUNT_AVG_3_MNTH=SUM(COUNT_AVG_3_MNTH,1) ;END;

			ACC_AVG_LMT_LST_3M_AMT=ACC_LMT_LST_3M_AMT / COUNT_AVG_3_MNTH ;



		/*Variable to hold the maximum value of colateral amount  in last 3 months*/
			IF (COLLATERAL_AMT > COALESCE(ACC_MAX_PCL_LST_3M_AMT,min_value)) THEN DO;
				ACC_MAX_PCL_LST_3M_AMT = COLLATERAL_AMT;	END;
		/*Variable to hold the minimum value of colateral amount in last 3 months*/	
			IF (COLLATERAL_AMT < COALESCE(ACC_MIN_PCL_LST_3M_AMT,max_value)) THEN	DO;							 	 
				ACC_MIN_PCL_LST_3M_AMT = COLLATERAL_AMT; END;
		/*Variable to hold the maximum value of mortgage open to buy amount in last 3 months*/	
			IF (MORTGAGE_OPEN_TO_BUY_AMT > COALESCE(ACC_MAX_OTB_LST_3M_AMT,min_value)) THEN 
				ACC_MAX_OTB_LST_3M_AMT = MORTGAGE_OPEN_TO_BUY_AMT;	
		/*Variable to hold the minimum value of mortgage open to buy amount in last 3 months*/
			IF (MORTGAGE_OPEN_TO_BUY_AMT < COALESCE(ACC_MIN_OTB_LST_3M_AMT,max_value)) THEN								 	 
				ACC_MIN_OTB_LST_3M_AMT = MORTGAGE_OPEN_TO_BUY_AMT;
	
 		END;
/*If COUNT < 6, viz. the iteration is for last 6 months */ 
ELSE IF ( COUNT <  6)  THEN 		
		DO;				  
	/*Counting  how many times the account status was active in last 6 months.*/
			IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_ACT.) THEN DO;
					ACC_ACT_STS_LST_6M_CNT=SUM(ACC_ACT_STS_LST_6M_CNT,1); END;
	/*Counting  how many times the account status was inactive in last 6 months.*/
			ELSE IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_INA.) THEN DO;
					ACC_INA_STS_LST_6M_CNT=SUM(ACC_INA_STS_LST_6M_CNT,1); END; 
	/*Bijoy: This variable is deleted from the metedata, however the follwing 
	  derivation is kept for future use.*/
			IF CALLABLE_FACILITY_USED_FLG IN (&CHECK_FLAG_TRUE.) THEN DO;
					ACC_CALL_USE_LST_6M_CNT=SUM(ACC_CALL_USE_LST_6M_CNT,1);	END;
	/*Variable to hold number of time the current limit amount decreased in last 
	  six month.*/ 
 	     	IF (COALESCE(CURRENT_LIMIT_AMT,min_value) > COALESCE(TEMP_CREDT_AMT_6,min_value)) THEN  	
				DO;	
					ACC_LMT_DEC_LST_6M_CNT=SUM(ACC_LMT_DEC_LST_6M_CNT,1);
					TEMP_CREDT_AMT_6=CURRENT_LIMIT_AMT;											
				END;
	/*Variable to hold number of time the current limit amount increased in last 
	  six month.*/ 
		    ELSE IF (COALESCE(CURRENT_LIMIT_AMT,max_value) < COALESCE(TEMP_CREDT_AMT_6,max_value))THEN 
					DO;			 
						ACC_LMT_INR_LST_6M_CNT=SUM(ACC_LMT_INR_LST_6M_CNT,1);
						TEMP_CREDT_AMT_6=CURRENT_LIMIT_AMT;
					END;				
	/*Variable to hold number of time the overdraft limit amount increased in last 
		six month.*/			
			IF (COALESCE(OVERDRAFT_LIMIT_AMT,max_value) < COALESCE(TEMP_OVER_DRFT_AMT_6,max_value))  THEN  	
					DO;
			   			ACC_ODLMT_INR_LST_6M_CNT=SUM(ACC_ODLMT_INR_LST_6M_CNT,1);
						TEMP_OVER_DRFT_AMT_6=OVERDRAFT_LIMIT_AMT;
					END; 
	/*If the temporary variable TEMP_OVER_DRFT_AMT_6 , holds  amount less then or 
      equal to the overdraft limit amount then current value of the overdraft limit 
	  amount get assigned to the temporary variable.*/
			 ELSE DO; TEMP_OVER_DRFT_AMT_6=OVERDRAFT_LIMIT_AMT;END;
					
		/*Accumulating the current limit amount for last 6 months*/
			ACC_LMT_LST_6M_AMT=SUM(ACC_LMT_LST_6M_AMT,CURRENT_LIMIT_AMT);
		/*Variable to hold the maximum value of current limit amount in last 6 months*/
	 		IF (CURRENT_LIMIT_AMT>=COALESCE(ACC_MAX_LMT_LST_6M_AMT,min_value)) THEN DO;
					ACC_MAX_LMT_LST_6M_AMT=CURRENT_LIMIT_AMT;	END;
		/*Variable to hold the minimum value of current limit amount in last 6 months*/	
			IF (CURRENT_LIMIT_AMT < COALESCE(ACC_MIN_LMT_LST_6M_AMT,max_value)) THEN	DO;							 	 
					ACC_MIN_LMT_LST_6M_AMT=CURRENT_LIMIT_AMT;END;
		/*Variable to hold the average value of current limit amount for last 6 months */
			IF CURRENT_LIMIT_AMT NE . THEN DO;
					COUNT_AVG_6_MNTH=SUM(COUNT_AVG_6_MNTH,1) ;END;
			ACC_AVG_LMT_LST_6M_AMT=ACC_LMT_LST_6M_AMT / COUNT_AVG_6_MNTH ; 

		/*Variable to hold the maximum value of colateral amount  in last 6 months*/
			IF (COLLATERAL_AMT>=COALESCE(ACC_MAX_PCL_LST_6M_AMT,min_value)) THEN DO;
					ACC_MAX_PCL_LST_6M_AMT=COLLATERAL_AMT;	END;		
		/*Variable to hold the minimum value of colateral amount  in last 6 months*/	
			IF (COLLATERAL_AMT < COALESCE(ACC_MIN_PCL_LST_6M_AMT,max_value)) THEN	DO;							 	 
					ACC_MIN_PCL_LST_6M_AMT=COLLATERAL_AMT; 	END;
		/*Variable to hold the maximum value of mortgage open to buy amount in last 6 months*/	
			IF (MORTGAGE_OPEN_TO_BUY_AMT>=COALESCE(ACC_MAX_OTB_LST_6M_AMT,min_value)) THEN DO;
					ACC_MAX_OTB_LST_6M_AMT=MORTGAGE_OPEN_TO_BUY_AMT; END;	
		/*Variable to hold the minimum value of mortgage open to buy amount in last 6 months*/	
			IF (MORTGAGE_OPEN_TO_BUY_AMT < COALESCE(ACC_MIN_OTB_LST_6M_AMT,max_value)) THEN DO;							 	 
					ACC_MIN_OTB_LST_6M_AMT=MORTGAGE_OPEN_TO_BUY_AMT; END; 
			 			
	    END; 
/*If COUNT < 12, viz. the iteration is for last 12 months */
	 ELSE IF  ( COUNT <  12 ) THEN 
		DO;
	/*Calculating how many times the account status was active in last 12 months.*/	
			IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_ACT.) THEN DO;
			   ACC_ACT_STS_LST_12M_CNT=SUM(ACC_ACT_STS_LST_12M_CNT,1); END; 
	/*Calculating how many times the account status was inactive in last 12 months.*/	
			ELSE IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_INA.) THEN DO;
			   ACC_INA_STS_LST_12M_CNT=SUM(ACC_INA_STS_LST_12M_CNT,1);	END; 
	/*Bijoy: This variable is deleted from the metedata, however the follwing 
	  derivation is kept for future use.*/
			IF CALLABLE_FACILITY_USED_FLG IN (&CHECK_FLAG_TRUE.) THEN DO;
			   ACC_CALL_USE_LST_12M_CNT=SUM(ACC_CALL_USE_LST_12M_CNT,1); END;
	/*Variable to hold number of time the current limit amount decreased in last 
	   twelve month.*/ 
			IF (COALESCE(CURRENT_LIMIT_AMT,min_value) > COALESCE(TEMP_CREDT_AMT_12,min_value)) THEN  	
			   DO;
 				   ACC_LMT_DEC_LST_12M_CNT=SUM(ACC_LMT_DEC_LST_12M_CNT,1);
				   TEMP_CREDT_AMT_12=CURRENT_LIMIT_AMT;
			   END;
	/*Variable to hold number of time the current limit amount increased in last 
	   twelve month.*/
			ELSE IF (COALESCE(CURRENT_LIMIT_AMT,max_value)  < COALESCE(TEMP_CREDT_AMT_12,max_value))THEN 
				DO;
			    	ACC_LMT_INR_LST_12M_CNT=SUM(ACC_LMT_INR_LST_12M_CNT,1);
					TEMP_CREDT_AMT_12=CURRENT_LIMIT_AMT;
				END;			
	/*Variable to hold number of time the overdraft limit amount increased in last 
		twelve month.*/
			IF  (COALESCE( OVERDRAFT_LIMIT_AMT,max_value) < COALESCE(TEMP_OVER_DRFT_AMT_12,min_value))  THEN  	
				DO;						
					ACC_ODLMT_INR_LST_12M_CNT=SUM(ACC_ODLMT_INR_LST_12M_CNT,1);
					TEMP_OVER_DRFT_AMT_12=OVERDRAFT_LIMIT_AMT;
				END; 
	/*If the temporary variable TEMP_OVER_DRFT_AMT_12, holds  amount less then or 
      equal to the overdraft limit amount then current value of the overdraft limit 
	  amount get assigned to the temporary variable.*/
 			ELSE DO;
			  	TEMP_OVER_DRFT_AMT_12=OVERDRAFT_LIMIT_AMT;END; 

		/*Accumulating the current limit amount for last 12 months*/
			ACC_LMT_LST_12M_AMT=SUM(ACC_LMT_LST_12M_AMT,CURRENT_LIMIT_AMT);
		/*Variable to hold the maximum value of current limit amount in last 12 months*/
			IF (CURRENT_LIMIT_AMT>=COALESCE(ACC_MAX_LMT_LST_12M_AMT,min_value)) THEN DO;
				ACC_MAX_LMT_LST_12M_AMT=CURRENT_LIMIT_AMT;	END;
		/*Variable to hold the minimum value of current limit amount in last 12 months*/	
			IF (CURRENT_LIMIT_AMT <COALESCE(ACC_MIN_LMT_LST_12M_AMT,max_value)) THEN DO;							 	 
				ACC_MIN_LMT_LST_12M_AMT=CURRENT_LIMIT_AMT;END;
		/*Variable to hold the average value of current limit amount for last 12 months */
			IF CURRENT_LIMIT_AMT NE . THEN DO;
				COUNT_AVG_12_MNTH=SUM(COUNT_AVG_12_MNTH,1) ;END;

			ACC_AVG_LMT_LST_12M_AMT=ACC_LMT_LST_12M_AMT / COUNT_AVG_12_MNTH ;

		/*Variable to hold the maximum value of colateral amount  in last 12 months*/
			IF (COLLATERAL_AMT>=COALESCE(ACC_MAX_PCL_LST_12M_AMT,min_value)) THEN DO;
				ACC_MAX_PCL_LST_12M_AMT=COLLATERAL_AMT;	END;				
		/*Variable to hold the minimum value of colateral amount  in last 12 months*/
			IF (COLLATERAL_AMT <COALESCE(ACC_MIN_PCL_LST_12M_AMT,max_value)) THEN DO;								 	 
				ACC_MIN_PCL_LST_12M_AMT=COLLATERAL_AMT; END;
		/*Variable to hold the maximum value of mortgage open to buy amount in last 12 months*/	
			IF (MORTGAGE_OPEN_TO_BUY_AMT>=COALESCE(ACC_MAX_OTB_LST_12M_AMT,min_value)) THEN DO;
				ACC_MAX_OTB_LST_12M_AMT=MORTGAGE_OPEN_TO_BUY_AMT;	END;
	   /*Variable to hold the minimum value of mortgage open to buy amount in last 12 months*/
			IF (MORTGAGE_OPEN_TO_BUY_AMT <COALESCE(ACC_MIN_OTB_LST_12M_AMT,max_value)) THEN	DO;							 	 
				ACC_MIN_OTB_LST_12M_AMT=MORTGAGE_OPEN_TO_BUY_AMT; END;	
			
		END;
/*If COUNT < 24, viz. the iteration is for last 13-24 months */
  	 ELSE IF (COUNT <24) THEN
	 	DO;
	/*Counting  how many times the account status was active in last 12 to 24 months.*/		
			IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_ACT.) THEN DO;
					ACC_ACT_STS_13_24M_CNT=SUM(ACC_ACT_STS_13_24M_CNT,1); END; 
	/*Counting  how many times the account status was inactive in last 12 to 24 months.*/	
			ELSE IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_INA.) THEN DO;
					ACC_INA_STS_13_24M_CNT=SUM(ACC_INA_STS_13_24M_CNT,1); END; 
	/*Bijoy: This variable is deleted from the metedata, however the follwing 
	  derivation is kept for future use.*/
			IF CALLABLE_FACILITY_USED_FLG IN (&CHECK_FLAG_TRUE.) THEN DO;
					ACC_CALL_USE_13_24M_CNT=SUM(ACC_CALL_USE_13_24M_CNT,1); END;
			
			IF FIRST.ACCOUNT_RK  THEN 
				DO;
		/*Assign the current_limit_amt & overdraft_limit_amt to a temporary 
		retained variable.*/
				   TEMP_CREDT_AMT_13_24=CURRENT_LIMIT_AMT;
				   TEMP_OVER_DRFT_AMT_13_24=OVERDRAFT_LIMIT_AMT;  
				END;
		/*Variable to hold number of time the current limit amount decreased in last 
	  		13 to 24 month.*/ 
			ELSE IF (COALESCE(CURRENT_LIMIT_AMT,min_value) >COALESCE(TEMP_CREDT_AMT_13_24,min_value)) THEN  	
				DO; 
					ACC_LMT_DEC_13_24M_CNT=SUM(ACC_LMT_DEC_13_24M_CNT,1);
					TEMP_CREDT_AMT_13_24=CURRENT_LIMIT_AMT;

 				END;
		/*Variable to hold number of time the current limit amount increased in last 
	  		13 to 24 month.*/ 
			ELSE IF (COALESCE(CURRENT_LIMIT_AMT,max_value) <COALESCE(TEMP_CREDT_AMT_13_24,max_value))THEN 
				DO; 
					ACC_LMT_INR_13_24M_CNT=SUM(ACC_LMT_INR_13_24M_CNT,1);
					TEMP_CREDT_AMT_13_24=CURRENT_LIMIT_AMT;

				END;
		/*Variable to hold number of time the overdraft limit amount increased in last 
			13 to 24 month.*/				
			IF (COALESCE(OVERDRAFT_LIMIT_AMT,max_value) <COALESCE(TEMP_OVER_DRFT_AMT_13_24M,max_value))  THEN  	
				DO;
					ACC_ODLMT_INR_13_24M_CNT=SUM(ACC_ODLMT_INR_13_24M_CNT,1);
					TEMP_OVER_DRFT_AMT_13_24M=OVERDRAFT_LIMIT_AMT;
				END; 
		/*If the temporary variable TEMP_OVER_DRFT_AMT_13_24M, holds  amount less then or 
      		equal to the overdraft limit amount then current value of the overdraft limit 
	  		amount get assigned to the temporary variable.*/
			ELSE DO; TEMP_OVER_DRFT_AMT_13_24M=OVERDRAFT_LIMIT_AMT; END;
		/*Accumulating the current limit amount for last 13 to 24 months*/
 			ACC_LMT_13_24M_AMT = SUM(ACC_LMT_13_24M_AMT, CURRENT_LIMIT_AMT);
		/*Variable to hold the maximum value of current limit amount in last 13 to 24 months*/
			IF (CURRENT_LIMIT_AMT >COALESCE(ACC_MAX_LMT_13_24M_AMT,min_value)) THEN DO;
				ACC_MAX_LMT_13_24M_AMT=CURRENT_LIMIT_AMT;	END;
		/*Variable to hold the minimum value of current limit amount in last 13 to 24 months*/	
			IF (CURRENT_LIMIT_AMT <COALESCE(ACC_MIN_LMT_13_24M_AMT,max_value)) THEN	DO;							 	 
				ACC_MIN_LMT_13_24M_AMT=CURRENT_LIMIT_AMT; END;
		/*Variable to hold the average value of current limit amount for last 13 to 24 months */
			IF CURRENT_LIMIT_AMT NE . THEN DO;
				COUNT_AVG_13_24M_MNTH=SUM(COUNT_AVG_13_24M_MNTH,1) ;END;

			ACC_AVG_LMT_13_24M_AMT=ACC_LMT_13_24M_AMT / COUNT_AVG_13_24M_MNTH;
		/*Variable to hold the maximum value of colateral amount  in last 13 to 24 months*/
			IF (COLLATERAL_AMT >COALESCE(ACC_MAX_PCL_13_24M_AMT,min_value)) THEN DO;
				ACC_MAX_PCL_13_24M_AMT=COLLATERAL_AMT;	END;				
		/*Variable to hold the minimum value of colateral amount  in last 13 to 24 months*/
			IF (COLLATERAL_AMT <COALESCE(ACC_MIN_PCL_13_24M_AMT,max_value)) THEN	DO;							 	 
				ACC_MIN_PCL_13_24M_AMT=COLLATERAL_AMT; END;
		/*Variable to hold the maximum value of mortgage open to buy amount in last 13 to 24 
				months*/
			IF (MORTGAGE_OPEN_TO_BUY_AMT>=COALESCE(ACC_MAX_OTB_13_24M_AMT,min_value)) THEN DO;
				ACC_MAX_OTB_13_24M_AMT=MORTGAGE_OPEN_TO_BUY_AMT; END;
		/*Variable to hold the minimum value of mortgage open to buy amount in last 13 to 24 
				months*/
			IF (MORTGAGE_OPEN_TO_BUY_AMT <COALESCE(ACC_MIN_OTB_13_24M_AMT,max_value)) THEN DO;								 	 
				ACC_MIN_OTB_13_24M_AMT=MORTGAGE_OPEN_TO_BUY_AMT; END;
			
		END;
 /****Account life to date ABT variable******************************************/

%if &PERIOD. = 100 %then 
%do;
	IF FIRST.ACCOUNT_RK  THEN 
		DO; 
		/*First observation of current limit amount*/
		   TEMP_CREDT_AMT=CURRENT_LIMIT_AMT;
		/*First observation of current limit date*/	
		   TEMP_CURR_DT=CURRENT_LIMIT_DT; 
		   TEMP_ELST_DT=CURRENT_LIMIT_DT; /*Why this temporary variabe */
		/*Variable to hold latest current limit change date*/
/*		   ACC_LMT_INR_LTST_DT=CURRENT_LIMIT_DT;*/
		/*First observation of valid start datetime*/	
		   TEMP_CURRENT_START_DTTM=VALID_START_DTTM;
		/*First observation  of the collateral amount*/
		   TEMP_COLATERAL_AMT=COLLATERAL_AMT;
		/*Ratio of first observation actual advance amount and collateral amount.
		   	This is used to calculate LTV ratio*/					   
		   TEMP_FIRST_LTV_AMT=ACTUAL_ADVANCE_AMT/COLLATERAL_AMT;	
 		/*Variable to hold latest Card reissue date */
		    ACC_LTST_CCD_REISU_DT=CARD_REISSUE_DT;						 
		/*First observation for the overdraft limit date*/
		   TEMP_OVERDRAFT_LIMIT_DT=OVERDRAFT_LIMIT_DT;
		/*First observation for the overdraft amount*/
		   TEMP_OVERDRAFT_LIMIT_AMT=OVERDRAFT_LIMIT_AMT;
		/*Variable to hold initial overdraft limit at time of opening of an account*/
		   ACC_INI_ODLMT_AMT=OVERDRAFT_LIMIT_AMT; 
		/*First observation for the  Actual Advance Amount*/
		   FIRST_ACTUAL_ADVANCE_AMT = ACTUAL_ADVANCE_AMT;
   		/*Variable to hold months since overdraft limit changed for the account*/
 		   ACC_SNC_ODLMT_CHNG_MTH_CNT=INTCK('MONTH',OVERDRAFT_LIMIT_DT,LOAD_ABT_USER_INPUT_DATE);

		END;
	/****************Change for the current limit amount**************************/
   ELSE 
	   	DO; 
		/*Variable to hold number of times the credit limit was upgraded life to date*/
		   IF (CURRENT_LIMIT_AMT <COALESCE(TEMP_CREDT_AMT,max_value))  THEN 
			  DO; 		
		  		ACC_CCD_UPG_LTD_CNT=SUM(ACC_CCD_UPG_LTD_CNT,1);
				ACC_LMT_INR_ELST_DT = TEMP_ELST_DT;	

				IF ACC_CCD_UPG_LTD_CNT EQ 1 THEN DO;
					ACC_LMT_INR_LTST_DT = TEMP_ELST_DT; END;					
			  END;
	/*First change in the current limit amount is captured in the variable which hold the 
	value of previous credit limit amount.*/

		   IF (CURRENT_LIMIT_AMT NE TEMP_CREDT_AMT) THEN 
			   DO;
				 PRV_LMT_CNT_TEMP=SUM(PRV_LMT_CNT_TEMP,1);
				 IF PRV_LMT_CNT_TEMP EQ 1 THEN DO;
					 ACC_PRV_LMT_AMT=TEMP_CREDT_AMT;END; 
		 	   END;

		   TEMP_ELST_DT = CURRENT_LIMIT_DT;
		   TEMP_CREDT_AMT = CURRENT_LIMIT_AMT;	
		

/****************Change for the collateral amount**************************/		
			IF (COLLATERAL_AMT ^= TEMP_COLATERAL_AMT)THEN 
				DO;								
					ACC_PCL_COUNTER = SUM(ACC_PCL_COUNTER, 1);
					IF (ACC_PCL_COUNTER EQ 1) THEN DO;
						ACC_PRV_PCL_VAL_AMT=COLLATERAL_AMT;	END;						
				END; 
			
			/*This block of code has to be put into the do while loop */
			IF 	COUNT EQ 1 THEN 
				DO;
					ACC_DSB_PRV_MTH_AMT=ACTUAL_ADVANCE_AMT;
					ACC_WRT_OFF_PRV_MTH_AMT=CHARGE_OFF_AMT;
					ACC_DWN_PAY_PRV_MTH_AMT=DOWNPAYMENT_AMT;
					ACC_RENEW_PRV_MTH_CNT=ACCOUNT_RENEWAL_CNT;
				END;
	
			 
			/*Variable to hold Percentage of LTV ratio to Previous LTV ratio 
				Current LTV ratio / Previous LTVratio.*/
			IF (COLLATERAL_AMT ^= TEMP_COLATERAL_AMT) OR (ACTUAL_ADVANCE_AMT ^= FIRST_ACTUAL_ADVANCE_AMT) THEN 
				DO;
					ACC_LTV_COUNTER = SUM(ACC_LTV_COUNTER, 1);
					IF (ACC_LTV_COUNTER EQ 1) THEN 
						DO;
							ACC_PRV_LTV_AMT=ACTUAL_ADVANCE_AMT/COLLATERAL_AMT;
							ACC_LTV_TO_PRV_LTV_PCT = SUM(FIRST_ACTUAL_ADVANCE_AMT, ACTUAL_ADVANCE_AMT)/SUM(TEMP_COLATERAL_AMT, COLLATERAL_AMT)*100;
						END;
				END;
		 
/*Variable to hold previous overdraft limit of an account*/
			IF  (OVERDRAFT_LIMIT_AMT ^= TEMP_OVERDRAFT_LIMIT_AMT)  THEN 
				DO;	
					/*The variable name 	
					COUNT_TEMP_OVER_DFT_DEC is actually checks the change in overdraft limit */
					COUNT_TEMP_OVER_DFT_DEC=SUM(COUNT_TEMP_OVER_DFT_DEC,1);

				    IF COUNT_TEMP_OVER_DFT_DEC EQ 1 THEN DO;
					    ACC_PRV_ODLMT_AMT=OVERDRAFT_LIMIT_AMT;END;
				END;	

			IF (OVERDRAFT_LIMIT_AMT ^= .) THEN	DO;
				ACC_INI_ODLMT_AMT = OVERDRAFT_LIMIT_AMT; END;

END;
/*Variable to hold days count since when callable facility was used*/   
IF CALLABLE_FACILITY_USED_FLG IN (&CHECK_FLAG_TRUE.) THEN DO; 						
	ACC_SNC_FST_CALL_USE_DAY_CNT=INTCK('DTDAY',VALID_START_DTTM,LOAD_ABT_USER_INPUT_DTTM);END;

/*Variable to hold months count for collection status code*/
IF COLLECTIONS_STATUS_CD IN (&COL_COLLECTION_STATUS.) THEN DO;
		ACC_SNC_COLL_MTH_CNT=INTCK('DTMONTH',VALID_START_DTTM,LOAD_ABT_USER_INPUT_DTTM);END;

/*Variable to hold the minimum date Credit Card was reissued.*/
IF CARD_REISSUE_DT NE . THEN DO;
	ACC_ELST_CCD_REISU_DT=CARD_REISSUE_DT ; END;
 
IF LAST.ACCOUNT_RK THEN
DO; 
/*Variable to hold the maximum limit amount that can be borrowed against an account.*/
	ACC_APPL_LMT_AMT=CURRENT_LIMIT_AMT;
/*Variable to hold the Current Limit Date.*/
	ACC_APPL_LMT_DT=CURRENT_LIMIT_DT;
/*Variable to hold Value of primary collateral on application date OR as of the 
	earliest available date from history.*/
	ACC_APPL_PCL_VAL_AMT=COLLATERAL_AMT;
/*Variable to hold loan to value ratio at the time of application  OR as of the earliest 
	available date from history	Loan To Value.*/
	ACC_APPL_LON_TO_PCL_VAL_AMT=ACTUAL_ADVANCE_AMT/COLLATERAL_AMT;
/*Variable to hold the maximum disburse amount.*/
	ACC_APPL_DSBR_CURR_MTH_AMT=ACTUAL_ADVANCE_AMT;
END;
/**/	
%end;
/*******************************************************************************************/
/*Decrementing the date time by one month.Increment the count for next month.*/
VALID_END_TEMP=INTNX('DTMONTH',VALID_END_TEMP,-1,'END');
COUNT+1;
/*Any record having the more then one month of data
For e.g 
Valid_start_dttm  	valid_end_dttm       account_status_code 
02jan2004:00:00:00	02mar2004:00:00:00    'ACT'
Here account status was active for two months so account status as active 
should be counted as 2 not 1.So finding such records and updating the aggregation is done here.*/

DO WHILE ((VALID_START_DTTM<= VALID_END_TEMP<=VALID_END_DTTM)  AND COUNT < (&PERIOD.)); 
/*Assigning the value of previous variable to the next level variable.*/
	IF (COUNT EQ 3)  THEN 
		DO;
				%acc_basic_abt_assign_3_to_6;
		END;
/*Assigning the value of previous variable to the next level variable.*/ 
	IF (COUNT EQ 6) THEN 	
		DO;
				%acc_basic_abt_assign_6_to_12;
		END;

	IF (COUNT EQ 12) THEN 	
		DO;
			TEMP_CREDT_AMT_13_24 = TEMP_CREDT_AMT_12;
			TEMP_OVER_DRFT_AMT_13_24 = TEMP_OVER_DRFT_AMT_12; 
		END;
 /*If COUNT < 3, viz. the iteration is for last 3 months */
	IF  (COUNT < 3) THEN 
		DO;
			IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_ACT.) THEN DO;
					ACC_ACT_STS_LST_3M_CNT=SUM(ACC_ACT_STS_LST_3M_CNT,1);END; 

			ELSE IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_INA.) THEN DO;
					ACC_INA_STS_LST_3M_CNT=SUM(ACC_INA_STS_LST_3M_CNT,1); END; 						

			IF CALLABLE_FACILITY_USED_FLG IN (&CHECK_FLAG_TRUE.) THEN DO;
					ACC_CALL_USE_LST_3M_CNT=SUM(ACC_CALL_USE_LST_3M_CNT,1);END; 

			IF CURRENT_LIMIT_AMT NE . THEN DO;	 
				COUNT_AVG_3_MNTH=SUM(COUNT_AVG_3_MNTH,1);END;

			ACC_LMT_LST_3M_AMT=SUM(ACC_LMT_LST_3M_AMT,CURRENT_LIMIT_AMT);							
			ACC_AVG_LMT_LST_3M_AMT=ACC_LMT_LST_3M_AMT / COUNT_AVG_3_MNTH;		
 		END;
 /*If COUNT < 6, viz. the iteration is for last 6 months */			
		ELSE IF ( COUNT < 6)  THEN 
			DO;  
				IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_ACT.) THEN DO; 	
					ACC_ACT_STS_LST_6M_CNT=SUM(ACC_ACT_STS_LST_6M_CNT,1);
				END;			
				ELSE IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_INA.) THEN DO; 				
					ACC_INA_STS_LST_3M_CNT=SUM(ACC_INA_STS_LST_6M_CNT,1);END; 					

				IF CALLABLE_FACILITY_USED_FLG IN (&CHECK_FLAG_TRUE.) THEN DO;
					ACC_CALL_USE_LST_6M_CNT=SUM(ACC_CALL_USE_LST_6M_CNT,1);END;

				IF CURRENT_LIMIT_AMT NE . THEN DO;	
					COUNT_AVG_6_MNTH=SUM(COUNT_AVG_6_MNTH,1);END;

				ACC_LMT_LST_6M_AMT=SUM(ACC_LMT_LST_6M_AMT,CURRENT_LIMIT_AMT); 
				ACC_AVG_LMT_LST_6M_AMT=ACC_LMT_LST_6M_AMT / COUNT_AVG_6_MNTH ;	

						
			END;
 /*If COUNT < 12, viz. the iteration is for last 12 months */
		ELSE IF  ( COUNT < 12 ) THEN 
			DO;						
				IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_ACT.) THEN DO;
					ACC_ACT_STS_LST_12M_CNT=SUM(ACC_ACT_STS_LST_12M_CNT,1);END;					 
				ELSE IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_INA.) THEN DO;
					ACC_INA_STS_LST_12M_CNT=SUM(ACC_INA_STS_LST_12M_CNT,1);END;		 
				IF CALLABLE_FACILITY_USED_FLG IN (&CHECK_FLAG_TRUE.) THEN DO;
					ACC_CALL_USE_LST_12M_CNT=SUM(ACC_CALL_USE_LST_12M_CNT,1);END;
			
				IF CURRENT_LIMIT_AMT NE . THEN DO;	
					COUNT_AVG_12_MNTH=SUM(COUNT_AVG_12_MNTH,1);END;
					ACC_LMT_LST_12M_AMT=SUM(ACC_LMT_LST_12M_AMT,CURRENT_LIMIT_AMT);			
					ACC_AVG_LMT_LST_12M_AMT=ACC_LMT_LST_12M_AMT / COUNT_AVG_12_MNTH;	
	 
	  		END;
 /*If COUNT < 24, viz. the iteration is for last 13-24 months */
 		ELSE IF (COUNT < 24) THEN 
	 		DO;
				IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_ACT.) THEN DO;
					ACC_ACT_STS_13_24M_CNT=SUM(ACC_ACT_STS_13_24M_CNT,1);END; 
				ELSE IF ACCOUNT_STATUS_CD IN (&ACCT_STATUS_INA.) THEN DO;
					ACC_INA_STS_13_24M_MTH_CNT=SUM(ACC_INA_STS_13_24M_MTH_CNT,1);END; 
				IF CALLABLE_FACILITY_USED_FLG IN (&CHECK_FLAG_TRUE.) THEN DO;
					ACC_CALL_USE_13_24M_CNT=SUM(ACC_CALL_USE_13_24M_CNT,1);	END;

				IF CURRENT_LIMIT_AMT NE . THEN DO;
					COUNT_AVG_13_24M_MNTH=SUM(COUNT_AVG_13_24M_MNTH,1);END;
					ACC_LMT_13_24M_AMT=SUM(ACC_LMT_13_24M_AMT,CURRENT_LIMIT_AMT);				
					ACC_AVG_LMT_13_24M_AMT=ACC_LMT_13_24M_AMT / COUNT_AVG_13_24M_MNTH;	
			END;

/*For life to date variables */
			IF 	COUNT EQ 1 THEN 
				DO;
					ACC_DSB_PRV_MTH_AMT=ACTUAL_ADVANCE_AMT;
					ACC_WRT_OFF_PRV_MTH_AMT=CHARGE_OFF_AMT;
					ACC_DWN_PAY_PRV_MTH_AMT=DOWNPAYMENT_AMT;
					ACC_RENEW_PRV_MTH_CNT=ACCOUNT_RENEWAL_CNT;
				END;


/*Decrementing the date time by one month.Increment the count for next month.*/
	VALID_END_TEMP=INTNX('DTMONTH',VALID_END_TEMP,-(1),'END');
	COUNT+1;
END;

IF (COUNT EQ 12 OR (COUNT_TEMP<= 12 AND COUNT > 12) ) AND &PERIOD. NE 24 THEN 	
	DO;
		TEMP_CREDT_AMT_13_24 = TEMP_CREDT_AMT_12;
		TEMP_OVER_DRFT_AMT_13_24 = TEMP_OVER_DRFT_AMT_12; 
	END;

IF LAST.ACCOUNT_RK THEN
	DO;	
		IF (COUNT <= 3)  THEN 
			DO; 
			/*Is needed in case of premature exit, data is present only
			  for last 3 months. */
				%acc_basic_abt_assign_3_to_6;
				%acc_basic_abt_assign_6_to_12;
			END;
		IF (COUNT  <= 6) THEN 	
			DO; 
			/*Is needed in case of premature exit, data is present only
			  for last 6 months. */
		  		%acc_basic_abt_assign_6_to_12;
			END;

		/*Assign the value of retained variables to the actual variable
		  being written to the data set.*/
		PRIMARY_CUSTOMER_RK=PRIMARY_CUSTOMER_RK_RET; 
		ACC_CLS_DT=ACC_CLS_DT_RET; 
		ACC_OPEN_DT=ACC_OPEN_DT_RET; 
		ACCOUNT_TYPE_CD=ACCOUNT_TYPE_CD_RET; 
		ACCOUNT_STATUS_CD=ACCOUNT_STATUS_CD_RET; 
		COLLATERAL_CD=COLLATERAL_CD_RET; 
		ACC_CLS_TYP_CD=CLOSE_REASON_CD; 
		ACCOUNT_SUB_TYPE_CD=ACCOUNT_SUB_TYPE_CD_RET;
		ALLOW_OVERDRAFT_FLG=ALLOW_OVERDRAFT_FLG_RET; 

		OUTPUT; 
		/*Set of reset statements. Retain variables will be reset by the call of 
		  following macro */
		%acc_basic_lst_initialize; 
		%if &PERIOD. = 24 %then %do;
		VALID_END_TEMP =LOAD_ABT_12M_BCK_DTTM ; COUNT=12; %end;
		%else %do;
		VALID_END_TEMP =LOAD_ABT_USER_INPUT_DTTM;  COUNT= 0; %end;
	END;
RUN;

%mend;

