/*  The input to this macro is the 
1) PERIOD: (1(Current month),3, 6, 12, 24 and 100(LTD ABT)) for which the variables have
			to be aggregated.
			If PERIOD=1, then aggregation for current month will be calculated and stored in,
			ACC_DEF_RCV_CURR_ABT.
			If PERIOD=3, then aggregation for last 3 months will be calculated and stored in,
			ACC_DEF_RCV_LST_3M_ABT.
			If PERIOD=6, then aggregation for last 3 & 6 months will be calculated and stored in,
			ACC_DEF_RCV_LST_3M_ABT,ACC_DEF_RCV_LST_6M_ABT. 
			If PERIOD=12, then aggregation for last 3, 6 & 12 months will be calculated and stored in,
			ACC_DEF_RCV_LST_3M_ABT,ACC_DEF_RCV_LST_6M_ABT,ACC_DEF_RCV_LST_12M_ABT. 
			If PERIOD=24, then aggregation for last 13-24 months will be calculated and stored in,
			ACC_DEF_RCV_LST_13_24M_ABT. 
			If PERIOD=100, then aggregation for Life to date  will be calculated and stored in,
			ACC_DEF_RCV_LTD_ABT. 
2) INPUT_TABLE: The input table which is already filter for the 
				PERIOD (Current month,3, 6, 12, 13-24,Life to date).
*/

%macro acc_def_recv_abt(PERIOD=, INPUT_TABLE=);

/*Sort the input data BY ACCOUNT_RK in ascending order 
  and BY TIME_SK in descending order.
*/
PROC SORT DATA=abtscr.&INPUT_TABLE.;
	BY ACCOUNT_RK DESCENDING TIME_SK;
RUN;

/*The data step begins here. The data step reads the sorted input data set
& outputs aggregation tables based on the PERIOD.
*/
data 
%if &PERIOD. =1 %then 
		%do; /*If PERIOD =1*/
			%acc_def_recv_curr_abt_keep;
		%end;

%else %if &PERIOD. = 3 %then 
		%do; /*If PERIOD = 3*/
			%acc_def_recv_curr_abt_keep
			%acc_def_recv_lst_3m_abt_keep;
		%end;
%else %if &PERIOD. = 6 %then 
		%do ; /*If PERIOD = 6*/ 
			%acc_def_recv_curr_abt_keep
			%acc_def_recv_lst_3m_abt_keep
			%acc_def_recv_lst_6m_abt_keep;
		%end;
%else %if &PERIOD. = 12 %then 
		%do; /*If PERIOD = 12*/
			%acc_def_recv_curr_abt_keep
			%acc_def_recv_lst_3m_abt_keep
			%acc_def_recv_lst_6m_abt_keep
			%acc_def_recv_lst_12m_abt_keep;
		%end;
%else %if &PERIOD. = 24 %then 
		%do; /*If PERIOD = 24*/
			%acc_def_recv_lst_13_24m_abt_keep;
	    %end;
%else %if &PERIOD. = 100 %then 
		%do; /*If PERIOD = 100,This indicates the life to date ABT.*/
			%acc_def_recv_curr_abt_keep
			%acc_def_recv_lst_3m_abt_keep
			%acc_def_recv_lst_6m_abt_keep
			%acc_def_recv_lst_12m_abt_keep
			%acc_def_recv_lst_13_24m_abt_keep
			%acc_def_recv_ltd_abt_keep;
	    %end;
/* Set the input table for reading */
SET abtscr.&INPUT_TABLE.;
BY ACCOUNT_RK DESCENDING TIME_SK;

/*List of variables to be retained */
			%acc_def_recv_abt_retain;
/*For the 13-24 months ABT variables the curr_time should be time_sk as of
			12 month back as compared to curr_time_sk(BACK_12M_TIME_SK).
			For the current,3,6 and 12 months the curr_time is the curr_time_sk.
 */
%if &PERIOD. = 24 %then %do;
	RETAIN CURR_TIME . COUNT 12;
	CURR_TIME = BACK_12M_TIME_SK;
/*	COUNT = 12;*/
%end;
%else %do;
	RETAIN CURR_TIME . COUNT 0 COUNT_TEMP .;
	CURR_TIME = CURR_TIME_SK;
/*	COUNT = 0;*/
%end;

COUNT_TEMP=COUNT;

/* Check to see if data is missing for certain period in the input table. If so,
   then adjust the count accordingly */
DO WHILE (TIME_SK < CURR_TIME);
	CURR_TIME = CURR_TIME - 1;
/*	COUNT = COUNT + 1;*/
END;

/* Check to see if there is more than one entry for certain period in the input table. 
   If so,  then adjust the count accordingly */
DO WHILE (CURR_TIME < TIME_SK ) ;
	CURR_TIME = CURR_TIME + 1;
/*	COUNT = COUNT - 1;*/
END;

IF FIRST.ACCOUNT_RK THEN
	DO;
		PRIMARY_CUSTOMER_RK_RET = PRIMARY_CUSTOMER_RK; 
		ACCOUNT_TYPE_CD_RET = ACCOUNT_TYPE_CD;
		ACCOUNT_SUB_TYPE_CD_RET = ACCOUNT_SUB_TYPE_CD;
		COLLATERAL_CD_RET = COLLATERAL_CD;
		ACCOUNT_STATUS_CD_RET = ACCOUNT_STATUS_CD;
	END;
/*Check to see if the count has reached some level (3,6,12), if so then assign the
   value of perivous variable to the next level variable */

IF FIRST.TIME_SK THEN DO;
	IF (COUNT EQ 1 OR (COUNT_TEMP  <= 1 AND COUNT > 1))  THEN DO;	
		%acc_def_recv_abt_curr_to_3; END;
	IF (COUNT EQ 3 OR (COUNT_TEMP  <= 3 AND COUNT > 3)) THEN DO;
			%acc_def_recv_abt_assign_3_to_6;END;
	IF (COUNT EQ 6 OR (COUNT_TEMP  <= 6 AND COUNT > 6)) THEN DO;
			%acc_def_recv_abt_assign_6_to_12;END;
/*Variable to hold months since last recovery made*/
	ACC_SNC_LST_RCV_MTH_CNT=INTCK('MONTH',INPUT(PUT(TIME_SK,12.),CALENDER_LAST_MTH_DT.),LOAD_ABT_USER_INPUT_DATE);
END;

/*Aggregation done here for calculating the total recovery at cost amount and
	VALUE_REALIZED_AMT for the current month, 3, 6, 12 and 12 to 24 month.
	Summing for  different recovery from type code the VALUE_REALIZED_AMT viz. 
	PCU_RECOVERY_FROM_TYPE (recovery is done from primary customer),
	GUR_RECOVERY_FROM_TYPE (recovery is done from guarantor.), 
	INC_RECOVERY_FROM_TYPE (recovery is done from insurance cover), 
	SRD_RECOVERY_FROM_TYPE (recovery is done from security deposit cover),
	PCL_RECOVERY_FROM_TYPE (recovery is done from sale of collateral).
*/

IF (COUNT < 1) THEN 
	DO;
		 ACC_RCV_CST_CURR_MTH_AMT=SUM(ACC_RCV_CST_CURR_MTH_AMT,RECOVERY_COST_AMT);
		 ACC_RCV_CURR_MTH_AMT=SUM(ACC_RCV_CURR_MTH_AMT,VALUE_REALIZED_AMT);
		 IF RECOVERY_FROM_TYPE_CD IN (&PCU_RECOVERY_FROM_TYPE.) THEN DO;
				ACC_RCV_PRI_CUS_CURR_MTH_AMT=SUM(ACC_RCV_PRI_CUS_CURR_MTH_AMT,VALUE_REALIZED_AMT);END;
		 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&GUR_RECOVERY_FROM_TYPE.) THEN DO;
				ACC_RCV_GUR_CURR_MTH_AMT=SUM(ACC_RCV_GUR_CURR_MTH_AMT,VALUE_REALIZED_AMT);END;
		 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&INC_RECOVERY_FROM_TYPE.) THEN DO;
				ACC_RCV_INS_CURR_MTH_AMT=SUM(ACC_RCV_INS_CURR_MTH_AMT,VALUE_REALIZED_AMT);END;
		 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&SRD_RECOVERY_FROM_TYPE.) THEN DO;
				ACC_RCV_SRTY_DEP_CURR_MTH_AMT=SUM(ACC_RCV_SRTY_DEP_CURR_MTH_AMT,VALUE_REALIZED_AMT);END;
		 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&PCL_RECOVERY_FROM_TYPE.) THEN DO;
				ACC_RCV_PCL_SLS_CURR_MTH_AMT =SUM(ACC_RCV_PCL_SLS_CURR_MTH_AMT,VALUE_REALIZED_AMT) ;END;
	END;
	/**/
 IF (COUNT < 3) THEN 
	DO;

		 ACC_RCV_CST_LST_3M_AMT=SUM(ACC_RCV_CST_LST_3M_AMT,RECOVERY_COST_AMT);
		 ACC_RCV_LST_3M_AMT=SUM(ACC_RCV_LST_3M_AMT,VALUE_REALIZED_AMT);
		 IF RECOVERY_FROM_TYPE_CD IN (&PCU_RECOVERY_FROM_TYPE.) THEN DO;
				ACC_RCV_PRI_CUS_LST_3M_AMT=SUM(ACC_RCV_PRI_CUS_LST_3M_AMT,VALUE_REALIZED_AMT);END;
		 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&GUR_RECOVERY_FROM_TYPE.) THEN DO;
				ACC_RCV_GUR_LST_3M_AMT =SUM(ACC_RCV_GUR_LST_3M_AMT,VALUE_REALIZED_AMT);END;
		 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&INC_RECOVERY_FROM_TYPE.) THEN DO;
				ACC_RCV_INS_LST_3M_AMT=SUM(ACC_RCV_INS_LST_3M_AMT,VALUE_REALIZED_AMT);END;
		 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&SRD_RECOVERY_FROM_TYPE.) THEN DO;
				ACC_RCV_SRTY_DEP_LST_3M_AMT=SUM(ACC_RCV_SRTY_DEP_LST_3M_AMT,VALUE_REALIZED_AMT);END;
		 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&PCL_RECOVERY_FROM_TYPE.) THEN DO;
				ACC_RCV_PCL_SLS_LST_3M_AMT=SUM(ACC_RCV_PCL_SLS_LST_3M_AMT,VALUE_REALIZED_AMT) ;END;
 

	END;	

	ELSE IF (COUNT <  6)  THEN 
		DO;
			 ACC_RCV_CST_LST_6M_AMT=SUM(ACC_RCV_CST_LST_6M_AMT,RECOVERY_COST_AMT);
			 ACC_RCV_LST_6M_AMT=SUM(ACC_RCV_LST_6M_AMT,VALUE_REALIZED_AMT);
			 IF RECOVERY_FROM_TYPE_CD IN (&PCU_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_PRI_CUS_LST_6M_AMT=SUM(ACC_RCV_PRI_CUS_LST_6M_AMT,VALUE_REALIZED_AMT);END;
				 ELSE IF RECOVERY_FROM_TYPE_CD IN (&GUR_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_GUR_LST_6M_AMT=SUM(ACC_RCV_GUR_LST_6M_AMT,VALUE_REALIZED_AMT);END;
			 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&INC_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_INS_LST_6M_AMT=SUM(ACC_RCV_INS_LST_6M_AMT,VALUE_REALIZED_AMT);END;
			 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&SRD_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_SRTY_DEP_LST_6M_AMT=SUM(ACC_RCV_SRTY_DEP_LST_6M_AMT,VALUE_REALIZED_AMT);END;
			 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&PCL_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_PCL_SLS_LST_6M_AMT=SUM(ACC_RCV_PCL_SLS_LST_6M_AMT,VALUE_REALIZED_AMT);END;
	
		END;

	
	ELSE IF (COUNT <  12)  THEN 
		DO;
			  ACC_RCV_CST_LST_12M_AMT=SUM(ACC_RCV_CST_LST_12M_AMT,RECOVERY_COST_AMT);
			  ACC_RCV_LST_12M_AMT=SUM(ACC_RCV_LST_12M_AMT,VALUE_REALIZED_AMT);
			  IF RECOVERY_FROM_TYPE_CD IN (&PCU_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_PRI_CUS_LST_12M_AMT=SUM(ACC_RCV_PRI_CUS_LST_12M_AMT,VALUE_REALIZED_AMT);END;
			 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&GUR_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_GUR_LST_12M_AMT=SUM(ACC_RCV_GUR_LST_12M_AMT,VALUE_REALIZED_AMT);END;
			 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&INC_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_INS_LST_12M_AMT=SUM(ACC_RCV_INS_LST_12M_AMT,VALUE_REALIZED_AMT);END;
			 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&SRD_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_SRTY_DEP_LST_12M_AMT=SUM(ACC_RCV_SRTY_DEP_LST_12M_AMT,VALUE_REALIZED_AMT);END;
			 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&PCL_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_PCL_SLS_LST_12M_AMT=SUM(ACC_RCV_PCL_SLS_LST_12M_AMT,VALUE_REALIZED_AMT);END;
		END;	
	ELSE IF (COUNT <24) THEN
		DO;
			ACC_RCV_CST_13_24M_AMT=SUM(ACC_RCV_CST_13_24M_AMT,RECOVERY_COST_AMT);
			ACC_RCV_13_24M_AMT=SUM(ACC_RCV_13_24M_AMT,VALUE_REALIZED_AMT);
		 	IF RECOVERY_FROM_TYPE_CD IN (&PCU_RECOVERY_FROM_TYPE.) THEN DO;
				ACC_RCV_PRI_CUS_13_24M_AMT=SUM(ACC_RCV_PRI_CUS_13_24M_AMT,VALUE_REALIZED_AMT);END;
			 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&GUR_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_GUR_13_24M_AMT=SUM(ACC_RCV_GUR_13_24M_AMT,VALUE_REALIZED_AMT);END;
				ELSE IF RECOVERY_FROM_TYPE_CD IN (&INC_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_INS_13_24M_AMT=SUM(ACC_RCV_INS_13_24M_AMT,VALUE_REALIZED_AMT);END;
			 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&SRD_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_SRTY_DEP_13_24M_AMT=SUM(ACC_RCV_SRTY_DEP_13_24M_AMT,VALUE_REALIZED_AMT);END;
			 	ELSE IF RECOVERY_FROM_TYPE_CD IN (&PCL_RECOVERY_FROM_TYPE.) THEN DO;
					ACC_RCV_PCL_SLS_13_24M_AMT=SUM(ACC_RCV_PCL_SLS_13_24M_AMT,VALUE_REALIZED_AMT);END;
	END;

/*Increment the count and at the same time decrement the CURR_TIME to cater to the next
  lowest time period. */
IF LAST.TIME_SK THEN 
	DO;
		COUNT = COUNT + 1;
		CURR_TIME = CURR_TIME - 1;
	END;

/* If the end of the group is reached then output the data sets */
IF LAST.ACCOUNT_RK THEN
	DO;	
		/*Assign the value of retained variables to the actual variable
		   being written to the data set.*/
		CUSTOMER_RK = PRIMARY_CUSTOMER_RK_RET;
		ACCOUNT_TYPE_CD = ACCOUNT_TYPE_CD_RET;
		ACCOUNT_SUB_TYPE_CD = ACCOUNT_SUB_TYPE_CD_RET;
		COLLATERAL_CD = COLLATERAL_CD_RET;
		ACCOUNT_STATUS_CD = ACCOUNT_STATUS_CD_RET;

		IF (COUNT <=1)  THEN	
		/*Is needed in case of premature exit, data is present only
		  for current months. */
			 DO;
				%acc_def_recv_abt_curr_to_3;
				%acc_def_recv_abt_assign_3_to_6;
				%acc_def_recv_abt_assign_6_to_12;	
			 END;
		 IF (COUNT <= 3) THEN	
		/*Is needed in case of premature exit, data is present only
		  for 3 months.*/
			 DO;
				%acc_def_recv_abt_assign_3_to_6;
				%acc_def_recv_abt_assign_6_to_12;		 
			 END;
			 ELSE  IF (COUNT <= 6)  THEN
			/* Is needed in case of premature exit, data is present only
			   for 6 months.*/
				 DO;
						%acc_def_recv_abt_assign_6_to_12;
					
		 		 END;	
			
		/*Output the data set */
		OUTPUT; 
		
		/*Reset all the retain variables for the next account group */
	  		%acc_def_recv_abt_reset_var;

		%if &PERIOD. = 24 %then %do;
	 
		CURR_TIME=BACK_12M_TIME_SK; COUNT = 12;  %end;
		%else %do;
		CURR_TIME=CURR_TIME_SK; COUNT = 0; %end;
	END;

RUN;
%mend;
/*%let CURR_TIME_SK=8;*/
/*%let BACK_12M_TIME_SK=7;*/
/*%LET PCU_RECOVERY_FROM_TYPE ='PCR';*/
/*%LET GUR_RECOVERY_FROM_TYPE ='GUR';*/
/*%LET INC_RECOVERY_FROM_TYPE ='INC';*/
/*%LET SRD_RECOVERY_FROM_TYPE ='SRD';*/
/*%LET PCL_RECOVERY_FROM_TYPE ='SLS'; */
/*%let TABLE_NM=Default_recovery;*/
/*%let PERIOD=6;*/
/*%acc_def_recv_abt(PERIOD=&PERIOD., INPUT_TABLE=&TABLE_NM.);*/
