/* The input to this macro is the 
1) PERIOD: (3, 6, 12, 24) for which the variables have
to be aggregated.
	If PERIOD=1, then aggregation for current month  will be calculated and stored in,
	ACC_INQ_DIS_CURR_ABT and ACC_INQ_OTH_CURR_ABT.
	If PERIOD=3, then aggregation for last 3 months will be calculated and stored in,
	ACC_INQ_DIS_CURR_ABT,ACC_INQ_LST_3M_ABT,ACC_INQ_OTH_CURR_ABT and ACC_INQ_OTH_LST_3M_ABT.
	If PERIOD=6, then aggregation for last 3 & 6 months will be calculated and stored in,
	ACC_INQ_DIS_CURR_ABT,ACC_INQ_LST_3M_ABT,ACC_INQ_LST_6M_ABT,ACC_INQ_OTH_CURR_ABT 
	,ACC_INQ_OTH_LST_3M_ABT and ACC_INQ_OTH_LST_6M_ABT.
	If PERIOD=12, then aggregation for last 3, 6 & 12 months will be calculated and stored in,
	ACC_INQ_DIS_CURR_ABT,ACC_INQ_LST_3M_ABT,ACC_INQ_LST_6M_ABT,ACC_INQ_LST_12M_ABT,
	ACC_INQ_OTH_CURR_ABT,ACC_INQ_OTH_LST_3M_ABT , ACC_INQ_OTH_LST_6M_ABT 
	and ACC_INQ_OTH_LST_12M_ABT.
	If PERIOD=24, then aggregation for last 13-24 months will be calculated and stored in,
	ACC_INQ_DIS_CURR_ABT,ACC_INQ_LST_3M_ABT,ACC_INQ_LST_6M_ABT,ACC_INQ_LST_12M_ABT,
	ACC_INQ_LST_13_24M_ABT,ACC_INQ_OTH_CURR_ABT,ACC_INQ_OTH_LST_3M_ABT , ACC_INQ_OTH_LST_6M_ABT 
	,ACC_INQ_OTH_LST_12M_ABT and ACC_INQ_OTH_LST_13_24M_ABT. 
2) INPUT_TABLE: The input table which is already filter for the PERIOD
	(current(1),3, 6, 12,Last 13 to 24 month(24)).
*/

%macro acc_inq_lst_abt(PERIOD=, INPUT_TABLE=);

/*Sort the input data BY ACCOUNT_RK in ascending order 
and BY TIME_SK in descending order */

PROC SORT DATA=ABTSCR.&INPUT_TABLE.;
	BY ACCOUNT_RK DESCENDING TIME_SK;
RUN;

/*The data step begins here. The data step reads the sorted input data set
& outputs aggregation tables based on the PERIOD*/

data 
%if &PERIOD. = 1 %then %do; /*If PERIOD = 1 current month*/
      %acc_inq_curr_abt_keep; %end;
%else %if &PERIOD. = 3 %then 
	%do; /*If PERIOD = 3*/
	  %acc_inq_curr_abt_keep
      %acc_inq_lst_3m_abt_keep; 
	%end;
%else %if &PERIOD. = 6 %then 
	%do ; /*If PERIOD = 6*/ 
	  %acc_inq_curr_abt_keep
 	  %acc_inq_lst_3m_abt_keep 
	  %acc_inq_lst_6m_abt_keep;
 	%end;
%else %if &PERIOD. = 12 %then 
	%do; /*If PERIOD = 12*/
      %acc_inq_curr_abt_keep
 	  %acc_inq_lst_3m_abt_keep 
	  %acc_inq_lst_6m_abt_keep
	  %acc_inq_lst_12m_abt_keep;
	%end;
%else %if &PERIOD. = 24 %then 
	%do; /*If PERIOD = 24 for 13-24 month*/
		 %acc_inq_lst_13_24m_abt_keep;
	%end;

/* Set the input table for reading */
SET ABTSCR.&INPUT_TABLE.;
BY ACCOUNT_RK DESCENDING TIME_SK;
/*These are temporary constants for storing max & min value, which will be used
in the code as a reference for finding max, min for the variables
The value of max & min can be changed as per the need of the implementation team
*/
min_value=&min_value.;
max_value=&max_value.;

/*List of variables to be retained */
%acc_inq_retain 

%if &PERIOD. = 24 %then %do;
	RETAIN CURR_TIME . COUNT 12;
	CURR_TIME = BACK_12M_TIME_SK;
/*	COUNT  = 12;*/
%end;
%else %do;
	RETAIN CURR_TIME . COUNT 0;
	CURR_TIME = CURR_TIME_SK;
/*	COUNT = 0;*/
%end;

COUNT_TMP=COUNT;

/* Check to see if data is missing for certain period in the input table. If so,
   then adjust the count accordingly */
DO WHILE (TIME_SK < CURR_TIME);
	CURR_TIME = CURR_TIME - 1;
/*	COUNT = COUNT + 1;*/
END;

/* Check to see if there is more than one entry for certain period in the input table. 
   If so,  then adjust the count accordingly */
DO WHILE (CURR_TIME < TIME_SK ) ;
	CURR_TIME = CURR_TIME + 1;
/*	COUNT = COUNT - 1;*/
END;

/*Assign the value of following variables to the retained variables. 
This variables will be written to the data set during LAST.ACCOUNT_RK */
IF FIRST.ACCOUNT_RK THEN
	DO;
	PRIMARY_CUSTOMER_RK_RET = PRIMARY_CUSTOMER_RK;
	ALLOW_OVERDRAFT_FLG_RET = ALLOW_OVERDRAFT_FLG;
	ACCOUNT_TYPE_CD_RET = ACCOUNT_TYPE_CD;
	ACCOUNT_SUB_TYPE_CD_RET = ACCOUNT_SUB_TYPE_CD;
	COLLATERAL_CD_RET = COLLATERAL_CD;
	ACCOUNT_STATUS_CD_RET = ACCOUNT_STATUS_CD;
	END;
 
IF FIRST.TIME_SK THEN 
	DO;
		IF (COUNT EQ 1 OR (COUNT_TMP  <= 1 AND COUNT > 1)) THEN DO;
			%acc_inq_assign_curr_to_3;	END;
		IF (COUNT EQ 3 OR (COUNT_TMP  <= 3 AND COUNT > 3)) THEN DO;
			%acc_inq_assign_3_to_6;	END;
		IF (COUNT EQ 6 OR (COUNT_TMP  <= 6 AND COUNT > 6)) THEN DO;
			%acc_inq_assign_6_to_12; END;
	END;


/*The expressions like summations, max, min, count, average are all done here */	 

IF (COUNT < 1) THEN 
	DO;
 		IF TRANSACTION_TYPE_CD IN (&DST_TRANS_TYPE.) THEN DO;		 
			ACC_DUP_STMT_REQ_CURR_MTH_CNT = SUM(ACC_DUP_STMT_REQ_CURR_MTH_CNT, inquiry_cnt); END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&CLI_TRANS_TYPE.) THEN DO;		 
			ACC_LMT_INR_REQ_CURR_MTH_CNT = SUM(ACC_LMT_INR_REQ_CURR_MTH_CNT, inquiry_cnt);	END;
	    ELSE IF  TRANSACTION_TYPE_CD IN (&CLD_TRANS_TYPE.) THEN DO;		 
			ACC_LMT_DEC_REQ_CURR_MTH_CNT = SUM(ACC_LMT_DEC_REQ_CURR_MTH_CNT, inquiry_cnt);	END;
	    ELSE IF  TRANSACTION_TYPE_CD IN (&QRY_TRANS_TYPE.) THEN DO;		 
			ACC_QRY_CURR_MTH_CNT = SUM(ACC_QRY_CURR_MTH_CNT, inquiry_cnt);	END;
	    ELSE IF  TRANSACTION_TYPE_CD IN (&COM_TRANS_TYPE.) THEN DO;		 
			ACC_COM_CURR_MTH_CNT = SUM(ACC_COM_CURR_MTH_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&RTC_TRANS_TYPE.) THEN DO;		 
			ACC_RT_CHNG_REQ_CURR_MTH_CNT = SUM(ACC_RT_CHNG_REQ_CURR_MTH_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&TNC_TRANS_TYPE.) THEN DO;		 
			ACC_TNR_CHNG_REQ_CURR_MTH_CNT = SUM(ACC_TNR_CHNG_REQ_CURR_MTH_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&PRD_TRANS_TYPE.) THEN DO;		 
			ACC_PAY_RED_INQ_CURR_MTH_CNT = SUM(ACC_PAY_RED_INQ_CURR_MTH_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&OLI_TRANS_TYPE.) THEN DO;		 
			ACC_ODLMT_INR_REQ_CURR_MTH_CNT = SUM(ACC_ODLMT_INR_REQ_CURR_MTH_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&OLD_TRANS_TYPE.) THEN DO;		 
			ACC_ODLMT_DEC_REQ_CURR_MTH_CNT = SUM(ACC_ODLMT_DEC_REQ_CURR_MTH_CNT, inquiry_cnt);	END;
		ELSE IF TRANSACTION_TYPE_CD IN (&DIS_TRANS_TYPE.) THEN 
			DO;			 
			/*Calculating the maximum of dispute amount for current month*/
				IF DISPUTE_AMT > COALESCE(ACC_MAX_DIS_CURR_MTH_AMT, min_value) THEN 
					ACC_MAX_DIS_CURR_MTH_AMT = DISPUTE_AMT;
				IF INQUIRY_CNT > COALESCE(ACC_MAX_DIS_CURR_MTH_CNT, min_value) THEN 
					ACC_MAX_DIS_CURR_MTH_CNT = INQUIRY_CNT;	

			/*Calculating the minimum of dispute amount for current month*/
				IF DISPUTE_AMT < COALESCE(ACC_MIN_DIS_CURR_MTH_AMT, max_value) THEN								 	 
					ACC_MIN_DIS_CURR_MTH_AMT = DISPUTE_AMT;
				IF ACC_MIN_DIS_CURR_MTH_CNT = 0 THEN
					ACC_MIN_DIS_CURR_MTH_CNT = INQUIRY_CNT;
				ELSE
					ACC_MIN_DIS_CURR_MTH_CNT = MIN(ACC_MIN_DIS_CURR_MTH_CNT, INQUIRY_CNT);
/*				IF INQUIRY_CNT < COALESCE(ACC_MIN_DIS_CURR_MTH_CNT, max_value) THEN */
/*					ACC_MIN_DIS_CURR_MTH_CNT = INQUIRY_CNT;	*/

			/*Aggregating the dissipute amount for current month	*/
				ACC_DIS_CURR_MTH_AMT =SUM(ACC_DIS_CURR_MTH_AMT ,DISPUTE_AMT);
			/*Calculating the total number of account dispute in current month*/
				ACC_DIS_CURR_MTH_CNT=SUM(ACC_DIS_CURR_MTH_CNT, inquiry_cnt);				
			END;
	END;	 
ELSE IF (COUNT < 3) THEN 
	DO;
 		IF TRANSACTION_TYPE_CD IN (&DST_TRANS_TYPE.) THEN DO;		 
			ACC_DUP_STMT_REQ_LST_3M_CNT = SUM(ACC_DUP_STMT_REQ_LST_3M_CNT, inquiry_cnt); END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&CLI_TRANS_TYPE.) THEN DO;		 
			ACC_LMT_INR_REQ_LST_3M_CNT = SUM(ACC_LMT_INR_REQ_LST_3M_CNT, inquiry_cnt);	END;
	    ELSE IF  TRANSACTION_TYPE_CD IN (&CLD_TRANS_TYPE.) THEN DO;		 
			ACC_LMT_DEC_REQ_LST_3M_CNT = SUM(ACC_LMT_DEC_REQ_LST_3M_CNT, inquiry_cnt);	END;
	    ELSE IF  TRANSACTION_TYPE_CD IN (&QRY_TRANS_TYPE.) THEN DO;		 
			ACC_QRY_LST_3M_CNT = SUM(ACC_QRY_LST_3M_CNT, inquiry_cnt);	END;
	    ELSE IF  TRANSACTION_TYPE_CD IN (&COM_TRANS_TYPE.) THEN DO;		 
			ACC_COM_LST_3M_CNT = SUM(ACC_COM_LST_3M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&RTC_TRANS_TYPE.) THEN DO;		 
			ACC_RT_CHNG_REQ_LST_3M_CNT = SUM(ACC_RT_CHNG_REQ_LST_3M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&TNC_TRANS_TYPE.) THEN DO;		 
			ACC_TNR_CHNG_REQ_LST_3M_CNT = SUM(ACC_TNR_CHNG_REQ_LST_3M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&PRD_TRANS_TYPE.) THEN DO;		 
			ACC_PAY_RED_INQ_LST_3M_CNT = SUM(ACC_PAY_RED_INQ_LST_3M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&OLI_TRANS_TYPE.) THEN DO;		 
			ACC_ODLMT_INR_REQ_LST_3M_CNT = SUM(ACC_ODLMT_INR_REQ_LST_3M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&OLD_TRANS_TYPE.) THEN DO;		 
			ACC_ODLMT_DEC_REQ_LST_3M_CNT = SUM(ACC_ODLMT_DEC_REQ_LST_3M_CNT, inquiry_cnt);	END;
		ELSE IF TRANSACTION_TYPE_CD IN (&DIS_TRANS_TYPE.) THEN 
			DO;			 
			/*Calculating the maximum of dispute amount for last 3 month*/
				IF DISPUTE_AMT > COALESCE(ACC_MAX_DIS_LST_3M_AMT, min_value) THEN 
					ACC_MAX_DIS_LST_3M_AMT = DISPUTE_AMT;	
				IF INQUIRY_CNT > COALESCE(ACC_MAX_DIS_LST_3M_CNT, min_value) THEN 
					ACC_MAX_DIS_LST_3M_CNT = INQUIRY_CNT;	

			/*Calculating the minimum of dispute amount for last 3 month*/
				IF DISPUTE_AMT < COALESCE(ACC_MIN_DIS_LST_3M_AMT, max_value) THEN								 	 
					ACC_MIN_DIS_LST_3M_AMT = DISPUTE_AMT;
				IF ACC_MIN_DIS_LST_3M_CNT = 0 THEN
					ACC_MIN_DIS_LST_3M_CNT = INQUIRY_CNT;
				ELSE
					ACC_MIN_DIS_LST_3M_CNT=MIN(ACC_MIN_DIS_LST_3M_CNT,INQUIRY_CNT);
/*				IF INQUIRY_CNT < COALESCE(ACC_MIN_DIS_LST_3M_CNT, max_value) THEN */
/*					ACC_MIN_DIS_LST_3M_CNT = INQUIRY_CNT;	*/

			/*Aggregating the dispute amount for last 3 month	*/
				ACC_DIS_LST_3M_AMT=SUM(ACC_DIS_LST_3M_AMT,DISPUTE_AMT);
			/*Calculating the total number of account dispute in last 3 month*/
				ACC_DIS_LST_3M_CNT=SUM(ACC_DIS_LST_3M_CNT, inquiry_cnt);				
			END;
	END;	 
ELSE IF (COUNT < 6)  THEN 
	DO;
		IF TRANSACTION_TYPE_CD IN (&DST_TRANS_TYPE.) THEN DO;		 
			ACC_DUP_STMT_REQ_LST_6M_CNT+inquiry_cnt; END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&CLI_TRANS_TYPE.) THEN  DO;		 
			ACC_LMT_INR_REQ_LST_6M_CNT+inquiry_cnt;	 END;
	    ELSE IF  TRANSACTION_TYPE_CD IN (&CLD_TRANS_TYPE.) THEN  DO;		 
			ACC_LMT_DEC_REQ_LST_6M_CNT+inquiry_cnt;	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&QRY_TRANS_TYPE.) THEN  DO;		 
			ACC_QRY_LST_6M_CNT+inquiry_cnt;	END;
	    ELSE IF  TRANSACTION_TYPE_CD IN (&COM_TRANS_TYPE.) THEN DO;		 
			ACC_COM_LST_6M_CNT+inquiry_cnt;	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&RTC_TRANS_TYPE.) THEN DO;		 
			ACC_RT_CHNG_REQ_LST_6M_CNT = SUM(ACC_RT_CHNG_REQ_LST_6M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&TNC_TRANS_TYPE.) THEN DO;		 
			ACC_TNR_CHNG_REQ_LST_6M_CNT = SUM(ACC_TNR_CHNG_REQ_LST_6M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&PRD_TRANS_TYPE.) THEN DO;		 
			ACC_PAY_RED_INQ_LST_6M_CNT = SUM(ACC_PAY_RED_INQ_LST_6M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&OLI_TRANS_TYPE.) THEN DO;		 
			ACC_ODLMT_INR_REQ_LST_6M_CNT = SUM(ACC_ODLMT_INR_REQ_LST_6M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&OLD_TRANS_TYPE.) THEN DO;		 
			ACC_ODLMT_DEC_REQ_LST_6M_CNT = SUM(ACC_ODLMT_DEC_REQ_LST_6M_CNT, inquiry_cnt);	END;
		ELSE IF TRANSACTION_TYPE_CD IN (&DIS_TRANS_TYPE.) THEN 
				DO;	
			/*Calculating the maximum of dispute amount for last 6 month*/
				IF DISPUTE_AMT > COALESCE(ACC_MAX_DIS_LST_6M_AMT, min_value) THEN 
					ACC_MAX_DIS_LST_6M_AMT=DISPUTE_AMT;	
				IF INQUIRY_CNT > COALESCE(ACC_MAX_DIS_LST_6M_CNT, min_value) THEN 
					ACC_MAX_DIS_LST_6M_CNT = INQUIRY_CNT;	

			/*Calculating the minimum of dispute amount for last 6 month*/
				IF DISPUTE_AMT < COALESCE(ACC_MIN_DIS_LST_6M_AMT, max_value) THEN  								 	 
					ACC_MIN_DIS_LST_6M_AMT=DISPUTE_AMT;	 
				IF ACC_MIN_DIS_LST_6M_CNT = 0 THEN
					ACC_MIN_DIS_LST_6M_CNT = INQUIRY_CNT;
				ELSE
					ACC_MIN_DIS_LST_6M_CNT=MIN(ACC_MIN_DIS_LST_6M_CNT,INQUIRY_CNT); 
/*				IF INQUIRY_CNT < COALESCE(ACC_MIN_DIS_LST_6M_CNT, max_value) THEN */
/*					ACC_MIN_DIS_LST_6M_CNT = INQUIRY_CNT;	*/

			/*Aggregating the dispute amount for last 6 month	*/
					ACC_DIS_LST_6M_AMT=SUM(DISPUTE_AMT,ACC_DIS_LST_6M_AMT);
			/*Calculating the total number of account dispute in last 6 month*/							 
					ACC_DIS_LST_6M_CNT=SUM(ACC_DIS_LST_6M_CNT, inquiry_cnt);
 				END;	 
	END;	 
ELSE IF (COUNT <  12)  THEN 
	DO;
	 	IF TRANSACTION_TYPE_CD=&DST_TRANS_TYPE. THEN DO;		 
			ACC_DUP_STMT_REQ_LST_12M_CNT+inquiry_cnt; END;
		ELSE IF  TRANSACTION_TYPE_CD=&CLI_TRANS_TYPE. THEN DO;		 
			ACC_LMT_INR_REQ_LST_12M_CNT+inquiry_cnt; END;
	    ELSE IF  TRANSACTION_TYPE_CD=&CLD_TRANS_TYPE. THEN DO;		 
			ACC_LMT_DEC_REQ_LST_12M_CNT+inquiry_cnt; END;
		ELSE IF  TRANSACTION_TYPE_CD=&QRY_TRANS_TYPE. THEN DO;		 
			ACC_QRY_LST_12M_CNT+inquiry_cnt;END;
	    ELSE IF  TRANSACTION_TYPE_CD=&COM_TRANS_TYPE. THEN DO;		 
			ACC_COM_LST_12M_CNT+inquiry_cnt;END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&RTC_TRANS_TYPE.) THEN DO;		 
			ACC_RT_CHNG_REQ_LST_12M_CNT = SUM(ACC_RT_CHNG_REQ_LST_12M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&TNC_TRANS_TYPE.) THEN DO;		 
			ACC_TNR_CHNG_REQ_LST_12M_CNT = SUM(ACC_TNR_CHNG_REQ_LST_12M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&PRD_TRANS_TYPE.) THEN DO;		 
			ACC_PAY_RED_INQ_LST_12M_CNT = SUM(ACC_PAY_RED_INQ_LST_12M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&OLI_TRANS_TYPE.) THEN DO;		 
			ACC_ODLMT_INR_REQ_LST_12M_CNT = SUM(ACC_ODLMT_INR_REQ_LST_12M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&OLD_TRANS_TYPE.) THEN DO;		 
			ACC_ODLMT_DEC_REQ_LST_12M_CNT = SUM(ACC_ODLMT_DEC_REQ_LST_12M_CNT, inquiry_cnt);	END;
		ELSE IF TRANSACTION_TYPE_CD IN (&DIS_TRANS_TYPE.) THEN 
				DO;	
			 /*Calculating the maximum of dispute amount for last 12 month*/
				IF DISPUTE_AMT > COALESCE(ACC_MAX_DIS_LST_12M_AMT, min_value) THEN 
					ACC_MAX_DIS_LST_12M_AMT=DISPUTE_AMT;
				IF INQUIRY_CNT > COALESCE(ACC_MAX_DIS_LST_12M_CNT, min_value) THEN 
					ACC_MAX_DIS_LST_12M_CNT = INQUIRY_CNT;	

			  /*Calculating the minimum of dispute amount for last 12 month*/
				IF DISPUTE_AMT < COALESCE(ACC_MIN_DIS_LST_12M_AMT, max_value) THEN								 	 
					ACC_MIN_DIS_LST_12M_AMT=DISPUTE_AMT;
				IF ACC_MIN_DIS_LST_12M_CNT = 0 THEN
					ACC_MIN_DIS_LST_12M_CNT = INQUIRY_CNT;
				ELSE
					ACC_MIN_DIS_LST_12M_CNT=MIN(ACC_MIN_DIS_LST_12M_CNT,INQUIRY_CNT);	
/*				IF INQUIRY_CNT < COALESCE(ACC_MIN_DIS_LST_12M_CNT, max_value) THEN */
/*					ACC_MIN_DIS_LST_12M_CNT = INQUIRY_CNT;	*/

			/*Aggregating the dispute amount for last 12 month	*/					
					ACC_DIS_LST_12M_AMT=SUM(ACC_DIS_LST_12M_AMT,DISPUTE_AMT);
			/*Calculating the total number of account dispute in last 12 month*/
					ACC_DIS_LST_12M_CNT=SUM(ACC_DIS_LST_12M_CNT, inquiry_cnt);
				END; 
	END;		 
ELSE IF (COUNT <24) THEN
	DO;	
		IF TRANSACTION_TYPE_CD=&DST_TRANS_TYPE. THEN  DO;		 
			ACC_DUP_STMT_REQ_13_24M_CNT+inquiry_cnt; END;
		ELSE IF  TRANSACTION_TYPE_CD=&CLI_TRANS_TYPE. THEN DO;		 
			ACC_LMT_INR_REQ_13_24M_CNT+inquiry_cnt;	 END;
	    ELSE IF  TRANSACTION_TYPE_CD=&CLD_TRANS_TYPE. THEN DO;		 
			ACC_LMT_DEC_REQ_13_24M_CNT+inquiry_cnt;	END;
		ELSE IF  TRANSACTION_TYPE_CD=&QRY_TRANS_TYPE. THEN DO;		 
			ACC_QRY_13_24M_CNT+inquiry_cnt;	END;
	    ELSE IF  TRANSACTION_TYPE_CD=&COM_TRANS_TYPE. THEN DO;		 
			ACC_COM_13_24M_CNT+inquiry_cnt;	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&RTC_TRANS_TYPE.) THEN DO;		 
			ACC_RT_CHNG_REQ_13_24M_CNT = SUM(ACC_RT_CHNG_REQ_13_24M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&TNC_TRANS_TYPE.) THEN DO;		 
			ACC_TNR_CHNG_REQ_13_24M_CNT = SUM(ACC_TNR_CHNG_REQ_13_24M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&PRD_TRANS_TYPE.) THEN DO;		 
			ACC_PAY_RED_INQ_13_24M_CNT = SUM(ACC_PAY_RED_INQ_13_24M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&OLI_TRANS_TYPE.) THEN DO;		 
			ACC_ODLMT_INR_REQ_13_24M_CNT = SUM(ACC_ODLMT_INR_REQ_13_24M_CNT, inquiry_cnt);	END;
		ELSE IF  TRANSACTION_TYPE_CD IN (&OLD_TRANS_TYPE.) THEN DO;		 
			ACC_ODLMT_DEC_REQ_13_24M_CNT = SUM(ACC_ODLMT_DEC_REQ_13_24M_CNT, inquiry_cnt);	END;
   		ELSE IF TRANSACTION_TYPE_CD IN (&DIS_TRANS_TYPE.) THEN 
		DO;	
		/*Calculating the maximum of dispute amount for last 13-24 month*/
			IF DISPUTE_AMT > COALESCE(ACC_MAX_DIS_13_24M_AMT, min_value) THEN 
				ACC_MAX_DIS_13_24M_AMT=DISPUTE_AMT;	
			IF INQUIRY_CNT > COALESCE(ACC_MAX_DIS_13_24M_CNT, min_value) THEN 
				ACC_MAX_DIS_13_24M_CNT = INQUIRY_CNT;	

		/*Calculating the minimum of dispute amount for last 13-24 month*/
			IF DISPUTE_AMT < COALESCE(ACC_MIN_DIS_13_24M_AMT, max_value) THEN								 	 
				ACC_MIN_DIS_13_24M_AMT=DISPUTE_AMT;	
			IF ACC_MIN_DIS_13_24M_CNT = 0 THEN
				ACC_MIN_DIS_13_24M_CNT = INQUIRY_CNT;
			ELSE
				ACC_MIN_DIS_13_24M_CNT=MIN(ACC_MIN_DIS_13_24M_CNT,INQUIRY_CNT);	
/*			IF INQUIRY_CNT < COALESCE(ACC_MIN_DIS_13_24M_CNT, max_value) THEN */
/*				ACC_MIN_DIS_13_24M_CNT = INQUIRY_CNT;	*/

		/*Aggregating the dispute amount for last 13-24 month	*/						
			ACC_DIS_13_24M_AMT=SUM(ACC_DIS_13_24M_AMT,DISPUTE_AMT);
		/*Calculating the total number of account dispute in last 12 month*/
			ACC_DIS_13_24M_CNT=SUM(ACC_DIS_13_24M_CNT, inquiry_cnt);
		END;	
	END;

/*Increment the count and at the same time decrement the CURR_TIME to cater to the next
lowest time period */
IF LAST.TIME_SK THEN 
	DO;
		COUNT = COUNT + 1;
		CURR_TIME = CURR_TIME - 1;
	END;

/*If the end of the group is reached then output the data sets */
IF LAST.ACCOUNT_RK THEN
DO;	 
	/*Assign the value of retained variables to the actual variable
	being written to the data set */
	CUSTOMER_RK = PRIMARY_CUSTOMER_RK_RET;
	ALLOW_OVERDRAFT_FLG = ALLOW_OVERDRAFT_FLG_RET;
	ACCOUNT_TYPE_CD = ACCOUNT_TYPE_CD_RET;
	ACCOUNT_SUB_TYPE_CD =ACCOUNT_SUB_TYPE_CD_RET;
	COLLATERAL_CD = COLLATERAL_CD_RET;
	ACCOUNT_STATUS_CD = ACCOUNT_STATUS_CD_RET;

	IF (COUNT <= 1) THEN	
		DO;
	/*Is needed in case of premature exit, data is present only
	for current month*/
		%acc_inq_assign_curr_to_3;
		%acc_inq_assign_3_to_6;
		%acc_inq_assign_6_to_12;
		END;
	ELSE IF (COUNT <= 3) THEN	
	/*Is needed in case of premature exit, data is present only
	for 3 months */
		DO;
			%acc_inq_assign_3_to_6;
			%acc_inq_assign_6_to_12;	/*  assign for 12 month */
		END;
	ELSE IF (COUNT <= 6) THEN
	/*Is needed in case of premature exit, data is present only
	for 6 months */
		DO;
			%acc_inq_assign_6_to_12;			 	
		END;			

	/*Output the data set */
	OUTPUT; 
	
	/*Reset all the retain variables for the next account group */
	%acc_inq_reset_var;
 
	%if &PERIOD. = 24 %then %do;	 
		CURR_TIME = BACK_12M_TIME_SK; COUNT = 12;  %end;
	%else %do;
		CURR_TIME = CURR_TIME_SK; COUNT = 0; %end;
END;

RUN;
%mend;

