/* The input to this macro is the 
1) PERIOD: (3, 6, 12, 24) for which the variables have
to be aggregated.
If PERIOD=3, then aggregation for last 3 months will be calculated and stored in,
ACC_OTBND_LST_3M_ABT.
If PERIOD=6, then aggregation for last 3 & 6 months will be calculated and stored in,
ACC_OTBND_LST_3M_ABT,ACC_OTBND_LST_6M_ABT. 
If PERIOD=12, then aggregation for last 3, 6 & 12 months will be calculated and stored in,
ACC_OTBND_LST_3M_ABT, ACC_OTBND_LST_6M_ABTT, ACC_OTBND_LST_12M_ABT. 
If PERIOD=24, then aggregation for last 13-24 months will be calculated and stored in,
ACC_OTBND_LST_13_24M_ABT. 
2) INPUT_TABLE: The input table which is already filter for the PERIOD (3, 6, 12, 13-24).
*/
%macro acc_otbnd_lst_abt(PERIOD=, INPUT_TABLE=);

/*Sort the input data BY ACCOUNT_RK in ascending order 
and BY TIME_SK in descending order */
PROC SORT DATA=abtscr.&INPUT_TABLE.;
	BY ACCOUNT_RK DESCENDING TIME_SK;
RUN;
/*The data step begins here. The data step reads the sorted input data set
& outputs aggregation tables based on the PERIOD*/

data 
%if &PERIOD. = 1 %then %do; /*If PERIOD = 1*/
      		%acc_ot_bnd_curr_abt_keep; %end;
%if &PERIOD. = 3 %then 
		%do; /*If PERIOD = 3*/
			%acc_ot_bnd_curr_abt_keep
			%acc_ot_bnd_lst_3m_abt_keep;
		%end;
%else %if &PERIOD. = 6 %then 
		%do ; /*If PERIOD = 6*/ 
			%acc_ot_bnd_curr_abt_keep
			%acc_ot_bnd_lst_3m_abt_keep
			%acc_ot_bnd_lst_6m_abt_keep;
		%end;
%else %if &PERIOD. = 12 %then 
		%do; /*If PERIOD = 12*/
			%acc_ot_bnd_curr_abt_keep
			%acc_ot_bnd_lst_3m_abt_keep
			%acc_ot_bnd_lst_12m_abt_keep
			%acc_ot_bnd_lst_6m_abt_keep;
		%end;
%else %if &PERIOD. = 24 %then 
		%do; /*If PERIOD = 24*/
			%acc_ot_bnd_lst_13_24M_abt_keep;
	    %end;
/* Set the input table for reading */
SET abtscr.&INPUT_TABLE.;
BY ACCOUNT_RK DESCENDING TIME_SK;
/*Depending on whether the PERIOD is (3, 6, 12) or 24, the retained variable will be
initialized */
/*List of variables to be retained */
%acc_ot_bnd_lst_abt_retain;

%if &PERIOD. = 24 %then %do;
	RETAIN CURR_TIME . COUNT 12;  
	CURR_TIME = BACK_12M_TIME_SK;
%end;
%else %do;
	RETAIN CURR_TIME . COUNT 0 COUNT_TEMP .; 
	CURR_TIME = CURR_TIME_SK;
%end;

/*Common variables to retained, applicable for all datasets */
LENGTH ACCOUNT_TYPE_CD_RET ACCOUNT_SUB_TYPE_CD_RET COLLATERAL_CD_RET ACCOUNT_STATUS_CD_RET $3
ALLOW_OVERDRAFT_FLG_RET $1;

RETAIN PRIMARY_CUSTOMER_RK_RET ALLOW_OVERDRAFT_FLG_RET ACCOUNT_TYPE_CD_RET
ACCOUNT_SUB_TYPE_CD_RET COLLATERAL_CD_RET ACCOUNT_STATUS_CD_RET ;

/*Assign the value of count to the temporary variables COUNT_TEMP */
COUNT_TEMP=COUNT;

/* Check to see if data is missing for certain period in the input table. If so,
   then adjust the count accordingly */
DO WHILE (TIME_SK < CURR_TIME);
	CURR_TIME = CURR_TIME - 1;
/*	COUNT = COUNT + 1;*/
END;

/* Check to see if there is more than one entry for certain period in the input table. 
   If so,  then adjust the count accordingly */
DO WHILE (CURR_TIME < TIME_SK ) ;
	CURR_TIME = CURR_TIME + 1;
/*	COUNT = COUNT - 1;*/
END;

/*Assign the value of following variables to the retained variables. 
This variables will be written to the data set during LAST.ACCOUNT_RK */
IF FIRST.ACCOUNT_RK THEN
	DO;
	PRIMARY_CUSTOMER_RK_RET = PRIMARY_CUSTOMER_RK;
	ALLOW_OVERDRAFT_FLG_RET = ALLOW_OVERDRAFT_FLG;
	ACCOUNT_TYPE_CD_RET = ACCOUNT_TYPE_CD;
	ACCOUNT_SUB_TYPE_CD_RET = ACCOUNT_SUB_TYPE_CD;
	COLLATERAL_CD_RET = COLLATERAL_CD;
	ACCOUNT_STATUS_CD_RET = ACCOUNT_STATUS_CD;
	END;

/*Check to see if the count has reached some level (3,6,12), if so then assign the
value of perivous variable to the next level variable */
IF FIRST.TIME_SK THEN 
	DO;
		IF (COUNT EQ 1 OR (COUNT_TEMP  <= 1 AND COUNT > 1)) THEN DO;
			%acc_ot_bnd_lst_asign_curr_to_3;	END;
		IF (COUNT EQ 3 OR (COUNT_TEMP  <= 3 AND COUNT > 3)) THEN DO;	
			%acc_ot_bnd_lst_abt_asign_3_to_6;END;
		IF (COUNT EQ 6 OR (COUNT_TEMP  <= 6 AND COUNT > 6)) THEN DO;
			%acc_ot_bnd_lst_abt_asign_6_to_12;END;
	END;

/*Counting the different transaction type viz. 
  statement issue for this parameter used as STI_TRANS_TYPE,
  delayed payment request for this parameter used as DPR_TRANS_TYPE and 
  check book issue  for this parameter used as CBI_TRANS_TYPE.
  Done in the current, 3,6,12 and 24 month period.
*/

IF (COUNT < 1) THEN 
	DO;
		IF TRANSACTION_TYPE_CD=&STI_TRANS_TYPE. THEN	DO;		 
				ACC_STMT_ISU_CURR_MTH_CNT=SUM(ACC_STMT_ISU_CURR_MTH_CNT,OUTBOUND_COMM_CNT);	END;
		 ELSE IF TRANSACTION_TYPE_CD=&DPR_TRANS_TYPE. THEN DO;
				ACC_DLD_PAY_REM_CURR_MTH_CNT=SUM(ACC_DLD_PAY_REM_CURR_MTH_CNT,OUTBOUND_COMM_CNT);END;
 		 ELSE IF TRANSACTION_TYPE_CD=&CBI_TRANS_TYPE. THEN DO;
				ACC_CHQ_BK_ISU_CURR_MTH_CNT=SUM(ACC_CHQ_BK_ISU_CURR_MTH_CNT,OUTBOUND_COMM_CNT);END;
	END;
IF (COUNT < 3) THEN 
	DO;
		IF TRANSACTION_TYPE_CD=&STI_TRANS_TYPE. THEN	DO;		 
				ACC_STMT_ISU_LST_3M_CNT=SUM(ACC_STMT_ISU_LST_3M_CNT,OUTBOUND_COMM_CNT);	END;
		 ELSE IF TRANSACTION_TYPE_CD=&DPR_TRANS_TYPE. THEN DO;
				ACC_DLD_PAY_REM_LST_3M_CNT=SUM(ACC_DLD_PAY_REM_LST_3M_CNT,OUTBOUND_COMM_CNT);END;
 		 ELSE IF TRANSACTION_TYPE_CD=&CBI_TRANS_TYPE. THEN DO;
				ACC_CHQ_BK_ISU_LST_3M_CNT=SUM(ACC_CHQ_BK_ISU_LST_3M_CNT,OUTBOUND_COMM_CNT);END;
	END;	
ELSE IF (COUNT <  6)  THEN 
	DO;
		 IF TRANSACTION_TYPE_CD=&STI_TRANS_TYPE. THEN DO;				 
					ACC_STMT_ISU_LST_6M_CNT=SUM(ACC_STMT_ISU_LST_6M_CNT,OUTBOUND_COMM_CNT);END;
		  ELSE IF TRANSACTION_TYPE_CD=&DPR_TRANS_TYPE. THEN DO;
					ACC_DLD_PAY_REM_LST_6M_CNT=SUM(ACC_DLD_PAY_REM_LST_6M_CNT,OUTBOUND_COMM_CNT);END;
 		  ELSE IF TRANSACTION_TYPE_CD=&CBI_TRANS_TYPE. THEN DO;
		  			ACC_CHQ_BK_ISU_LST_6M_CNT=SUM(ACC_CHQ_BK_ISU_LST_6M_CNT,OUTBOUND_COMM_CNT);END;
	END;	
ELSE IF (COUNT <  12)  THEN 
	DO;
	 	IF TRANSACTION_TYPE_CD=&STI_TRANS_TYPE. THEN 	DO;				 
				ACC_STMT_ISU_LST_12M_CNT=SUM(ACC_STMT_ISU_LST_12M_CNT,OUTBOUND_COMM_CNT); END;
		 ELSE IF TRANSACTION_TYPE_CD=&DPR_TRANS_TYPE. THEN DO;
				ACC_DLD_PAY_REM_LST_12M_CNT=SUM(ACC_DLD_PAY_REM_LST_12M_CNT,OUTBOUND_COMM_CNT); END;	
 		 ELSE IF TRANSACTION_TYPE_CD=&CBI_TRANS_TYPE. THEN DO;
				ACC_CHQ_BK_ISU_LST_12M_CNT=SUM(ACC_CHQ_BK_ISU_LST_12M_CNT,OUTBOUND_COMM_CNT); END;
	END;	
ELSE IF (COUNT <24) THEN

		IF TRANSACTION_TYPE_CD=&STI_TRANS_TYPE. THEN DO;
               ACC_STMT_ISU_13_24M_CNT=SUM(ACC_STMT_ISU_13_24M_CNT,OUTBOUND_COMM_CNT);END;
		 ELSE IF TRANSACTION_TYPE_CD=&DPR_TRANS_TYPE. THEN DO;				   
				ACC_DLD_PAY_REM_13_24M_CNT=SUM(ACC_DLD_PAY_REM_13_24M_CNT,OUTBOUND_COMM_CNT);END;	
 		 ELSE IF TRANSACTION_TYPE_CD=&CBI_TRANS_TYPE. THEN DO;
				ACC_CHQ_BK_ISU_13_24M_CNT=SUM(ACC_CHQ_BK_ISU_13_24M_CNT,OUTBOUND_COMM_CNT);
	END;

/*Increment the count and at the same time decrement the CURR_TIME to cater to the next
lowest time period */
IF LAST.TIME_SK THEN DO;
	COUNT = COUNT + 1;
	CURR_TIME = CURR_TIME - 1;
END;

/*If the end of the group is reached then output the data sets */
IF LAST.ACCOUNT_RK THEN
DO;	 
	/*Assign the value of retained variables to the actual variable
	being written to the data set */
	PRIMARY_CUSTOMER_RK = PRIMARY_CUSTOMER_RK_RET;
	ALLOW_OVERDRAFT_FLG = ALLOW_OVERDRAFT_FLG_RET;
	ACCOUNT_TYPE_CD = ACCOUNT_TYPE_CD_RET;
	ACCOUNT_SUB_TYPE_CD =ACCOUNT_SUB_TYPE_CD_RET;
	COLLATERAL_CD = COLLATERAL_CD_RET;
	ACCOUNT_STATUS_CD = ACCOUNT_STATUS_CD_RET;

	IF (COUNT <= 1) THEN	
		DO;
/*Is needed in case of premature exit, data is present only
for current months */
			%acc_ot_bnd_lst_asign_curr_to_3;
			%acc_ot_bnd_lst_abt_asign_3_to_6;
			%acc_ot_bnd_lst_abt_asign_6_to_12;	
		END;
	IF (COUNT <= 3) THEN	
/*Is needed in case of premature exit, data is present only
for 3 months */
		DO;
			%acc_ot_bnd_lst_abt_asign_3_to_6;
			%acc_ot_bnd_lst_abt_asign_6_to_12;	
		END;
		ELSE IF (COUNT <= 6) THEN
		/*Is needed in case of premature exit, data is present only
		for 6 months */
			DO;
				%acc_ot_bnd_lst_abt_asign_6_to_12;
	 		END;			
	/*Output the data set */
	OUTPUT; 	

	/*Reset all the retain variables for the next account group */
  	%acc_ot_bnd_lst_abt_reset_var;

	%if &PERIOD. = 24 %then %do; 
	CURR_TIME=BACK_12M_TIME_SK; COUNT = 12;  %end;
	%else %do;
	CURR_TIME=CURR_TIME_SK; COUNT = 0; %end;
END;

RUN;
%mend;

