/* The input to this macro is the 

INPUT_TABLE: The input table which is already filtered for LTD. 

This macro creates the ACC_TRANS_DETAIL_LTD_ABT table which stores the life to date

calculations and aggregations.

*/

%macro macro_acc_trans_detail_ltd_abt(INPUT_TABLE=);

/* Sorted in ascending order on all the variables */

PROC SORT DATA=ABTSCR.&INPUT_TABLE.;

	BY ACCOUNT_RK TRANS_TYPE_CD CHANNEL_TYPE_CD MEDIUM_CD LAST_TRANS_DTTM;

RUN;



/*The data step begins here. The data step reads the sorted input data set

& outputs aggregation table for LTD*/



data 

	%acc_trans_detail_ltd_abt_keep; 



/* Set the input table for reading */

SET ABTSCR.&INPUT_TABLE.;

BY ACCOUNT_RK TRANS_TYPE_CD CHANNEL_TYPE_CD MEDIUM_CD LAST_TRANS_DTTM;



length ACC_LST_PAY_MTH_NO $6. 

	   ACC_LST_INST_PAY_MTH_NO $6.

	   ACC_LST_PREPAY_MTH_NO $6.

	   ACC_LTST_IBT_MTH_NO $6. ;



/*List of variables to be retained */

	/*This macro has the unconditional retain statement for variables*/

	  %abt_transdetail_ltd_macro_retain;



	IF LAST.TRANS_TYPE_CD THEN 

	DO;

	/* Check if transaction type is payment */

		IF TRANS_TYPE_CD IN (&PAY_TRANS_TYPE) THEN

		DO;

			ACC_LST_PAY_MD_CD = MEDIUM_CD;

			ACC_LST_PAY_MTH_NO = CATS(YEAR(DATEPART(LAST_TRANS_DTTM)),PUT(MONTH(DATEPART(LAST_TRANS_DTTM)),z2.));

			ACC_SNC_LST_PAY_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM);

		END;



	/* Check if transaction type is principal payment */

		IF TRANS_TYPE_CD IN (&PPL_TRANS_TYPE) THEN

		DO;

			ACC_LST_INST_PAID_DT = DATEPART(LAST_TRANS_DTTM);

			ACC_SNC_LST_INST_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM);

			ACC_SNC_LST_INST_PYD_DAY_CNT = INTCK('DTDAY',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM);

			ACC_LST_INST_PAY_MTH_NO = CATS(YEAR(DATEPART(LAST_TRANS_DTTM)),PUT(MONTH(DATEPART(LAST_TRANS_DTTM)),z2.));

		END;

	/* Check if transaction type is prepayment */

		IF TRANS_TYPE_CD IN (&PPY_TRANS_TYPE) THEN DO;

			ACC_LST_PREPAY_MTH_NO = CATS(YEAR(DATEPART(LAST_TRANS_DTTM)),PUT(MONTH(DATEPART(LAST_TRANS_DTTM)),z2.)); END;

	/* Check if transaction type is Incoming balance transfer */

		IF TRANS_TYPE_CD IN (&IBT_TRANS_TYPE) THEN

		DO;

			ACC_LTST_IBT_AMT = LAST_TRANS_AMT;

			ACC_LTST_IBT_MTH_NO = CATS(YEAR(DATEPART(LAST_TRANS_DTTM)),PUT(MONTH(DATEPART(LAST_TRANS_DTTM)),z2.));

		END;		

		

	/* Check if transaction type is Withdrawal*/

		IF TRANS_TYPE_CD IN (&WDR_TRANS_TYPE) THEN DO;

			ACC_SNC_LTST_WDR_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM); END;

		

	/* Check if transaction type is Direct debit */

		IF TRANS_TYPE_CD IN (&DDR_TRANS_TYPE) THEN DO;

			ACC_SNC_LST_DDR_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM); END;



	/* Check if transaction type is purchase */

		IF TRANS_TYPE_CD IN (&PUR_TRANS_TYPE) THEN DO;

			ACC_MTH_SNC_LST_PUR_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM); END;



	/* Check if transaction type is deposit */

		IF TRANS_TYPE_CD IN (&DEP_TRANS_TYPE) THEN DO;

			ACC_SNC_LST_DEP_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM); END;

	

	/* Check if transaction type is Interest paid to account */	

		IF TRANS_TYPE_CD IN (&IPD_TRANS_TYPE) THEN

		DO;

			ACC_SNC_LST_INT_RCD_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM);

			ACC_SNC_LST_INT_RCD_DAY_CNT = INTCK('DTDAY',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM);

		END;

	

	/* Check if transaction type is Interest reinvested */

		IF TRANS_TYPE_CD IN (&INI_TRANS_TYPE) THEN DO;

			ACC_SNC_LST_INT_RINV_DAY_CNT = INTCK('DTDAY',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM); END;



	/* Check if transaction type is Standing order payment*/

		IF TRANS_TYPE_CD IN (&SOR_TRANS_TYPE) THEN DO;

			ACC_SNC_LST_SORD_PAY_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM); END;

	END;



	IF LAST.CHANNEL_TYPE_CD	THEN 

	DO;

		/* Check if withdrawal has happened by atm */

			IF CHANNEL_TYPE_CD IN (&ATM_CHANNEL) AND TRANS_TYPE_CD IN (&WDR_TRANS_TYPE) THEN DO;

				ACC_SNC_LTST_ATM_WDR_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM); END;



		/* Check if withdrawal has happened by teller */

			IF CHANNEL_TYPE_CD IN (&TLR_CHANNEL) AND TRANS_TYPE_CD IN (&WDR_TRANS_TYPE) THEN DO;

				ACC_SNC_LTST_TLR_WDR_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM); END;



		/* Check if transaction happened by ATM */			

			IF CHANNEL_TYPE_CD IN (&ATM_CHANNEL) THEN DO;

				ACC_SNC_LTST_ATM_USE_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM); END;

		/* Check if transaction happened by a Branch */	

			IF CHANNEL_TYPE_CD IN (&TLR_CHANNEL) THEN DO;	

				ACC_SNC_LTST_BRN_USE_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM); END;

		/* Check if transaction happened by Internet */			

			IF CHANNEL_TYPE_CD IN (&INN_CHANNEL) THEN DO;

				ACC_SNC_LTST_INN_USE_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM); END;

		/* Check if transaction happened by Phone */			

			IF CHANNEL_TYPE_CD IN (&PHN_CHANNEL) THEN DO;

				ACC_SNC_LTST_PHN_USE_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM); END;

	END;

	

	IF LAST.ACCOUNT_RK THEN 

	DO;

		/* Irrespective of any transaction */	

		ACC_SNC_LTST_TRNS_MTH_CNT = INTCK('DTMONTH',LAST_TRANS_DTTM,LOAD_ABT_USER_INPUT_DTTM);

		ACC_LTST_TRNS_DT = DATEPART(LAST_TRANS_DTTM); /*Could be for credit card */



		/*Output the data set */

		OUTPUT;

		

		/*Reset all variables for new account group */

		%abt_transdetail_ltd_macro_reset;

	END;	 

run;

%mend macro_acc_trans_detail_ltd_abt;

