%macro build_score_abt(repository=, work_lib=);
	options mvarsize=25000; 

	/* Handle missing values */
	%if %str(&repository) = %str() %then %do;
		%put WARNING: Metadata Repository should be provided. Defaulting to Foundation Repository.;
		%let repository = Foundation;
	%end;

	%if %str(&work_lib) = %str() %then %do;
		%put WARNING: Temporary storage library not provided. Defaulting to work.;
		%let work_lib = work;
	%end;

	/*Proc printto will redirect the log to the directory
	"Data/bisdata/log". */
	%global log_name;
	data _NULL_;
	name=put(time(),mmss8.1);
	name1=kscan(name,1,":.");
	name2=kscan(name,2,":.");
	name3=kscan(name,3,":."); 
	name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
	call symput('log_name',"Data/bisdata/log/scr_abt_build_"||ktrim(kleft(name4))||".log");
	run;

	%put NOTE: Sending log messages to :&log_name;

	proc printto log="&log_name";
	quit;

	/* Pick up models which are going to be used for scoring today */
	%select_models_to_build(work_lib=&work_lib);

	/* Build a format on table analytic.ABT_LEVEL to get LEVEL_DESC as per L_NO (Level Number) */
	%build_level_format;

	/* Pick up distict Scoring ABTs to build for all the models to be built */
	proc sql noprint;
		select distinct SCR_A_NO, count(distinct SCR_A_NO) 
			into :scr_abt_lst separated by "#", :scr_abt_cnt
		from &work_lib..SCR_ABT_MODEL;
	quit;

	/* Build each Scoring ABT */
	%do index_abt = 1 %to &scr_abt_cnt;
		%let scr_abt_key = %qscan(&scr_abt_lst, &index_abt, "#");

		/* Get all models connected to scoring abt to set the status */
		proc sql noprint;
			select distinct model_sk
				into :mlst separated by ","
			from &work_lib..SCR_ABT_MODEL
			where SCR_A_NO=&scr_abt_key;
		quit;

		/* 1. Set status of abt as "Building ABT */
		/* 2. Set prev_run_dt equal to next_run_dt since processing has started */
		proc sql;
			update analytic.SCR_MDL_SCHEDULE
			/*I18N-scnjih-20080430-1329*/
			/*set PREV_RUN_STATUS= 'Building ABT',PREV_RUN_DT=NEXT_RUN_DT*/
			set PREV_RUN_STATUS="%sysfunc(sasmsg(smd_ds.bismsg,build_score_abt.sas.1, noquote))",PREV_RUN_DT=NEXT_RUN_DT
			/*I18N-scnjih-20080430-1329*/
			where model_sk in (&mlst) and NEXT_RUN_DT <= today();
		quit;		

		%let phy_nm=;
		%let obs_dt=;
		/* Get ABT Physical name and observation date */
		proc sql noprint;
			select distinct SCR_ABT_TABLE_NM, LOAD_FOR_RUN
				into :phy_nm, :obs_dt
			from &work_lib..SCR_ABT_MODEL
			where SCR_A_NO = &scr_abt_key;
		quit;
		%let phy_nm=%trim(%left(&phy_nm));
		%let obs_dt=%trim(%left(&obs_dt));
		%put &phy_nm &obs_dt;

		/************** Build the required aggregate tables **************/
		%let error_code=;
		%build_scr_aggr_tables(work_lib=&work_lib, abt_key=&scr_abt_key, error_cd=&error_code,
			run_dt=&obs_dt);

		/************** End of Build the required aggregate tables **************/

		proc printto log="&log_name";
		quit;

		/* In case of error while running the jobs set prev_status to 'FAILED' and
			do not build ABT.
		*/
		%if %str(&error_code) ne %str() %then %do;
			proc sql;
				update analytic.SCR_MDL_SCHEDULE
				/*I18N-scnjih-20080430-1329*/
				/*set PREV_RUN_STATUS='Failed'*/
				set PREV_RUN_STATUS="%sysfunc(sasmsg(smd_ds.bismsg,build_score_abt.sas.4, noquote))"
				/*I18N-scnjih-20080430-1329*/
				where model_sk in (&mlst) and NEXT_RUN_DT <= today();
			quit;

			/* Do not continue creating the current ABT */
		%end;
		%else %do;
			/************** Create the ABT **************/
			/* Physical name of the abt being built is the <table_name>_<as_of_date> */
			%let abt_ds=abt.&phy_nm._&obs_dt.;
			%put &abt_ds;

			%let error_code=;
			%create_scr_abt(abt_key=&scr_abt_key, phy_table_nm=&abt_ds, error_cd=&error_code);

			/************** End of Create the ABT **************/

			/****** in case of error while running the jobs set prev_status to 'FAILED' and
				do not continue scoring ******************/
			%if %str(&error_code) ne %str() %then %do;
				proc sql;
					update analytic.SCR_MDL_SCHEDULE
				/*I18N-scnjih-20080430-1329*/
				/*set PREV_RUN_STATUS='Failed'*/
				set PREV_RUN_STATUS="%sysfunc(sasmsg(smd_ds.bismsg,build_score_abt.sas.4, noquote))"
				/*I18N-scnjih-20080430-1329*/
					where model_sk in (&mlst) and NEXT_RUN_DT <= today();
				quit;

				/* Do not continue creating the current ABT */
			%end;
			%else %do;
				/* Set status of abt as "ABT Built */
				proc sql;
					update analytic.SCR_MDL_SCHEDULE
					/*I18N-scnjih-20080430-1329*/
					/*set PREV_RUN_STATUS='ABT Built'*/
					set PREV_RUN_STATUS= "%sysfunc(sasmsg(smd_ds.bismsg,build_score_abt.sas.2, noquote))"
					/*I18N-scnjih-20080430-1329*/
					where model_sk in (&mlst) and NEXT_RUN_DT <= today();
				quit;

				/* Set phy name of ABT */
				proc sql;
					update analytic.scr_abt_master
					set ABT_PHY_TABLE_NM="&abt_ds"
					where SCR_A_NO=&scr_abt_key;
				quit;

				/* Set status of abt as "Scoring ABT */
				proc sql;
					update analytic.SCR_MDL_SCHEDULE
					/*I18N-scnjih-20080430-1329*/
					/*set PREV_RUN_STATUS='Scoring ABT'*/
					set PREV_RUN_STATUS="%sysfunc(sasmsg(smd_ds.bismsg,build_score_abt.sas.3, noquote))"
					/*I18N-scnjih-20080430-1329*/
					where model_sk in (&mlst) and NEXT_RUN_DT <= today();
				quit;

				/* Get all models associated with the Scoring ABT which have to be run now. */
				proc sql noprint;
					select distinct MODEL_SK, Model_NM, SCR_L_NO, 
						MODEL_TYPE_CD, MODEL_PRODUCT_TYPE_CD, count(distinct MODEL_SK)
						into :model_key_lst separated by "#", 
							:model_nm_lst separated by "#", 
							:abt_level_lst separated by "#", 
							:model_type_lst separated by "#",
							:model_prod_lst separated by "#",
							:model_cnt
					from &work_lib..SCR_ABT_MODEL
					where SCR_A_NO = &scr_abt_key;
				quit;

				/************** Get details of each model and score it **************/

				%do index_mdl = 1 %to &model_cnt;
					/* Get key, name of the model referenced by index_mdl */
					%let model_key = %qscan(&model_key_lst, &index_mdl, "#");
					%let model_nm = %qscan(&model_nm_lst, &index_mdl, "#");
					%let abt_level_no = %qscan(&abt_level_lst, &index_mdl, "#");
					%let model_type = %qscan(&model_type_lst, &index_mdl, "#");
					%let model_prod = %qscan(&model_prod_lst, &index_mdl, "#");

					/* Get Score code and required columns for each model from metadata */
					%let error_code=;
					%let input_columns=;
					%let score_code=;
					%let model_name=%nrquote(%'&model_nm%');

					%let abt_level=;
					/* Get level description */
					data _null_;
						abt_level=put(&abt_level_no, ABTLVL.);
						call symput('abt_level',kupcase(abt_level));
					run;

					%let new_abt_nm = &&abt_ds._&model_prod;

					/* Filtering the abt based on product */
					%if "&abt_level" eq "ACCOUNT" %then %do;
						data &new_abt_nm;
						set &abt_ds;
							where ACCOUNT_TYPE_CD="&model_prod";
						run;
					%end;
					%if "&abt_level" eq "APPLICATION" %then %do;
						data &new_abt_nm;
						set &abt_ds;
							where ACC_PRD_TYP_CD="&model_prod";							
						run;
					%end;
					%else %do;
						%let new_abt_nm = &abt_ds; 
					%end;	

					/* Get model details from the Metadata and score the input abt provided */
					%get_model_details(repository=&repository, model_nm=&model_name, 
						work_lib=&work_lib, in_ds=&new_abt_nm, out_ds=&work_lib..ABT_Score_Output, 
						error_cd=&error_code);
					%if %str(&error_code) ne %str() %then %do;
						/******* Set set prev_status to 'FAILED' and do not continue *******/
						proc sql;
							update analytic.SCR_MDL_SCHEDULE
				/*I18N-scnjih-20080430-1329*/
				/*set PREV_RUN_STATUS='Failed'*/
							set PREV_RUN_STATUS="%sysfunc(sasmsg(smd_ds.bismsg,build_score_abt.sas.4, noquote))"
				/*I18N-scnjih-20080430-1329*/
							where model_sk in (&mlst) and NEXT_RUN_DT <= today();
						quit;

						/* Do not continue creating the current ABT */
					%end;
					%else %do;
						/* Write results back to the DDS */
						%let error_code=;
						%write_back_dds(score_ds=&work_lib..ABT_Score_Output, 
							model_key=&model_key, error_cd=&error_code, model_type=&model_type,
							abt_level_no=&abt_level_no, work_lib=work);

						%if %str(&error_code) ne %str() %then %do;
							/******* Set set prev_status to 'FAILED' and do not continue *******/
							proc sql;
								update analytic.SCR_MDL_SCHEDULE
				/*I18N-scnjih-20080430-1329*/
				/*set PREV_RUN_STATUS='Failed'*/
								set PREV_RUN_STATUS="%sysfunc(sasmsg(smd_ds.bismsg,build_score_abt.sas.4, noquote))"
				/*I18N-scnjih-20080430-1329*/								
								where model_sk in (&mlst) and NEXT_RUN_DT <= today();
							quit;

							/* Do not continue creating the current ABT */
						%end;
						%else %do;
							/* Set status of model as "Complete" */
							proc sql;
								update analytic.SCR_MDL_SCHEDULE
				/*I18N-scnjih-20080430-1329*/
				/*set PREV_RUN_STATUS='Complete'*/
								set PREV_RUN_STATUS="%sysfunc(sasmsg(smd_ds.bismsg,build_score_abt.sas.5, noquote))"
				/*I18N-scnjih-20080430-1329*/
								where model_sk = &model_key and NEXT_RUN_DT <= today();
							quit;

							/* Set NEXT_RUN_DT as per the frequency */
							proc sql;
								update analytic.SCR_MDL_SCHEDULE
								set NEXT_RUN_DT=case frequency_cd 
									when 'Monthly' then intnx('MONTH', PREV_RUN_DT, 1, 'SAME')
									when 'Quarterly' then intnx('QTR', PREV_RUN_DT, 1, 'SAME')
									when 'Half Yearly' then intnx('SEMIYEAR', PREV_RUN_DT, 1, 'SAME')
									when 'Yearly' then intnx('YEAR', PREV_RUN_DT, 1, 'SAME')
									when 'Run Once' then .
									else PREV_RUN_DT end
								where model_sk = &model_key and NEXT_RUN_DT <= today();
							quit;
						%end;
					%end;
				%end; /* Models loop */
			%end; 
		%end; /* Continue creating ABT */
	%end; /* Scoring ABT loop */

	proc printto;
	quit;
%mend build_score_abt;
/*%build_score_abt;*/

