%macro build_scr_aggr_tables(work_lib=, abt_key=, error_cd=, run_dt=);

	/* Handle missing values */
	%if %str(&work_lib) = %str() %then %do;
		%put WARNING: Temporary storage library not provided. Defaulting to work.;
		%let work_lib = work;
	%end;

	%if %str(&abt_key) = %str() %then %do;
		%put ERROR: ABT Key not provided. Exiting.;
		%let error_code=ERROR;
		%return;
	%end;

	%if %str(&run_dt) = %str() %then %do;
		%put ERROR: Date of data capture not provided. Exiting.;
		%let error_code=ERROR;
		%return;
	%end;

	/* Backup the existing Parameter List table as _&abt_key._<date>_<time> and 
		create a new one for use */
	%global backup_table_name;
	%let backup_table_name=;

	%if %sysfunc(exist(control.parameter_list_scr_abt)) %then %do;
		/* Backup the existing Parameter List table as _&abt_key._<date>_<time> and 
			create a new one for use */
		%global backup_table_name;
		%let backup_table_name=;
		data _NULL_;
			name=put(date(), date9.)||"_"||strip(tranwrd(put(time(), time6.), ":", "_"));
			call symput('backup_table_name', "_"||strip(&abt_key)||"_"||trim(left(name)));
		run;

		data control.&backup_table_name.;
			set control.parameter_list_scr_abt;
			output control.&backup_table_name.;
		run;

		proc sql;
			drop table control.parameter_list_scr_abt;
		quit;
	%end;

	data control.parameter_list_scr_abt;
		length JOB_NM $40.;
		length LEVEL_NO 8.;
		length RETURN_CD 8.;
		stop;
	run;

	/* Insert the job names for the input variables in Parameter List table 
		CONTROL.PARAMETER_LIST_SCR_ABT
		Columns: JOB_NM, LEVEL_NO, RETURN_CD
	*/
	proc sql;
		create table &work_lib..scr_abt_x_var as
		select * 
		from analytic.Scr_abt_x_var
		where scr_a_no=&abt_key and upcase(is_selected_flg)='Y';

		/* Manual insertion of key variables */
		insert into work.scr_abt_x_var
		(SCR_A_NO, V_NO, IS_SELECTED_FLG) 
		values (&abt_key, 999995, 'Y')
		values (&abt_key, 999996, 'Y')
		values (&abt_key, 999997, 'Y');
		/* End of manual insertion */

		create table &work_lib..job_levels as
		select distinct Table_x_job.job_nm, job_level_no as level_no, . as return_cd,
			child_jobs
		from &work_lib..scr_abt_x_var inner join analytic.Var_master
		on (Scr_abt_x_var.v_no = Var_master.v_no)
		inner join analytic.Table_x_job
		on (Var_master.agg_table_nm = Table_x_job.var_table_nm)
		inner join analytic.Job_x_level
		on (Table_x_job.job_nm = Job_x_level.job_nm)
		order by job_level_no;
	quit;

	/* To remove extra jobs */
	%global child_jobs;

	proc sql noprint;
		select distinct child_jobs into :child_jobs separated by ',' 
		from &work_lib..job_levels 
		where child_jobs NE '';
	quit;
	%if %str(&child_jobs) NE %str() %then %do;
		proc sql;
			delete from &work_lib..job_levels where job_nm in ("&child_jobs.");
		quit;
	%end;
	proc sql;
		alter table &work_lib..job_levels drop child_jobs;
	quit;

	proc append data=&work_lib..job_levels base=control.parameter_list_scr_abt force;
	quit;

	/* Set the data capture date in macro variable LOAD_ABT_USER_INPUT_DTTM
	1. Only global definition of LOAD_ABT_USER_INPUT_DTTM will be available in autoexec.
	2. Pass this macro thro the loop jobs to the final ETL jobs.
	3. When the autoexec for the ETL jobs run, the other variables dependent on 
		LOAD_ABT_USER_INPUT_DTTM will get set.
	*/
	data _null_;
		ld_dt="&run_dt"d;
		ld_dttm=dhms(ld_dt, 0,0,0);
		call symput('LOAD_ABT_USER_INPUT_DTTM', ld_dttm);
	run;

	/* Call the MasterLoopJob to run the jobs to build the Scoring ABT */
	%include jobs(MasterLoopScoringABTJob.sas);

	/* To check for error check if there are any jobs with return_cd not equal to 0
		in the Parameter List table. 
	*/
	proc sql noprint;
		select count(*) into :no_failed 
		from control.parameter_list_scr_abt
		where return_cd ne 0;
	quit;

	/* In case of error while running the jobs set error_code to 'ERROR' */
	%if &no_failed ne 0 %then %let error_code=ERROR;

%mend build_scr_aggr_tables;
