%macro get_model_details(repository=, model_nm=, work_lib=, in_ds=, out_ds=, error_cd=);
	/* Handle missing values */
	%if %str(&repository) = %str() %then %do;
		%put ERROR: Metadata Repository should be provided. Defaulting to Foundation Repository.;
		%let repository = Foundation;
	%end;

	%if %str(&model_nm) = %str() %then %do;
		%put ERROR: MODEL_NM for the model to be scored is not available. Please ensure that there is a value for MODEL_NM in dimension ANALYTICAL_MODEL_DIM and it should be the name provided when registering the Enterprise Miner model;
		%abort;
	%end;

	%if %str(&work_lib) = %str() %then %do;
		%put WARNING: Work library not provided. Defaulting to work.;
		%let work_lib = work;
	%end;

	/* File reference to the file which will be generated by proc metadata code */
	filename out_file 'Data/bisdata/scratch/outmodel.xml' lrecl=1000000;
	filename res_file 'Data/bisdata/scratch/code.sas';

	/* Step 1. Get the ID for the Foundation Repository */
	PROC METADATA
	IN="<GetRepositories>
	<Repositories/>
	<Flags>0</Flags>
	<Options/>
	</GetRepositories>"
	out=out_file;
	RUN;

	filename SXLEMAP 'Data/bisdata/xmlmap/Repositories.map';
	libname out_file xml xmlmap=SXLEMAP access=READONLY;
	proc datasets lib=out_file; 
	quit;

	data &work_lib..Repositories;
	set out_file.Repositories;
	run;

	/* Step 2. Select ID of the correct Repository. */
	proc sql noprint;
		select ID into :repository_id 
		from &work_lib..Repositories
		where ktrim(kleft(Name))="&repository";
	quit;
/*	%put &repository_id;*/

	%let Model_Metadata_String= %str(<GetMetadataObjects><Reposid>)&repository_id.%str(</Reposid>
		                    <Type>MiningResult</Type>
		                    <Objects/>
							<NS>SAS</NS>
		                    <Flags>388</Flags>
		       <Options>
			    <XMLSELECT Search=%"*[@Name EQ )&model_nm.%str(]%"/>
		     	<Templates>
					<Miningresult>
						<Sourcecode/>
					</Miningresult>
					<Textstore id="""" storedtext="""" />
				</Templates>
			</Options>
		</GetMetadataObjects>);
	%put &Model_Metadata_String;

	proc metadata
	IN="&Model_Metadata_String."
	out=out_file;
	run;

/*	filename  SXLEMAP 'Data/bisdata/xmlmap/MiningResult.map';*/
/*	libname   out_file xml xmlmap=SXLEMAP;*/
/**/
/*	data &work_lib..Input_Columns;*/
/*		set out_file.Column;*/
/*	run;*/
/**/
/*	options mvarsize=20000;*/
/*	proc sql noprint;*/
/*	select columnname into :input_columns separated by ','*/
/*	from &work_lib..Input_Columns;*/
/*	quit;*/

	data _null_;
		file res_file;
		str="data " || "&out_ds" || ";";
		put str;
/*		str1="set " || strip("&work_lib") || ".ABT_Table" || ";";*/
		str1="set " || "&in_ds" || ";";
		put str1;
	run;

	data _null_;
		retain str1; 
		retain status 0;
		file res_file mod;
		infile out_file column=column;
		length aa rest str1 $4000;
		M=Column;
	 	input @M aa @@;
		if aa='' then aa='.';
		if status = 0 then do;
			posn1=index(aa, "StoredText=");
			if posn1 > 0 then do;
				aa = ksubstr ( aa ,posn1+12 );
				status=1;
			end;
		end;
		if status = 1 then do;
			aa=tranwrd(aa, '&quot;', "'");
			aa=tranwrd(aa, '&lt;', "<");
			aa=tranwrd(aa, '&gt;', ">");

			posn=index(aa, "&#x0a;");
			if posn > 0 then do;
				do while (posn > 0);
					rest = ksubstr ( aa ,posn+6 );
					if posn > 1 then
						str1 = ktrim(kleft(str1)) || " " ||ksubstr (ktrim(kleft(aa)) ,1,posn - 1 );
					else
						str1 = ktrim(kleft(str1)) || " ";
					put str1;
					str1 = '';
					posn=index(rest, "&#x0a;");
					aa = rest;
				end;
				str1 = ktrim(kleft(str1)) || " " || rest;
			end;
			else Do;
				str1  = ktrim(kleft(str1 )) ||" "|| ktrim(left(aa ));
			end;
		end;
	run;

	data _null_;
		file res_file mod;
		put "run;";
	run;

	/* Create a view / table of the ABT variables with only the variables 
		in the InputTable */
/*	proc sql;*/
/*		create table &work_lib..ABT_Table as*/
/*		select &input_columns, TGT_VAR*/
/*		from &in_ds;*/
/*	quit;*/

	/*
	Code to check for errors.
	Possibly error will happen only if the columns expected by eminer model do not
	match the columns of the scoring ABT provided.  
	In this case, return to the calling program with error_code=ERROR*/

	%if &sqlrc > 4 %then %do;
		%put Error: The columns in the Input dataset &in_ds do not match the columns required by model code. Please check the columns.;

		/******* Set set prev_status to 'FAILED' and do not continue *******/
		proc sql;
			update analytic.SCR_MDL_SCHEDULE
			/*I18N-scnjih-20080430-1410*/
			/*set PREV_RUN_STATUS='Failed'*/
			set PREV_RUN_STATUS= "%sysfunc(sasmsg(smd_ds.bismsg,get_model_details.sas.1, noquote))"
			/*I18N-scnjih-20080430-1410*/
			where model_sk in (&mlst) and NEXT_RUN_DT <= today();
		quit;
		%let error_code=ERROR;
	%end;
	%else %do;
		/* Apply the code from eminer on the dataset created in the previous stage */
		%include res_file /SOURCE2;
		%if &sysrc > 4 %then %let error_code=ERROR;
	%end;
%mend;
