/* 
Select models where next score date <= today and the data for that month has
been loaded in the star.

Tables:
analytic.Scr_abt_schedule
control.star_schema_load_dates
*/

%macro select_models_to_build(work_lib);
	/* Handle missing values */
	%if %str(&work_lib) = %str() %then %do;
		%put WARNING: Work library not provided. Defaulting to work.;
		%let work_lib = work;
	%end;

	/* Pick up the models which are ready to run */
	proc sql;
		create table &work_lib..SCR_ABT as
		select distinct SCR_ABT_MASTER.SCR_A_NO, SCR_ABT_TABLE_NM, SCR_L_NO, 
			intnx('month',NEXT_RUN_DT, -1, 'end') format=date9. as LOAD_FOR_RUN, 
			SCR_ABT_X_MODEL.MODEL_SK, MODEL_NM, MODEL_ID, MODEL_TYPE_CD,MODEL_PRODUCT_TYPE_CD
		from analytic.SCR_ABT_MASTER INNER JOIN analytic.SCR_ABT_X_MODEL
		ON (SCR_ABT_MASTER.SCR_A_NO = SCR_ABT_X_MODEL.SCR_A_NO and 
			kupcase(SCR_ABT_X_MODEL.IS_SELECTED_FLG) = "Y")
		INNER JOIN analytic.SCR_MDL_SCHEDULE
		ON (SCR_ABT_X_MODEL.MODEL_SK = SCR_MDL_SCHEDULE.MODEL_SK)
		INNER JOIN dim.ANALYTICAL_MODEL_DIM
		ON (SCR_ABT_X_MODEL.MODEL_SK = ANALYTICAL_MODEL_DIM.MODEL_SK)
		INNER JOIN analytic.SCR_ABT_X_VAR
		ON (SCR_ABT_MASTER.SCR_A_NO = SCR_ABT_X_VAR.SCR_A_NO and 
			kupcase(SCR_ABT_X_VAR.IS_SELECTED_FLG) = "Y")
		where NEXT_RUN_DT <= today();
	quit;

	/* Pick up the distinct list of Scoring ABTs for the selected models */
	proc sql;
		create table &work_lib..SCR_ABT_MODEL as
		select SCR_ABT.*
		from &work_lib..SCR_ABT, control.STAR_SCHEMA_LOAD_DATES
		where MONTH(LOAD_DT) = MONTH(LOAD_FOR_RUN) and 
			YEAR(LOAD_DT) = YEAR(LOAD_FOR_RUN) and
			LOAD_STATUS = 'Y';
	quit;
%mend select_models_to_build;


