/*
Macro Name	: CI
Function	: Computes Wald's Confidence Limits with given Mean, STDDev and Alpha .
Created by	: BIS Team
Date		: Apr 07, 2006
SAS Version	: 9.1

Called-by	:PD_CI and LGD_CCF_CI macro
Calls		:None

Parameters	: 

input_ds		: Name of the input data set 
Alpha			: Value of Alpha to get (1-alpha)*100% CI	
output_ds		: Name of the data set which stores brier score.
	
Input Dataset(s) Format:
For PD
--------------------------------------------------------------------------
Name				Type		Format
--------------------------------------------------------------------------
Pool_Name			Character 	Default Formatting	
Pool_Seq	 		Number		Default Formatting
No_Of_ACC_Actual	Number		Default Formatting
No_of_Acc_Dev	 	Number 		Default Formatting
PD	 				Number		Default Formatting
Score_Points	 	Number		Default Formatting
No_Of_Actual_Bads	Number		Default Formatting	
Mean				Number		Default Formatting	
Stdev				Number		Default Formatting	
--------------------------------------------------------------------------
For CCF
-------------------------------------------------------------------------
Name				Type		Format
------------------------------------------------------------------------
Pool_Name			Character	Default Format
Pool_Seq            Numeric		Default Format
ActualCCF           Numeric		Default Format
EstimatedCCF        Numeric		Default Format
No_of_Acc_Actual    Numeric		Default Format
No_of_Acc_Dev       Numeric		Default Format
No_of_Actual_bads   Numeric		Default Format
Mean				Numeric		Default Format
Stdev				Numeric		Default Format	
------------------------------------------------------------------------
For LGD
-------------------------------------------------------------------------
Name				Type		Format
------------------------------------------------------------------------
Pool_Name			Character	Default Format
Pool_Seq            Numeric		Default Format
Actual_LGD			Numeric		Default Format
EstimatedLGD		Numeric		Default Format
No_of_Acc_Actual    Numeric		Default Format
No_of_Acc_Dev       Numeric		Default Format
No_of_Actual_bads   Numeric		Default Format
Mean				Numeric		Default Format
Stdev				Numeric		Default Format	
------------------------------------------------------------------------
Output Dataset(s) Format:
output_ds:
-------------------------------------------------------------------------
Name			Type		Format
------------------------------------------------------------------------
Pool_Name		Character	Default Format		
LowerConf		Numeric		Default Format
UpperConf		Numeric		Default Format
------------------------------------------------------------------------

Logic:
	LCL =Mean - Z_alpha * Stdev;
	UCL =Mean + Z_alpha * Stdev;

where Z_Alpha is such that P[N(0,1) > Z_Alpha] = Alpha/2

Notes:
1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
2. It is assumed that data set of specified as input_ds has valid specified fileds.
3. For all output datasets (Viz output_ds),it is assumend that
	a. it has valid name.
	b. Macro has necessary required rights to create the datasets with specified name @ specified location.
	c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.

*/
%macro ci(input_ds= ,Alpha=,output_CI=);
%let Z_alpha = %sysEvalf(1.0 - &Alpha/2);
%let lbl_Conf = %sysEvalf((1.0 - &Alpha)*100);
%let Z_alpha = %sysfunc(probit(&Z_Alpha));

data &output_CI(keep= Pool_Name LowerConf UpperConf);
	set &input_ds;
	attrib
	 /*I18N-scnjih-20080423-1714*/
	/*LowerConf label= "&lbl_Conf% Lower Confidence Limit"*/
	/*UpperConf label= "&lbl_Conf% Upper Confidence Limit"*/
	LowerConf label= "&lbl_Conf% %sysfunc( sasmsg(smd_ds.bismsg,ci.sas.1, noquote))"
	UpperConf label= "&lbl_Conf% %sysfunc( sasmsg(smd_ds.bismsg,ci.sas.2, noquote))"
	 /*I18N-scnjih-20080423-1714*/
	;
	LowerConf =Mean - &Z_alpha * Stdev;
	UpperConf =Mean + &Z_alpha * Stdev;
run;
%mend ci;
