/*
Macro Name	: CCF_CI
Function	: Calls routine which computes Confidence Limit for CCF for given Alpha.
			  for the variable based on ACT_FLAG value and also applies necessary lables to output datasets.
Created by	: BIS Team
Date		: Apr 07, 2006
SAS Version	: 9.1

Called-by	: CCF CI screen, Stored proc Name(s) : Check with Deepa.
Calls		:LGD_CCF_CI

Parameters	: 

input_ds		: Name of the input data set 
MSE				: Value of Mean Square Error (>0)
Alpha			: Value of Alpha to get (1-alpha)*100% CI	
output_ds		: Name of the data set which stores brier score.
ACT_FLAG		: Flag to indicate whether CI to be calculated using actual CCF values (Default value 1)
				 (1: Actual CCF 0: Devlopment CCF)
	
Input Dataset(s) Format
-------------------------------------------------------------------------
Name				Type		Format
------------------------------------------------------------------------
Pool_Name			Character	Default Format
Pool_Seq            Numeric		Default Format
ActualCCF           Numeric		Default Format
EstimatedCCF        Numeric		Default Format
No_of_Acc_Actual    Numeric		Default Format
No_of_Acc_Dev       Numeric		Default Format
No_of_Actual_bads   Numeric		Default Format
------------------------------------------------------------------------
Output Dataset(s) Format:

output_ds:
-------------------------------------------------------------------------
Name			Type		Format
------------------------------------------------------------------------
Pool_Name		Character	Default Format		
Pool_Seq		Numeric		Default Format
NO_ACC			Numeric		Default Format
Estimated_CCF	Numeric		Default Format
Actual_CCF		Numeric		Default Format
LowerConf		Numeric		Default Format
UpperConf		Numeric		Default Format
------------------------------------------------------------------------

Logic:
1. Based on ACT_FLAG value selects the necessary variable and calls the macro to calculate CIs.

Notes:
1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
2. It is assumed that data set of specified as input_ds has valid specified fileds.
3. For all output datasets (Viz output_graph_ds,output_stat_ds),it is assumend that
	a. it has valid name.
	b. Macro has necessary required rights to create the datasets with specified name @ specified location.
	c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.
4. Value of MSE should be calculated using same data before calling this macro.
   User can calculate MSE using "Error_Measures" macro to calculate MSE. 
   But user can do its own formula to calculate MSE and supply to this macro.

*/
%macro ccf_ci(input_ds= ,MSE =,Alpha=,output_ds=,ACT_FLAG=1);
%if &ACT_FLAG=1 %then
	%let Var = Actual_CCF;
%else
	%let Var = Estimated_CCF;

%lgd_ccf_ci(input_ds=&input_ds,MSE =&MSE,Alpha=&Alpha,output_ds=output, Var=&Var,ACT_FLAG=&ACT_FLAG);

data &output_ds(keep =Pool_Name Pool_Seq NO_ACC Estimated_CCF Actual_CCF LowerConf UpperConf);
	set output;
	attrib
 /*I18N-scnjih-20080418-0932*/
/*	Pool_Name		label = "Pool Name"*/
/*	NO_ACC			label = "No. of Accounts"*/
/*	Estimated_CCF	label = "Estimated CCF"*/
/*	Actual_CCF		label = "Actual CCF"*/
/*	Pool_Seq		label = "Pool Sequence"*/
/*	;*/
	Pool_Name		label = "%sysfunc(sasmsg(smd_ds.bismsg,ccf_ci.sas.1, noquote))"
	NO_ACC			label =  "%sysfunc(sasmsg(smd_ds.bismsg,ccf_ci.sas.2, noquote))"
	Estimated_CCF	label =  "%sysfunc(sasmsg(smd_ds.bismsg,ccf_ci.sas.3, noquote))"
	Actual_CCF		label =  "%sysfunc(sasmsg(smd_ds.bismsg,ccf_ci.sas.4, noquote))"
	Pool_Seq		    label =  "%sysfunc(sasmsg(smd_ds.bismsg,ccf_ci.sas.5, noquote))"
	;
 /*I18N-scnjih-20080418-0932*/
run;
%mend ccf_ci;
