/*
Macro Name	: LGD_CI
Function	: Calls routine which computes Confidence Limits for LGD for given Alpha.
			  for the variable based on ACT_FLAG value and also applies necessary lables to output datasets.
Created by	: BIS Team
Date		: Apr 07, 2006
SAS Version	: 9.1

Called-by	: LGD CI screen, Stored proc Name(s) : Check with Deepa.
Calls		: LGD_CCF_CI

Parameters	: 

input_ds		: Name of the input data set 
MSE				: Value of Mean Square Error (>0)
Alpha			: Value of Alpha to get (1-alpha)*100% CI	
output_ds		: Name of the data set which stores brier score.
ACT_FLAG		: Flag to indicate whether CI to be calculated using actual CCF values (Default value 1)
				 (1: Actual CCF 0: Devlopment CCF)
	
Input Dataset(s) Format:
-------------------------------------------------------------------------
Name				Type		Format
------------------------------------------------------------------------
Pool_Name			Character	Default Format
Pool_Seq            Numeric		Default Format
Actual_LGD			Numeric		Default Format
EstimatedLGD		Numeric		Default Format
No_of_Acc_Actual    Numeric		Default Format
No_of_Acc_Dev       Numeric		Default Format
No_of_Actual_bads   Numeric		Default Format
------------------------------------------------------------------------

Output Dataset(s) Format:
output_ds:
-------------------------------------------------------------------------
Name			Type		Format
------------------------------------------------------------------------
Pool_Name		Character	Default Format		
Pool_Seq					Default Format
NO_ACC			Numeric		Default Format
Estimated_LGD	Numeric		Default Format
Actual_LGD		Numeric		Default Format
LowerConf		Numeric		Default Format
UpperConf		Numeric		Default Format
------------------------------------------------------------------------

Logic:
1. Based on ACT_FLAG value selects the necessary variable and calls the macro to calculate CIs.

Notes:
1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
2. It is assumed that data set of specified as input_ds has valid specified fileds.
3. For all output datasets (Viz output_graph_ds,output_stat_ds),it is assumend that
	a. it has valid name.
	b. Macro has necessary required rights to create the datasets with specified name @ specified location.
	c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.
4. Value of MSE should be calculated using same data before calling this macro.
   User can calculate MSE using "Error_Measures" macro to calculate MSE. 
   But user can do its own formula to calculate MSE and supply to this macro.

*/
%macro lgd_ci(input_ds= ,MSE =,Alpha=,output_ds=,ACT_FLAG=1);

%if &ACT_FLAG=1 %then
	%let Var = Actual_LGD;
%else
	%let Var = Estimated_LGD;

%lgd_ccf_ci(input_ds=&input_ds,MSE =&MSE,Alpha=&Alpha,output_ds=work.output, Var=&Var,ACT_FLAG=&ACT_FLAG);

data &output_ds(keep =Pool_Name Pool_Seq NO_ACC Estimated_LGD Actual_LGD LowerConf UpperConf);
	set work.output;
	attrib
	 /*I18N-scnjih-20080418-0939*/
/*	Pool_Name		label = "Pool Name"*/
/*	NO_ACC			label = "No. of Accounts"*/
/*	Estimated_LGD	label = "Estimated LGD"*/
/*	Actual_LGD		label = "Actual LGD"*/
/*	Pool_Seq		label = "Pool Sequence"*/
/*	;*/
	Pool_Name		label =  "%sysfunc(sasmsg(smd_ds.bismsg,lgd_ci.sas.1, noquote))"
	NO_ACC			label = "%sysfunc(sasmsg(smd_ds.bismsg,lgd_ci.sas.2, noquote))"
	Estimated_LGD	label = "%sysfunc(sasmsg(smd_ds.bismsg,lgd_ci.sas.3, noquote))"
	Actual_LGD		label = "%sysfunc(sasmsg(smd_ds.bismsg,lgd_ci.sas.4, noquote))"
	Pool_Seq		    label = "%sysfunc(sasmsg(smd_ds.bismsg,lgd_ci.sas.5, noquote))"
	;
	 /*I18N-scnjih-20080418-0939*/
run;
%mend lgd_ci;
