/*********************************************************************
       Module:  shift_indices

     Function:  This stored process creates the table of Score and event shift indices.


      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	shift_index
        Calls:  NA

Datasets used:  Supplied as the parameter
                Input datset is passed which is output of Macro generate_feed_mip.
				otput dataste where you will collect the value.
                
   		Logic: 1.Computaion of shift of score cardspoints for attribute proportion 
				 per attribute for a variable.
			   2.Computaion of shift of score cardspoints for event proportion 
				 per attribute for a variable.
				
   Parameters:  INPUT (From Report Screen when link is used for navigation) 
				1.input_ds   :Dataset passed is  
				2.output_ds  :out put library. where we have our dataset.
	Notes:
				1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
				2. It is assumed that data set of specified as input_ds has valid specified fileds.
				3. For all output datasets (Viz output_ds),it is assumend that
					a. it has valid name.
					b. Macro has necessary required rights to create the datasets with specified name @ specified location.
					c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.
***************************************************************************/
%macro shift_indices(input_ds=,output_ds=);
/*Code to get shift indices begins here*/
data work.totals;
	set &input_ds end=last;

	prop_act_tot + No_of_ACC_actual;
	prop_dev_tot + No_of_ACC_Dev;

	prop_evt_act_tot + No_of_events_actual;
	prop_evt_dev_tot + No_of_events_Dev;

	if last then do;
	 	call symput('PAT',prop_act_tot);
	 	call symput('PDT',prop_dev_tot);
	 	call symput('PEAT',prop_evt_act_tot);
	 	call symput('PEDT',prop_evt_dev_tot);	
	end;
run;

data &output_ds;
	set work.totals (drop=prop_act_tot prop_dev_tot prop_evt_act_tot prop_evt_dev_tot);
	/*I18N-scnjih-20080418-0943*/
/*	label Attr_Name=Attribute Name */
/*			Seq_No=Seq No*/
/*			scorecard_points=Scorecard Points (SP)*/
/*			prop_actual=Attribute Proportion Actual (A)*/
/*			prop_dev=Attribute Proportion Development (B)*/
/*			prop_evt_act=Event Proportion Actual (C)*/
/*			prop_evt_dev=Event Proportion Development (D)*/
/*			score_shift_index=Score Shift Index	[  ((A*100)-(B*100))*SP  ]*/
/*			event_shift_index=Event Shift Index	[  ((C*100)-(D*100))*SP  ];*/
	label Attr_Name= "%sysfunc(sasmsg(smd_ds.bismsg,shift_indices.sas.1, noquote))" 
			Seq_No="%sysfunc(sasmsg(smd_ds.bismsg,shift_indices.sas.2, noquote))" 
			scorecard_points="%sysfunc(sasmsg(smd_ds.bismsg,shift_indices.sas.3, noquote))" 
			prop_actual="%sysfunc(sasmsg(smd_ds.bismsg,shift_indices.sas.4, noquote))" 
			prop_dev="%sysfunc(sasmsg(smd_ds.bismsg,shift_indices.sas.5, noquote))" 
			prop_evt_act="%sysfunc(sasmsg(smd_ds.bismsg,shift_indices.sas.6, noquote))" 
			prop_evt_dev="%sysfunc(sasmsg(smd_ds.bismsg,shift_indices.sas.7, noquote))" 
			score_shift_index="%sysfunc(sasmsg(smd_ds.bismsg,shift_indices.sas.8, noquote))" 
			event_shift_index="%sysfunc(sasmsg(smd_ds.bismsg,shift_indices.sas.9, noquote))" ;
		/*I18N-scnjih-20080418-0943*/
	format scorecard_points &CS_DEC_FMT. prop_actual &CS_DEC_FMT. prop_dev &CS_DEC_FMT. 
			prop_evt_act &CS_DEC_FMT. prop_evt_dev &CS_DEC_FMT. score_shift_index &CS_DEC_FMT. 
			event_shift_index &CS_DEC_FMT.;
	prop_actual=No_of_ACC_actual/&PAT;
	prop_dev=No_of_ACC_Dev/&PDT;
	prop_evt_act=No_of_events_actual/&PEAT;
	prop_evt_dev=No_of_events_Dev/&PEDT;

	score_shift_index = ((prop_actual*100)  - (prop_dev*100))    * scorecard_points;
	event_shift_index = ((prop_evt_act*100) - (prop_evt_dev*100))* scorecard_points;
run;

%mend shift_indices;
