/*********************************************************************
       Module:  stability_indices

     Function:  This stored process creates the table of Score and event shift indices.


      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	variable_stability_index
        Calls:  NA

Datasets used:  Supplied as the parameter
                Input datset is passed which is output of Macro generate_feed_mip.
				otput dataste where you will collect the value.
                
   		Logic: 1.Computaion for variable stability index.
			   2.Computaion for event stability index.
				
   Parameters:  INPUT (From Report Screen when link is used for navigation) 
				1.input_ds   :Dataset passed is  
				2.output_ds  :out put library. where we have our dataset.
Notes:
				1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
				2. It is assumed that data set of specified as input_ds has valid specified fileds.
				3. For all output datasets (Viz output_ds),it is assumend that
					a. it has valid name.
					b. Macro has necessary required rights to create the datasets with specified name @ specified location.
					c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.
***************************************************************************/
%macro stability_indices(input_ds=, output_ds=);
/*Code to get stability indices begins here*/
data work.totals;
	set &input_ds end=last;

	prop_act_tot + No_of_ACC_actual;
	prop_dev_tot + No_of_ACC_Dev;

	prop_evt_act_tot + No_of_events_actual;
	prop_evt_dev_tot + No_of_events_Dev;

	if last then do;
	 	call symput('PAT',prop_act_tot);
	 	call symput('PDT',prop_dev_tot);
	 	call symput('PEAT',prop_evt_act_tot);
	 	call symput('PEDT',prop_evt_dev_tot);	
	end;
run;

data &output_ds;
	set work.totals (drop=prop_act_tot prop_dev_tot prop_evt_act_tot prop_evt_dev_tot);
	 /*I18N-scnjih-20080418-0947*/
/*	label Attr_Name=Attribute Name */
/*			Seq_No=Seq No			*/
/*			scorecard_points=Scorecard Points (SP)*/
/*			prop_actual=Attribute Proportion Actual (A)*/
/*			prop_dev=Attribute Proportion Development (B)*/
/*			prop_evt_act=Event Proportion Actual (C)*/
/*			prop_evt_dev=Event Proportion Development (D)*/
/*		    variable_stability_index=Variable Stability Index [(A-B)*(log(A/B))]*/
/*			event_stability_index=Event Stability Index [(C-D)*(log(C/D))];*/
	label Attr_Name= "%sysfunc(sasmsg(smd_ds.bismsg,stability_indices.sas.1, noquote))" 
			Seq_No="%sysfunc(sasmsg(smd_ds.bismsg,stability_indices.sas.2, noquote))" 		
			scorecard_points="%sysfunc(sasmsg(smd_ds.bismsg,stability_indices.sas.3, noquote))" 
			prop_actual="%sysfunc(sasmsg(smd_ds.bismsg,stability_indices.sas.4, noquote))" 
			prop_dev="%sysfunc(sasmsg(smd_ds.bismsg,stability_indices.sas.5, noquote))" 
			prop_evt_act="%sysfunc(sasmsg(smd_ds.bismsg,stability_indices.sas.6, noquote))" 
			prop_evt_dev="%sysfunc(sasmsg(smd_ds.bismsg,stability_indices.sas.7, noquote))" 
		    variable_stability_index="%sysfunc(sasmsg(smd_ds.bismsg,stability_indices.sas.8, noquote))" 
			event_stability_index="%sysfunc(sasmsg(smd_ds.bismsg,stability_indices.sas.9, noquote))" ;
	/*I18N-scnjih-20080418-0947*/
	format scorecard_points &CS_DEC_FMT. prop_actual &CS_DEC_FMT. prop_dev &CS_DEC_FMT.
			prop_evt_act &CS_DEC_FMT. prop_evt_dev &CS_DEC_FMT. 
			variable_stability_index  &CS_DEC_FMT. event_stability_index &CS_DEC_FMT.;
	prop_actual=No_of_ACC_actual/&PAT;
	prop_dev=No_of_ACC_Dev/&PDT;
	prop_evt_act=No_of_events_actual/&PEAT;
	prop_evt_dev=No_of_events_Dev/&PEDT;

	diffV=prop_actual-prop_dev;
	diffE=prop_evt_act-prop_evt_dev;

	ratioV=prop_actual/prop_dev;
	ratioE=prop_evt_act/prop_evt_dev;

	log_ratioV=log(ratioV);
	log_ratioE=log(ratioE);

	variable_stability_index = diffV*log_ratioV;
	event_stability_index = diffE*log_ratioE;

	drop diffV diffE ratioV ratioE log_ratioV log_ratioE;
run;
%mend stability_indices;
