/*
Macro Name	: Lift_Chart
Function	: Generates data for lift chart and Gain's table.
Created by	: BIS Team
Date		: Apr 07, 2006
SAS Version	: 9.1

Called-by	: Called by Lift and Gain screen Stored proc name : Check with Deepa
			 
Calls		: Ar_stat (macro which computes CAP and AR)

Parameters	: 

input_ds		: Name of the input data set
output_graph_ds	: Name of the data set which stores data for graph of events vs non events.

Input Dataset(s) Format: 
--------------------------------------------------------------------------
Name				Type		Format
--------------------------------------------------------------------------
Pool_Name			Character 	Default Formatting	
Pool_Seq	 		Number		Default Formatting
No_Of_ACC_Actual	Number		Default Formatting
No_of_Acc_Dev	 	Number 		Default Formatting
PD	 				Number		Default Formatting
Score_Points	 	Number		Default Formatting
No_Of_Actual_Bads	Number		Default Formatting	
--------------------------------------------------------------------------

Output Dataset(s) Format:
-------------------------------------------------------------------------
Name		Type		Format
------------------------------------------------------------------------
Pool_Seq	Numeric		Default Formatting 
cum_totacc	Numeric		Default Formatting	
Lift		Numeric		7.3
base		Numeric		Default Formatting
--------------------------------------------------------------------------
Logic:
1. From input table generate data for CAP curve using AR_Stat macro.
2. AR_Stat will generate Captured response for actual model and random model
3. Define Lift as ratio of Captured response for actual model and random model
4. Define base as 1 (random model/random model)
5. Obtained lift is gain over random model and monotonic decreasing chart generated is lift chart.

Notes:
1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
2. It is assumed that data set of specified as input_ds has valid specified fileds.
3. For all output datasets (Viz output_ds),it is assumend that
	a. it has valid name.
	b. Macro has necessary required rights to create the datasets with specified name @ specified location.
	c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.

*/
%macro lift_chart(input_ds=,output_graph_ds=);
%let err_code=;
/*****************************************************************/
%check_alldefaults_nodefaults(&input_ds,No_Of_ACC_Actual,No_Of_Actual_Bads, err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/

%ar_stat(input_ds=&input_ds,output_graph_ds= Dist_AR,output_stat_ds=ARStat);

data &output_graph_ds;
	attrib
	/*I18N-scnjih-20080418-0951*/
/*		Lift		label = "Lift Value" format = &CS_DEC_FMT.*/
/*		cum_totacc	label = "Cumulative No. of Accounts" */
/*		Base		label = "Base Value" */
/*		Pool_Seq	label = "Pool Sequence"*/
/*		Ideal		label = "Ideal Value" format = &CS_DEC_FMT.*/
/*	;*/
		Lift		label ="%sysfunc(sasmsg(smd_ds.bismsg,lift_chart.sas.1, noquote))" format = &CS_DEC_FMT.
		cum_totacc	label = "%sysfunc(sasmsg(smd_ds.bismsg,lift_chart.sas.2, noquote))" 
		Base		label = "%sysfunc(sasmsg(smd_ds.bismsg,lift_chart.sas.3, noquote))"
		Pool_Seq	label = "%sysfunc(sasmsg(smd_ds.bismsg,lift_chart.sas.4, noquote))"
		Ideal		label = "%sysfunc(sasmsg(smd_ds.bismsg,lift_chart.sas.5, noquote))" format = &CS_DEC_FMT.
	;
	/*I18N-scnjih-20080418-0951*/
	set Dist_AR;
	Lift = caprespcum/cum_propRan_bads;
	base = cum_propRan_bads/cum_propRan_bads;
	ideal = cum_propIdealBads/cum_propRan_bads;
	keep Pool_Seq cum_totacc Lift base ideal;
run;
/*****************************************************************/
%errorhandler(err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/

%return;
/*****************************************************************/
%Error_Handler:
%put ERROR: &err_code;
%defdata(input_ds=&input_ds,stat='Lift',
		out_graph_ds = &output_graph_ds,output_ds = ,out_stat_ds=);
%mend lift_chart;
