/*
Macro Name	: PD_Vs_Defaultrate
Function	: Generates data for graph of Observed Default rate estimated PD.
Created by	: BIS Team
Date		: Apr 07, 2006
SAS Version	: 9.1

Called-by	:PD vs Default rate chart
			 
Calls		: Ar_stat (macro which computes CAP and AR)

Parameters	: 

input_ds		: Name of the input data set
output_ds	: Name of the data set which stores data for graph graph of Observed Default rate estimated PD.

Input Dataset(s) Format: 
--------------------------------------------------------------------------
Name				Type		Format
--------------------------------------------------------------------------
Pool_Name			Character 	Default Formatting	
Pool_Seq	 		Number		Default Formatting
No_Of_ACC_Actual	Number		Default Formatting
No_of_Acc_Dev	 	Number 		Default Formatting
PD	 				Number		Default Formatting
Score_Points	 	Number		Default Formatting
No_Of_Actual_Bads	Number		Default Formatting	
--------------------------------------------------------------------------
Output Dataset(s) Format:
output_ds
-------------------------------------------------------------------------
Name				Type		Format
------------------------------------------------------------------------
Pool_Name			Character 	Default Formatting	
Pool_Seq	 		Number		Default Formatting
No_Of_ACC_Actual	Number		Default Formatting
No_of_Acc_Dev	 	Number 		Default Formatting
PD	 				Number		Default Formatting
Score_Points	 	Number		Default Formatting
No_Of_Actual_Bads	Number		Default Formatting	
ObsPD				Numeric		Default Format
Ratio				Numeric		Default Format
------------------------------------------------------------------------

Logic:
1. Compute default rate as #Bads in pool /# actual accounts in a pool for every pool
2. TO compute overall deviation between Default rate and Pd compute ABS(log (Default rate/ PD))
3. If you sum all the such ratios you will get Total deviance from expected pd for a modelling scheme.

Notes:
1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
2. It is assumed that data set of specified as input_ds has valid specified fileds.
3. For all output datasets (Viz output_ds),it is assumend that
	a. it has valid name.
	b. Macro has necessary required rights to create the datasets with specified name @ specified location.
	c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.

*/
%macro pd_vs_defaultrate(input_ds=, output_ds=);
%let err_code=;
/*****************************************************************/
%check_alldefaults_nodefaults(&input_ds,No_Of_ACC_Actual,No_Of_Actual_Bads, err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/

data &output_ds;
	set &input_ds;
	ObsPD = No_Of_Actual_Bads/No_Of_Acc_Actual;
	Ratio = Abs(log(ObsPD/PD));

	attrib
	/*I18N-scnjih-20080418-1048*/
/*	Pool_Name			label = "Pool Name"*/
/*	No_Of_Acc_Actual 	label = "No. of Accounts Actual"*/
/*	No_of_ACC_Dev		label = "No. of Accounts Development"*/
/*	No_of_Actual_Bads	label = "No. of Actual Bads"*/
/*	Ratio				label = "Observed v/s Estimated Index [Abs(log(A/B))]"*/
/*	ObsPd				label = "Default Rate (A)"*/
/*	PD					label = "Estimated PD (B)"*/
/*	score_points		label = "Score Points"*/
/*	;*/
	Pool_Name			label =  "%sysfunc(sasmsg(smd_ds.bismsg,pd_vs_defaultrate.sas.1, noquote))"
	No_Of_Acc_Actual 	label = "%sysfunc(sasmsg(smd_ds.bismsg,pd_vs_defaultrate.sas.2, noquote))"
	No_of_ACC_Dev		label = "%sysfunc(sasmsg(smd_ds.bismsg,pd_vs_defaultrate.sas.3, noquote))"
	No_of_Actual_Bads	label = "%sysfunc(sasmsg(smd_ds.bismsg,pd_vs_defaultrate.sas.4, noquote))"
	Ratio				    label = "%sysfunc(sasmsg(smd_ds.bismsg,pd_vs_defaultrate.sas.5, noquote))"
	ObsPd				label = "%sysfunc(sasmsg(smd_ds.bismsg,pd_vs_defaultrate.sas.6, noquote))"
	PD					label = "%sysfunc(sasmsg(smd_ds.bismsg,pd_vs_defaultrate.sas.7, noquote))"
	score_points		label ="%sysfunc(sasmsg(smd_ds.bismsg,pd_vs_defaultrate.sas.8, noquote))"
	;
	/*I18N-scnjih-20080418-1048*/
run;
/*****************************************************************/
%errorhandler(err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/

%return;
/*****************************************************************/
%Error_Handler:
%put ERROR: &err_code;
%defdata(input_ds=&input_ds,stat='PD_Def',
		out_graph_ds =,output_ds = &output_ds,out_stat_ds=);

%mend pd_vs_defaultrate;
