/******************************************************************************************************
       Module:  feed_table

     Function:  This stored process creates the HTML table of dataste passed.
				If labels are passed into the macro, then they are used. 
				Otherwise, the labels are picked up from the input dataset.

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All reports which need a table on the screen
        Calls:  NA

Datasets used:  Supplied as the parameter
                The input dataset may have any structure. Only the columns passed into the macro
				should exist in the input dataset and these columns will be shown on screen.
                
         Logic: 1.Take dataset as input and depending upon number of dataset passed it creates 
				  Number of tables in HTML for that dataset.
                2.Path provide for file _webout to out put the dataset. 
				3.Uses name given to diffrent dataset to be displayed.
				4.Calls Macor draw_table_feed.
				5.Display the table on screen using the column labels as the table headers and the
				   data from the selected columns as the data in the table.
				
   Parameters:  INPUT (From Report Screen when link is used for navigation) 

				1.	ds         : Name of dataset to be passed in the macro. This is 
       			 				 the out dataset of feed macro. In case of multiple 
	    		 				 dataset pass the name of dataset separated by #.

				2.	out_lib1   :out put library. where we have our dataset.

				3.	data_name  :This is this parameter where you pass name 
               					for the dataset. This will appear on top of band.
                				In case of multiple dataset, pass name separated
                				By #. 

				4. name_html   :Here we pass the name of html.By this name HTML will be created 
			    				on specified location 
	NOTE:  This macro contains tags for created table and style sheet also. This could be 
		   used separately.Dataset name and dataset if multiple should be passed separated by #. 
		   Name, which is to be displayed on HTML and is passed as parameter,is not 
		   allowed to contain # sign.
******************************************************************************************************/

%macro feed_table(ds=,out_lib1=,data_name=,name_html=);

%let token=;/****Here we collect value of each dataset separated by #******/
%let token_nm=;/*Here we collect value of each dataset name separated by #*/

/********Here we count number of datsaset seperated by '# 'taken as counter *********/

%let b = 0;
data _null_;
	cnt = count("&data_name","#");
	call symput ('b',cnt);	
run;

%let end=%eval(&b+1);/*We are evaluating value of  b in variable "end " is used in every loop**/

/**CS_REPORT_PATH  :A parameter defined in Auto exe file.This will put this html 
					in path given in CS_REPORT_PATH and then we append the name of html 
					what we have accepted in the parameter passed in feed_macro as name_html
*******************************/

%let path1=%scan(&CS_REPORT_PATH,1,%str(%'));
%let path="&path1/&name_html";  
data _null_;
 
/*I18N-scnhuh-20080422-1631*/

	    file &path &webout_options;
/*I18N-scnhuh-20080422-1631*/  
		put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" '@;
		put '"http://www.w3.org/TR/html4/loose.dtd"> ';
		put '<html> ';
		put '<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
		put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/		
	 /*I18N-scnjih-20080425-1313*/
		/*put '<title>Feed</title>';*/
			put '<title>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,feed_table.sas.3, noquote))"@;
			put '</title>';		
	 /*I18N-scnjih-20080425-1313*/
		put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css"> ';
		put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css"> ';
		put '<style type="text/css"> ';
		put '<!-- ';
		put '.style2 {font-size: small} ';
		put '--> ';
		put '</style> ';
		put '<body>';
		put '<form>';
		put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED"> ';
		put '<tr> ';
	run;
/******Count for this do loop is taken by counting number of dataset separated by #
	value is taken in a macro variable end, defined above.*/
	%do i = 1 %to &end;
			%let token = %scan(&ds,&i,#);
			%let token_nm = %scan(&data_name,&i,#);
		proc sql noprint;
			select name 
			into :col_name separated by ","
			from sashelp.vcolumn
			where libname=UPCASE("&out_lib1") and memname=UPCASE("&token"); 
		quit;
				%let cl_names=%nrquote(&col_name);
				%let cl_labels=%nrquote();


			%if &i=1 %then %do;
				%let path="&path1&name_html";  
			%end;

			%else %do;
				%let path="&path1&name_html" mod;  
			%end;


	options mlogic mprint;

	

	%if &i=1 %then %do;
		data _null_;
 
/*I18N-scnhuh-20080422-1631*/

		    file &path  &webout_options mod;
/*I18N-scnhuh-20080422-1631*/
			put '<td align="right"> ';
			put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0"> ';
			put '<tr> ';
		 	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
			put '<tr> ';
			put '<td>&nbsp;</td>';
			put '<td width="215"><div align="right"><img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td> ';
			put '</tr></table>';
		run;
	%end;
	%else %do;
	data _null_;
 
/*I18N-scnhuh-20080422-1631*/

		    file &path &webout_options mod;
/*I18N-scnhuh-20080422-1631*/
			put '<td align="right"> ';
			put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0"> ';
			put '<tr> ';
		 	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
			put '<tr> ';
			put '<td>&nbsp;</td>';
			put '<td width="215"><div align="right"></div></td> ';
			put '</tr></table>';
	run;
	%end;

	 data _null_;
 
/*I18N-scnhuh-20080422-1631*/

	    file &path &webout_options mod;	    /******Here we pass name of dataset given in token_nm*********/
/*I18N-scnhuh-20080422-1631*/
			put '<H2 align="left">';put "&token_nm";  put'</H2></td> ';
			put '</tr> ';
			put '<tr><td>';
			put '<p class="LabelFont">&nbsp;</p> ';

		run;
/********Macro  draw_table_feed.This create table of dataset passsed.
		   Here we pass name of Dataset name what we have taken in token.
		   this will create dataset in loop.

		Parameter Passed

		1.ds			: Dataset name with the out library.
		2.col_names     : Column  name in  dataset 
		3.col_labels    : Column  lables
		4.Path          : where to web out the created HTML, this is same as above.it will
						  take value from parameter you pass in macro feed_table **/

			%draw_table_feed(ds=&out_lib..&token.,col_names=&cl_names,col_labels=&cl_labels,file_path=&path);

		data _null_;
 
/*I18N-scnhuh-20080422-1631*/

		file &path &webout_options mod;
/*I18N-scnhuh-20080422-1631*/
			put'<p>&nbsp;</p><div align="left">';
			put '<p class=NoteFont>'@;
				 /*I18N-scnjih-20080421-1314*/
/*			put '<strong>Note:</strong> All pools with no actual and development information will be ignored</p>';*/
			put '<strong>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,feed_table.sas.1, noquote))"@;
			put '</strong>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,feed_table.sas.2, noquote))"@;
			put '</p>';
      		/*I18N-scnjih-20080421-1314*/
			put'</div>';
			put '</td> ';
			put '</tr> ';
			put '</table> ';
			put '<tr><td><p>&nbsp;</p></td></tr> ';
			put '</td></tr> ';

		run;
	%if &i =&end %then %do;
		data _null_;
 
/*I18N-scnhuh-20080422-1631*/

		file &path &webout_options mod;
/*I18N-scnhuh-20080422-1631*/
			put '<tr> ';
			put '<td height="32" bgcolor="#F1EACB">&nbsp;&nbsp;';
			put '</td>';
			put '</tr>';
	 	run;
	%end;
%end;/*Do loop end here */
		data _null_;
 
/*I18N-scnhuh-20080422-1631*/

		file &path &webout_options mod;
/*I18N-scnhuh-20080422-1631*/
			put '</table> ';
			put '</form> ';
			put '</body> ';
			put '</html> ';
		run;


%mend feed_table;
