/******************************************************************************************************
       Module:  graph_options

     Function:  This macro sets the graph options uniformly across all reports.

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All Report screens that have a graph
        Calls:  NA

Datasets used:  No input datasets required for processing of the stored process
 
        Logic:  It sets all the graph options for all reports and selects the colors to be used when
				rendering the graph. To access the colors being set in this macro, the respective macro
				variables for the colors should be created in the calling program. This macro only sets
				the values in the macro variables.

				This macro sets the out path of the gifs to the folder created in the environment which
				will be shared between the server layer and web layer. This is picked up from the macro
				variable CS_REPORT_PATH in the bis_customize_para.sas.
				
   Parameters:  INPUT
				None

				OUTPUT
				color_symbol1	: Color 1
				color_symbol2	: Color 2
				color_symbol3	: Color 3
				color_symbol4	: Color 4
				color_symbol5	: Color 5
				color_symbol6	: Color 6
				color_symbol7	: Color 7
				color_symbol8	: Color 8
				color_symbol9	: Color 9
				color_symbol10	: Color 10
				color_symbol20	: Color 20(Used only in KS graph)

******************************************************************************************************/
%macro graph_options;
filename odsout &CS_REPORT_PATH;
ods listing close;
ods html path=odsout style=default gpath=odsout nogtitle gfootnote;
/*I18N-scnhuh-20080428-1010*/
/*change ftitle ftext*/
goptions NOCHARACTERS reset=global gunit=pct border cback=white xpixels= 460 ypixels=200
             device=gif goutmode=replace gsfname=odsout
             colors=(black cx7C95CA cxCF974B cxCD7BA1 cx588526 cxB00F14)
             ftitle=swissb ftext=simplex htitle=10 htext=5;
/*			ftitle='mincho' ftext='mincho' */
/*I18N-scnhuh-20080428-1010*/
/* Set Colors */
%let color_symbol1=cx7C95CA;
%let color_symbol2=cxCF974B;
%let color_symbol3=cxCD7BA1;
%let color_symbol4=cx66A5A0;
%let color_symbol5=cxB00F14;
%let color_symbol6=cx588526;
%let color_symbol7=cxB689CD;
%let color_symbol8=cx94BDE1;
%let color_symbol9=cxBABC5C;
%let color_symbol10=cxDE7E6F;
%let color_symbol20=white; /* specifically for the KS graph */

/* specific for Overtime graphs */

%let color_overtime_red=cxFFEAEC; /* Red */
%let color_overtime_yellow=cxFFFFDD; /* Yellow */
%let color_overtime_green=cxDDFFDD; /* Green */
%mend graph_options;

