%macro load_lgd_model_measure_fact(model=,tgtprd=,time=,dev_flg=,product_type_cd=);

proc sql noprint;
	select 	MEASURE_SK, measure_cd into :measure_sk_list separated by "#"  
	, :measure_cd_lst  separated by "#" 
	from dim.Measure_dim
	where MODEL_TYPE_CD=&model_type. and PRODUCT_TYPE_CD="&product_type_cd."
	;
quit;

%if &dev_flg eq %str(Y) %then %do;
	proc sql noprint;
		select CUT_OFF_SCORE into :cut_off 
		from martscr.analytical_model_dim_ext
		where model_sk=&model;

		create table work.out_mdl_act as
		SELECT POOL_SK, ACCOUNT_SK as account_sk, 
			case when actual_lgd > estimated_account_lgd then 1 else . end as ACTUAL_GOOD_BAD, 
			ACTUAL_LGD, ESTIMATED_ACCOUNT_LGD
		FROM fact.model_dev_fact
		where model_sk=&model
		order by 1;

		create table work.mdl_data as
		select POOL_SK, COUNT(ACCOUNT_SK) AS NO_OF_ACCOUNT_ACTUAL, 
			avg(ESTIMATED_ACCOUNT_LGD) as estimated_lgd, MAX(ACTUAL_LGD) as actual_lgd,
			SUM(ACTUAL_GOOD_BAD) as NO_OF_ACTUAL_BADS
		from work.out_mdl_act
		group by POOL_SK;
		
		create table work.mdl_data_seq as
		select mdl_data.*, pool_dim.pool_seq_no as pool_seq_no
		from work.mdl_data, dim.pool_dim
		where mdl_data.pool_sk = pool_dim.pool_sk;
	quit;

	/*Pool level feed */
	proc sql;
	create table work.out_mdl_lgd_pool AS
	select POOL_SK as pool_name, pool_seq_no as pool_seq,
		&epsilon as no_of_acc_dev, 
		coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual, 
		ACTUAL_LGD as actual_lgd, estimated_lgd, 
		NO_OF_ACTUAL_BADS as no_of_actual_bads
	FROM work.mdl_data_seq
	order by 2;
	quit;

	/*Account level feed */
	proc sql;
	create table work.out_mdl_lgd_account AS
	SELECT ACCOUNT_SK, ACTUAL_LGD, ESTIMATED_ACCOUNT_LGD as estimated_lgd
	FROM work.out_mdl_act;
	quit;

	%let err_code=;
	%check_alldefaults_nodefaults(work.out_mdl_lgd_pool,No_Of_ACC_Actual,
		No_Of_Actual_Bads, err_code);

	%if (&err_code ne 'NONE')%then %do;
		%let cnt=1;
		%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
		%do %while(&measure_sk_list_insert ne %str());
			%if  &measure_cd_id_rslv.  ne   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_system_stability_index.1, noquote))
					and &measure_cd_id_rslv.  ne   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_confidence_interval.1, noquote))    
				%then %do;
				proc sql;
					insert into fact.MODEL_MEASURE_FACT
					(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG) 
					values(&model, &time, &measure_sk_list_insert, ., 'Y')
					;
				quit;
			%end;
			%let cnt=%eval(&cnt+1);
			%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
		%end;		
	%end;

	%else %do;
		%ar_stat(input_ds=work.out_mdl_lgd_pool,output_graph_ds=work.graph_ar,output_stat_ds=work.ar);
		%errormeasures(input_ds=out_mdl_lgd_pool,input_ds_estvar=Estimated_LGD,input_ds_actvar=Actual_LGD,output_ds=work.mse_mad);
		%mape(input_ds=out_mdl_lgd_pool,input_ds_estvar=Estimated_LGD,input_ds_actvar=Actual_LGD,output_ds=work.mape);
		%chisq(input_ds=out_mdl_lgd_pool,input_ds_estvar=Estimated_LGD,input_ds_actvar=Actual_LGD,output_ds=work.chisq);
		%corr (input_ds=out_mdl_lgd_pool,input_ds_estvar= Estimated_LGD,input_ds_actvar=Actual_LGD,output_ds=work.corr);

		proc sql noprint;
			select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ar.1, noquote)) 
				into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ar.1, noquote)) 
				from work.ar;
			select 
				%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mse.1, noquote)), 
				%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mad.1, noquote)) 
				into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mse.1, noquote)), 
					 :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mad.1, noquote)) 
				from work.mse_mad;
			select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mean_absoute_percent_error.1, noquote)) 
				into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mean_absoute_percent_error.1, noquote)) 
				from work.mape;
			select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote)) 
				into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote)) 
				from work.chisq;
			select measure_value 
				into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_corr.1, noquote)) 
				from work.corr;
		quit;

		proc sql noprint;
			select count(*) into :cnt_recs
			from fact.MODEL_MEASURE_FACT
			where MODEL_SK=&model and  SCORE_TIME_SK = &time and DEV_FLG='Y';
		quit;

		%if &cnt_recs = 0 %then %do;
			%let cnt=1;
			%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);

			%do %while(&measure_sk_list_insert ne %str());
				%let measure_cd_id_rslv=%qscan(&measure_cd_lst,&cnt,#);

				%if  &measure_cd_id_rslv.  ne   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_system_stability_index.1, noquote))
						and &measure_cd_id_rslv.  ne   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_confidence_interval.1, noquote))    
					%then %do;
					data _null_;
						length resolved_measure_id 8;
						if resolve("&&&measure_cd_id_rslv") = "" then
							resolved_measure_id=.;
						else
							resolved_measure_id=input(resolve("&&&measure_cd_id_rslv"),best32.);
						call symput('resolved_measure_id',resolved_measure_id);
					run;

					proc sql;
						insert into fact.MODEL_MEASURE_FACT 
						(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
							values(&model, &time, &measure_sk_list_insert, &resolved_measure_id, 'Y')
						;
					quit;	
				%end;
				%let cnt=%eval(&cnt+1);
				%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
	 		%end;
		%end;
	%end;
%end;
%else %do;
	%let start_time = %eval(&time - &tgtprd);
	%let end_time = %eval(&time);
	
	%if &start_time > 0 %then %do;
		%do i = &start_time %to &end_time;

			%put start_time=start_time.;
			%put trg_prd=&tgtprd.;

			%let itime=%sysfunc(ktrim(%sysfunc(kleft(&i))));
			%let suff=_&model._&itime;
			%let suff=%sysfunc(ktrim(%sysfunc(kleft(&suff))));

			%if %sysfunc(exist(fact.ACCOUNT_LGD_FACT&suff.)) %then %do;
			%generate_feed(in_filter=, out_lib_nm=work, out_table_nm_pool=out_lgd_pool, 
				out_table_nm_acct=out_lgd_account, feed_for=&FEED_FOR_LGD, long_run=&LONG_RUN,
				pd_score=, range_interval=, no_of_quantile=, long_run_type=&LONG_RUN_TYPE, 
				model_time_key=&suff,product_type_code=&product_type_cd.);
						%let err_code=;
				%check_alldefaults_nodefaults(work.out_lgd_pool,No_Of_ACC_Actual,No_Of_Actual_Bads, err_code);

				 %if (&err_code ne 'NONE')%then %do;

					%if &i eq &time %then %do;
						%let cnt=1;
						%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
						%do %while(&measure_sk_list_insert ne %str());
							proc sql;
								insert into fact.MODEL_MEASURE_FACT
								(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG) 
								values(&model, &i., &measure_sk_list_insert, ., 'N')
								;
							quit;
							%let cnt=%eval(&cnt+1);
							%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
						%end;
					%end;
				 %end;
				 %else %do;
					%ssi(input_ds=work.out_lgd_pool,output_ds=work.ssi);
					%ar_stat(input_ds=work.out_lgd_pool,output_graph_ds=work.graph_ar,output_stat_ds=work.ar);
					%errormeasures(input_ds=work.out_lgd_pool,input_ds_estvar=Estimated_LGD,input_ds_actvar=Actual_LGD,output_ds=work.mse_mad);
					%mape(input_ds=work.out_lgd_pool,input_ds_estvar=Estimated_LGD,input_ds_actvar=Actual_LGD,output_ds=work.mape);
					%chisq(input_ds=work.out_lgd_pool,input_ds_estvar=Estimated_LGD,input_ds_actvar=Actual_LGD,output_ds=work.chisq);
					%corr (input_ds=work.out_lgd_pool,input_ds_estvar= Estimated_LGD,input_ds_actvar=Actual_LGD,output_ds=work.corr);

					proc sql noprint;
						select sum(SIndex) 
							into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_system_stability_index.1, noquote)) 
							from work.ssi;
							select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ar.1, noquote)) 
								into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ar.1, noquote)) 
								from work.ar;
							select 
								%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mse.1, noquote)), 
								%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mad.1, noquote)) 
								into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mse.1, noquote)), 
									 :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mad.1, noquote)) 
								from work.mse_mad;
							select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mean_absoute_percent_error.1, noquote)) 
								into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mean_absoute_percent_error.1, noquote)) 
								from work.mape;
							select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote)) 
								into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote)) 
								from work.chisq;
							select measure_value 
								into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_corr.1, noquote)) 
								from work.corr;
					quit;

					proc sql noprint;
						select count(*) into :cnt_recs
						from fact.MODEL_MEASURE_FACT
						where MODEL_SK=&model and SCORE_TIME_SK = &i and DEV_FLG='N';
					quit;

					%if &cnt_recs = 0 %then %do;
						%let cnt=1;
						%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
						%do %while(&measure_sk_list_insert ne %str());
							%let measure_cd_id_rslv=%qscan(&measure_cd_lst,&cnt,#);

					        data _null_;
							  length resolved_measure_id 8;
							  if resolve("&&&measure_cd_id_rslv") = "" then
							     resolved_measure_id=.;
							  else
							     resolved_measure_id=input(resolve("&&&measure_cd_id_rslv"),best32.);
							 
							  call symput('resolved_measure_id',resolved_measure_id);
							run;

							%if  &measure_cd_id_rslv.  eq   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_confidence_interval.1, noquote))    
								%then %do;

	 							proc sql;
								 insert into fact.MODEL_MEASURE_FACT 
								(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
									values(&model, &i., &measure_sk_list_insert,1, 'N')
								;
							%end;
							%else %do;
								 proc sql;
								 insert into fact.MODEL_MEASURE_FACT 
								(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
									values(&model, &i., &measure_sk_list_insert,&resolved_measure_id, 'N')
								;
							%end;							
							quit;
							%let cnt=%eval(&cnt+1);
							%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
						%end;
					%end;

					%else %do;
						data work.updfact;
						set fact.MODEL_MEASURE_FACT;
							stop;
						run;
	/* Create temp table structure to be used later for update */
						%let cnt=1;
						%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
						%do %while(&measure_sk_list_insert ne %str());
							%let measure_cd_id_rslv=%qscan(&measure_cd_lst,&cnt,#);

					        data _null_;
							  length resolved_measure_id 8;
							  if resolve("&&&measure_cd_id_rslv") = "" then
							     resolved_measure_id=.;
							  else
							     resolved_measure_id=input(resolve("&&&measure_cd_id_rslv"),best32.);
							 
							  call symput('resolved_measure_id',resolved_measure_id);
							run;

							%if  &measure_cd_id_rslv.  eq   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_confidence_interval.1, noquote))    
								%then %do;

	 							proc sql;
								 insert into work.updfact 
								(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
									values(&model, &i., &measure_sk_list_insert,1, 'N')
								;
							%end;
							%else %do;
								 proc sql;
								 insert into work.updfact 
								(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
									values(&model, &i., &measure_sk_list_insert,&resolved_measure_id, 'N')
								;
							%end;							
							quit;
							%let cnt=%eval(&cnt+1);
							%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
						%end;

						/* All records for the MEASURE_VALUE field in MODEL_MEASURE_FACT 
						are updated by going N months back from the scoring month,
						where N is the target period months count */

						/* The following UPDATE uses a correlated query */
							proc sql;
								update fact.MODEL_MEASURE_FACT m
								set MEASURE_VALUE = 
									(select MEASURE_VALUE from work.updfact where MEASURE_SK = m.MEASURE_SK)
								where SCORE_TIME_SK = &i and MODEL_SK = &model and DEV_FLG = 'N';
							quit;
					%end;
				 %end;
			%end;
		%end;
	%end;
%end;
%mend load_lgd_model_measure_fact;
