%macro load_pd_score_card_variable_fact(model=,time=,tgtprd=,time_date=,dev_flg=,
										product_type_cd=,model_type_val=);

proc sql noprint;
	select 	MEASURE_SK, measure_cd into :measure_sk_list separated by "#"  
	, :measure_cd_lst  separated by "#" 
	from dim.Measure_dim
	where MODEL_TYPE_CD=&model_type. and PRODUCT_TYPE_CD="&product_type_cd."
	;
quit;

%put *************&measure_sk_list.;
%if &dev_flg eq %str(Y) %then %do;
	%let var_list=;
	proc sql noprint;

		select distinct variable_sk into :var_list separated by " "
		from dim.SCORE_CARD_DIM 
		where model_sk=&model;
	quit;
 
	%let tgt_time = .;
	proc sql noprint;
		select time_sk into :tgt_time
		from dim.TIME_DIM
		where CAL_MONTH_LAST_DT = INTNX('MONTH',&time_date,&tgtprd,'END');
	quit;
	%let tgt_time =&tgt_time;

	%let var_sk=%str();
	%let var_cnt = 1;
	%let var_sk=%qscan(&var_list,&var_cnt);
	%do %while(&var_sk ne %str());
		proc sql;
			CREATE TABLE work.out_inp_mdl_pool_sql AS
			SELECT SCORE_CARD_DIM.MODEL_SK as MODEL_SK,
				SCORE_CARD_VARIABLE_DIM.VARIABLE_NAME AS VAR_NAME,
				SCORE_CARD_DIM.VARIABLE_GROUP_LABEL AS ATTR_NAME, 
				SCORE_CARD_DIM.NO_OF_ACCOUNTS AS NO_OF_ACC_DEV,
				SCORE_CARD_DIM.NO_OF_DEFAULTS AS NO_OF_EVENTS_DEV,
				SCORE_CARD_DIM.SCORE_CARD_POINTS AS SCORECARD_POINTS,
				SCORE_CARD_DIM.AVERAGE_SCORE AS AVERAGE_SCORE,
				SCORE_CARD_DIM.VARIABLE_GROUP_NO AS SEQ_NO				
			FROM dim.SCORE_CARD_DIM 
			INNER JOIN dim.SCORE_CARD_VARIABLE_DIM
			ON (SCORE_CARD_DIM.VARIABLE_SK = SCORE_CARD_VARIABLE_DIM.VARIABLE_SK)
			where SCORE_CARD_DIM.model_sk=&model and 
				SCORE_CARD_VARIABLE_DIM.VARIABLE_SK=&var_sk;

			/* Attribute level data */
			CREATE TABLE work.out_inp_mdl_pool AS
			SELECT VAR_NAME, ATTR_NAME, SEQ_NO,
				MAX(SCORECARD_POINTS) AS SCORECARD_POINTS, 
				MAX(&epsilon) AS NO_OF_ACC_DEV, 
				MAX(&epsilon) AS NO_OF_EVENTS_DEV, 
				MAX(AVERAGE_SCORE) AS AVERAGE_SCORE_DEV, 
				MAX(NO_OF_ACC_DEV) AS NO_OF_ACC_ACTUAL,
				MAX(NO_OF_EVENTS_DEV) AS NO_OF_EVENTS_ACTUAL
			FROM work.out_inp_mdl_pool_sql
			GROUP BY VAR_NAME, ATTR_NAME, SEQ_NO;
		quit;

		%let err_code=;
		%check_alldefaults_nodefaults(work.out_mdl_applpd_pool,No_Of_ACC_Actual,
			NO_OF_EVENTS_ACTUAL, err_code);
		%put **********ERROR_CODE***&err_code;
		%put *******i***&i***end_time***&end_time*****time***********&time;

		%if (&err_code ne 'NONE')%then %do;
			%let cnt=1;
			%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
			%do %while(&measure_sk_list_insert ne %str());
				proc sql;
					insert into fact.SCORE_CARD_VARIABLE_FACT
					(VARIABLE_SK, MODEL_SK, SCORE_TIME_SK, TARGET_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG) 
					values(&var_sk, &model, &time, &tgt_time, &measure_sk_list_insert,., 'Y')
					;
				quit;
				%let cnt=%eval(&cnt+1);
				%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
			%end;		
		%end;
		%else %do;
			%info_woe(input_ds=work.Out_inp_mdl_pool, input_Acc_var=NO_OF_ACC_ACTUAL, input_Events_var=NO_OF_EVENTS_ACTUAL,Output_ds=work.info);
			%gini_index(input_ds=work.Out_inp_mdl_pool,Output_ds=work.gini);
			%ks(input_ds=work.Out_inp_mdl_pool, out_graph_ds=work.ks);


			proc sql noprint;
				select distinct Infoval
					into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_info_val_stats.1, noquote))  
					from work.info;
				select distinct gini 
					into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_gini_index.1, noquote)) 	
					from work.gini;
				select max(%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ks.1, noquote))) 
					into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ks.1, noquote)) 
					from work.ks;
			quit;

			proc sql noprint;
				select count(*) into :cnt_recs
				from fact.Score_card_variable_fact
				where MODEL_SK=&model and  SCORE_TIME_SK = &time and DEV_FLG='Y';
			quit;

			%if &cnt_recs = 0 %then %do;
				%let cnt=1;
				%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
				%put ********Measure count******&measure_sk_list_insert.;
				%do %while(&measure_sk_list_insert ne %str());
					%let measure_cd_lst_rslv=%qscan(&measure_cd_lst,&cnt,#);

					data _null_;
						length resolved_measure_id 8;
						if resolve("&&&measure_cd_lst_rslv") = "" then
						 resolved_measure_id=.;
						else
						 resolved_measure_id=input(resolve("&&&measure_cd_lst_rslv"),best32.);
						call symput('resolved_measure_id',resolved_measure_id);
					run;
					proc sql;
					insert into fact.SCORE_CARD_VARIABLE_FACT 
					(VARIABLE_SK, MODEL_SK, SCORE_TIME_SK, TARGET_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
					values(&var_sk, &model, &time, &tgt_time, &measure_sk_list_insert, &resolved_measure_id, 'Y')
					;
					quit;	
				%let cnt=%eval(&cnt+1);
				%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
		 		%end;
			%end;


			%let var_cnt=%eval(&var_cnt+1);
			%let var_sk=%qscan(&var_list,&var_cnt);
		%end;
	%end;
%end;
%else %do;
	%let tgt_time = .;
	%let var_list=;
	%put **********&tgtprd.;
	proc sql noprint;

		select distinct variable_sk into :var_list separated by " "
		from dim.SCORE_CARD_DIM 
		where model_sk=&model;
	quit;

	%let tgt_time = %sysfunc(ktrim(%sysfunc(kleft(&tgt_time))));
	%let start_time = %eval(&time - &tgtprd);/* "time" is time_sk for the current month. tgt is target period.*/
	%let end_time = %eval(&time);			   /* tgt_time is the target time_sk.*/
	%put ***start_time******&start_time.;
	%put ***end_time******&end_time.;
	%if &start_time > 0 %then %do;
		%do i = &start_time %to &end_time;

			%let itime=&i;
			%let suff=_&model._&itime;
			%let suff=&suff;
			
			proc sql noprint;
				select time_sk into :tgt_time
				from dim.TIME_DIM
				where CAL_MONTH_LAST_DT = INTNX('MONTH',&time_date,&tgtprd,'END');/*&itime*/
			quit;


			
			%let var_sk=%str();
			%let var_cnt=1;
			%let var_sk=%qscan(&var_list,&var_cnt);
			%let suff=%sysfunc(ktrim(%sysfunc(kleft(&suff))));
			%put ************&suff.;	
	    	%put ***MDl_NM********&model.*****TIME*****&time****TABLE***fact.ACCOUNT_PD_FACT_&model._&i.;
			%if %sysfunc(exist(fact.Score_card_fact&suff.))  %then %do;
				%do %while(&var_sk ne %str());
/*					%if &model_type=%str('MIP') %then */
/*						%generate_feed_mip(in_filter=1, out_lib_nm=work, out_table_nm_pool=out_inp_pool, */
/*							out_table_nm_acct=out_inp_account, feed_for=&FEED_FOR_PD, var=&var_sk, */
/*							model_time_key=&suff);*/
/*					%else %if &model_type=%str(&PD_APP_MODEL) %then */
						%generate_feed_mip(in_filter=1, out_lib_nm=work, out_table_nm_pool=out_inp_pool, 
							out_table_nm_acct=out_inp_account, feed_for=&FEED_FOR_APPLPD, var=&var_sk, 
							model_time_key=&suff);

						%let err_code=;
						%check_alldefaults_nodefaults(work.out_inp_pool,No_Of_ACC_Actual,No_Of_Actual_Bads, err_code);
						%put **********ERROR_CODE***&err_code;

						 %if (&err_code ne 'NONE')%then %do;
							%if &i eq &time %then %do;
								%let cnt=1;
								%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
								%do %while(&measure_sk_list_insert ne %str());
									proc sql;
										insert into fact.MODEL_MEASURE_FACT
										(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG) 
										values(&model, &i., &measure_sk_list_insert, ., 'N')
										;
									quit;
									%let cnt=%eval(&cnt+1);
									%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
								%end;
							%end;
						%end;
						%else %do;
							%shift_indices(input_ds=work.out_inp_pool,output_ds=work.shift);
							%stability_indices(input_ds=work.out_inp_pool, output_ds=work.stability);
							%info_woe(input_ds=work.out_inp_pool, input_Acc_var=NO_OF_ACC_ACTUAL, input_Events_var=NO_OF_EVENTS_ACTUAL,Output_ds=work.info);
							%gini_index(input_ds=work.out_inp_pool,Output_ds=work.gini);
							%get_chi_square_table(input_ds=work.out_inp_pool,output_ds=work.chi);
							%ks(input_ds=work.out_inp_pool, out_graph_ds=work.ks);


							proc sql noprint;
								select sum(score_shift_index) 
									into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_score_shift_index.1, noquote)) 
									from work.shift;
								select sum(event_shift_index) 
									into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_event_shift_index.1, noquote)) 
									from work.shift;
								select sum(variable_stability_index) 
									into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_var_stb_index.1, noquote)) 
									from work.stability;
								select sum(event_stability_index) 
									into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_event_stab_index.1, noquote)) 
									from work.stability;
								select distinct Infoval 
									into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_info_val_stats.1, noquote)) 
									from work.info;
								select distinct gini 
									into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_gini_index.1, noquote)) 
									from work.gini;
								select distinct 
									p_value format=6. 
									into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_person_chi_sq.1, noquote)) 
									from work.chi;
								select max(%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ks.1, noquote))) 
									into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ks.1, noquote)) 
									from work.ks;
							quit;
							proc sql noprint;
								select count(*) into :cnt_recs
								from fact.Score_card_variable_fact
								where MODEL_SK=&model and DEV_FLG='N'
									and SCORE_TIME_SK=&i.;
							quit;
							%put *******HERE***************&cnt_recs.;
							%if &cnt_recs = 0 %then %do;
								%let cnt=1;
								%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
								%put ********Measure count******&measure_sk_list_insert.;
								%do %while(&measure_sk_list_insert ne %str());
									%let measure_cd_lst_rslv=%qscan(&measure_cd_lst,&cnt,#);

									data _null_;
										length resolved_measure_id 8;
										if resolve("&&&measure_cd_lst_rslv") = "" then
										 resolved_measure_id=.;
										else
										 resolved_measure_id=input(resolve("&&&measure_cd_lst_rslv"),best32.);
										call symput('resolved_measure_id',resolved_measure_id);
									run;
												%if  &measure_cd_lst_rslv.  eq   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_attrib_evt_scr.1, noquote))    
													or	 &measure_cd_lst_rslv.  eq   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_attrib_prop_scr.1, noquote))  
													%then %do;
						 							proc sql;
													 insert into fact.SCORE_CARD_VARIABLE_FACT 
													(VARIABLE_SK, MODEL_SK, SCORE_TIME_SK, TARGET_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
														values(&var_sk, &model, &time, &tgt_time, &measure_sk_list_insert,1, 'N')
													;
												%end;
												%else %do;
													 proc sql;
													 insert into fact.MODEL_MEASURE_FACT 
													(VARIABLE_SK, MODEL_SK, SCORE_TIME_SK, TARGET_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
													values(&var_sk, &model, &time, &tgt_time, &measure_sk_list_insert,&resolved_measure_id, 'N')
													;
												%end;		
								%let cnt=%eval(&cnt+1);
								%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
						 		%end;
							%end;
							%else %do;
				/* Create temp table structure to be used later for update */
								data work.updfact;
								set fact.SCORE_CARD_VARIABLE_FACT;
									stop;
								run;
										%let cnt=1;
										%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
										%put ********Measure count******&measure_sk_list_insert.;
										%do %while(&measure_sk_list_insert ne %str());
											%let measure_cd_lst_rslv=%qscan(&measure_cd_lst,&cnt,#);

											data _null_;
												length resolved_measure_id 8;
												if resolve("&&&measure_cd_lst_rslv") = "" then
												 resolved_measure_id=.;
												else
												 resolved_measure_id=input(resolve("&&&measure_cd_lst_rslv"),best32.);
												call symput('resolved_measure_id',resolved_measure_id);
											run;
														%if  &measure_cd_lst_rslv.  eq   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_attrib_evt_scr.1, noquote))    
															or	 &measure_cd_lst_rslv.  eq   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_attrib_prop_scr.1, noquote))  
															%then %do;
								 							proc sql;
															 insert into work.updfact; 
															(VARIABLE_SK, MODEL_SK, SCORE_TIME_SK, TARGET_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
																values(&var_sk, &model, &time, &tgt_time, &measure_sk_list_insert,1, 'N')
															;
														%end;
														%else %do;
															 proc sql;
															 insert into work.updfact; 
															(VARIABLE_SK, MODEL_SK, SCORE_TIME_SK, TARGET_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
															values(&var_sk, &model, &time, &tgt_time, &measure_sk_list_insert,&resolved_measure_id, 'N')
															;
														%end;		
										%let cnt=%eval(&cnt+1);
										%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
								 		%end;
								/* The following UPDATE uses a correlated query. Update only those records whose time key 
								   lies between (score time + 1 month) and (target time) key */
										proc sql;
											update fact.SCORE_CARD_VARIABLE_FACT s
											set MEASURE_VALUE = 
												(select MEASURE_VALUE from work.updfact where MEASURE_SK = s.MEASURE_SK)
											where MODEL_SK = &model and DEV_FLG = 'N' 
												and &time > SCORE_TIME_SK and &time <= TARGET_TIME_SK;
							%end;/*Here*/			
							%let var_cnt=%eval(&var_cnt+1);
							%let var_sk=%qscan(&var_list,&var_cnt);
						%end;
				%end;
			%end;
		%end;
	%end;
%end;
%mend load_pd_score_card_variable_fact;
