%macro load_score_card_variable_fact(model_type=,dev_flg=);

%if %sysfunc(exist(fact.SCORE_CARD_VARIABLE_FACT)) eq 0 %then %do;
	proc sql;
		CREATE TABLE fact.SCORE_CARD_VARIABLE_FACT (
		       VARIABLE_SK          NUMERIC(8) FORMAT=12. INFORMAT=12. LABEL='_RKorSK',
		       MEASURE_SK           NUMERIC(8) FORMAT=12. INFORMAT=12. LABEL='_RKorSK',
		       MEASURE_VALUE        NUMERIC(8),
		       DEV_FLG              CHARACTER(1) FORMAT=$1. INFORMAT=$1. LABEL='Flags',
		       SCORE_TIME_SK        NUMERIC(8) FORMAT=12. INFORMAT=12. LABEL='_RKorSK',
		       TARGET_TIME_SK       NUMERIC(8) FORMAT=12. INFORMAT=12. LABEL='_RKorSK',
		       MODEL_SK             NUMERIC(8) FORMAT=12. INFORMAT=12. LABEL='Surrogate key for the analytical model dimension.'
		);

		CREATE UNIQUE INDEX XPKSCORE_CARD_VARIABLE_FACT ON fact.SCORE_CARD_VARIABLE_FACT
		(
		       VARIABLE_SK,
		       MODEL_SK,
		       MEASURE_SK,
		       TARGET_TIME_SK,
		       SCORE_TIME_SK,
		       DEV_FLG
		);
	quit;
%end;

%let model = -2; /*Assuming there will not be a value of -2 in input table*/
%if &dev_flg eq %str(Y) %then %do;
	proc sql noprint;
		select MODEL_SK,model_product_type_cd into :model separated by "#", 
			:product separated by "#"
		from martscr.ANALYTICAL_MODEL_DIM_EXT, mdlmart.MODEL_INPUT
		where MODEL_TYPE_CD=&model_type 
			AND DEPLOYMENT_STATUS_CD=&PRD_MODEL_DEPLOYMENT
			AND	MODEL_INPUT.MODEL_NM = ANALYTICAL_MODEL_DIM_EXT.MODEL_NM
			AND kupcase(MODEL_INPUT.status) IN (%sysfunc(kupcase(&CS_MODEL_STATUS))
			AND kupcase(MODEL_INPUT.ABT_TYPE) IN (%sysfunc(kupcase(&CS_ABT_TYPE_MDL));
	quit;
%end;
%else %do;
	proc sql noprint;
		select MODEL_SK ,TARGET_PERIOD_MTHS_CNT ,model_product_type_cd,MODEL_TYPE_CD
			into :model separated by "#", 
				 :tgtprd separated by "#",
				:product separated by "#",
				:model_cd separated by "#"
		from martscr.ANALYTICAL_MODEL_DIM_EXT, mdlmart.MODEL_INPUT
		where MODEL_TYPE_CD=&model_type
			AND DEPLOYMENT_STATUS_CD=&PRD_MODEL_DEPLOYMENT
			AND	MODEL_INPUT.MODEL_NM = ANALYTICAL_MODEL_DIM_EXT.MODEL_NM
			AND kupcase(MODEL_INPUT.status) IN (%sysfunc(kupcase(&CS_MODEL_STATUS)))
			AND kupcase(MODEL_INPUT.ABT_TYPE) IN (%sysfunc(kupcase(&CS_ABT_TYPE_SCR)));
	quit;
%end;
%let model = %sysfunc(ktrim(%sysfunc(kleft(&model))));
%let model_cd=&model_cd.;
%put model=&model;
%put product=&product.;
%put model_cd=&model_cd.;

%if &model NE -2 and &model NE . %then %do;
	proc sql noprint;
		select time_sk, cal_month_last_dt  into :time_sk , :time_date
		from martscr.TIME_DIM_EXT;
	quit;
	%let time=%sysfunc(ktrim(%sysfunc(kleft(&time_sk))));
	%let time_date =%sysfunc(ktrim(%sysfunc(kleft(&time_date))));
	%put time=&time;

	%let model_no=%str();
	%let cnt=1;
	%let product_type=%qscan(&product,&cnt,#);
	%let model_no=%qscan(&model,&cnt,#);
	%let target_prd=%qscan(&tgtprd,&cnt,#);
	%let model_cd_lst=%qscan(&model_cd,&cnt,#);
	%do %while(&model_no ne %str());
			%load_pd_score_card_variable_fact(model=&model_no,time=&time,time_date=&time_date
												,tgtprd=&target_prd,dev_flg=&dev_flg,
												product_type_cd=&product_type.,model_type_val=&model_cd_lst.);
		%let cnt=%eval(&cnt+1);
		%let model_no=%qscan(&model,&cnt,#);
		%let target_prd=%qscan(&tgtprd,&cnt,#);
		%let product_type=%qscan(&product,&cnt,#);
		%let model_cd_lst=%qscan(&model_cd,&cnt,#);
	%end;
%end;
%mend load_score_card_variable_fact;

