/**********************************************************************************************
       Module: feed_ccf_long_run
     Function:  This macro calculates the Maximum value or  average value  
				CCF  for given value of  period.

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All report screens. 

        Calls:  1. Macro create_ccf_sql.
				2. Macro quantile_calculation.
				3. Macro create_range_table.

Datasets used:  No input datasets required for processing of the macro.
 
        Logic:  calls the quantile_calculation and create_range_table for quantile formation and 
				range table creation on the basis of value of 	long_run_type.
   Parameters: 
		INPUT: 
				in_filter 		 	:	where clause .
				out_lib_nm			:	where the dataset will be created.
				out_table_nm_pool	:	The table name for pool level feed.
				out_table_nm_acct	:	The table name for account/application level feed
				no_of_quantile		:   number of quantile which we required.
				score_card_column   :	which contains score ranges 
				pd_ccf_lgd_column	:   It contains the name PD CCF or LGD
				long_run_type		: 	This tell which values you want to select it is for either 
									  	MAX of AVG.
**********************************************************************************************/

%macro feed_ccf_long_run(in_filter=, out_lib_nm=, out_table_nm_pool=, out_table_nm_acct=,
pd_score=, range_interval=, no_of_quantile=, long_run_type=, model_time_key=);

%let model_name=;
%create_ccf_sql(in_filter=&in_filter, out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool,
model_time_key=&model_time_key);

%if &error_code = ERROR %then
%RETURN;

%if &range_interval = %then
%quantile_calculation (out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool._range,
in_lib_nm=&out_lib_nm, in_table_nm_pool=&out_table_nm_pool._sql,
pd_score=&pd_score, no_of_quantile=&no_of_quantile,
score_card_column=, pd_ccf_lgd_column=estimated_account_ccf);
%else
%do;
%create_range_table (out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool._range,
in_lib_nm=&out_lib_nm, in_table_nm_pool=&out_table_nm_pool._sql,
pd_score=&pd_score, range_interval=&range_interval);
%end;

/*Account level feed */ 
proc sql;
create view &out_lib_nm..&out_table_nm_acct.

 /*I18N-scnjih-20080418-1135*/
/*as SELECT ACCOUNT_ID as account_id label="Account Identifier", */
/*CUSTOMER_ID as customer_id label="Customer Identifier",*/
/*ACTUAL_CCF as actual_ccf label="Actual CCF", */
/*ESTIMATED_ACCOUNT_CCF as estimated_ccf label="Estimated CCF"*/
	as SELECT ACCOUNT_ID as account_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_ccf_long_run.sas.1, noquote))", 
	CUSTOMER_ID as customer_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_ccf_long_run.sas.2, noquote))",
	ACTUAL_CCF as actual_ccf label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_ccf_long_run.sas.3, noquote))", 
	ESTIMATED_ACCOUNT_CCF as estimated_ccf label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_ccf_long_run.sas.4, noquote))"
/*I18N-scnjih-20080418-1135*/

FROM &out_lib_nm..&out_table_nm_pool._sql
order by 1;
quit;

/*End account level feed */

/*Get the no. of account development */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._dev as
select POOL_NAME, 
SUM(case when ESTIMATED_ACCOUNT_CCF > FROM_SCORE AND ESTIMATED_ACCOUNT_CCF <= TO_SCORE THEN 
1 ELSE . END) as NO_OF_ACCOUNT_DEV 
FROM &out_lib_nm..&out_table_nm_pool._dist,
FACT.MODEL_DEV_FACT,
&out_lib_nm..&out_table_nm_pool._range
WHERE &out_table_nm_pool._dist.MODEL_SK = MODEL_DEV_FACT.MODEL_SK
GROUP BY POOL_NAME;
quit;
/*End. no. of account development */

/*Long run calculation of estimated ccf value */
proc sql;
	create table work.lrun_ccf as
	select YEAR_START_DT, ESTIMATED_CCF,
		BALANCE_AT_DEFAULT * (LIMIT_AT_START/LIMIT_AT_DEFAULT) as BAL_DFT,
		((calculated BAL_DFT - BALANCE_AT_START)/(LIMIT_AT_DEFAULT - BALANCE_AT_START)) AS
		ACTUAL_CCF from longrun._lng&model_name._ccf;
quit;

proc sql;
create table &out_lib_nm..&out_table_nm_pool._lrun1 AS
select lrun_ccf.year_start_dt, pool_name, pool_seq_no,
sum (case when lrun_ccf.ESTIMATED_CCF > from_score  and lrun_ccf.ESTIMATED_CCF <= to_score then
	lrun_ccf.ACTUAL_CCF	else . end) as ACTUAL_CCF,
sum (case when lrun_ccf.ESTIMATED_CCF > from_score  and lrun_ccf.ESTIMATED_CCF <= to_score then
1 else . end) as NO_OF_ACCOUNTS,
calculated ACTUAL_CCF / calculated NO_OF_ACCOUNTS as ESTIMATED_POOL_CCF
from work.lrun_ccf, &out_lib_nm..&out_table_nm_pool._range 
group by year_start_dt, pool_name, pool_seq_no;
quit;

%if &long_run_type = MAX %then
%do;
proc sql;
create table &out_lib_nm..&out_table_nm_pool._lrun2 AS 
select pool_name, pool_seq_no, 
max(estimated_pool_ccf) as estimated_pool_ccf
from &out_lib_nm..&out_table_nm_pool._lrun1
group by pool_name, pool_seq_no;
quit;
%end;
%else
%do;
proc sql;
create table &out_lib_nm..&out_table_nm_pool._lrun2 AS 
select pool_name, pool_seq_no, 
avg(estimated_pool_ccf) as estimated_pool_ccf
from &out_lib_nm..&out_table_nm_pool._lrun1
group by pool_name, pool_seq_no;
quit;
%end;
/*End, long run calculation of estimated ccf value */

/*Update the pool_range table with the estimated_pool_lgd */
proc sql;
update &out_lib_nm..&out_table_nm_pool._range &out_table_nm_pool._range1
set est_pool_rate = 
(select estimated_pool_ccf from &out_lib_nm..&out_table_nm_pool._lrun2
where &out_table_nm_pool._range1.POOL_NAME = &out_table_nm_pool._lrun2.POOL_NAME);
quit;
/*End, updation of range_table */

/*Get the no of account actual */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._act AS
SELECT POOL_NAME,
SUM(case when ESTIMATED_ACCOUNT_CCF > FROM_SCORE AND ESTIMATED_ACCOUNT_CCF <= TO_SCORE THEN 
1 ELSE . END) AS NO_OF_ACCOUNT_ACTUAL, 
AVG(case when ESTIMATED_ACCOUNT_CCF > FROM_SCORE AND ESTIMATED_ACCOUNT_CCF <= TO_SCORE THEN 
ACTUAL_CCF ELSE . END) AS ACTUAL_CCF,
SUM(case when ESTIMATED_ACCOUNT_CCF > FROM_SCORE AND ESTIMATED_ACCOUNT_CCF <= TO_SCORE 
AND ACTUAL_CCF > est_pool_rate THEN 
1 ELSE . END) AS NO_OF_ACTUAL_BADS, 
MAX(CAL_MON_LAST_DT) as PERIOD
FROM &out_lib_nm..&out_table_nm_pool._sql,
&out_lib_nm..&out_table_nm_pool._range 
GROUP BY POOL_NAME;
quit;

/*End no. of account actual */


/*Start of pool level feed */
proc sql;
create view &out_lib_nm..&out_table_nm_pool. AS

/*I18N-scnjih-20080418-1135*/
/*select &out_table_nm_pool._lrun2.POOL_NAME as pool_name label="Pool Name",*/
/*&out_table_nm_pool._lrun2.POOL_SEQ_NO as pool_seq label="Pool Sequence",*/
/*coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label="No of Accounts (Development)", */
/*coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label="No of Accounts (Actual)", */
/*ACTUAL_CCF as actual_ccf label="Actual CCF", */
/*coalesce(&out_table_nm_pool._lrun2.ESTIMATED_POOL_CCF, est_pool_rate) as estimated_ccf label="Estimated CCF", */
/*PERIOD label="Period" informat=&CS_TIME_PER_FMT. format=&CS_TIME_PER_FMT.,*/
/*NO_OF_ACTUAL_BADS as no_of_actual_bads label="No of Events (Actual)"*/
	select &out_table_nm_pool._lrun2.POOL_NAME as pool_name label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_ccf_long_run.sas.5, noquote))",
	&out_table_nm_pool._lrun2.POOL_SEQ_NO as pool_seq label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_ccf_long_run.sas.6, noquote))",
	coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_ccf_long_run.sas.7, noquote))", 
	coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_ccf_long_run.sas.8, noquote))", 
	ACTUAL_CCF as actual_ccf label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_ccf_long_run.sas.9, noquote))", 
	coalesce(&out_table_nm_pool._lrun2.ESTIMATED_POOL_CCF, est_pool_rate) as estimated_ccf label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_ccf_long_run.sas.10, noquote))", 
	PERIOD label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_ccf_long_run.sas.11, noquote))" informat =&CS_TIME_PER_FMT. format =&CS_TIME_PER_FMT.,
	NO_OF_ACTUAL_BADS as no_of_actual_bads label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_ccf_long_run.sas.12, noquote))"
/*I18N-scnjih-20080418-1135*/

FROM &out_lib_nm..&out_table_nm_pool._range
LEFT JOIN &out_lib_nm..&out_table_nm_pool._lrun2
ON (&out_table_nm_pool._range.POOL_NAME = &out_table_nm_pool._lrun2.POOL_NAME)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._act
ON (&out_table_nm_pool._range.POOL_NAME = &out_table_nm_pool._act.POOL_NAME)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._dev
ON (&out_table_nm_pool._range.POOL_NAME = &out_table_nm_pool._dev.POOL_NAME)
where sum(NO_OF_ACCOUNT_DEV, NO_OF_ACCOUNT_ACTUAL) <> .
order by 2;
quit;

/*End of pool level feed */

%mend feed_ccf_long_run;
