/**********************************************************************************************
       Module: feed_lgd_dynamic
     Function: This macro generates the feed table for given range and given quantile. 
			   For LGD .

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All report screens. 

        Calls:  1. Macro create_lgd_sql.
				2. Macro quantile_calculation.
				3. Macro create_range_table.

Datasets used:  No input datasets required for processing of the macro.
 
        Logic:  This macro generates the LGD feed table for the given range 
				and number of quantile. In this it calls macro create_lgd_sql, 
				macro quantile_calculation,macro create_range_table.For creating table 
				for given range and number of quantile.
				
   Parameters: 
		INPUT: 
				in_filter 		 	:	where clause .
				out_lib_nm			:	where the dataset will be created.
				out_table_nm_pool	:	The table name for pool level feed.
				out_table_nm_acct	:	The table name for account/application level feed
				no_of_quantile		:   number of quantile which we required.
				range_interval		:	which contains range interval for PD CCF or LGD.
				pd_score			:   It contains the name PD CCF or LGD.
				model_time_key		:	This is the combination of  selected model and selected 
										time for that model E.G. 100_1025 , 103_1027).

**********************************************************************************************/
%macro feed_lgd_dynamic(in_filter=, out_lib_nm=, out_table_nm_pool=, out_table_nm_acct=,
pd_score=, range_interval=, no_of_quantile=, model_time_key=);

%create_lgd_sql(in_filter=&in_filter, out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool,
model_time_key=&model_time_key);

%if &error_code = ERROR %then
%RETURN;

%if &range_interval = %then
%quantile_calculation (out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool._range,
in_lib_nm=&out_lib_nm, in_table_nm_pool=&out_table_nm_pool._sql,
pd_score=&pd_score, no_of_quantile=&no_of_quantile,
score_card_column=, pd_ccf_lgd_column=estimated_account_lgd);
%else
%do;
%create_range_table (out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool._range,
in_lib_nm=&out_lib_nm, in_table_nm_pool=&out_table_nm_pool._sql,
pd_score=&pd_score, range_interval=&range_interval);
%end;

/*Account level feed */ 
proc sql;
create view &out_lib_nm..&out_table_nm_acct.

/*I18N-scnjih-20080418-1320*/
/*as SELECT ACCOUNT_ID as account_id label="Account Identifier", */
/*CUSTOMER_ID as customer_id label="Customer Identifier", */
/*ACTUAL_LGD as actual_lgd label="Actual LGD", */
/*ESTIMATED_ACCOUNT_LGD as estimated_lgd label="Estimated LGD"*/
as SELECT ACCOUNT_ID as account_id label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_dynamic.sas.1, noquote))", 
CUSTOMER_ID as customer_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_dynamic.sas.2, noquote))", 
ACTUAL_LGD as actual_lgd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_dynamic.sas.3, noquote))", 
ESTIMATED_ACCOUNT_LGD as estimated_lgd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_dynamic.sas.4, noquote))"
/*I18N-scnjih-20080418-1320*/
FROM &out_lib_nm..&out_table_nm_pool._sql order by 1;
quit;
/*End account level feed */

/*Get the no. of account development */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._dev as
select POOL_NAME, 
SUM(case when ESTIMATED_ACCOUNT_LGD > FROM_SCORE AND ESTIMATED_ACCOUNT_LGD <= TO_SCORE THEN 
1 ELSE . END) as NO_OF_ACCOUNT_DEV,
AVG(case when ESTIMATED_ACCOUNT_LGD > FROM_SCORE AND ESTIMATED_ACCOUNT_LGD <= TO_SCORE THEN 
ESTIMATED_ACCOUNT_LGD ELSE . END) AS ESTIMATED_POOL_LGD 
FROM &out_lib_nm..&out_table_nm_pool._dist,
FACT.MODEL_DEV_FACT,
&out_lib_nm..&out_table_nm_pool._range
WHERE &out_table_nm_pool._dist.MODEL_SK = MODEL_DEV_FACT.MODEL_SK
GROUP BY POOL_NAME;
quit;
/*End. no. of account development */

/*Update the pool_range table with the estimated_pool_lgd */
proc sql;
update &out_lib_nm..&out_table_nm_pool._range &out_table_nm_pool._range1
set est_pool_rate = 
(select estimated_pool_lgd from &out_lib_nm..&out_table_nm_pool._dev
where &out_table_nm_pool._range1.POOL_NAME = &out_table_nm_pool._dev.POOL_NAME);
quit;
/*End, updation of range_table */

/*Get the no of account actual */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._act AS
SELECT POOL_NAME,
SUM(case when ESTIMATED_ACCOUNT_LGD > FROM_SCORE AND ESTIMATED_ACCOUNT_LGD <= TO_SCORE THEN 
1 ELSE . END) AS NO_OF_ACCOUNT_ACTUAL, 
SUM(case when ESTIMATED_ACCOUNT_LGD > FROM_SCORE AND ESTIMATED_ACCOUNT_LGD <= TO_SCORE THEN 
ACTUAL_LOSS ELSE . END) AS SUM_ACTUAL_LOSS, 
SUM(case when ESTIMATED_ACCOUNT_LGD > FROM_SCORE AND ESTIMATED_ACCOUNT_LGD <= TO_SCORE THEN 
EXPOSURE_AT_DEFAULT ELSE . END) AS SUM_EXPOSURE_AT_DEFAULT, 
CALCULATED SUM_ACTUAL_LOSS / CALCULATED SUM_EXPOSURE_AT_DEFAULT * 100 AS ACTUAL_LGD,
SUM(case when ESTIMATED_ACCOUNT_LGD > FROM_SCORE AND ESTIMATED_ACCOUNT_LGD <= TO_SCORE 
AND ACTUAL_LGD > est_pool_rate THEN 
1 ELSE . END) AS NO_OF_ACTUAL_BADS, 
MAX(CAL_MON_LAST_DT) as PERIOD
FROM &out_lib_nm..&out_table_nm_pool._sql,
&out_lib_nm..&out_table_nm_pool._range 
GROUP BY POOL_NAME;
quit;

/*End no. of account actual */


/*Start of pool level feed */
proc sql;
create view &out_lib_nm..&out_table_nm_pool. AS

/*I18N-scnjih-20080418-1320*/
/*select &out_table_nm_pool._range.POOL_NAME as pool_name label="Pool Name", */
/*&out_table_nm_pool._range.POOL_SEQ_NO as pool_seq label="Pool Sequence",*/
/*coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label="No of Accounts (Development)", */
/*coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label="No of Accounts (Actual)",*/
/*coalesce(ESTIMATED_POOL_LGD, est_pool_rate) as estimated_lgd label="Estimated LGD",  */
/*ACTUAL_LGD as actual_lgd label="Actual LGD", */
/*PERIOD label="Period" informat=&CS_TIME_PER_FMT. format=&CS_TIME_PER_FMT.,*/
/*NO_OF_ACTUAL_BADS as no_of_actual_bads label="No of Events (Actual)"*/
select &out_table_nm_pool._range.POOL_NAME as pool_name label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_dynamic.sas.5, noquote))", 
&out_table_nm_pool._range.POOL_SEQ_NO as pool_seq label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_dynamic.sas.6, noquote))",
coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_dynamic.sas.7, noquote))", 
coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_dynamic.sas.8, noquote))",
coalesce(ESTIMATED_POOL_LGD, est_pool_rate) as estimated_lgd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_dynamic.sas.9, noquote))",  
ACTUAL_LGD as actual_lgd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_dynamic.sas.10, noquote))", 
PERIOD label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_dynamic.sas.11, noquote))" informat =&CS_TIME_PER_FMT. format =&CS_TIME_PER_FMT.,
NO_OF_ACTUAL_BADS as no_of_actual_bads label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_dynamic.sas.12, noquote))"
/*I18N-scnjih-20080418-1320*/

FROM &out_lib_nm..&out_table_nm_pool._range
LEFT JOIN &out_lib_nm..&out_table_nm_pool._act
ON (&out_table_nm_pool._range.POOL_NAME = &out_table_nm_pool._act.POOL_NAME)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._dev
ON (&out_table_nm_pool._range.POOL_NAME = &out_table_nm_pool._dev.POOL_NAME)
where sum(NO_OF_ACCOUNT_DEV, NO_OF_ACCOUNT_ACTUAL) <> .
order by 2;
quit;
/*End of pool level feed */
%mend feed_lgd_dynamic;


