/**********************************************************************************************
       Module: feed_pd_appl_dynamic
     Function: This macro generates the feed table for given range and given quantile. 
			   For Application PD .

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All report screens. 

        Calls:  1. Macro create_pd_appl_sql.
				2. Macro quantile_calculation.
				3. Macro create_range_table.

Datasets used:  No input datasets required for processing of the macro.
 
        Logic:  This macro generates the Application PD feed table for the given range 
				and number of quantile. In this it calls macro create_lgd_sql, 
				macro quantile_calculation,macro create_range_table.For creating table 
				for given range and number of quantile.
				
   Parameters: 
		INPUT: 
				in_filter 		 	:	where clause .
				out_lib_nm			:	where the dataset will be created.
				out_table_nm_pool	:	The table name for pool level feed.
				out_table_nm_acct	:	The table name for account/application level feed
				no_of_quantile		:   number of quantile which we required.
				range_interval		:	which contains range interval for PD CCF or LGD.
				pd_score			:   It contains the name PD CCF or LGD.
				model_time_key		:	This is the combination of  selected model and selected 
										time for that model E.G. 100_1025 , 103_1027).
				product_type_code	: 	This is the selected product type code (E.G. MTG, LON).

**********************************************************************************************/
%macro feed_pd_appl_dynamic(in_filter=, out_lib_nm=, out_table_nm_pool=, out_table_nm_acct=,
pd_score=, range_interval=, no_of_quantile=, model_time_key=, product_type_code=);

%create_pd_appl_sql(in_filter=&in_filter, out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool,
model_time_key=&model_time_key, product_type_code=&product_type_code);

%if &error_code = ERROR %then
%RETURN;

%if &range_interval = %then %do;
%quantile_calculation (out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool._1m_range,
in_lib_nm=&out_lib_nm, in_table_nm_pool=&out_table_nm_pool._1m_sql,
pd_score=&pd_score, no_of_quantile=&no_of_quantile,
score_card_column=score_points, pd_ccf_lgd_column=estimated_appl_pd);

/* For historic data */
%quantile_calculation (out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool._range,
in_lib_nm=&out_lib_nm, in_table_nm_pool=&out_table_nm_pool._sql,
pd_score=&pd_score, no_of_quantile=&no_of_quantile,
score_card_column=score_points, pd_ccf_lgd_column=estimated_appl_pd);
%end;
%else %do;
%create_range_table (out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool._1m_range,
in_lib_nm=&out_lib_nm, in_table_nm_pool=&out_table_nm_pool._1m_sql,
pd_score=&pd_score, range_interval=&range_interval);

/* For historic data */
%create_range_table (out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool._range,
in_lib_nm=&out_lib_nm, in_table_nm_pool=&out_table_nm_pool._sql,
pd_score=&pd_score, range_interval=&range_interval);
%end;

/*Application level feed */ 
proc sql;
create view &out_lib_nm..&out_table_nm_acct._1m
/*I18N-scnjih-20080418-1417*/
/*as SELECT APPLICATION_ID as account_id label="Application Identifier", */
/*APPLICANT_ID as applicant_id label="Applicant Identifier", */
/*SCORE_POINTS as score_points label="Score Points", */
/*ACTUAL_GOOD_BAD as actual_good_bad label="Observed Default", */
/*PREDICTED_GOOD_BAD as predicted_good_bad label="Predicted Default", */
/*ESTIMATED_APPL_PD as pd label="Estimated PD"*/
as SELECT APPLICATION_ID as account_id label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.1, noquote))", 
APPLICANT_ID as applicant_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.2, noquote))", 
SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.3, noquote))", 
ACTUAL_GOOD_BAD as actual_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.4, noquote))", 
PREDICTED_GOOD_BAD as predicted_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.5, noquote))", 
ESTIMATED_APPL_PD as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.6, noquote))"
/*I18N-scnjih-20080418-1417*/
FROM &out_lib_nm..&out_table_nm_pool._1m_sql order by 1;
quit;

/* For historic data */
proc sql;
create view &out_lib_nm..&out_table_nm_acct.
/*I18N-scnjih-20080418-1417*/
/*as SELECT APPLICATION_ID as account_id label="Application Identifier", */
/*APPLICANT_ID as applicant_id label="Applicant Identifier", */
/*SCORE_POINTS as score_points label="Score Points", */
/*ACTUAL_GOOD_BAD as actual_good_bad label="Observed Default", */
/*PREDICTED_GOOD_BAD as predicted_good_bad label="Predicted Default", */
/*ESTIMATED_APPL_PD as pd label="Estimated PD"*/
as SELECT APPLICATION_ID as account_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.7, noquote))", 
APPLICANT_ID as applicant_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.8, noquote))", 
SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.9, noquote))", 
ACTUAL_GOOD_BAD as actual_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.10, noquote))", 
PREDICTED_GOOD_BAD as predicted_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.11, noquote))", 
ESTIMATED_APPL_PD as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.12, noquote))"
/*I18N-scnjih-20080418-1417*/
FROM &out_lib_nm..&out_table_nm_pool._sql order by 1;
quit;

/*End application level feed */

%if &pd_score = SCORE %then
%do;

/*Get the outcome code from the application dimension for development sample */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._appl as
select MODEL_DEV_APPL_FACT.APPLICATION_SK, MODEL_SK, SCORE_POINTS, 
ESTIMATED_APPL_PD, OUTCOME_CD FROM
FACT.MODEL_DEV_APPL_FACT
INNER JOIN DIM.APPLICATION_DIM
ON (MODEL_DEV_APPL_FACT.APPLICATION_SK = APPLICATION_DIM.APPLICATION_SK);
quit;
/*End, get the outcome code */

/*Get the no. of account development */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._1m_dev as
select POOL_NAME, 
SUM(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
1 ELSE . END) as NO_OF_APPL_DEV, 
AVG(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
ESTIMATED_APPL_PD ELSE . END) AS ESTIMATED_POOL_PD,
SUM(case when OUTCOME_CD in (&outcome_accept) and /*To find accepted application */
SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE
then 1 else . end) AS NO_OF_APPL_DEV_ACCEPTED
FROM &out_lib_nm..&out_table_nm_pool._dist,
&out_lib_nm..&out_table_nm_pool._appl,
&out_lib_nm..&out_table_nm_pool._1m_range
WHERE &out_table_nm_pool._dist.MODEL_SK = &out_table_nm_pool._appl.MODEL_SK
GROUP BY POOL_NAME;
quit;
/*End. no. of account development */

/*Get the no. of account development for historic data */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._dev as
select POOL_NAME, 
SUM(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
1 ELSE . END) as NO_OF_APPL_DEV, 
AVG(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
ESTIMATED_APPL_PD ELSE . END) AS ESTIMATED_POOL_PD,
SUM(case when OUTCOME_CD in (&outcome_accept) and /*To find accepted application */
SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE
then 1 else . end) AS NO_OF_APPL_DEV_ACCEPTED
FROM &out_lib_nm..&out_table_nm_pool._dist,
&out_lib_nm..&out_table_nm_pool._appl,
&out_lib_nm..&out_table_nm_pool._range
WHERE &out_table_nm_pool._dist.MODEL_SK = &out_table_nm_pool._appl.MODEL_SK
GROUP BY POOL_NAME;
quit;
/*End. no. of account development for historic data */

/*Get the no of application actual */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._1m_act AS
SELECT SCORE_TIME_SK, POOL_NAME,
SUM(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
1 ELSE . END) AS NO_OF_APPL_ACTUAL, 
SUM(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
ACTUAL_GOOD_BAD ELSE . END) AS NO_OF_ACTUAL_BADS,
SUM(case when OUTCOME_CD in (&outcome_accept) and /*To find accepted application */
SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE
then 1 else . end) AS NO_OF_APPL_ACCEPTED,
MAX(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
SCORE_POINTS ELSE . END)AS MAX_SCORE_POINTS, 
MAX(CAL_MON_LAST_DT) as PERIOD
FROM &out_lib_nm..&out_table_nm_pool._1m_sql,
&out_lib_nm..&out_table_nm_pool._1m_range 
GROUP BY SCORE_TIME_SK, POOL_NAME;
quit;

/*End no. of application actual */

/*Get the no of application actual for historic data */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._act AS
SELECT &time_key as SCORE_TIME_SK, POOL_NAME,
SUM(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
1 ELSE . END) AS NO_OF_APPL_ACTUAL, 
SUM(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
ACTUAL_GOOD_BAD ELSE . END) AS NO_OF_ACTUAL_BADS,
SUM(case when OUTCOME_CD in (&outcome_accept) and /*To find accepted application */
SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE
then 1 else . end) AS NO_OF_APPL_ACCEPTED,
MAX(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
SCORE_POINTS ELSE . END)AS MAX_SCORE_POINTS, 
MAX(CAL_MON_LAST_DT) as PERIOD
FROM &out_lib_nm..&out_table_nm_pool._sql,
&out_lib_nm..&out_table_nm_pool._range 
GROUP BY POOL_NAME;
quit;

/*End no. of application actual for historic data */

/*Get the distinct values of 
TIME_SK from _sql
POOL_NAME from _mdl 
Perform cartesian product for TIME_SK, POOL_NAME */
proc sql;
create view &out_lib_nm..&out_table_nm_pool._1m_pool
as select distinct pool_name from &out_lib_nm..&out_table_nm_pool._1m_range;

/* For historic data */
proc sql;
create view &out_lib_nm..&out_table_nm_pool._pool
as select distinct pool_name from &out_lib_nm..&out_table_nm_pool._range;

create view &out_lib_nm..&out_table_nm_pool._time
as select distinct SCORE_TIME_SK as time_sk from &out_lib_nm..&out_table_nm_pool._1m_sql;

create table &out_lib_nm..&out_table_nm_pool._1m_pt
as select time_sk, pool_name from
&out_lib_nm..&out_table_nm_pool._time, &out_lib_nm..&out_table_nm_pool._1m_pool;

/* For historic data */
create table &out_lib_nm..&out_table_nm_pool._pt
as select time_sk, pool_name from
&out_lib_nm..&out_table_nm_pool._time, &out_lib_nm..&out_table_nm_pool._pool;
quit;
/*End of cartesian product */

/*Start of pool level feed */
proc sql;
create view &out_lib_nm..&out_table_nm_pool._1m AS
/*I18N-scnjih-20080418-1417*/
/*select TIME_SK label="Score Time", */
/*&out_table_nm_pool._1m_range.POOL_NAME as pool_name label="Pool Name", */
/*&out_table_nm_pool._1m_range.POOL_SEQ_NO as pool_seq label="Pool Sequence",*/
/*coalesce(NO_OF_APPL_DEV, &epsilon) as no_of_appl_dev label="No of Applications (Development)",*/
/*NO_OF_APPL_DEV_ACCEPTED as no_of_acc_dev label="No of Applications Accepted (Development)",*/
/*NO_OF_APPL_DEV - NO_OF_APPL_DEV_ACCEPTED as no_of_appl_dev_rejected label="No of Applications Rejected (Development)", */
/*coalesce(NO_OF_APPL_ACTUAL, &epsilon) as no_of_appl_actual label="No of Applications (Actual)", */
/*NO_OF_APPL_ACCEPTED as no_of_acc_actual label="No of Applications Accepted (Actual)",*/
/*NO_OF_ACTUAL_BADS as no_of_actual_bads label="No of Events (Actual)",*/
/*NO_OF_APPL_ACTUAL - NO_OF_APPL_ACCEPTED as no_of_appl_rejected label="No of Applications Rejected (Actual)",*/
/*coalesce(ESTIMATED_POOL_PD, est_pool_rate) as pd label="Estimated PD", */
/*MAX_SCORE_POINTS as score_points label="Score Points",*/
/*PERIOD label="Period" informat=&CS_TIME_PER_FMT. format=&CS_TIME_PER_FMT.*/
select TIME_SK label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.13, noquote))", 
&out_table_nm_pool._1m_range.POOL_NAME as pool_name label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.14, noquote))", 
&out_table_nm_pool._1m_range.POOL_SEQ_NO as pool_seq label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.15, noquote))",
coalesce(NO_OF_APPL_DEV, &epsilon) as no_of_appl_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.16, noquote))",
NO_OF_APPL_DEV_ACCEPTED as no_of_acc_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.17, noquote))",
NO_OF_APPL_DEV - NO_OF_APPL_DEV_ACCEPTED as no_of_appl_dev_rejected label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.18, noquote))", 
coalesce(NO_OF_APPL_ACTUAL, &epsilon) as no_of_appl_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.19, noquote))", 
NO_OF_APPL_ACCEPTED as no_of_acc_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.20, noquote))",
NO_OF_ACTUAL_BADS as no_of_actual_bads label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.21, noquote))",
NO_OF_APPL_ACTUAL - NO_OF_APPL_ACCEPTED as no_of_appl_rejected label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.22, noquote))",
coalesce(ESTIMATED_POOL_PD, est_pool_rate) as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.23, noquote))", 
MAX_SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.24, noquote))",
PERIOD label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.25, noquote))" informat =&CS_TIME_PER_FMT. format =&CS_TIME_PER_FMT.
/*I18N-scnjih-20080418-1417*/

FROM &out_lib_nm..&out_table_nm_pool._1m_pt
LEFT JOIN &out_lib_nm..&out_table_nm_pool._1m_range
ON (&out_table_nm_pool._1m_pt.POOL_NAME = &out_table_nm_pool._1m_range.POOL_NAME)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._1m_act
ON (&out_table_nm_pool._1m_pt.POOL_NAME = &out_table_nm_pool._1m_act.POOL_NAME AND
    &out_table_nm_pool._1m_pt.TIME_SK = &out_table_nm_pool._1m_act.SCORE_TIME_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._1m_dev
ON (&out_table_nm_pool._1m_pt.POOL_NAME = &out_table_nm_pool._1m_dev.POOL_NAME)
where sum(NO_OF_APPL_DEV, NO_OF_APPL_ACTUAL) <> .
ORDER BY 1, 3;
quit;

/* For historic data */
proc sql;
create view &out_lib_nm..&out_table_nm_pool. AS
/*I18N-scnjih-20080418-1417*/
/*select TIME_SK label="Score Time", */
/*&out_table_nm_pool._range.POOL_NAME as pool_name label="Pool Name", */
/*&out_table_nm_pool._range.POOL_SEQ_NO as pool_seq label="Pool Sequence",*/
/*coalesce(NO_OF_APPL_DEV, &epsilon) as no_of_appl_dev label="No of Applications (Development)",*/
/*NO_OF_APPL_DEV_ACCEPTED as no_of_acc_dev label="No of Applications Accepted (Development)",*/
/*NO_OF_APPL_DEV - NO_OF_APPL_DEV_ACCEPTED as no_of_appl_dev_rejected label="No of Applications Rejected (Development)", */
/*coalesce(NO_OF_APPL_ACTUAL, &epsilon) as no_of_appl_actual label="No of Applications (Actual)", */
/*NO_OF_APPL_ACCEPTED as no_of_acc_actual label="No of Applications Accepted (Actual)",*/
/*NO_OF_ACTUAL_BADS as no_of_actual_bads label="No of Events (Actual)",*/
/*NO_OF_APPL_ACTUAL - NO_OF_APPL_ACCEPTED as no_of_appl_rejected label="No of Applications Rejected (Actual)",*/
/*coalesce(ESTIMATED_POOL_PD, est_pool_rate) as pd label="Estimated PD", */
/*MAX_SCORE_POINTS as score_points label="Score Points",*/
/*PERIOD label="Period" informat=&CS_TIME_PER_FMT. format=&CS_TIME_PER_FMT.*/
select TIME_SK label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.26, noquote))", 
&out_table_nm_pool._range.POOL_NAME as pool_name label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.27, noquote))", 
&out_table_nm_pool._range.POOL_SEQ_NO as pool_seq label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.28, noquote))",
coalesce(NO_OF_APPL_DEV, &epsilon) as no_of_appl_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.29, noquote))",
NO_OF_APPL_DEV_ACCEPTED as no_of_acc_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.30, noquote))",
NO_OF_APPL_DEV - NO_OF_APPL_DEV_ACCEPTED as no_of_appl_dev_rejected label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.31, noquote))", 
coalesce(NO_OF_APPL_ACTUAL, &epsilon) as no_of_appl_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.32, noquote))", 
NO_OF_APPL_ACCEPTED as no_of_acc_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.33, noquote))",
NO_OF_ACTUAL_BADS as no_of_actual_bads label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.34, noquote))",
NO_OF_APPL_ACTUAL - NO_OF_APPL_ACCEPTED as no_of_appl_rejected label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.35, noquote))",
coalesce(ESTIMATED_POOL_PD, est_pool_rate) as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.36, noquote))", 
MAX_SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.37, noquote))",
PERIOD label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.38, noquote))" informat =&CS_TIME_PER_FMT. format =&CS_TIME_PER_FMT.
/*I18N-scnjih-20080418-1417*/
FROM &out_lib_nm..&out_table_nm_pool._pt
LEFT JOIN &out_lib_nm..&out_table_nm_pool._range
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._range.POOL_NAME)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._act
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._act.POOL_NAME AND
    &out_table_nm_pool._pt.TIME_SK = &out_table_nm_pool._act.SCORE_TIME_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._dev
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._dev.POOL_NAME)
where sum(NO_OF_APPL_DEV, NO_OF_APPL_ACTUAL) <> .
ORDER BY 1, 3;
quit;

/*End of pool level feed */
%end;
%else
%do;
/*Get the outcome code from the application dimension for development sample */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._appl as
select MODEL_DEV_APPL_FACT.APPLICATION_SK, MODEL_SK, ESTIMATED_APPL_PD, OUTCOME_CD FROM
FACT.MODEL_DEV_APPL_FACT
INNER JOIN DIM.APPLICATION_DIM
ON (MODEL_DEV_APPL_FACT.APPLICATION_SK = APPLICATION_DIM.APPLICATION_SK);
quit;
/*End, get the outcome code */

/*Get the no. of account development */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._1m_dev as
select POOL_NAME, 
SUM(case when ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE THEN 
1 ELSE . END) as NO_OF_APPL_DEV,
AVG(case when ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE THEN 
ESTIMATED_APPL_PD ELSE . END) AS ESTIMATED_POOL_PD,
SUM(case when OUTCOME_CD in (&outcome_accept) and /*To find accepted application */ 
ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE
then 1 else . end) AS NO_OF_APPL_DEV_ACCEPTED 
FROM &out_lib_nm..&out_table_nm_pool._dist,
&out_lib_nm..&out_table_nm_pool._appl,
&out_lib_nm..&out_table_nm_pool._1m_range
WHERE &out_table_nm_pool._dist.MODEL_SK = &out_table_nm_pool._appl.MODEL_SK
GROUP BY POOL_NAME;
quit;

/* For historic data */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._dev as
select POOL_NAME, 
SUM(case when ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE THEN 
1 ELSE . END) as NO_OF_APPL_DEV,
AVG(case when ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE THEN 
ESTIMATED_APPL_PD ELSE . END) AS ESTIMATED_POOL_PD,
SUM(case when OUTCOME_CD in (&outcome_accept) and /*To find accepted application */ 
ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE
then 1 else . end) AS NO_OF_APPL_DEV_ACCEPTED 
FROM &out_lib_nm..&out_table_nm_pool._dist,
&out_lib_nm..&out_table_nm_pool._appl,
&out_lib_nm..&out_table_nm_pool._range
WHERE &out_table_nm_pool._dist.MODEL_SK = &out_table_nm_pool._appl.MODEL_SK
GROUP BY POOL_NAME;
quit;

/*End. no. of account development */

/*Get the no of account actual */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._1m_act AS
SELECT SCORE_TIME_SK, POOL_NAME,
SUM(case when ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE THEN 
1 ELSE . END) AS NO_OF_APPL_ACTUAL, 
SUM(case when ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE THEN 
ACTUAL_GOOD_BAD ELSE . END) AS NO_OF_ACTUAL_BADS,
SUM(case when OUTCOME_CD in (&outcome_accept) and /*To find accepted application */ 
ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE
then 1 else . end) AS NO_OF_APPL_ACCEPTED,
MAX(case when ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE THEN 
SCORE_POINTS ELSE . END)AS MAX_SCORE_POINTS, 
MAX(CAL_MON_LAST_DT) as PERIOD
FROM &out_lib_nm..&out_table_nm_pool._1m_sql,
&out_lib_nm..&out_table_nm_pool._1m_range 
GROUP BY SCORE_TIME_SK, POOL_NAME;
quit;

/* For historic data */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._act AS
SELECT &time_key as SCORE_TIME_SK, POOL_NAME,
SUM(case when ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE THEN 
1 ELSE . END) AS NO_OF_APPL_ACTUAL, 
SUM(case when ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE THEN 
ACTUAL_GOOD_BAD ELSE . END) AS NO_OF_ACTUAL_BADS,
SUM(case when OUTCOME_CD in (&outcome_accept) and /*To find accepted application */ 
ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE
then 1 else . end) AS NO_OF_APPL_ACCEPTED,
MAX(case when ESTIMATED_APPL_PD > FROM_SCORE AND ESTIMATED_APPL_PD <= TO_SCORE THEN 
SCORE_POINTS ELSE . END)AS MAX_SCORE_POINTS, 
MAX(CAL_MON_LAST_DT) as PERIOD
FROM &out_lib_nm..&out_table_nm_pool._sql,
&out_lib_nm..&out_table_nm_pool._range 
GROUP BY POOL_NAME;
quit;


/*End no. of account actual */

/*Get the distinct values of 
TIME_SK from _sql
POOL_NAME from _mdl 
Perform cartesian product for TIME_SK, POOL_NAME */
proc sql;
create view &out_lib_nm..&out_table_nm_pool._1m_pool
as select distinct pool_name from &out_lib_nm..&out_table_nm_pool._1m_range;

/* For historic data */
proc sql;
create view &out_lib_nm..&out_table_nm_pool._pool
as select distinct pool_name from &out_lib_nm..&out_table_nm_pool._range;

create view &out_lib_nm..&out_table_nm_pool._time
as select distinct SCORE_TIME_SK as time_sk from &out_lib_nm..&out_table_nm_pool._1m_sql;

create table &out_lib_nm..&out_table_nm_pool._1m_pt
as select time_sk, pool_name from
&out_lib_nm..&out_table_nm_pool._time, &out_lib_nm..&out_table_nm_pool._1m_pool;

/* For historic data */
create table &out_lib_nm..&out_table_nm_pool._pt
as select time_sk, pool_name from
&out_lib_nm..&out_table_nm_pool._time, &out_lib_nm..&out_table_nm_pool._pool;

quit;
/*End of cartesian product */

/*Start of pool level feed */
proc sql;
create view &out_lib_nm..&out_table_nm_pool._1m AS
/*I18N-scnjih-20080418-1417*/
/*select TIME_SK label="Score Time", */
/*&out_table_nm_pool._1m_range.POOL_NAME as pool_name label="Pool Name", */
/*&out_table_nm_pool._1m_range.POOL_SEQ_NO as pool_seq label="Pool Sequence",*/
/*coalesce(NO_OF_APPL_DEV, &epsilon) as no_of_appl_dev label="No of Applications (Development)", */
/*NO_OF_APPL_DEV_ACCEPTED as no_of_acc_dev label="No of Applications Accepted (Development)",*/
/*NO_OF_APPL_DEV - NO_OF_APPL_DEV_ACCEPTED as no_of_appl_dev_rejected label="No of Applications Rejected (Development)",*/
/*coalesce(NO_OF_APPL_ACTUAL, &epsilon) as no_of_appl_actual label="No of Applications (Actual)", */
/*NO_OF_APPL_ACCEPTED as no_of_acc_actual label="No of Applications Accepted (Actual)",*/
/*NO_OF_APPL_ACTUAL - NO_OF_APPL_ACCEPTED as no_of_appl_rejected label="No of Applications Rejected (Actual)",*/
/*NO_OF_ACTUAL_BADS as no_of_actual_bads label="No of Events (Actual)",*/
/*coalesce(ESTIMATED_POOL_PD, est_pool_rate) as pd label="Estimated PD", */
/*MAX_SCORE_POINTS as score_points label="Score Points",*/
/*PERIOD label="Period" informat=&CS_TIME_PER_FMT. format=&CS_TIME_PER_FMT.*/
select TIME_SK label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.13, noquote))", 
&out_table_nm_pool._1m_range.POOL_NAME as pool_name label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.14, noquote))", 
&out_table_nm_pool._1m_range.POOL_SEQ_NO as pool_seq label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.15, noquote))",
coalesce(NO_OF_APPL_DEV, &epsilon) as no_of_appl_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.16, noquote))", 
NO_OF_APPL_DEV_ACCEPTED as no_of_acc_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.17, noquote))",
NO_OF_APPL_DEV - NO_OF_APPL_DEV_ACCEPTED as no_of_appl_dev_rejected label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.18, noquote))",
coalesce(NO_OF_APPL_ACTUAL, &epsilon) as no_of_appl_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.19, noquote))", 
NO_OF_APPL_ACCEPTED as no_of_acc_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.20, noquote))",
NO_OF_APPL_ACTUAL - NO_OF_APPL_ACCEPTED as no_of_appl_rejected label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.21, noquote))",
NO_OF_ACTUAL_BADS as no_of_actual_bads label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.22, noquote))",
coalesce(ESTIMATED_POOL_PD, est_pool_rate) as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.23, noquote))", 
MAX_SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.24, noquote))",
PERIOD label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.25, noquote))"informat =&CS_TIME_PER_FMT. format =&CS_TIME_PER_FMT.
/*I18N-scnjih-20080418-1417*/
FROM &out_lib_nm..&out_table_nm_pool._1m_pt
LEFT JOIN &out_lib_nm..&out_table_nm_pool._1m_range
ON (&out_table_nm_pool._1m_pt.POOL_NAME = &out_table_nm_pool._1m_range.POOL_NAME)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._1m_act
ON (&out_table_nm_pool._1m_pt.POOL_NAME = &out_table_nm_pool._1m_act.POOL_NAME AND
    &out_table_nm_pool._1m_pt.TIME_SK = &out_table_nm_pool._1m_act.SCORE_TIME_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._1m_dev
ON (&out_table_nm_pool._1m_pt.POOL_NAME = &out_table_nm_pool._1m_dev.POOL_NAME)
where sum(NO_OF_APPL_DEV, NO_OF_APPL_ACTUAL) <> .
ORDER BY 1, 3;
quit;

/* For historic data */
proc sql;
create view &out_lib_nm..&out_table_nm_pool. AS
/*I18N-scnjih-20080418-1417*/
/*select TIME_SK label="Score Time", */
/*&out_table_nm_pool._range.POOL_NAME as pool_name label="Pool Name", */
/*&out_table_nm_pool._range.POOL_SEQ_NO as pool_seq label="Pool Sequence",*/
/*coalesce(NO_OF_APPL_DEV, &epsilon) as no_of_appl_dev label="No of Applications (Development)", */
/*NO_OF_APPL_DEV_ACCEPTED as no_of_acc_dev label="No of Applications Accepted (Development)",*/
/*NO_OF_APPL_DEV - NO_OF_APPL_DEV_ACCEPTED as no_of_appl_dev_rejected label="No of Applications Rejected (Development)",*/
/*coalesce(NO_OF_APPL_ACTUAL, &epsilon) as no_of_appl_actual label="No of Applications (Actual)", */
/*NO_OF_APPL_ACCEPTED as no_of_acc_actual label="No of Applications Accepted (Actual)",*/
/*NO_OF_APPL_ACTUAL - NO_OF_APPL_ACCEPTED as no_of_appl_rejected label="No of Applications Rejected (Actual)",*/
/*NO_OF_ACTUAL_BADS as no_of_actual_bads label="No of Events (Actual)",*/
/*coalesce(ESTIMATED_POOL_PD, est_pool_rate) as pd label="Estimated PD", */
/*MAX_SCORE_POINTS as score_points label="Score Points",*/
/*PERIOD label="Period" informat=&CS_TIME_PER_FMT. format=&CS_TIME_PER_FMT.*/
select TIME_SK label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.13, noquote))", 
&out_table_nm_pool._range.POOL_NAME as pool_name label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.14, noquote))", 
&out_table_nm_pool._range.POOL_SEQ_NO as pool_seq label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.15, noquote))",
coalesce(NO_OF_APPL_DEV, &epsilon) as no_of_appl_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.16, noquote))", 
NO_OF_APPL_DEV_ACCEPTED as no_of_acc_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.17, noquote))",
NO_OF_APPL_DEV - NO_OF_APPL_DEV_ACCEPTED as no_of_appl_dev_rejected label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.18, noquote))",
coalesce(NO_OF_APPL_ACTUAL, &epsilon) as no_of_appl_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.19, noquote))", 
NO_OF_APPL_ACCEPTED as no_of_acc_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.20, noquote))",
NO_OF_APPL_ACTUAL - NO_OF_APPL_ACCEPTED as no_of_appl_rejected label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.21, noquote))",
NO_OF_ACTUAL_BADS as no_of_actual_bads label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.22, noquote))",
coalesce(ESTIMATED_POOL_PD, est_pool_rate) as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.23, noquote))", 
MAX_SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.24, noquote))",
PERIOD label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_dynamic.sas.25, noquote))" informat =&CS_TIME_PER_FMT. format =&CS_TIME_PER_FMT.
/*I18N-scnjih-20080418-1417*/
FROM &out_lib_nm..&out_table_nm_pool._pt
LEFT JOIN &out_lib_nm..&out_table_nm_pool._range
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._range.POOL_NAME)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._act
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._act.POOL_NAME AND
    &out_table_nm_pool._pt.TIME_SK = &out_table_nm_pool._act.SCORE_TIME_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._dev
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._dev.POOL_NAME)
where sum(NO_OF_APPL_DEV, NO_OF_APPL_ACTUAL) <> .
ORDER BY 1, 3;
quit;

/*End of pool level feed */

%end;

%mend feed_pd_appl_dynamic;


