/**********************************************************************************************
       Module: feed_pd_dynamic
     Function: This macro generates the feed table for given range and given quantile. 
			   For PD .

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All report screens. 

        Calls:  1. Macro create_pd_sql.
				2. Macro quantile_calculation.
				3. Macro create_range_table.

Datasets used:  No input datasets required for processing of the macro.
 
        Logic:  This macro generates the PD feed table for the given range 
				and number of quantile. In this it calls macro create_lgd_sql, 
				macro quantile_calculation,macro create_range_table.For creating table 
				for given range and number of quantile.
				
   Parameters: 
		INPUT: 
				in_filter 		 	:	where clause .
				out_lib_nm			:	where the dataset will be created.
				out_table_nm_pool	:	The table name for pool level feed.
				out_table_nm_acct	:	The table name for account/application level feed
				no_of_quantile		:   number of quantile which we required.
				range_interval		:	which contains range interval for PD CCF or LGD.
				pd_score			:   It contains the name PD CCF or LGD.
				model_time_key		:	This is the combination of  selected model and selected 
										time for that model E.G. 100_1025 , 103_1027).

**********************************************************************************************/
%macro feed_pd_dynamic(in_filter=, out_lib_nm=, out_table_nm_pool=, out_table_nm_acct=,
pd_score=, range_interval=, no_of_quantile=, model_time_key=);

%create_pd_sql(in_filter=&in_filter, out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool,
model_time_key=&model_time_key);

%if &error_code = ERROR %then
%RETURN;

%if &range_interval = %then
%quantile_calculation (out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool._range,
in_lib_nm=&out_lib_nm, in_table_nm_pool=&out_table_nm_pool._sql,
pd_score=&pd_score, no_of_quantile=&no_of_quantile,
score_card_column=score_points, pd_ccf_lgd_column=estimated_account_pd);
%else
%create_range_table (out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool._range,
in_lib_nm=&out_lib_nm, in_table_nm_pool=&out_table_nm_pool._sql,
pd_score=&pd_score, range_interval=&range_interval);

/*Account level feed */ 
proc sql;
create view &out_lib_nm..&out_table_nm_acct.
 /*I18N-scnjih-20080418-1515*/
/*as SELECT ACCOUNT_ID as account_id label="Account Identifier", */
/*CUSTOMER_ID as customer_id label="Customer Identifier", */
/*SCORE_POINTS as score_points label="Score Points", */
/*ACTUAL_GOOD_BAD as actual_good_bad label="Observed Default", */
/*PREDICTED_GOOD_BAD as predicted_good_bad label="Predicted Default", */
/*ESTIMATED_ACCOUNT_PD as pd label="Estimated PD"*/
as SELECT ACCOUNT_ID as account_id label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.1, noquote))", 
CUSTOMER_ID as customer_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.2, noquote))", 
SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.3, noquote))", 
ACTUAL_GOOD_BAD as actual_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.4, noquote))", 
PREDICTED_GOOD_BAD as predicted_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.5, noquote))", 
ESTIMATED_ACCOUNT_PD as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.6, noquote))"
/*I18N-scnjih-20080418-1515*/
FROM &out_lib_nm..&out_table_nm_pool._sql;
quit;

/* End account level feed */

%if &pd_score = SCORE %then
%do;

/* Get the no. of account development */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._dev as
select POOL_NAME, 
SUM(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
1 ELSE . END) as NO_OF_ACCOUNT_DEV, 
AVG(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
ESTIMATED_ACCOUNT_PD ELSE . END) AS ESTIMATED_POOL_PD
FROM &out_lib_nm..&out_table_nm_pool._dist,
FACT.MODEL_DEV_FACT,
&out_lib_nm..&out_table_nm_pool._range
WHERE &out_table_nm_pool._dist.MODEL_SK = MODEL_DEV_FACT.MODEL_SK
GROUP BY POOL_NAME;
quit;
/*End. no. of account development */

/*Get the no of account actual */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._act AS
SELECT SCORE_TIME_SK, POOL_NAME,
SUM(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
1 ELSE . END) AS NO_OF_ACCOUNT_ACTUAL, 
SUM(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
ACTUAL_GOOD_BAD ELSE . END) AS NO_OF_ACTUAL_BADS,
MAX(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
SCORE_POINTS ELSE . END)AS MAX_SCORE_POINTS
FROM &out_lib_nm..&out_table_nm_pool._sql,
&out_lib_nm..&out_table_nm_pool._range 
GROUP BY SCORE_TIME_SK, POOL_NAME;
quit;
/*End no. of account actual */

/*Get the distinct values of 
TIME_SK from _sql
POOL_NAME from _mdl 
Perform cartesian product for TIME_SK, POOL_NAME */

proc sql;
create view &out_lib_nm..&out_table_nm_pool._pool
as select distinct pool_name from &out_lib_nm..&out_table_nm_pool._range;

create view &out_lib_nm..&out_table_nm_pool._time
as select distinct SCORE_TIME_SK as time_sk from &out_lib_nm..&out_table_nm_pool._sql;

create table &out_lib_nm..&out_table_nm_pool._pt
as select time_sk, pool_name from
&out_lib_nm..&out_table_nm_pool._time, &out_lib_nm..&out_table_nm_pool._pool;
quit;
/*End of cartesian product */

/*Start of pool level feed */
proc sql;
create view &out_lib_nm..&out_table_nm_pool. AS
/*I18N-scnjih-20080418-1515*/
/*select TIME_SK label="Score Time", */
/*&out_table_nm_pool._range.POOL_NAME as pool_name label="Pool Name", */
/*&out_table_nm_pool._range.POOL_SEQ_NO as pool_seq label="Pool Sequence",*/
/*coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label="No of Accounts (Development)", */
/*coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label="No of Accounts (Actual)", */
/*NO_OF_ACTUAL_BADS as no_of_actual_bads label="No of Events (Actual)",*/
/*coalesce(ESTIMATED_POOL_PD, est_pool_rate) as pd label="Estimated PD", */
/*MAX_SCORE_POINTS as score_points label="Score Points"*/
select TIME_SK label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.7, noquote))", 
&out_table_nm_pool._range.POOL_NAME as pool_name label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.8, noquote))", 
&out_table_nm_pool._range.POOL_SEQ_NO as pool_seq label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.9, noquote))",
coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.10, noquote))", 
coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.11, noquote))", 
NO_OF_ACTUAL_BADS as no_of_actual_bads label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.12, noquote))",
coalesce(ESTIMATED_POOL_PD, est_pool_rate) as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.13, noquote))", 
MAX_SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.14, noquote))"

/*I18N-scnjih-20080418-1515*/
FROM &out_lib_nm..&out_table_nm_pool._pt
LEFT JOIN &out_lib_nm..&out_table_nm_pool._range 
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._range.POOL_NAME)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._act
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._act.POOL_NAME AND 
    &out_table_nm_pool._pt.TIME_SK = &out_table_nm_pool._act.SCORE_TIME_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._dev
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._dev.POOL_NAME)
where sum(NO_OF_ACCOUNT_DEV, NO_OF_ACCOUNT_ACTUAL) <> .
order by 1, 3;
quit;
/*End of pool level feed */
%end;
%else
%do;

/*Get the no. of account development */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._dev as
select POOL_NAME, 
SUM(case when ESTIMATED_ACCOUNT_PD > FROM_SCORE AND ESTIMATED_ACCOUNT_PD <= TO_SCORE THEN 
1 ELSE . END) as NO_OF_ACCOUNT_DEV,
AVG(case when ESTIMATED_ACCOUNT_PD > FROM_SCORE AND ESTIMATED_ACCOUNT_PD <= TO_SCORE THEN 
ESTIMATED_ACCOUNT_PD ELSE . END) AS ESTIMATED_POOL_PD 
FROM &out_lib_nm..&out_table_nm_pool._dist,
FACT.MODEL_DEV_FACT,
&out_lib_nm..&out_table_nm_pool._range
WHERE &out_table_nm_pool._dist.MODEL_SK = MODEL_DEV_FACT.MODEL_SK
GROUP BY POOL_NAME;
quit;
/*End. no. of account development */

/*Get the no of account actual */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._act AS
SELECT SCORE_TIME_SK, POOL_NAME,
SUM(case when ESTIMATED_ACCOUNT_PD > FROM_SCORE AND ESTIMATED_ACCOUNT_PD <= TO_SCORE THEN 
1 ELSE . END) AS NO_OF_ACCOUNT_ACTUAL, 
SUM(case when ESTIMATED_ACCOUNT_PD > FROM_SCORE AND ESTIMATED_ACCOUNT_PD <= TO_SCORE THEN 
ACTUAL_GOOD_BAD ELSE . END) AS NO_OF_ACTUAL_BADS,
MAX(case when ESTIMATED_ACCOUNT_PD > FROM_SCORE AND ESTIMATED_ACCOUNT_PD <= TO_SCORE THEN 
SCORE_POINTS ELSE . END)AS MAX_SCORE_POINTS
FROM &out_lib_nm..&out_table_nm_pool._sql,
&out_lib_nm..&out_table_nm_pool._range 
GROUP BY SCORE_TIME_SK, POOL_NAME;
quit;
/*End no. of account actual */

/*Get the distinct values of 
TIME_SK from _sql
POOL_NAME from _mdl 
Perform cartesian product for TIME_SK, POOL_NAME */

proc sql;
create view &out_lib_nm..&out_table_nm_pool._pool
as select distinct pool_name from &out_lib_nm..&out_table_nm_pool._range;

create view &out_lib_nm..&out_table_nm_pool._time
as select distinct SCORE_TIME_SK as time_sk from &out_lib_nm..&out_table_nm_pool._sql;

create table &out_lib_nm..&out_table_nm_pool._pt
as select time_sk, pool_name from
&out_lib_nm..&out_table_nm_pool._time, &out_lib_nm..&out_table_nm_pool._pool;
quit;
/*End of cartesian product */

/*Start of pool level feed */
proc sql;
create view &out_lib_nm..&out_table_nm_pool. AS
/*I18N-scnjih-20080418-1515*/
/*select TIME_SK label="Score Time", */
/*&out_table_nm_pool._range.POOL_NAME as pool_name label="Pool Name", */
/*&out_table_nm_pool._range.POOL_SEQ_NO as pool_seq label="Pool Sequence",*/
/*coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label="No of Accounts (Development)", */
/*coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label="No of Accounts (Actual)", */
/*NO_OF_ACTUAL_BADS as no_of_actual_bads label="No of Events (Actual)",*/
/*coalesce(ESTIMATED_POOL_PD, est_pool_rate) as pd label="Estimated PD", */
/*MAX_SCORE_POINTS as score_points label="Score Points"*/
select TIME_SK label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.15, noquote))", 
&out_table_nm_pool._range.POOL_NAME as pool_name label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.16, noquote))", 
&out_table_nm_pool._range.POOL_SEQ_NO as pool_seq label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.17, noquote))",
coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.18, noquote))", 
coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.19, noquote))", 
NO_OF_ACTUAL_BADS as no_of_actual_bads label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.20, noquote))",
coalesce(ESTIMATED_POOL_PD, est_pool_rate) as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.21, noquote))", 
MAX_SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_dynamic.sas.22, noquote))"
/*I18N-scnjih-20080418-1515*/
FROM &out_lib_nm..&out_table_nm_pool._pt
LEFT JOIN &out_lib_nm..&out_table_nm_pool._range
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._range.POOL_NAME)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._act
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._act.POOL_NAME AND
    &out_table_nm_pool._pt.TIME_SK = &out_table_nm_pool._act.SCORE_TIME_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._dev
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._dev.POOL_NAME) 
where sum(NO_OF_ACCOUNT_DEV, NO_OF_ACCOUNT_ACTUAL) <> .
order by 1, 3;
quit;
/*End of pool level feed */

%end;

%mend feed_pd_dynamic;


