/**********************************************************************************************
       Module: feed_pd_long_run
     Function:  This macro calculates the Maximum value or  average value  
				PD  for given value of  period.

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All report screens. 

        Calls:  1. Macro create_pd_sql.
				2. Macro quantile_calculation.
				3. Macro create_range_table.

Datasets used:  No input datasets required for processing of the macro.
 
        Logic:  calls the quantile_calculation and create_range_table for quantile formation and 
				range table creation on the basis of value of 	long_run_type.
   Parameters: 
		INPUT: 
				in_filter 		 	:	where clause .
				out_lib_nm			:	where the dataset will be created.
				out_table_nm_pool	:	The table name for pool level feed.
				out_table_nm_acct	:	The table name for account/application level feed
				no_of_quantile		:   number of quantile which we required.
				score_card_column   :	which contains score ranges 
				pd_ccf_lgd_column	:   It contains the name PD CCF or LGD
				long_run_type		: 	This tell which values you want to select it is for either 
									  	MAX of AVG.
**********************************************************************************************/

%macro feed_pd_long_run(in_filter=, out_lib_nm=, out_table_nm_pool=, out_table_nm_acct=,
pd_score=, range_interval=, no_of_quantile=, long_run_type=, model_time_key=);

%let model_name=;
%create_pd_sql(in_filter=&in_filter, out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool,
model_time_key=&model_time_key);

%if &error_code = ERROR %then
%RETURN;

%if &range_interval = %then
%quantile_calculation (out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool._range,
in_lib_nm=&out_lib_nm, in_table_nm_pool=&out_table_nm_pool._sql,
pd_score=&pd_score, no_of_quantile=&no_of_quantile,
score_card_column=score_points, pd_ccf_lgd_column=estimated_account_pd);
%else
%create_range_table (out_lib_nm=&out_lib_nm, out_table_nm_pool=&out_table_nm_pool._range,
in_lib_nm=&out_lib_nm, in_table_nm_pool=&out_table_nm_pool._sql, 
pd_score=&pd_score, range_interval=&range_interval);

/*Account level feed */ 
proc sql;
create view &out_lib_nm..&out_table_nm_acct.
/*I18N-scnjih-20080418-1525*/
/*as SELECT ACCOUNT_ID as account_id label="Account Identifier", */
/*CUSTOMER_ID as customer_id label="Customer Identifier", */
/*SCORE_POINTS as score_points label="Score Points", */
/*ACTUAL_GOOD_BAD as actual_good_bad label="Observed Default", */
/*PREDICTED_GOOD_BAD as predicted_good_bad label="Predicted Default", */
/*ESTIMATED_ACCOUNT_PD as pd label="Estimated PD"*/
as SELECT ACCOUNT_ID as account_id label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.1, noquote))", 
CUSTOMER_ID as customer_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.2, noquote))", 
SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.3, noquote))", 
ACTUAL_GOOD_BAD as actual_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.4, noquote))", 
PREDICTED_GOOD_BAD as predicted_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.5, noquote))", 
ESTIMATED_ACCOUNT_PD as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.6, noquote))"
/*I18N-scnjih-20080418-1525*/
FROM &out_lib_nm..&out_table_nm_pool._sql;
quit;

/*End account level feed */

%if &pd_score = SCORE %then
%do;

/*Get the no. of account development */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._dev as
select POOL_NAME, 
SUM(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
1 ELSE . END) as NO_OF_ACCOUNT_DEV 
FROM &out_lib_nm..&out_table_nm_pool._dist,
FACT.MODEL_DEV_FACT,
&out_lib_nm..&out_table_nm_pool._range
WHERE &out_table_nm_pool._dist.MODEL_SK = MODEL_DEV_FACT.MODEL_SK
GROUP BY POOL_NAME;
quit;
/*End. no. of account development */

/*Get the no of account actual */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._act AS
SELECT SCORE_TIME_SK, POOL_NAME,
SUM(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
1 ELSE . END) AS NO_OF_ACCOUNT_ACTUAL, 
SUM(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
ACTUAL_GOOD_BAD ELSE . END) AS NO_OF_ACTUAL_BADS,
MAX(case when SCORE_POINTS > FROM_SCORE AND SCORE_POINTS <= TO_SCORE THEN 
SCORE_POINTS ELSE . END)AS MAX_SCORE_POINTS
FROM &out_lib_nm..&out_table_nm_pool._sql,
&out_lib_nm..&out_table_nm_pool._range 
GROUP BY SCORE_TIME_SK, POOL_NAME;
quit;

/*End no. of account actual */

/*Long run calculation of estimated pd value */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._lrun1 AS
select lrun_pd.year_start_dt, pool_name, pool_seq_no,
sum (case when lrun_pd.SCORE_POINTS > from_score  and lrun_pd.SCORE_POINTS <= to_score then
lrun_pd.actual_good_bad else . end) as NO_OF_BADS,
sum (case when lrun_pd.SCORE_POINTS > from_score  and lrun_pd.SCORE_POINTS <= to_score then
1 else . end) as NO_OF_ACCOUNTS,
calculated NO_OF_BADS / calculated NO_OF_ACCOUNTS as ESTIMATED_POOL_PD
from longrun._lng&model_name._pd as lrun_pd, &out_lib_nm..&out_table_nm_pool._range 
group by year_start_dt, pool_name, pool_seq_no;
quit;


%if &long_run_type = MAX %then
%do;
proc sql;
create table &out_lib_nm..&out_table_nm_pool._lrun2 AS 
select pool_name, pool_seq_no, 
max(estimated_pool_pd) as estimated_pool_pd
from &out_lib_nm..&out_table_nm_pool._lrun1
group by pool_name, pool_seq_no;
quit;
%end;
%else
%do;
proc sql;
create table &out_lib_nm..&out_table_nm_pool._lrun2 AS 
select pool_name, pool_seq_no, 
avg(estimated_pool_pd) as estimated_pool_pd
from &out_lib_nm..&out_table_nm_pool._lrun1
group by pool_name, pool_seq_no;
quit;
%end;
/*End, long run calculation of estimated pd value */

/*Get the distinct values of 
TIME_SK from _sql
POOL_NAME from _mdl 
Perform cartesian product for TIME_SK, POOL_NAME */
proc sql;
create view &out_lib_nm..&out_table_nm_pool._pool
as select distinct pool_name from &out_lib_nm..&out_table_nm_pool._range;

create view &out_lib_nm..&out_table_nm_pool._time
as select distinct SCORE_TIME_SK as time_sk from &out_lib_nm..&out_table_nm_pool._sql;

create table &out_lib_nm..&out_table_nm_pool._pt
as select time_sk, pool_name from
&out_lib_nm..&out_table_nm_pool._time, &out_lib_nm..&out_table_nm_pool._pool;
quit;
/*End of cartesian product */

/*Start of pool level feed */
proc sql;
create view &out_lib_nm..&out_table_nm_pool. AS
/*I18N-scnjih-20080418-1525*/
/*select TIME_SK label="Score Time", */
/*&out_table_nm_pool._lrun2.POOL_NAME as pool_name label="Pool Name",*/
/*&out_table_nm_pool._lrun2.POOL_SEQ_NO as pool_seq label="Pool Sequence",*/
/*coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label="No of Accounts (Development)", */
/*coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label="No of Accounts (Actual)", */
/*NO_OF_ACTUAL_BADS as no_of_actual_bads label="No of Events (Actual)",*/
/*coalesce(&out_table_nm_pool._lrun2.ESTIMATED_POOL_PD, est_pool_rate) as pd label="Estimated PD", */
/*MAX_SCORE_POINTS as score_points label="Score Points"*/
select TIME_SK label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.7, noquote))", 
&out_table_nm_pool._lrun2.POOL_NAME as pool_name label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.8, noquote))",
&out_table_nm_pool._lrun2.POOL_SEQ_NO as pool_seq label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.9, noquote))",
coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.10, noquote))", 
coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.11, noquote))", 
NO_OF_ACTUAL_BADS as no_of_actual_bads label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.12, noquote))",
coalesce(&out_table_nm_pool._lrun2.ESTIMATED_POOL_PD, est_pool_rate) as pd label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.13, noquote))", 
MAX_SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.14, noquote))"
/*I18N-scnjih-20080418-1525*/
FROM &out_lib_nm..&out_table_nm_pool._pt
LEFT JOIN &out_lib_nm..&out_table_nm_pool._range
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._range.POOL_NAME)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._lrun2
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._lrun2.POOL_NAME)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._act
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._act.POOL_NAME AND
    &out_table_nm_pool._pt.TIME_SK = &out_table_nm_pool._act.SCORE_TIME_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._dev
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._dev.POOL_NAME)
where sum(NO_OF_ACCOUNT_DEV, NO_OF_ACCOUNT_ACTUAL) <> .
order by 1, 3;
quit;
/*End of pool level feed */

%end;
%else
%do;

/*Get the no. of account development */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._dev as
select POOL_NAME, 
SUM(case when ESTIMATED_ACCOUNT_PD > FROM_SCORE AND ESTIMATED_ACCOUNT_PD <= TO_SCORE THEN 
1 ELSE . END) as NO_OF_ACCOUNT_DEV 
FROM &out_lib_nm..&out_table_nm_pool._dist,
FACT.MODEL_DEV_FACT,
&out_lib_nm..&out_table_nm_pool._range
WHERE &out_table_nm_pool._dist.MODEL_SK = MODEL_DEV_FACT.MODEL_SK
GROUP BY POOL_NAME;
quit;
/*End. no. of account development */

/*Get the no of account actual */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._act AS
SELECT SCORE_TIME_SK, POOL_NAME,
SUM(case when ESTIMATED_ACCOUNT_PD > FROM_SCORE AND ESTIMATED_ACCOUNT_PD <= TO_SCORE THEN 
1 ELSE . END) AS NO_OF_ACCOUNT_ACTUAL, 
SUM(case when ESTIMATED_ACCOUNT_PD > FROM_SCORE AND ESTIMATED_ACCOUNT_PD <= TO_SCORE THEN 
ACTUAL_GOOD_BAD ELSE . END) AS NO_OF_ACTUAL_BADS,
MAX(case when ESTIMATED_ACCOUNT_PD > FROM_SCORE AND ESTIMATED_ACCOUNT_PD <= TO_SCORE THEN 
SCORE_POINTS ELSE . END)AS MAX_SCORE_POINTS
FROM &out_lib_nm..&out_table_nm_pool._sql,
&out_lib_nm..&out_table_nm_pool._range 
GROUP BY SCORE_TIME_SK, POOL_NAME;
quit;
/*End no. of account actual */

/*Long run calculation of estimated pd value */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._lrun1 AS
select lrun_pd.year_start_dt, pool_name, pool_seq_no,
sum (case when lrun_pd.estimated_pd > from_score  and lrun_pd.estimated_pd <= to_score then
actual_good_bad else . end) as NO_OF_BADS,
sum (case when lrun_pd.estimated_pd > from_score  and lrun_pd.estimated_pd <= to_score then
1 else . end) as NO_OF_ACCOUNTS,
calculated NO_OF_BADS / calculated NO_OF_ACCOUNTS as ESTIMATED_POOL_PD
from longrun._lng&model_name._pd as lrun_pd, &out_lib_nm..&out_table_nm_pool._range 
group by year_start_dt, pool_name, pool_seq_no;
quit;

%if &long_run_type = MAX %then
%do;
proc sql;
create table &out_lib_nm..&out_table_nm_pool._lrun2 AS 
select pool_name, pool_seq_no, 
max(estimated_pool_pd) as estimated_pool_pd
from &out_lib_nm..&out_table_nm_pool._lrun1
group by pool_name, pool_seq_no;
quit;
%end;
%else
%do;
proc sql;
create table &out_lib_nm..&out_table_nm_pool._lrun2 AS 
select pool_name, pool_seq_no, 
avg(estimated_pool_pd) as estimated_pool_pd
from &out_lib_nm..&out_table_nm_pool._lrun1
group by pool_name, pool_seq_no;
quit;
%end;
/*End, long run calculation of estimated pd value */

/*Get the distinct values of 
TIME_SK from _sql
POOL_NAME from _mdl 
Perform cartesian product for TIME_SK, POOL_NAME */
proc sql;
create view &out_lib_nm..&out_table_nm_pool._pool
as select distinct pool_name from &out_lib_nm..&out_table_nm_pool._range;

create view &out_lib_nm..&out_table_nm_pool._time
as select distinct SCORE_TIME_SK as time_sk from &out_lib_nm..&out_table_nm_pool._sql;

create table &out_lib_nm..&out_table_nm_pool._pt
as select time_sk, pool_name from
&out_lib_nm..&out_table_nm_pool._time, &out_lib_nm..&out_table_nm_pool._pool;
quit;
/*End of cartesian product */

/*Start of pool level feed */
proc sql;
create view &out_lib_nm..&out_table_nm_pool. AS
/*I18N-scnjih-20080418-1525*/
/*select TIME_SK label="Score Time", */
/*&out_table_nm_pool._lrun2.POOL_NAME as pool_name label="Pool Name",*/
/*&out_table_nm_pool._lrun2.POOL_SEQ_NO as pool_seq label="Pool Sequence",*/
/*coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label="No of Accounts (Development)", */
/*coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label="No of Accounts (Actual)", */
/*NO_OF_ACTUAL_BADS as no_of_actual_bads label="No of Events (Actual)",*/
/*coalesce(&out_table_nm_pool._lrun2.ESTIMATED_POOL_PD, est_pool_rate) as pd label="Estimated PD", */
/*MAX_SCORE_POINTS as score_points label="Score Points"*/
select TIME_SK label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.7, noquote))", 
&out_table_nm_pool._lrun2.POOL_NAME as pool_name label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.8, noquote))",
&out_table_nm_pool._lrun2.POOL_SEQ_NO as pool_seq label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.9, noquote))",
coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.10, noquote))", 
coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.11, noquote))", 
NO_OF_ACTUAL_BADS as no_of_actual_bads label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.12, noquote))",
coalesce(&out_table_nm_pool._lrun2.ESTIMATED_POOL_PD, est_pool_rate) as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.13, noquote))", 
MAX_SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_long_run.sas.14, noquote))"
/*I18N-scnjih-20080418-1525*/
FROM &out_lib_nm..&out_table_nm_pool._pt
LEFT JOIN &out_lib_nm..&out_table_nm_pool._range
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._range.POOL_NAME)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._lrun2
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._lrun2.POOL_NAME)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._act
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._act.POOL_NAME AND
    &out_table_nm_pool._pt.TIME_SK = &out_table_nm_pool._act.SCORE_TIME_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._dev
ON (&out_table_nm_pool._pt.POOL_NAME = &out_table_nm_pool._dev.POOL_NAME)
where sum(NO_OF_ACCOUNT_DEV, NO_OF_ACCOUNT_ACTUAL) <> . 
order by 1, 3;
quit;

/*End of pool level feed */

%end;

%mend feed_pd_long_run;
