/**********************************************************************************************
       Module:  feed_lgd_pool_mip
     Function:  This macro provides the view table for Applied LGD Model on pool level. 

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All report screens. 

        Calls:  NA

Datasets used:  No input datasets required for processing of the macro.
 
        Logic:  On selected model  and time this macro creates the 
				view  for  variable provided.All columns of score_card_fact  
				are joined by all respective dimension by the  Applied LGD table
				having name with model type and time (E.g. APPL_LGD_FACT_301_1016,  
				APPL_LGD_FACT_301_1014)with respective dimension of score_card_fact
				with model and time key (E.g. Score_card_fact_301_1016 , 
				Score_card_fact_301_1014 ).

   Parameters: 
		INPUT: 
				in_filter 		 	:	where clause in this case it is 1.
				out_lib_nm			:	where the dataset will be created.
				out_table_nm_pool	:	The table name for pool level feed.
				out_table_nm_acct	:	The table name for account/application level feed
				var					: 	Selected variable (E.G.variable 1).
				model_time_key		:	This is the combination of  selected model and selected 
										time for that model E.G. 100_1025 , 103_1027).
**********************************************************************************************/
%macro feed_lgd_pool_mip(in_filter=, out_lib_nm=, out_table_nm_pool=, 
	out_table_nm_acct=, var=, model_time_key=);

/*Generate a table by joining score_card_fact with all respective dimensions */
proc sql;
CREATE TABLE &out_lib_nm..&out_table_nm_pool._sql AS
SELECT SCORE_CARD_VARIABLE_DIM.VARIABLE_NAME AS VAR_NAME,
	SCORE_CARD_DIM.VARIABLE_GROUP_LABEL AS ATTR_NAME, 
	SCORE_CARD_DIM.NO_OF_ACCOUNTS AS NO_OF_ACC_DEV,
	SCORE_CARD_DIM.NO_OF_DEFAULTS AS NO_OF_EVENTS_DEV,
	SCORE_CARD_DIM.AVERAGE_SCORE AS AVERAGE_SCORE_DEV,
	SCORE_CARD_DIM.SCORE_CARD_POINTS AS SCORECARD_POINTS,
	SCORE_CARD_DIM.VARIABLE_GROUP_NO AS SEQ_NO,
	ACCOUNT_LGD_FACT&model_time_key..ACCOUNT_SK AS ACCOUNT_SK,
	CASE WHEN (ACTUAL_LGD > ESTIMATED_POOL_LGD) THEN 1 ELSE 0 END AS ACTUAL_GOOD_BAD
FROM FACT.SCORE_CARD_FACT&model_time_key. 
	INNER JOIN DIM.ANALYTICAL_MODEL_DIM 
	ON (SCORE_CARD_FACT&model_time_key..MODEL_SK = ANALYTICAL_MODEL_DIM.MODEL_SK) 
	INNER JOIN DIM.SCORE_CARD_DIM
	ON (SCORE_CARD_FACT&model_time_key..SCORE_CARD_SK = SCORE_CARD_DIM.SCORE_CARD_SK) 
	INNER JOIN DIM.SCORE_CARD_VARIABLE_DIM
	ON (SCORE_CARD_DIM.VARIABLE_SK = SCORE_CARD_VARIABLE_DIM.VARIABLE_SK)
	INNER JOIN FACT.ACCOUNT_LGD_FACT&model_time_key.
	ON (SCORE_CARD_FACT&model_time_key..MODEL_SK = ACCOUNT_LGD_FACT&model_time_key..MODEL_SK AND 
		SCORE_CARD_FACT&model_time_key..SCORE_TIME_SK = ACCOUNT_LGD_FACT&model_time_key..SCORE_TIME_SK AND 
		SCORE_CARD_FACT&model_time_key..ACCOUNT_SK = ACCOUNT_LGD_FACT&model_time_key..ACCOUNT_SK)
	INNER JOIN DIM.TIME_DIM 
	ON (SCORE_CARD_FACT&model_time_key..SCORE_TIME_SK = TIME_DIM.TIME_SK)
where &in_filter and SCORE_CARD_VARIABLE_DIM.VARIABLE_SK=&var ;
quit;
/*End, Generate a table by joining score_card_fact with all respective dimensions */

/*
Code to check for errors.
Possibly error will happen only if the filter condition is not properly passed. 
In this case, return to the calling program with error_code=ERROR
*/
%if &sqlrc = 8 %then
%do;
%let error_code = ERROR;
%RETURN;
%end;
/*End of code to check errors */


/* Attribute level data */
proc sql;
CREATE VIEW &out_lib_nm..&out_table_nm_pool. AS
 /*I18N-scnjih-20080421-0939*/
/*SELECT VAR_NAME label="Variable Name", ATTR_NAME label="Attribute Name", */
/*	SEQ_NO label="Sequence",*/
/*	MAX(SCORECARD_POINTS) AS SCORECARD_POINTS label="Scorecard Points", */
/*	MAX(NO_OF_ACC_DEV) AS NO_OF_ACC_DEV label="No of Accounts (Development)", */
/*	MAX(NO_OF_EVENTS_DEV) AS NO_OF_EVENTS_DEV label="No of Events (Development)", */
/*	MAX(AVERAGE_SCORE_DEV) AS AVERAGE_SCORE_DEV label="Average Score points (Development)", */
/*	COUNT(ACCOUNT_SK) AS NO_OF_ACC_ACTUAL label="No of Accounts (Actual)",*/
/*	SUM(ACTUAL_GOOD_BAD) AS NO_OF_EVENTS_ACTUAL label="No of Events (Actual)"*/
SELECT VAR_NAME label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_pool_mip.sas.1, noquote))", ATTR_NAME label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_pool_mip.sas.2, noquote))", 
	SEQ_NO label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_pool_mip.sas.3, noquote))",
	MAX(SCORECARD_POINTS) AS SCORECARD_POINTS label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_pool_mip.sas.4, noquote))", 
	MAX(NO_OF_ACC_DEV) AS NO_OF_ACC_DEV label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_pool_mip.sas.5, noquote))", 
	MAX(NO_OF_EVENTS_DEV) AS NO_OF_EVENTS_DEV label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_pool_mip.sas.6, noquote))", 
	MAX(AVERAGE_SCORE_DEV) AS AVERAGE_SCORE_DEV label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_pool_mip.sas.7, noquote))", 
	COUNT(ACCOUNT_SK) AS NO_OF_ACC_ACTUAL label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_pool_mip.sas.8, noquote))",
	SUM(ACTUAL_GOOD_BAD) AS NO_OF_EVENTS_ACTUAL label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_lgd_pool_mip.sas.9, noquote))"
	/*I18N-scnjih-20080421-0939*/
FROM &out_lib_nm..&out_table_nm_pool._sql
GROUP BY VAR_NAME, SEQ_NO, ATTR_NAME;
quit;

/* We are not calculating score range for ccf */
/* Attribute across score ranges */
/*proc sql;*/
/*CREATE TABLE &out_lib_nm..&out_table_nm_acct._sql AS*/
/*SELECT distinct SCORE_CARD_FACT.MODEL_SK, SCORE_CARD_VARIABLE_DIM.VARIABLE_NAME AS VAR_NAME,*/
/*	SCORE_CARD_DIM.VARIABLE_GROUP_LABEL AS ATTR_NAME, SCORE_CARD_DIM.SCORE_CARD_SK,*/
/*	SCORE_RANGE_FACT.FROM_SCORE, SCORE_RANGE_FACT.TO_SCORE,*/
/*	ACCOUNT_LGD_FACT.ACCOUNT_SK AS ACCOUNT_SK,*/
/*	CASE WHEN (ACTUAL_LGD > ESTIMATED_POOL_LGD) THEN 1 ELSE 0 PREDICTED_GOOD_BAD*/
/*FROM FACT.SCORE_CARD_FACT */
/*	INNER JOIN DIM.ANALYTICAL_MODEL_DIM */
/*	ON (SCORE_CARD_FACT.MODEL_SK = ANALYTICAL_MODEL_DIM.MODEL_SK) */
/*	INNER JOIN DIM.SCORE_CARD_DIM*/
/*	ON (SCORE_CARD_FACT.SCORE_CARD_SK = SCORE_CARD_DIM.SCORE_CARD_SK) */
/*	INNER JOIN DIM.SCORE_CARD_VARIABLE_DIM*/
/*	ON (SCORE_CARD_DIM.VARIABLE_SK = SCORE_CARD_VARIABLE_DIM.VARIABLE_SK)*/
/*	INNER JOIN FACT.SCORE_RANGE_FACT*/
/*	ON (SCORE_CARD_FACT.MODEL_SK = SCORE_RANGE_FACT.MODEL_SK)*/
/*	INNER JOIN FACT.ACCOUNT_LGD_FACT*/
/*	ON (SCORE_CARD_FACT.MODEL_SK = ACCOUNT_LGD_FACT.MODEL_SK AND */
/*		SCORE_CARD_FACT.SCORE_TIME_SK = ACCOUNT_LGD_FACT.SCORE_TIME_SK AND */
/*		SCORE_CARD_FACT.ACCOUNT_SK = ACCOUNT_LGD_FACT.ACCOUNT_SK)*/
/*	INNER JOIN DIM.TIME_DIM */
/*	ON (SCORE_CARD_FACT.SCORE_TIME_SK = TIME_DIM.TIME_SK)*/
/*&in_filter and SCORE_CARD_VARIABLE_DIM.VARIABLE_SK=&var and */
/*	ACCOUNT_LGD_FACT.SCORE_POINTS > FROM_SCORE AND ACCOUNT_LGD_FACT.SCORE_POINTS <= TO_SCORE;*/
/*quit;*/

/*
Code to check for errors.
Possibly error will happen only if the filter condition is not properly passed. 
In this case, return to the calling program with error_code=ERROR
*/
/*%if &sqlrc = 8 %then*/
/*%do;*/
/*%let error_code = ERROR;*/
/*%RETURN;*/
/*%end;*/
/*End of code to check errors */

/*proc sql;*/
/*CREATE TABLE &out_lib_nm..&out_table_nm_acct._act AS*/
/*SELECT MODEL_SK, SCORE_CARD_SK, VAR_NAME, ATTR_NAME, FROM_SCORE, TO_SCORE,*/
/*	COUNT(ACCOUNT_SK) AS NO_OF_ACC_ACT, SUM(PREDICTED_GOOD_BAD) AS NO_OF_EVENTS_ACT*/
/*FROM &out_lib_nm..&out_table_nm_acct._sql*/
/*GROUP BY MODEL_SK, SCORE_CARD_SK, VAR_NAME, ATTR_NAME, FROM_SCORE, TO_SCORE;*/
/*quit;*/
/**/
/*proc sql;*/
/*CREATE VIEW &out_lib_nm..&out_table_nm_acct. AS*/
/*SELECT VAR_NAME, ATTR_NAME, &out_table_nm_acct._act.FROM_SCORE, */
/*	&out_table_nm_acct._act.TO_SCORE, NO_OF_ACC_ACT, NO_OF_EVENTS_ACT,*/
/*	NO_OF_ACCOUNTS AS NO_OF_ACC_DEV, NO_OF_DEFAULTS AS NO_OF_EVENTS_DEV*/
/*FROM &out_lib_nm..&out_table_nm_acct._act INNER JOIN FACT.SCORE_RANGE_FACT*/
/*	ON (&out_table_nm_acct._act.MODEL_SK = SCORE_RANGE_FACT.MODEL_SK AND*/
/*		&out_table_nm_acct._act.SCORE_CARD_SK = SCORE_RANGE_FACT.SCORE_CARD_SK AND*/
/*		&out_table_nm_acct._act.FROM_SCORE = SCORE_RANGE_FACT.FROM_SCORE AND*/
/*		&out_table_nm_acct._act.TO_SCORE = SCORE_RANGE_FACT.TO_SCORE);*/
/*quit;*/

%mend feed_lgd_pool_mip;
