/* The input to this macro is the 
1) PERIOD: (1, 3, 6, 12, 24) for which the variables have
to be aggregated.
If PERIOD=1, then aggregation for the current month will be calculated and stored in the
OTE_TRANS_PAYMENTS_CURR_MTH table.

If PERIOD=3, then aggregation for current month and last 3 months will be calculated and stored in,
OTE_TRANS_PAYMENTS_CURR_MTH
OTE_TRANS_DEP_WDR_LST_3M, OTE_TRANS_DR_CR_LST_3M, OTE_TRANS_PAYMENTS_LST_3M,
OTE_TRANS_PUR_CADV_OVL_LST_3M and OTE_TRANS_SUMMARY_LST_3M
tables.

If PERIOD=6, then aggregation for current month and last 3 & 6 months will be calculated and stored in,
OTE_TRANS_PAYMENTS_CURR_MTH
OTE_TRANS_DEP_WDR_LST_3M, OTE_TRANS_DR_CR_LST_3M, OTE_TRANS_PAYMENTS_LST_3M,
OTE_TRANS_PUR_CADV_OVL_LST_3M and OTE_TRANS_SUMMARY_LST_3M
OTE_TRANS_DEP_WDR_LST_6M, OTE_TRANS_DR_CR_LST_6M, OTE_TRANS_PAYMENTS_LST_6M,
OTE_TRANS_PUR_CADV_OVL_LST_6M and OTE_TRANS_SUMMARY_LST_6M
tables.
 
If PERIOD=12, then aggregation for current month and last 3, 6 & 12 months will be calculated and stored in,
OTE_TRANS_PAYMENTS_CURR_MTH
OTE_TRANS_DEP_WDR_LST_3M, OTE_TRANS_DR_CR_LST_3M, OTE_TRANS_PAYMENTS_LST_3M,
OTE_TRANS_PUR_CADV_OVL_LST_3M and OTE_TRANS_SUMMARY_LST_3M
OTE_TRANS_DEP_WDR_LST_6M, OTE_TRANS_DR_CR_LST_6M, OTE_TRANS_PAYMENTS_LST_6M,
OTE_TRANS_PUR_CADV_OVL_LST_6M and OTE_TRANS_SUMMARY_LST_6M,
OTE_TRANS_DEP_WDR_LST_12M
tables.
 
2) TABLE: The input table which is already filtered for the PERIOD (1, 3, 6, 12). 
*/
%macro ote_acc_trans_lst_abt(PERIOD=, INPUT_TABLE=);
/*Sort the input data BY ACCOUNT_RK in ascending order 
and BY TIME_SK in descending order */
PROC SORT DATA=ABTSCR.&INPUT_TABLE.;
	BY ACCOUNT_RK DESCENDING TIME_SK;
RUN;

/*The data step begins here. The data step reads the sorted input data set
& outputs aggregation tables based on the PERIOD*/

data 
%if &PERIOD. = 1 %then %do; /*If PERIOD = 1*/
	%ote_acc_trans_curr_mth_abt_keep; %end;
%else %if &PERIOD. = 3 %then /*If PERIOD = 3*/
%do;
	%ote_acc_trans_curr_mth_abt_keep	
	%ote_acc_trans_lst_3m_abt_keep; 
%end;
%else %if &PERIOD. = 6 %then /*If PERIOD = 6*/ 
%do;
	%ote_acc_trans_curr_mth_abt_keep 
	%ote_acc_trans_lst_3m_abt_keep
	%ote_acc_trans_lst_6m_abt_keep;
%end;
%else %if &PERIOD. = 12 %then /*If PERIOD = 12*/
%do;
	%ote_acc_trans_curr_mth_abt_keep 
	%ote_acc_trans_lst_3m_abt_keep
	%ote_acc_trans_lst_6m_abt_keep
	%ote_acc_trans_lst_12m_abt_keep;
%end;


/* Set the input table for reading */
SET ABTSCR.&INPUT_TABLE.;
BY ACCOUNT_RK DESCENDING TIME_SK;

/*List of variables to be retained */
/*This macro has the unconditional retain statement for variables*/
	%ote_abt_trans_retain;
	
/*Depending on whether the PERIOD is (3, 6, 12) or 24, the retained variable will be
initialized */
	RETAIN CURR_TIME;
	CURR_TIME = OTE_CURR_TIME_SK;
	RETAIN COUNT 0 COUNT_TMP;

	RETAIN 	CUSTOMER_RK_RET ;

/* Assign the value of count at the start of every iteration. 
	Later used to check in conditions where counters are between 3 and 6 */
COUNT_TMP = COUNT;

/* Check to see if data is missing for certain period in the input table. If so,
   then adjust the count accordingly */
DO WHILE (TIME_SK < CURR_TIME);
	CURR_TIME = CURR_TIME - 1;
/*	COUNT = COUNT + 1;*/
END;

/* Check to see if there is more than one entry for certain period in the input table. 
   If so,  then adjust the count accordingly */
DO WHILE (CURR_TIME < TIME_SK ) ;
	CURR_TIME = CURR_TIME + 1;
/*	COUNT = COUNT - 1;*/
END;

/*Assign the value of following variables to the retained variables. 
	This variables will be written to the data set during LAST.ACCOUNT_RK */
IF FIRST.ACCOUNT_RK THEN DO;
	CUSTOMER_RK_RET = CUSTOMER_RK;
END;

IF FIRST.TIME_SK THEN 
DO;
	/*Check to see if the count has reached some level (1, 3,6,12), if so then assign the
	value of previous variable to the next level variable */

	IF COUNT EQ 1 OR (COUNT_TMP  <= 1 AND COUNT > 1) THEN DO;
	/* This macro has the assignment statements for variables of current month to 3 months */
		%ote_abt_trans_assign_1_to_3; END;	
	IF COUNT EQ 3 OR (COUNT_TMP  <= 3 AND COUNT > 3) THEN DO;
	/* This macro has the assignment statements for variables of 3 months to 6 months */
		%ote_abt_trans_assign_3_to_6; END;
	IF COUNT EQ 6 OR (COUNT_TMP  <= 6 AND COUNT > 6) THEN DO;
	/* This macro has the assignment statements for variables of 6 months to 12 months */
		%ote_abt_trans_assign_6_to_12; END;	
END;

/*The expressions like summations, max, min, count, average are all done here */
/*Check starts for 3 month calculations */
IF (COUNT < 1) THEN
DO;	
/* Variables of OTE_TRANS_DEP_WDR_CURR_MTH */	
	/* Check if transaction type is Deposit */
	IF TRANSACTION_TYPE_CD IN (&DEP_TRANS_TYPE) THEN 
	DO;
			ACC_DEP_CURR_MTH_CNT + TRANSACTION_CNT;
	END;
	
/* Variables of OTE_TRANS_DR_CR_CURR_MTH */
	/*Check if transactions are made using Debit card*/
	IF CREDIT_DEBIT_FLG IN (&DEBIT_FLAG) THEN 
	DO;
			ACC_DR_TRNS_CURR_MTH_CNT + TRANSACTION_CNT;
	END;
		
/* Variables of OTE_TRANS_PAYMENTS_CURR_MTH */
/*Check if transaction type is prepayment type */
		IF TRANSACTION_TYPE_CD IN (&PPY_TRANS_TYPE) THEN DO;
			ACC_PREPAY_CURR_MTH_AMT + TRANSACTION_AMT; END;	

/* Variables of OTE_TRANS_PUR_CADV_OVL_CURR_MTH */
/* Check if transaction type is purchase */
	IF TRANSACTION_TYPE_CD IN (&PUR_TRANS_TYPE) THEN 
	DO;
		ACC_PUR_CURR_MTH_AMT + TRANSACTION_AMT;
	END;	

/* Variables of OTE_TRANS_SUMMARY_CURR_MTH */
	/* Total number of transactions in the current month */
		ACC_TRNS_CURR_MTH_CNT + TRANSACTION_CNT;
	
END;
ELSE IF (COUNT < 3) THEN 
DO;
/* Variables of OTE_TRANS_DEP_WDR_LST_3M */
	/* Check if transaction type is Deposit */
	IF TRANSACTION_TYPE_CD IN (&DEP_TRANS_TYPE) THEN 
	DO;
			ACC_DEP_LST_3M_CNT + TRANSACTION_CNT;
	END;
	
/* Variables of OTE_TRANS_DR_CR_LST_3M */
	/*Check if transactions are made using Debit card*/
	IF CREDIT_DEBIT_FLG IN (&DEBIT_FLAG) THEN 
	DO;
			ACC_DR_TRNS_LST_3M_CNT + TRANSACTION_CNT;
	END;
		
/* Variables of OTE_TRANS_PAYMENTS_LST_3M */
/*Check if transaction type is prepayment type */
		IF TRANSACTION_TYPE_CD IN (&PPY_TRANS_TYPE) THEN DO;
			ACC_PREPAY_LST_3M_AMT + TRANSACTION_AMT; END;	

/* Variables of OTE_TRANS_PUR_CADV_OVL_LST_3M */
/* Check if transaction type is purchase */
	IF TRANSACTION_TYPE_CD IN (&PUR_TRANS_TYPE) THEN 
	DO;
		ACC_PUR_LST_3M_AMT + TRANSACTION_AMT;
	END;	

/* Variables of OTE_TRANS_SUMMARY_LST_3M */
	/* Total number of transactions in the last 3 months */
		ACC_TRNS_LST_3M_CNT + TRANSACTION_CNT;
END;

/*Check starts for 6 month calculations */	
ELSE IF (COUNT <  6) THEN 
DO;
/* Variables of OTE_TRANS_DEP_WDR_LST_6M */
	/* Check if transaction type is Deposit */
	IF TRANSACTION_TYPE_CD IN (&DEP_TRANS_TYPE) THEN 
	DO;
			ACC_DEP_LST_6M_CNT + TRANSACTION_CNT;
	END;
	
/* Variables of OTE_TRANS_DR_CR_LST_6M */
	/*Check if transactions are made using Debit card*/
	IF CREDIT_DEBIT_FLG IN (&DEBIT_FLAG) THEN 
	DO;
			ACC_DR_TRNS_LST_6M_CNT + TRANSACTION_CNT;
	END;
		

/* Variables of OTE_TRANS_PAYMENTS_LST_6M */
/*Check if transaction type is prepayment type */
		IF TRANSACTION_TYPE_CD IN (&PPY_TRANS_TYPE) THEN DO;
			ACC_PREPAY_LST_6M_AMT + TRANSACTION_AMT; END;	

/* Variables of OTE_TRANS_PUR_CADV_OVL_LST_6M */
/* Check if transaction type is purchase */
	IF TRANSACTION_TYPE_CD IN (&PUR_TRANS_TYPE) THEN 
	DO;
		ACC_PUR_LST_6M_AMT + TRANSACTION_AMT;
	END;	

/* Variables of OTE_TRANS_SUMMARY_LST_6M */
	/* Total number of transactions in the last 6 months */
		ACC_TRNS_LST_6M_CNT + TRANSACTION_CNT;
END;

/*Check starts for 12 month calculations */	
ELSE IF (COUNT <  12) THEN 
DO;
	/* Check if transaction type is Deposit */
	IF TRANSACTION_TYPE_CD IN (&DEP_TRANS_TYPE) THEN 
	DO;
			ACC_DEP_LST_12M_CNT + TRANSACTION_CNT;
	END;
	
/* Variables of OTE_TRANS_DR_CR_LST_12M */
	/*Check if transactions are made using Debit card*/
	IF CREDIT_DEBIT_FLG IN (&DEBIT_FLAG) THEN 
	DO;
			ACC_DR_TRNS_LST_12M_CNT + TRANSACTION_CNT;
	END;
		
	
/* Variables of OTE_TRANS_PAYMENTS_LST_12M */
/*Check if transaction type is prepayment type */
		IF TRANSACTION_TYPE_CD IN (&PPY_TRANS_TYPE) THEN DO;
			ACC_PREPAY_LST_12M_AMT + TRANSACTION_AMT; END;	

/* Variables of OTE_TRANS_PUR_CADV_OVL_LST_12M */
/* Check if transaction type is purchase */
	IF TRANSACTION_TYPE_CD IN (&PUR_TRANS_TYPE) THEN 
	DO;
		ACC_PUR_LST_12M_AMT + TRANSACTION_AMT;
	END;	

/* Variables of OTE_TRANS_SUMMARY_LST_12M */
	/* Total number of transactions in the last 12 months */
		ACC_TRNS_LST_12M_CNT + TRANSACTION_CNT;
	
END;

/*Increment the count and at the same time decrement the CURR_TIME to cater to the next
lowest time period */
COUNT = COUNT + 1;
CURR_TIME = CURR_TIME - 1;

/*If the end of the group is reached then output the data sets */
IF LAST.ACCOUNT_RK THEN
DO;	
	/*Assign the value of retained variables to the actual variable
	being written to the data set */
	CUSTOMER_RK = CUSTOMER_RK_RET;

	IF (COUNT <= 1) THEN	
	/*Is needed in case of premature exit, data is present only
	for the current month */
	DO;
		%ote_abt_trans_assign_1_to_3;
		%ote_abt_trans_assign_1_to_6;
		%ote_abt_trans_assign_1_to_12;
	END;
	ELSE IF (COUNT <= 3) THEN	
	/*Is needed in case of premature exit, data is present only
	for 3 months */
	DO;
		%ote_abt_trans_assign_3_to_6;
		%ote_abt_trans_assign_3_to_12;
	END;
	ELSE IF (COUNT <= 6) THEN
	/*Is needed in case of premature exit, data is present only
	for 6 months */
	DO;
		%ote_abt_trans_assign_6_to_12;
	END;	
		
	/*Output the data set */
	OUTPUT; 
	
	/*Reset all the retain variables for the next account group */
	/*This macro has the statements which resets all the variables for the next account group */
		%ote_abt_trans_reset;
		
	CURR_TIME = OTE_CURR_TIME_SK;
	COUNT = 0;
END;
run;
%mend ote_acc_trans_lst_abt;
