options nomprint;

/* Global Input Parameters */
%global scr_abt_name scr_abt_desc
purpose_key purpose_desc prod_key prod_desc level_key 
level_desc outcome_period var_level category sub_category group prev_step
var_keys first_load listopt scr_abt_table_name;

/* Start the session */
%let rc=%sysfunc(stpsrv_session(create));

/* Alias for the back-end library */
%let lib=analytic;

/* Loading macro aliases for the rest of the stored processes */
%select_abt_vars_screen_links;

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;

%macro chkduplicates;
%if %str(&save_scr_abt_key) eq %str(.) or %str(&save_scr_abt_key) eq %str() %then %do;
	%let name_exists=;
	%let inactname_exists=;

	/* Check whether the name is new or taken. */
	proc sql noprint;
		select count(*) into :name_exists
		from &lib..scr_abt_master
		where kupcase(scr_abt_nm)=kupcase(strip("&scr_abt_name"));

		select count(*) into :abttab_name_exists
		from &lib..scr_abt_master
		where kupcase(scr_abt_table_nm)=kupcase(strip("&scr_abt_table_name"));
	quit;
	%let name_exists=&name_exists;
	%let abttab_name_exists=&abttab_name_exists;


%if %str(&name_exists) ne %str(0) or %str(&abttab_name_exists) ne %str(0) %then %do;
data _null_;
		file _webout &webout_options;
		put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"';
		put '"http://www.w3.org/TR/html4/loose.dtd">';
		put '<html>';
		put '<head>';
		put '<link href="/SASABTFramework/styles/default.css" rel="stylesheet" type="text/css"> ';
		put '<style type="text/css">';
		put '<!--';
		put 'body {';
		put '	background-color: #FAF8ED;';
		put '}';
		put '-->';
		put '</style>';
		put '</head>';
		put '<body>';
		put "<form name=""form1"" action=""&_THISSESSION"" method=""post"">";
		put "    <input name='_program' value='' type='hidden' />";
		put '  </form>';
		put '  <script type="text/javascript">';
		put '  <!--';

		/* Pop up the message and proceed. */
		if "&name_exists" ne "0" then do;
			put '    alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_abtexists.1, noquote))" @;
			put '");'@;
		end;
		else if "&abttab_name_exists" ne "0" then do;
			put '    alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_abttabexists.1, noquote))" @;			
			put '");';	
		end;	
		put "    form1._program.value=&SCR_TEMPLATE_STEP1;";
		put '    form1.submit();';
		put '  -->';
		put '  </script>';
		put '</body>';
		put '</html>';
	run;
  %end;
%end;
%mend chkduplicates;
%chkduplicates;

/*Here, copy the parameters into the session variables -- only if you are coming from the right page. */
data _null_;
	if "&prev_step" eq "1" then do;
		call symput('save_scr_abt_name', "&scr_abt_name");
		call symput('save_scr_abt_desc', "&scr_abt_desc");
		call symput('save_scr_purpose_key', "&purpose_key");
		call symput('save_scr_purpose_desc', "&purpose_desc");
		call symput('save_scr_prod_key', "&prod_key");
		call symput('save_scr_prod_desc', "&prod_desc");
		call symput('save_scr_level_key', "&level_key");
		call symput('save_scr_level_desc', "&level_desc");
		call symput('save_scr_outcome_period', "&outcome_period");
		call symput('save_scr_abt_table_name', "&scr_abt_table_name");
	end;
	if "&prev_step" eq "2" then do;
		call symput('save_scr_var_keys', "&var_keys");
	end;
run;

%let modsks=0; /*default*/
proc sql noprint;
	/* Get Scoring ABT details */
	create table &out_lib..scr_abt as
	select scr_a_no, scr_abt_nm, scr_abt_desc, scr_l_no, level_desc
	from &lib..scr_abt_master, &lib..abt_level
	where scr_abt_master.scr_l_no = abt_level.l_no;

	/* Get Model details */
	create table &out_lib..model_details as
	select model_id,model_sk, model_nm, model_desc, put(model_type_cd,$modtype.) as model_type_desc, 
		put(model_product_type_cd, $prtype.) as model_product_type_desc, 
		put(deployment_status_cd, $moddep.) as deployment_status_desc, 
		target_period_mths_cnt
	from dim.analytical_model_dim
	where deployment_status_cd not in ("&EXP_MODEL_DEPLOYMENT") and model_sk > 0
	order by model_sk;

	/* Get number of models */
	select count(*) into :check_cnt
	from &out_lib..model_details;

	/* Get ABT Model Link */
	create table &out_lib..model_abt as
	select scr_a_no, scr_abt_x_model.model_sk, is_selected_flg
	from &lib..scr_abt_x_model, &out_lib..model_details
	where scr_abt_x_model.model_sk=model_details.model_sk
	order by scr_a_no, scr_abt_x_model.model_sk;

	create table &out_lib..temp as
	select * from &out_lib..model_abt where scr_a_no=&save_scr_abt_key and is_selected_flg='Y';

	select model_sk into :modsks separated by ',' 
	from &out_lib..model_abt where scr_a_no=&save_scr_abt_key and is_selected_flg='Y';
quit;

/* Start printing HTML */
data _NULL_;
	file _webout &webout_options;

	put '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">';
	put '<html xmlns="http://www.w3.org/1999/xhtml"><!-- InstanceBegin template="/Templates/dashboard.dwt" codeOutsideHTMLIsLocked="false" -->';
	put '  <head>';
	put '    <meta http-equiv="content-type" content="text/html;charset=utf-8" />';
	put '    <script type="text/javascript">';
	put '      <!--';

	/* This takes you back to previous wizard pages. */
	put 'function back(page)';
	put '{';
	put '  if(page == 1)';
	put "    form1._program.value=&TEMPLATE_STEP1;";
	put '  else if(page == 2)';
	put "    form1._program.value=&TEMPLATE_STEP2;";
	put '  else if(page == 3)';
	put "    form1._program.value=&TEMPLATE_STEP3;";
	put '  else';
	put "    form1._program.value=&TEMPLATE_STEP4;";
	put '  form1.submit();';
	put '}';

	/* This function is called when the previous button is clicked */
	put 'function previous()';
	put '{';
	put "    form1._program.value=&SCR_TEMPLATE_STEP1;";
	put '	 form1.submit()';
	put '}';

	/* Move to the next page. */
	put 'function next()';
	put '{';
	put 'var i,cnt=0,chkflag=0;';
	put 'if(!form1.check_box){';
	put 'alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.scr_tmplt_stp2_alert1.1, noquote))" @;			
	put '");';
	put 'return;}';
	put 'if(form1.check_box.checked==false)';
	put '{';
	put 'alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.scr_tmplt_stp2_alert2.1, noquote))" @;
	put '");'@;
	put 'return;';
	put '}';
	put 'form1.modstr.value="";';
	put 'form1.modsk.value="";';

	put 'if(form1.check_box.checked==true)';
	put '	form1.modstr.value = '@;
	put '"''"'@;
	put '+ form1.check_box.value +'@;
	put '"''"'@;
	put ';';
	put 'else {';
	put 'for(i=0;i<form1.check_box.length;i++){';
	put '	if(form1.check_box[i].checked==true){';
	put '		form1.modsk.value = form1.modsk.value + form1.msk[i].value;';
	put '		chkflag=1;';
	put '		if(form1.modstr.value=="")';
	put '			form1.modstr.value = '@;
	put '"''"'@; 
	put '+form1.check_box[i].value+';
	put '"''";'@;
	put '		else {';
	put 'form1.modstr.value ='@; 
	put 'form1.modstr.value +'@;
	put '","+'@;
	put '"''"'@;
	put '+ form1.check_box[i].value +'@;
	put '"''"'@;
	put ";"@;
	put '	}';
	put '  }';
	put ' }';
	put 'if(chkflag==0)';
	put '{';
	put 'alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.scr_tmplt_stp2_alert3.1, noquote))" @;
	put '");'@;
	put 'return;';
	put '}';
	put '}';
	put "form1._program.value = &SCR_TEMPLATE_STEP3";
	put 'form1.submit();';
	put '}';

	put 'function restrictnav()';
	put '{';
	put 'alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_restrictnav.1, noquote))" @;
	put '");';
	put 'return;';
	put '}';

	/* This function is called when the cancel button is clicked */
	put 'function cancel()';
	put '{';
	put "	form1._program.value=&SCR_TEMPLATE_LIST;";
	put '	form1.submit();';
	put '}';
run;
data _null_;
file _webout &webout_options;
	put '      //-->';
	put '    </script>';

 	  /*I18N-scnjih-20080429-1539*/
	/*put '    <!-- InstanceBeginEditable name="doctitle" --><title>Layout</title><!-- InstanceEndEditable -->';*/
		put '    <!-- InstanceBeginEditable name="doctitle" --><title>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,title_of_layout.1, noquote))"@;
		put '</title><!-- InstanceEndEditable -->';
	
	 /*I18N-scnjih-20080429-1539*/
	put '    <link rel="stylesheet" type="text/css" href="/SASABTFramework/styles/default.css" />';
	put '    <script src="/SASABTFramework/javascript/scripts.js" type="text/javascript"></script>';
	put '    <script src="/SASABTFramework/javascript/buttonMenu.js" type="text/javascript"></script>';
	put '    <script src="/SASABTFramework/javascript/overlib.js" type="text/javascript"></script>';
	put '    <script type="text/javascript" src="/SASABTFramework/javascript/table_controls.js"></script>';
	put '    <script type="text/javascript" src="/SASABTFramework/javascript/boxOver.js"></script>';
	put '  </head>';
	put '  <body>';
	
	put "<form name=""form1"" action=""&_THISSESSION"" method=""post"">";

	/* Input variables contain the state of the two lists. */
	put "      <input type=""hidden"" name=""_program"" value=&SCR_TEMPLATE_STEP3>";

	put '<input type="hidden" name="modstr" value="">';
	put '<input type="hidden" name="modsk" value="">';
	put '<input type="hidden" name="abt_key" value="">';
	
	put '      <div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div>';
	put '      <div id="banback">';

	/* Banner code. */
	put '          <table id="bantabs" border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '            <tr valign="top">';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_home.1, noquote))" @;
	put "</a></td>";
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_modeling.1, noquote))" @;
	put "</a></td>";
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tabsellft"><img src="/SASABTFramework/images/tab_upper_left_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tabsellab'><a href='#'>"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scoring.1, noquote))" @;
	put '</a></td>';
	put '              <td class="mmhide_tabselrgt"><img src="/SASABTFramework/images/tab_upper_right_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scheduling.1, noquote))" @;
	put '</a></td>';
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td width="100%">&nbsp;</td>';
	put '            </tr>';
	put '          </table>';
	put '      </div>';
	put '      <table border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '        <tr>';
	put '          <td id="butbar">';
	put '            <font color="#996600"> <b>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_create_or_edit_template.1, noquote))" @;
	put '</b>';
	put '            <span id="butfill">&nbsp;</span>';
	put '          </td>';
	put '        </tr>';
	put '      </table>';

	/* List on the left side */
	put '      <table border="0" cellpadding="0" cellspacing="0" summary="" width="100%" height="450">';
	put '        <tr valign="top">';
	put '          <td  id="navcel">';
	put '            <div id="navcol">';
	put '              <table border="0" cellspacing="0" summary="" class="mmhide_wizardsteps">';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td><img src="/SASABTFramework/images/AdjustmentComplete.gif"></td>';
	put '					<td>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.details.1, noquote))" @;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td nowrap class="mmhide_wizardstepact"></td>';
	put '                  <td class="mmhide_wizardstepact">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.Link_scoring_to_abt_mdl.1, noquote))" @;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td><img src="/SASABTFramework/images/blank.gif" width="16"></td>';
	put '                  <td>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.summary.1, noquote))" @;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td>';
	put '                  </td>';
	put '                  <td><img src="/SASABTFramework/images/blank.gif" width="180" height="1"></td>';
	put '                </tr>';
	put '              </table>';
	put '            </div>';
	put '          </td>';
	put '          <td id="navwdg"><img src="/SASABTFramework/images/blank.gif" name="navwdg" border="0" width="11" height="14" hspace="0" vspace="0" alt="" /></a></td>';
	put '          <td width="100%" id="wizardmain">';
	put '            <!--content comes here-->';
	put '            <div id="pagetitlesection">';
	put '            <div id="pagetitle">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.Link_scoring_to_abt_mdl.1, noquote))" @;
	put '            </div>';
	put '            <div id="pagesubtitle"><!-- InstanceBeginEditable name="pagesubtitle" -->&nbsp;<!-- InstanceEndEditable --></div>';
	put '            </div>';
	put '            <div class="formfields">';

	/* Here, we have non-changing textboxes that display the name and description. */
	put '              <table class="formfields" cellpadding="4" border="0">';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put '                    &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_name.1, noquote))" @;
	put ':';
	put '                  </td>';
	put '                  <td class="">';
	put "                    <input type=""text"" style=""width:200px;"" name=""Name"" value=""&save_scr_abt_name"" Disabled class=""inputtext"">";
	put '                  </td>';
	put '                </tr>';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put '                    &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_description.1, noquote))" @;
	put ':';
	put '                  </td>';
	put '                  <td class="">';
	put "                    <input type=""text"" style=""width:200px;"" name=""Description"" value=""&save_scr_abt_desc"" Disabled class=""inputtext"">";
	put '                  </td>';
	put '                </tr>';
	put '                <tr valign="top">';	
/*	put '				</table>';	*/
/*	put '      </table>';*/
run;

data _null_;
file _webout &webout_options;
	put '<table width="100%" border="0" cellpadding="0" cellspacing="0" class="tableview">';
	put '              <tr>';
	put '                <th class="tabletextcol"></th>';
	put '                <th class="tabletextcol">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modname.1, noquote))" @;
	put '</th>';
	put '                <th class="tabletextcol">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.moddesc.1, noquote))" @;
	put '</th>';
	put '                <th class="tabletextcol">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modtype.1, noquote))" @;
	put '</th>';
	put '                <th class="tabletextcol">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.depstatus.1, noquote))" @;
	put '</th>';
	put '                <th class="tabletextcol">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modprodtype.1, noquote))" @;
	put '</th>';
	put '                <th class="tabletextcol">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modocprd.1, noquote))" @;
	put '</th>';
	put '              </tr>';
run;

data _null_;
	file _webout &webout_options;
	set &out_lib..model_details;
	if  mod(_N_,2)=0 then
		put '                <tr class="tableevenrow">';
	else 
		put '                <tr class="tableoddrow">';
	put '                <td width="15" class="LabelFont"><div align="center">';
	put '                  <input type="checkbox" name="check_box" value="'@;
	put model_id@;	
	put '"'@;
	if model_sk in (&modsks) then
		put 'disabled checked=true'@;
	put '/>';

	put '<input type="hidden" name="msk" value="'@;
	put model_sk@;
	put '"/>';
	put '                </div></td>';
	put '                <td class="tabletextcol">'@;
	put model_nm@;
	put '</td>';
	put '                <td class="tabletextcol">'@;
	put model_desc@;
	put '</td>';
	put '                <td class="tabletextcol">'@;
	put model_type_desc@;
	put '</td>';
	put '                <td class="tabletextcol">'@;
	put deployment_status_desc@;
	put '</td>';
	put '                <td class="tabletextcol">'@;
	put model_product_type_desc@;
	put '</td>';
	put '                <td class="tablenumcol">'@;
	put target_period_mths_cnt@;
	put '</td>';
	put '              </tr>';
run;

data _NULL_;
	file _webout &webout_options;
    put '				</table>';
	put '			   </tr>';
	put '			</table>';
	put '          </div>';	
	put '          </td>';
	put '        </tr>';
	put '    </table>';
	/* Wizard navigation buttons */
	put '      <table border="0" cellpadding="3" cellspacing="0" summary="Action Buttons" id="dialogbuttons" width="100%">';
	put '        <tr>';
	put '          <td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.prevbttn.1, noquote))" @;
	put '" name="< Previous" type="button" onclick="previous()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.nextbttn.1, noquote))" @;
	put '" name="Next >" type="button" onclick="next()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="30"><img src="/SASABTFramework/images/blank.gif" width="30" height="1">';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg, abt.finishbttn.1, noquote))" @;
	put '" name="Finish" type="button" Disabled>';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.cancelbttn.1, noquote))" @;
	put '" name="Cancel" type="button" onclick="cancel()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '          </td>';
	put '          <td width="90%">&nbsp;';
	put '          </td>';
	put '        </tr>';
	put '      </table>';
	put '      <!--Big table ends here-->';
	put '      <div id="foot">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.copyright_notice.1, noquote))"@;
	put '      </div>';
	put '    </form>';
	put '  </body><!-- InstanceEnd -->';
	put '</html>';
run;
