options nomprint;
option SYMBOLGEN;

/* Global Input Parameters */
%global abt_key abt_name abt_table_name year month_no action obs_dt;

/* 	Action:
		N: None
		A: New ABT
		B: Build ABT
*/

%let lib=analytic;

/* Setting default values for any required parameters */
data _null_;
	if "&action"="" then call symput('action','N');
run;

/* Trimming extra spaces for all input paremeters */
%let action=&action;
%let abt_key=&abt_key;
%let abt_name=&abt_name;
%let abt_table_name=&abt_table_name;
%let year=&year;
%let month_no=&month_no;
%let obs_dt=&obs_dt;

/* Links specific for the Build ABT screen */
%select_abt_vars_screen_links;

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;

%macro mdlbuild;
proc sql noprint;
	create table &out_lib..mdl_abt as
	select distinct abt_master.a_no , abt_nm, abt_table_nm, abt_desc
	from &lib..abt_master, &lib..abt_x_var
	where abt_master.a_no = abt_x_var.a_no and
		abt_x_var.is_selected_flg='Y';

	select count(*) into :no_records
	from &out_lib..mdl_abt;

	create table &out_lib..build_mdl_abt as
	select abt_status.a_no, abt_nm, obs_dt, phy_table_nm, status_desc
	from &lib..abt_status, &lib..abt_master
	where abt_status.a_no = abt_master.a_no
	order by a_no;
quit;

proc sql;
select abt_table_nm into :abt_table_name 
from &out_lib..abt_records
where a_no=&abt_key;
quit;
%let abt_table_name=&abt_table_name;

proc sql;
	create table &out_lib..year as
	select distinct cal_year_no as year
	from dim.time_dim;
quit;

%let error_code=NONE;

/*Proc printto will redirect the log to the directory
"Data/bisdata/log". */
%global log_name;
data _NULL_;
name=put(time(),mmss8.1);
name1=kscan(name,1,":.");
name2=kscan(name,2,":.");
name3=kscan(name,3,":."); 
name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
call symput('log_name',"Data/bisdata/log/abt_build."||trim(left(name4))||".log");
run;

%put NOTE: Sending log messages to :&log_name;

proc printto log="&log_name";
quit;

%let obsdt=%sysfunc(mdy(&month_no,1,&year));

/* Delete status info if abtkey already exists */
proc sql;
	delete from &lib..abt_status where A_NO = &abt_key;
quit;

%if &sqlrc ne 0 %then
%do;
%let error_code = ERROR;
%end;

/* Insert status into the table */
proc sql;
	insert into &lib..abt_status
	(A_NO, OBS_DT, PHY_TABLE_NM, CREATION_DT, CREATED_BY, STATUS_DESC) 
	/*I18N-scnjih-20080430-1335*/
	/*VALUES(&abt_key,&obsdt,"&abt_table_name",.,"","Building ABT");*/
	VALUES(&abt_key,&obsdt,"&abt_table_name",.,"","%sysfunc(sasmsg(smd_ds.bismsg,build_mdl_abt.sas.1, noquote))");
	/*I18N-scnjih-20080430-1335*/
quit;

%if &sqlrc ne 0 %then
%do;
%let error_code = ERROR;
%end;

/*Proc printto will reset the log redirection */
proc printto;
quit; 

%put NOTE: Resetting log to _webout;
/*End of proc printto */

/* Show the relevant messages on the screen */
data _null_;
	file _webout &webout_options;
	put '<html>';
	put '<body>';
	put '<form method="post" action="/SASStoredProcess/do" name="form1">';
	put '<input type="hidden" name="_program" VALUE="">';
	put '<input type="hidden" name="obs_dt">';
	put '<input type="hidden" name="abt_key">';
	put '<input type="hidden" name="phy_nm">';
	put '<script language="JavaScript" type="text/JavaScript"> ';
	put '<!-- ';
%if %str(&error_code) eq %str(ERROR) %then %do;
	put '	alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.build_mdl_abt_alert1.1, noquote))"@;
	put "&log_name"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_frfurtherdtls.1, noquote))"@;
	put '")';
%end;
%else %do;
	/* Start the process of building in background */
	put "	form1.obs_dt.value=&obsdt";
	put "	form1.abt_key.value=&abt_key";
	put "	form1.phy_nm.value=""&abt_table_name""";
	put "	form1._program.value=&BUILD_ABT";
	put '	form1.submit();';
%end;
	put '//-->';
	put	'</script>';
	put '</body>';
	put '</form>';
	put '</html>';
run;
%mend mdlbuild;
%mdlbuild;
