options nomprint;

/* Global Input Parameters */
%global action sel_models abt_key;

/* Setting default values for any required parameters */
data _null_;
	if "&action"="" then call symput('action','N');
	if "&abt_key"="" then do;
		call symput('abt_key','.');
		call symput('abt_desc', ' ');
		call symput('level_desc', ' ');
	end;
run;

/* Trimming extra spaces for all input paremeters */
%let action=&action;
%let sel_models=&sel_models;
%let abt_key=&abt_key;

%let lib=analytic;

/* Links specific for the Link the Modeling ABT to the Model screen */
%select_abt_vars_screen_links;

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;

%let abt_desc=;
%let level_desc=;
%let models_cnt=;
%let abt_name=;
%let abt_desc=; 
%let level_desc=; 
%let prod_desc=; 
%let prod_param=;
%let purpose_lvl_param=;

/* Macro to retrieve the Model details for the selected existing ABT */
%macro model_details;
	proc sql;
		/* Get Model details */
		create table &out_lib..model_det_sel as
		select model_sk, model_nm, model_desc, 
			put(model_type_cd,$modtype.) as model_type_desc, 
			put(model_product_type_cd, $prtype.) as model_product_type_desc, 
			put(deployment_status_cd, $moddep.) as deployment_status_desc, 
			target_period_mths_cnt
		from dim.analytical_model_dim
		where deployment_status_cd not in ("&EXP_MODEL_DEPLOYMENT") and model_sk > 0
		order by model_sk;

		/* Get number of models */
		select count(*) into :models_cnt
		from &out_lib..model_det_sel;
		
		/* Get Modeling ABT details */
		select abt_nm, abt_desc, level_desc, product_type_desc, 
				abt_product.custpara_nm, abt_purpose_x_level.custpara_nm 
				into :abt_name, :abt_desc, :level_desc, :prod_desc, :prod_param, :purpose_lvl_param
			from &lib..abt_master inner join &lib..abt_level
				on (abt_master.l_no = abt_level.l_no)
				inner join &lib..abt_purpose_x_level
				on (abt_master.ap_no = abt_purpose_x_level.ap_no and 
					abt_master.l_no = abt_purpose_x_level.l_no)
				left join &lib..abt_product
				on (abt_master.p_no = abt_product.p_no)
			where abt_master.a_no = &abt_key;
	quit;
	
		proc sql noprint;
			%if %upcase(%str(&level_desc)) eq %upcase(%str(Customer)) %then %do;
				/* Get Model details */
				create table &out_lib..model_details as
				select analytical_model_dim.model_sk, model_nm, model_desc, 
					put(model_type_cd,$modtype.) as model_type_desc, 
					'' as model_product_type_desc, 
					put(deployment_status_cd, $moddep.) as deployment_status_desc, 
					target_period_mths_cnt, is_selected_flg
				from dim.analytical_model_dim left join &lib..abt_x_model
					on(analytical_model_dim.model_sk = abt_x_model.model_sk and 
						abt_x_model.a_no=&abt_key)
				where deployment_status_cd not in ("&EXP_MODEL_DEPLOYMENT") and 
					model_type_cd in (&&&purpose_lvl_param)
				order by analytical_model_dim.model_sk;
			%end;
			%else %do;
				/* Get Model details */
				create table &out_lib..model_details as
				select analytical_model_dim.model_sk, model_nm, model_desc, 
					put(model_type_cd,$modtype.) as model_type_desc, 
					put(model_product_type_cd, $prtype.) as model_product_type_desc, 
					put(deployment_status_cd, $moddep.) as deployment_status_desc, 
					target_period_mths_cnt, is_selected_flg
				from dim.analytical_model_dim left join &lib..abt_x_model
					on(analytical_model_dim.model_sk = abt_x_model.model_sk and 
						abt_x_model.a_no=&abt_key)
				where deployment_status_cd not in ("&EXP_MODEL_DEPLOYMENT") and 
					model_type_cd in (&&&purpose_lvl_param) and
					model_product_type_cd in (&&&prod_param)
				order by analytical_model_dim.model_sk;
			%end;

			/* Get number of models */
			select count(*) into :models_cnt
			from &out_lib..model_details;

			create table &out_lib..other_abt as
			select *
			from &lib..abt_x_model
			where a_no ne &abt_key;

			create table &out_lib..model_det_sel as
			select model_details.*, case when other_abt.a_no ne . then 'Y' else 'N' end as mapped
			from &out_lib..model_details left join &out_lib..other_abt
			on(model_details.model_sk=other_abt.model_sk and other_abt.is_selected_flg='Y');
		quit;
%mend;
%model_details;

/* Start HTML Screen*/
data _null_;
	file _webout &webout_options;
	put '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">';
	put '<html xmlns="http://www.w3.org/1999/xhtml">';
	put '<head>';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />';
/*I18N-scnhuh-20080418-1023*/	
	put '<link href="/SASABTFramework/styles/default.css" rel="stylesheet" type="text/css" />';
	put '<style type="text/css">';
	put '<!--';
	put '.style2 {font-size: small}';
	put 'body {';
	put '	background-color: #FAF8ED;';
	put '}';
	put '-->';
	put '</style>';
	put '</head>';

	put '<script language="JavaScript" type="text/JavaScript"> ';
	put '<!-- ';

	put 'function Save(){';
	put '	if((form1.abt_key.value == '''') || (form1.abt_key.value == ''.'')){';
	put '		alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.linkmdl_selmod.1, noquote))"@;
	put '")';
	put '		return;';
	put '	}';
	put '	var ch_val=""';
	if &models_cnt = 1 then do;
		put '	if(form1.selmodel.checked==true){';
		put '		ch_val = form1.selmodel.value';
		put '	}';
	end;
	else do;
		put "	for (var i=0; i < &models_cnt; i++){";
		put '		if(form1.selmodel[i].checked==true){';
		put '			if(ch_val == ""){';
		put '				ch_val = form1.selmodel[i].value';
		put '			}';
		put '			else{';
		put '				ch_val = ch_val + " " +form1.selmodel[i].value';
		put '			}';
		put '		}';
		put '	}';
	end;
	put '	form1.action.value="S"';
	put '	form1.sel_models.value=ch_val';

/* Shyam Added Start*/
/*	put '	if((form1.sel_models.value == '''') || (form1.sel_models.value == ''.'')){';*/
/*	put '		alert("Please select a Modeling ABT to link the models to.")';*/
/*	put '		return;';*/
/*	put '	}';*/
/* Shyam Added End*/

	put "	form1._program.value='&SELECT_MDL_ABT_LINKER'";
	put '	form1.submit()';
	put '}';

	put 'function Cancel()';
	put '{';
		put "form1._program.value=&TEMPLATE_LIST";
		put 'form1.submit()';
	put '}';

	put 'function regmodels()';
	put '{';
		put "form1._program.value=&POP_AM;";
		put 'form1.submit();';
	put '}';

	put '//-->';
	put	'</script> ';

	put '</head> ';

	put '<body>';
	put '<form name="form1" method="post" action="/SASStoredProcess/do">';
	put '<input type="hidden" name="_program" VALUE="">';

	abt_key=symget("abt_key");
	x='<input type="hidden" name="abt_key" value="'||strip(abt_key)||'">';
	put x;
	put '<input type="hidden" name="sel_models" value="">';
	put '<input type="hidden" name="action" value="">';
run;

%macro save_details;
	%if %upcase("&action") eq "S" %then %do;
		%let error_code=NONE;

		/*Proc printto will redirect the log to the directory
		"Data/bisdata/error". */
		%global log_name;
		data _NULL_;
		name=put(time(),mmss8.1);
		name1=kscan(name,1,":.");
		name2=kscan(name,2,":.");
		name3=kscan(name,3,":."); 
		name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
		call symput('log_name',"Data/bisdata/log/mdl_abt_link."||ktrim(kleft(name4))||".log");
		run;

		%put NOTE: Sending log messages to :&log_name;

		proc printto log="&log_name";
		quit;

		proc sql noprint;
			select count(*) into :no_records
			from &lib..abt_x_model
			where a_no=&abt_key;
		quit;

		%let no_records=&no_records;

		proc sort data=dim.analytical_model_dim out=work.model_srt;
			by model_sk;
		quit;

		data &out_lib..model_selection(keep=a_no model_sk is_selected_flg);
			length a_no 8.;
			length model_sk 8.;
			length is_selected_flg $1.;
			retain cnt 1;
			set work.model_srt(keep=model_sk deployment_status_cd
				where=(deployment_status_cd not in ("&EXP_MODEL_DEPLOYMENT")));
			a_no = &abt_key;
			if indexw("&sel_models",model_sk)>0 then 
				is_selected_flg = "Y";
			else is_selected_flg = "N";
		run;

		/* If it is a new ABT definition, insert it into the table */
		%if %str(&no_records) eq %str(0) %then %do;
			proc append data=&out_lib..model_selection base=&lib..abt_x_model force;
			quit;
		%end;
		/* If it is an existing ABT definition, update the record in the table */
		%else %if %str(&no_records) ne %str(0) and %str(&abt_key) ne %str(.) and
			%str(&abt_key) ne %str() %then %do;
			proc sort data=&lib..abt_x_model out=work.abt_x_model_srt;
				by a_no model_sk;
			quit;

			proc sort data=&out_lib..model_selection out=work.model_selection_srt;
				by a_no model_sk;
			quit;

			data &lib..abt_x_model;
				merge work.abt_x_model_srt(in=A) work.model_selection_srt(in=B);
				by a_no model_sk;
			run;		
		%end;

		/*Proc printto will reset the log redirection */
		proc printto;
		quit; 

		%put NOTE: Resetting log to _webout;
		/*End of proc printto */

		/* Show the relevant messages on the screen */
		data _null_;
/*I18N-scnhuh-20080418-2020*/
/*add &webout_options*/		
			file _webout&webout_options;
/*I18N-scnhuh-20080418-2020*/
			put '<script language="JavaScript" type="text/JavaScript"> ';
			put '<!-- ';
		%if %str(&error_code) eq %str(ERROR) %then %do;
			put '	alert("' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_savefailed.1, noquote))"@;
			put "&log_name"@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_frfurtherdtls.1, noquote))"@;
			put '")';
		%end;
		%else %do;
			put '	alert("' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.linkmdl_savesuccessful.1, noquote))"@;
			put '")';
			put '	document.form1.action.value="R"';
			put "	document.form1._program.value='&SELECT_MDL_ABT_LINKER'";
			put '	document.form1.submit()';

	/*Added by Shyam : Start*/
	put '{';
		put "form1._program.value=&TEMPLATE_LIST";
		put 'form1.submit()';
	put '}';
	/*Added by Shyam : End*/
		%end;
			put '//-->';
			put	'</script> ';
		run;
	%end;
%mend save_details;
%save_details;

data _null_;
file _webout &webout_options;	
		put '<table class="tableview">';
		put '<tr><td align="right"><a href="javascript:regmodels()">' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.linkmdl_capmodinfo.1, noquote))"@;
		put '</a></td></tr>';
		put '</table>';
		put '<br>';
run;
data _null_;
file _webout &webout_options;
		put '                <table class="tableview">';
		put '                  <tr>';
		put '            		<th class="tabletextcol">' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.linkmdl_abtdesc.1, noquote))"@;
		put '</th>';
		put '            		<td class="tabletextcol">'@;
		put "&abt_desc"@;
		put '</td>';
		put '                  </tr>';
		put '                  <tr>';
		put '            		<th class="tabletextcol">' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.linkmdl_abtlevel.1, noquote))"@;
		put '</th>';
		put '            		<td class="tabletextcol">'@;
		put "&level_desc"@;
		put '</td>';
		put '                  </tr>';
		put '                </table>';
		put '<br>';
		put '        <table  border="0" cellpadding="0" cellspacing="0" class="tableview">';
		put '          <tr>';
		put '            <td valign="top"><table width="100%" border="0" cellpadding="0" cellspacing="0">';
		put '              <tr>';
		put '                <th width="15" class="tabletextcol">&nbsp;</th>';
		put '                <th class="tabletextcol">' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modname.1, noquote))"@;
		put ' </th>';
		put '                <th class="tabletextcol">' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.moddesc.1, noquote))"@;
		put ' </th>';
		put '                <th class="tabletextcol">' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modtype.1, noquote))"@;
		put ' </th>';
		put '                <th class="tabletextcol">' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.depstatus.1, noquote))"@;
		put ' </th>';
		put '                <th class="tabletextcol">' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modprodtype.1, noquote))"@;
		put ' </th>';
		put '                <th class="tabletextcol">' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modocprd.1, noquote))"@;
		put ' </th>';
		put '              </tr>';
	run;

data _null_;
file _webout &webout_options;
set &out_lib..model_det_sel;
		if  mod(_N_,2)=0 then
			put '                <tr bgcolor="#F4F4F2">';
		else 
			put '                <tr bgcolor="#FFFFFF">';
		put '                <td width="15" class="LabelFont"><div align="center">';
		put '                  <input type="radio" name="selmodel" value="'@;
		put model_sk@;
		put '" '@;
		if is_selected_flg='Y' then put 'checked '@;
		if mapped='Y' then put 'disabled '@;
		put '/>';
		put '                </div></td>';
		put '                <td class="verttebleborder">'@;
		put model_nm@;
		put '</td>';
		put '                <td class="verttebleborder">';
		put model_desc@;
		put '</td>';
		put '                <td class="verttebleborder">'@;
		put model_type_desc@;
		put '</td>';
		put '                <td class="verttebleborder">'@;
		put deployment_status_desc@;
		put '</td>';
		put '                <td class="verttebleborder">'@;
		put model_product_type_desc@;
		put '</td>';
		put '                <td class="verttebleborder">'@;
		put target_period_mths_cnt@;
		put '</td>';
		put '              </tr>';
	run;

	data _null_;
	file _webout &webout_options;
		put '            </table></td>';
		put '          </tr>';
		put '        </table>';
		put '<br>';
		put '      <tr><td>&nbsp;</td></tr>';
		put '		   <tr bgcolor="#FAF8ED">';
		put '    		<td bgcolor="#F1EACB">&nbsp;&nbsp;';
		put '            <input type="button" name="Savebtn" value="' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.savebttn.1, noquote))"@;
		put '" class="mmhide_btn" onClick="javascript:Save()"/>';
		put '    		</td>';
		put '    		<td bgcolor="#F1EACB">&nbsp;&nbsp;';
		put '            <input type="button" name="Cancelbtn" value="' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.backbttn.1, noquote))"@;
		put '" class="mmhide_btn" onClick="javascript:Cancel()"/>';
		put '    		</td>';
		put '		   </tr></td>';
		put '        </tr>';
		put '      </table></td>';
		put '    </tr>';
		put '  </table>';
		put '</body>';
		put '</html>';
	run;
