/******************************************************************************************************
       Module:  template_step1

     Function:  This is the first step of the ABT template creation wizard. 
				Template details are entered here.

      Authors:  BIS Team
         Date:  July 2007
          SAS:  9.1

Datasets used:  The datasets being used in this screen are:
				1. analytic.Abt_purpose
				2. analytic.Abt_product
				3. analytic.Abt_purpose_x_product
				4. analytic.Abt_level
				5. analytic.Abt_purpose_x_level
				
******************************************************************************************************/
options nomprint;

/* Global Input Parameters */
%global abt_key abt_name abt_desc purpose_key
purpose_desc prod_key prod_desc level_key level_desc
outcome_period out_key prev_step first_load abt_table_name;

/* Start the session */
%let rc=%sysfunc(stpsrv_session(create));

/* Alias for the back-end library */
%let lib=analytic;

/* Trimming extra spaces for all input paremeters */
%let abt_key=&abt_key;
%let abt_name=&abt_name;
%let abt_desc=&abt_desc;
%let purpose_key=&purpose_key;
%let purpose_desc=&purpose_desc;
%let prod_key=&prod_key;
%let prod_desc=&prod_desc;
%let level_key=&level_key;
%let level_desc=&level_desc;
%let outcome_period=&outcome_period;
%let out_key=&out_key;
%let abt_table_name=&abt_table_name;

/* Here, copy the parameters into the session variables -- only if you are coming from the right page. */
data _null_;
	if "&prev_step" eq "0" then do;
		call symput('save_abt_key', "&abt_key");
		call symput('save_abt_name', "&abt_name");
		call symput('save_abt_desc', "&abt_desc");
		call symput('save_purpose_key', "&purpose_key");
		call symput('save_purpose_desc', "&purpose_desc");
		call symput('save_prod_key', "&prod_key");
		call symput('save_prod_desc', "&prod_desc");
		call symput('save_level_key', "&level_key");
		call symput('save_level_desc', "&level_desc");
		call symput('save_out_key', "&out_key");
		call symput('save_outcome_period', "&outcome_period");
		call symput('save_abt_table_name', "&abt_table_name");
	end;	
run;

/* Setting default values for any required parameters */
data _null_;
	if "&purpose_key"="" then call symput('purpose_key','.');
	if "&prod_key"="" then call symput('prod_key','.');
	if "&level_key"="" then call symput('level_key','.');
run;

/* Loading macro aliases for the rest of the stored processes */
%select_abt_vars_screen_links;

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;

/* Loading tables for the dropdown lists */
proc sql noprint;
	/* Data for ABT Purpose */
	create table &out_lib..abt_purpose as
	select distinct ap_no, abt_purpose_desc as abt_purpose
	from &lib..abt_purpose;

	/* Data for ABT Product */
	create table &out_lib..abt_prod as
	select distinct ap_no, abt_purpose_x_product.p_no, product_type_desc as product_type
	from &lib..abt_purpose_x_product, &lib..abt_product
	where abt_purpose_x_product.p_no = abt_product.p_no;

	/* Data for ABT Level */
	create table &out_lib..abt_level as
	select distinct ap_no, abt_purpose_x_level.l_no, level_desc
	from &lib..abt_purpose_x_level, &lib..abt_level
	where abt_purpose_x_level.l_no = abt_level.l_no;
quit;

/* Generating data for Outcome Period */
data &out_lib..outcome_period;
	outcome_period=1;
	do while(outcome_period <= 36);
		output;
		outcome_period+1;
	end;
run;

/* Start printing HTML */
data _NULL_;
	file _webout &webout_options;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"';
	put '"http://www.w3.org/TR/html4/loose.dtd">';
	put '<html>';
	put '<head>';
	put '<link href="/SASABTFramework/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<style type="text/css">';
	put '<!--';
	put 'body {';
	put '	background-color: #FAF8ED;';
	put '}';
	put '-->';
	put '</style>';

	put '<script>';
	put '<!-- ';

	/*	Initialize classes for Purpose, Product and Level */
	put 'function Purpose(no, id, purpose){';
	put '	this.no = no;';
	put '	this.id = id;';
	put '	this.purpose = purpose;';
	put '}';

	put 'function Product(no, id, id_purpose, product){';
	put '	this.no = no;';
	put '	this.id = id;';
	put '	this.purpose = id_purpose;';
	put '	this.product = product;';
	put '}';

	put 'function Level(no, id, id_purpose, level){';
	put '	this.no = no;';
	put '	this.id = id;';
	put '	this.purpose = id_purpose;';
	put '	this.level = level;';
	put '}';
run;

/* Initialize Array with Purpose Data */
data _null_;
	file _webout &webout_options;
	set &out_lib..abt_purpose end=last;
	if _N_=1 then put 'PurposeArray = new Array(';
	put '	new Purpose('@;
	put _N_@;
	put ', '@;
	put AP_NO@;
	put ', "'@;
	put ABT_PURPOSE@;
	if not last then put '"),';
	if last then do;
		put '")';
		put ');';
	end;
run;

/* Initialize Array with Product Data */
data _null_;
	file _webout &webout_options;
	set &out_lib..abt_prod end=last;
	if _N_=1 then put 'ProductArray = new Array(';
	put '	new Product('@;
	put _N_@;
	put ', '@;
	put P_NO@;
	put ', '@;
	put AP_NO@;
	put ', "'@;
	put PRODUCT_TYPE@; 
	if not last then put '"),';
	if last then do;
		put '")';
		put ');';
	end;
run;

/* Initialize Array with Level Data */
data _null_;
	file _webout &webout_options;
	set &out_lib..abt_level end=last;
	if _N_=1 then put 'LevelArray = new Array(';
	put '	new Level('@;
	put _N_@;
	put ', '@;
	put L_NO@;
	put ', '@;
	put AP_NO@;
	put ', "'@;
	put LEVEL_DESC@;
	if not last then put '"),';
	if last then do;
		put '")';
		put ');';
	end;
run;

data _null_;
	file _webout &webout_options;
	/* Initialize */
	put 'function init_main(sel_purpose, sel_prod, sel_level){';
	put '	document.form1.purpose.options[0]	= new Option("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.option_purpose.1, noquote))"@;
	put '");';
	put '	document.form1.prod.options[0] = new Option("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.option_product.1, noquote))"@;
	put '");';
	put '	document.form1.level.options[0] = new Option("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.option_level.1, noquote))"@;
	put '");';
	put '	for(i = 1; i <= PurposeArray.length; i++){';
	put '		document.form1.purpose.options[i]	= new Option(PurposeArray[i-1].purpose, PurposeArray[i-1].no);';
	put '		if(PurposeArray[i-1].id == sel_purpose)';
	put '			document.form1.purpose.options[i].selected = true;';
	put '	}';
	put '	OnChangeLevel(sel_level);';
	put '	OnChangeProduct(sel_prod);';
	put '}';

	/* OnChange Functions */
	/* On change of purpose, set the required values in the product and level
	combo boxes. */
	put 'function OnChangePurpose(){';
	put '	index = document.form1.purpose.selectedIndex;';
	put '	if (index==0) {';
	put '		document.form1.purpose_key.value = ''.''';
	put '		document.form1.purpose_desc.value = ''''';
	put '		document.form1.prod_key.value = ''.''';
	put '		document.form1.prod_desc.value = ''''';
	put '		document.form1.level_key.value = ''.''';
	put '		document.form1.level_desc.value = ''''';
	put '		document.form1.prod.options[0].selected = true;';
	put '		document.form1.level.options[0].selected = true;';
	put '	}';
	put '	else {';
	put '		document.form1.purpose_key.value = PurposeArray[index-1].id;';
	put '		document.form1.purpose_desc.value = PurposeArray[index-1].purpose;';
	put '		OnChangeLevel();';
	put '		OnChangeProduct();';
	put '	}';
	put '}';

	/* On change of purpose, set the required values in the level combo box. */
	put 'function OnChangeLevel(sel_level){';
	put '	sel_purpose_index = document.form1.purpose.selectedIndex;';
	put '	if (sel_purpose_index != 0) {';
	put '		sel_purpose_value = PurposeArray[sel_purpose_index-1].id;';
	put '		for(i = document.form1.level.length - 1; i > 0; i--)';
	put '			document.form1.level.options[i]	= null;';
	put '		j=1;';
	put '		for(i = 1; i <= LevelArray.length; i++){';
	put '			if(LevelArray[i-1].purpose == sel_purpose_value){';
	put '				document.form1.level.options[j]	= new Option(LevelArray[i-1].level, LevelArray[i-1].no);';
	put '				if(LevelArray[i-1].id == sel_level){';
	put '					document.form1.level.options[j].selected = true;';
	put '					document.form1.level_key.value = LevelArray[i-1].id;';
	put '					document.form1.level_desc.value = LevelArray[i-1].level;';
	put '				}';
	put '				j++;';
	put '			}';
	put '		}';
	put '	}';
	put '}';

	/* On change of purpose, set the required values in the product	combo box. */
	put 'function OnChangeProduct(sel_prod){';
	put '	sel_purpose_index = document.form1.purpose.selectedIndex;';
	put '	if (sel_purpose_index != 0) {';
	put '		sel_purpose_value = PurposeArray[sel_purpose_index-1].id;';
	put '		for(i = document.form1.prod.length - 1; i > 0; i--)';
	put '			document.form1.prod.options[i] = null;';
	put '		document.form1.prod_key.value = ".";';
	put '		document.form1.prod_desc.value = "";';
	put '		j=1;';
	put '		for(i = 1; i <= ProductArray.length; i++){';
	put '			if (document.form1.level_desc.value.replace(/ /,"") != "Customer"){';
	put '				if(ProductArray[i-1].purpose == sel_purpose_value){';
	put '					document.form1.prod.options[j]	= new Option(ProductArray[i-1].product, ProductArray[i-1].no);';
	put '					if(ProductArray[i-1].id == sel_prod){';
	put '						document.form1.prod.options[j].selected = true;';
	put '						document.form1.prod_key.value = ProductArray[i-1].id;';
	put '						document.form1.prod_desc.value = ProductArray[i-1].product;';
	put '					}';
	put '					j++;';
	put '				}';
	put '			}';
	put '		}';
	put '	}';
	put '}';


	/* For all dropdowns and model_types, the value holds the information such as 
	prod_type_cd:prod_type_desc. Hence depending on the selected index in the dropdown, 
	the code and descriptions have to extracted. This function does the job of extracting 
	the codes and descriptions. */
	put 'function getCodeDesc(mdl_val,mdl_key,mdl_name) {';
	put '	var len=mdl_val.length';
	put '	var indx=mdl_val.indexOf(":")';
	put '	var key_end=indx-1';
	put '	var nm_st=indx+1';
	put '	var nm_len=len-nm_st';
	put '	var key=mdl_val.substr(0,key_end)';
	put '	var nm=mdl_val.substr(nm_st,nm_len)';
	put '	mdl_key.value=key';
	put '	mdl_name.value=nm';
	put '}';

	/* When a level is selected, set the values in the required text boxes */
	put 'function setLevel(){';
	put '	index = document.form1.level.selectedIndex;';
	put '	if (index==0) {';
	put '		document.form1.level_key.value = ''.''';
	put '		document.form1.level_desc.value = ''''';
	put '	}';
	put '	else {';
	put '		key = document.form1.level.options[index].value;';
	put '		document.form1.level_key.value = LevelArray[key-1].id;';
	put '		document.form1.level_desc.value = LevelArray[key-1].level;';
	put '		if (document.form1.level_desc.value.replace(/ /,"") == "Customer"){';
	put '			for(i = document.form1.prod.length - 1; i > 0; i--)';
	put '				document.form1.prod.options[i] = null;';
	put '			document.form1.prod_key.value = ''.''';
	put '			document.form1.prod_desc.value = ''''';
	put '		}';
	put '		else {';
	put '			OnChangeProduct();';
	put '		}';
	put '	}';
	put '}';

	/* When a product type is selected, set the values in the required text boxes */
	put 'function setProdType(){';
	put '	index = document.form1.prod.selectedIndex;';
	put '	if (index==0) {';
	put '		document.form1.prod_key.value = ''.''';
	put '		document.form1.prod_desc.value = ''''';
	put '	}';
	put '	else {';
	put '		key = document.form1.prod.options[index].value';
	put '		document.form1.prod_key.value = ProductArray[key-1].id;';
	put '		document.form1.prod_desc.value = ProductArray[key-1].product;';
	put '	}';
	put '}';
	
	/* This function is called when the Next button is clicked. */
	put 'function next()';
	put '{';
	put 'if(chkchars(form1.abt_name.value)==false)';
		put 'return;';
	put 'if(chkchars(form1.abt_table_name.value)==false)';
		put 'return;';
	put '  if ((form1.abt_name.value=='''') || (form1.abt_desc.value=='''')';
	put '   || (form1.purpose_key.value=='''') || (form1.purpose_key.value==''.'')';
	put '   || (form1.level_key.value=='''') || (form1.level_key.value==''.'')';
	put '   || (form1.outcome_period.value==''''))';
	put '  {';
	put '    alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp1_alert1.1, noquote))"@;
	put '");';
	put '  }';
	put '  else if ((document.form1.level_desc.value.replace(/ /,"") != "Customer") &&';
	put '   ((form1.prod_key.value=='''') || (form1.prod_key.value==''.'')))';
	put '  {';
	put '    alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp1_alert2.1, noquote))"@;
	put '");';
	put '  }';
	put '  else';
	put '  {';
	put '    form1.submit();';
	put '  }';
	put '}';

	put 'function chkchars(obj)';
	put '{';
	put 'if(obj.charCodeAt(0)>=48 && obj.charCodeAt(0)<=57)';
	put '{alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.msgnumbeg.1, noquote))"@;
	put '");return false;}';
	put 'for(var i=0;i<obj.length;i++)';
	put '{';
	put 'if(obj.charCodeAt(i)!=95 && (obj.charCodeAt(i)<48||obj.charCodeAt(i)>57)'@;
	put '&& (obj.charCodeAt(i)<97||obj.charCodeAt(i)>122) && (obj.charCodeAt(i)<65||obj.charCodeAt(i)>90))';	
	put '{obj.value="";';
	put 'alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.msgspchrs.1, noquote))"@;
	put '");';
	put 'return false;}';
	put '}';
	put '}';

	put 'function restrictnav()';
	put '{';
	put 'alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_restrictnav.1, noquote))"@;
	put '");';
	put 'return;';
	put '}';

	/* This function is called when the cancel button is clicked */
	put 'function cancel()';
	put '{';
	put "	form1._program.value=&TEMPLATE_LIST;";
	put '	form1.submit();';
	put '}';

	put 'function validate_tabcol(obj,evt)';
	put '{';
	put 'var e = event || evt;';
	put 'var charCode = e.which || e.keyCode;';
	put 'if (charCode != 95 && (charCode < 48 || charCode > 57) && (charCode < 97 || charCode > 122) && (charCode < 65 || charCode > 90))';
	put '{';
		put '	return false;';
	put '}';
	put 'return true;';
	put '}';

	put 'function validate_exchar(obj,evt)';
	put '{';
	put 'var e = event || evt;';
	put 'var charCode = e.which || e.keyCode;';
	put 'if (charCode !=32 && charCode != 95 && (charCode < 48 || charCode > 57) && (charCode < 97 || charCode > 122) && (charCode < 65 || charCode > 90))';
	put '{';
		put '	return false;';
	put '}';
	put 'return true;';
	put '}';

	put '//--> ';
	put '</script>';
	
	/* External scripts */
  	put '<script src="/SASABTFramework/javascript/scripts.js" type="text/javascript"></script>';
  	put '<script src="/SASABTFramework/javascript/overlib.js" type="text/javascript"></script>';
  	put '<script type="text/javascript" src="/SASABTFramework/javascript/boxOver.js"></script>';
    
	put '</head> ';

	put '<body bgcolor="#FAF8ED">';
	put "<form name=""form1"" action=""&_THISSESSION"" method=""post"">";
	put "<input type='hidden' name='_program' value=&TEMPLATE_STEP2>";
	put '<input type="hidden" name="prev_step" value="1"/>';

	first_load=symget("first_load");
	x='<input type="hidden" name="first_load" value="'||strip(first_load)||'"/>';
	put x;


/* Hidden fields contain non-textbox form data */
	
	save_purpose_key=symget("save_purpose_key");
	x='<input type="hidden" name="purpose_key" value="'||strip(save_purpose_key)||'">';
	put x;
	save_purpose_desc=symget("save_purpose_desc");
	x='<input type="hidden" name="purpose_desc" value="'||strip(save_purpose_desc)||'">';
	put x;
	save_prod_key=symget("save_prod_key");
	x='<input type="hidden" name="prod_key" value="'||strip(save_prod_key)||'">';
	put x;
	save_prod_desc=symget("save_prod_desc");
	x='<input type="hidden" name="prod_desc" value="'||strip(save_prod_desc)||'">';
	put x;
	save_level_key=symget("save_level_key");
	x='<input type="hidden" name="level_key" value="'||strip(save_level_key)||'">';
	put x;
	save_level_desc=symget("save_level_desc");
	x='<input type="hidden" name="level_desc" value="'||strip(save_level_desc)||'">';
	put x;
run;

data _null_;
	file _webout &webout_options;
	put '      <div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div>';

	/* Banner code */
	put '      <div id="banback">';
	put '          <table id="bantabs" border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '            <tr valign="top">';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_home.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tabsellft"><img src="/SASABTFramework/images/tab_upper_left_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tabsellab'><a href='#'>"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_modeling.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabselrgt"><img src="/SASABTFramework/images/tab_upper_right_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scoring.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scheduling.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td width="100%">&nbsp;</td>';
	put '            </tr>';
	put '          </table>';
	put '      </div>';
	put '      <table border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '        <tr>';
	put '          <td id="butbar">';
	put '            <font color="#996600"> <b>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_create_or_edit_template.1, noquote))"@;
	put '</b>';
	put '            <span id="butfill">&nbsp;</span>';
	put '          </td>';
	put '        </tr>';
	put '      </table>';
	put '      <table border="0" cellpadding="0" cellspacing="0" summary="" width="100%" height="450">';
	put '        <tr valign="top">';
	put '          <td  id="navcel">';
	put '            <div id="navcol">';

	/* List on the left side */
	put '              <table border="0" cellspacing="0" summary="" class="mmhide_wizardsteps">';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td nowrap class="mmhide_wizardstepact"></td>';
	put '                  <td class="mmhide_wizardstepact">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.details.1, noquote))"@;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td><img src="/SASABTFramework/images/blank.gif" width="16"></td>';
	put '                  <td>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.input_variables.1, noquote))"@;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td><img src="/SASABTFramework/images/blank.gif" width="16"></td>';
	put '                  <td>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.outcome_variable.1, noquote))"@;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td><img src="/SASABTFramework/images/blank.gif" width="16"></td>';
	put '                  <td>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.summary.1, noquote))"@;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td>';
	put '                  </td>';
	put '                  <td><img src="/SASABTFramework/images/blank.gif" width="180" height="1"></td>';
	put '                </tr>';
	put '              </table>';
	put '            </div>';
	put '          </td>';
	put '          <td id="navwdg"><img src="/SASABTFramework/images/blank.gif" name="navwdg" border="0" width="11" height="14" hspace="0" vspace="0" alt="" /></a></td>';

	put '          <td width="100%" id="wizardmain">';

	put '            <div id="pagetitlesection">';
	put '              <div id="pagetitle">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.details.1, noquote))"@;
	put '              </div>';
	put '              <div id="pagesubtitle"><!-- InstanceBeginEditable name="pagesubtitle" -->&nbsp;<!-- InstanceEndEditable --></div>';
	put '            </div>';

	/* Start of form elements */
	put '            <div class="formfields">';
	put '              <table class="formfields" cellpadding="4" cellpadding="0" border="0" >';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_name.1, noquote))"@;
	put ':';
	put '                  </td>';
	put '                  <td class="">';
	put '                   <input type="text" name="abt_name"'@;
	if "&save_abt_name" eq "" then 
		put 'value=""'@;
	else	
		put "value = ""&save_abt_name"""@;
	if &save_abt_key ne . then
		put ' readonly=true '@;
	put 'maxLength="40" style="width:200px;" class="inputtext" onkeypress="return validate_tabcol(this);">';
	put '                  </td>';
	put '                </tr>';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_description.1, noquote))"@;
	put ':';
	put '                  </td>';
	put '                  <td class="">';
	put '                    <input type="text" name="abt_desc"'@;
	if "&save_abt_desc" eq "" then 
		put 'value=""'@;
	else	
		put "value = ""&save_abt_desc"""@;
	put '" maxLength="255" style="width:200px;" class="inputtext" onkeypress="return validate_exchar(this);">';
	put '                  </td>';
	put '                </tr>';

	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_abt_table_nm.1, noquote))"@;
	put ':';
	put '                  </td>';
	put '                  <td class="">';
	put '                    <input type="text" name="abt_table_name"'@;
	if "&save_abt_table_name" eq "" then 
		put 'value=""'@;
	else	
		put "value = ""&save_abt_table_name"""@;
	if &save_abt_key ne . then
		put ' readonly=true '@;
	put '" maxLength="18"  style="width:200px;" class="inputtext" onkeypress="return validate_tabcol(this);">';
	put '                  </td>';
	put '                </tr>';

	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_purpose.1, noquote))"@;
	put ':';
	put '                  </td>';
	put '                  <td class="">';
	put '                    <select name="purpose" onChange="javascript:OnChangePurpose()" class="longselect"'@;
	if &save_abt_key ne . then
		put ' disabled '@;
	put '></select>';
	put '                  </td>';
	put '                </tr>';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_level.1, noquote))"@;
	put ':';
	put '                  </td>';
	put '                  <td class="">';
	put '                    <select name="level" onChange="javascript:setLevel()" class="longselect"'@;
	if &save_abt_key ne . then
		put ' disabled '@;
	put '></select>';
	put '                  </td>';
	put '                </tr>';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_prodtype.1, noquote))"@;
	put ':';
	put '                  </td>';
	put '                  <td class="">';
	put '                    <select name="prod" onChange="javascript:setProdType()" class="longselect"'@;
	if &save_abt_key ne . then
		put ' disabled '@;
	put '></select>';
	put '                  </td>';
	put '                </tr>';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_outcome_period.1, noquote))"@;
	put ':';
	put '                  </td>';
	put '                  <td>';
	put '                    <select name="outcome_period" class="longselect">';
run;


/* Creates combo box for Outcome Period */
data _NULL_;
	file _webout &webout_options;
	set &out_lib..outcome_period;
	put '<option value="' @;
	put outcome_period @;
	put '" '@;
	if outcome_period = "&save_outcome_period" then put 'selected';
	else if ("&save_outcome_period"="." or "&save_outcome_period"="") and outcome_period='3' then put 'selected';
	put '>' @;
	put outcome_period @;
	put '</option>';
run;

data _null_;
	file _webout &webout_options;
	put '                    </select>';
	put '                  </td>';
	put '                </tr>';
	put '              </table>';
	put '            </div>';
	put '          </td>';
	put '        </tr>';
	put '      </table>';

	/* Initialize comboboxes for Purpose, Product and Level */
	put '<script>';
	put '<!-- ';
	if ("&save_purpose_key." = "" or "&save_purpose_key." = ".") and
		("&save_prod_key." = "" or "&save_prod_key." = ".") and
		("&save_level_key." = "" or "&save_level_key." = ".") 
		then put 'init_main();';
	else if (strip("&save_prod_key.") = "." or strip("&save_prod_key.") = "")
		then put "init_main(&save_purpose_key., '.', &save_level_key.);"; 
	else put "init_main(&save_purpose_key., &save_prod_key., &save_level_key.);"; 
 	put '//--> ';
	put '</script>';

	/* Wizard navigation buttons */
	put '      <table border="0" cellpadding="3" cellspacing="0" summary="Action Buttons" id="dialogbuttons" width="100%">';
	put '        <tr>';
	put '          <td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.prevbttn.1, noquote))"@;
	put '" name="Previous" type="button" Disabled>';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.nextbttn.1, noquote))"@;
	put '" name="Next" type="button" onclick="next()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="30"><img src="/SASABTFramework/images/blank.gif" width="30" height="1">';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" name="Finish" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.finishbttn.1, noquote))"@;
	put '" type="button" Disabled>';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.cancelbttn.1, noquote))"@;
	put '" name="Cancel" type="button" onclick="cancel()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '          </td>';
	put '          <td width="90%">&nbsp';
	put '          </td>';
	put '        </tr>';
	put '      </table>';

	put '      <!--Big table ends here-->';
	put '      <div id="foot">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.copyright_notice.1, noquote))"@;
	put '      </div>';
	put '    </form>';
		
	put '  </body><!-- InstanceEnd -->';
	put '</html>';
run;
