/******************************************************************************************************
       Module:  template_step2

     Function:  This is the second step of the ABT template creation wizard. 
				Input variables are selected here.

      Authors:  BIS Team
         Date:  July 2007
          SAS:  9.1

Datasets used:  The datasets being used in this screen are:
				1. analytic.Abt_level
				2. analytic.Var_master
				3. analytic.Abt_x_var

************************************************************************/
option nomprint;

/* Global Input Parameters */
%global abt_name abt_desc
purpose_key purpose_desc prod_key prod_desc level_key 
level_desc outcome_period var_level category sub_category group prev_step
var_keys first_load listopt abt_table_name showcatloc;

/* Start the session */
%let rc=%sysfunc(stpsrv_session(create));

/* Alias for the back-end library */
%let lib=analytic;

/* Loading macro aliases for the rest of the stored processes */
%select_abt_vars_screen_links;

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;

%macro chkduplicates;
%if %str(&save_abt_key) eq %str(.) or %str(&save_abt_key) eq %str() %then %do;
	%let name_exists=;
	%let inactname_exists=;

	/* Check whether the name is new or taken. */
	proc sql noprint;
		select count(*) into :name_exists
		from &lib..abt_master
		where kupcase(abt_nm)=kupcase(strip("&abt_name")) and is_deleted is missing;

		select count(*) into :abttab_name_exists
		from &lib..abt_master
		where kupcase(abt_table_nm)=kupcase(strip("&abt_table_name"));
	quit;
	%let name_exists=&name_exists;
	%let abttab_name_exists=&abttab_name_exists;

	/* Check whether the name matches a data set name which is inactive. */
	proc sql noprint;
		select count(*) into :inactname_exists
		from &lib..abt_master
		where kupcase(abt_nm)=kupcase(strip("&abt_name")) and is_deleted = 'Y';
	quit;
	%let inactname_exists=&inactname_exists;

%if %str(&name_exists) ne %str(0) or %str(&abttab_name_exists) ne %str(0) or
	%str(&inactname_exists) ne %str(0) %then %do;
data _null_;
		file _webout &webout_options;
		put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"';
		put '"http://www.w3.org/TR/html4/loose.dtd">';
		put '<html>';
		put '<head>';
		put '<link href="/SASABTFramework/styles/default.css" rel="stylesheet" type="text/css"> ';
		put '<style type="text/css">';
		put '<!--';
		put 'body {';
		put '	background-color: #FAF8ED;';
		put '}';
		put '-->';
		put '</style>';
		put '</head>';
		put '<body>';
		put "<form name=""form1"" action=""&_THISSESSION"" method=""post"">";
		put "    <input name='_program' value='' type='hidden' />";
		put '  </form>';
		put '  <script type="text/javascript">';
		put '  <!--';

		/* Pop up the message and proceed. */
		if "&name_exists" ne "0" then do;
			put '    alert("' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_abtexists.1, noquote))"@;
			put '");'@;
		end;
		else if "&abttab_name_exists" ne "0" then do;
			put '    alert("' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_abttabexists.1, noquote))"@;
			put '");';
		end;
		else if "&inactname_exists" ne "0" then do;
			put '    alert("' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_abtinactexists.1, noquote))"@;
			put '");';
		end;
		put "    form1._program.value=&TEMPLATE_STEP1;";
		put '    form1.submit();';
		put '  -->';
		put '  </script>';
		put '</body>';
		put '</html>';
	run;
  %end;
%end;
%mend chkduplicates;
%chkduplicates;

/* Setting default values for any required parameters */
data _null_;
	if "&var_level"="" then call symput('var_level','CAT');
	if %str("&prod_key")=%str("0") then call symput('prod_key',.);
	if "&showcatloc"="" then call symput('showcatloc','All Variables');
run;

/*Here, copy the parameters into the session variables -- only if you are coming from the right page. */
data _null_;
	if "&prev_step" eq "1" then do;
		call symput('save_abt_name', "&abt_name");
		call symput('save_abt_desc', "&abt_desc");
		call symput('save_purpose_key', "&purpose_key");
		call symput('save_purpose_desc', "&purpose_desc");
		call symput('save_prod_key', "&prod_key");
		call symput('save_prod_desc', "&prod_desc");
		call symput('save_level_key', "&level_key");
		call symput('save_level_desc', "&level_desc");
		call symput('save_outcome_period', "&outcome_period");
		call symput('save_abt_table_name', "&abt_table_name");
	end;
	if "&prev_step" eq "2" then do;
		call symput('save_var_keys', "&var_keys");
	end;
run;

data _null_;
if "&listopt" eq "" then
	call symput('listopt','1');
run;

%let no_records=0;

/* This macro retrieves input variable data. */
%macro get_data;

	/* Get a list of all variables. */
	proc sql noprint;
		select l_no into :cust_lvl 
		from &lib..abt_level
		where level_desc like '%Customer%';

		create table &out_lib..var_cat as
		select distinct Var_master.var_category, strip(var_sub_category) as var_sub_category, 
			strip(var_group) as var_group, v_no, strip(var_short_nm) as var_short_nm, 
			strip(var_desc) as var_desc, strip(var_nm) as var_nm
		from &lib..Var_master
		where (l_no = &save_level_key or l_no = &cust_lvl) and is_deleted is missing
		order by var_category, var_sub_category, var_group;
	quit;
	
	/* Sort them. */
	proc sort data=&out_lib..var_cat out=&out_lib..var_cat;
		by v_no;
	quit;

	/* This creates a table that contains the selection state of each variable, for the template in question.
	It retrieves data from the abt_x_var table: if the ABT has no entry there, it fills the table with 'N's. */
	%let no_recs=0;
	proc sql noprint;
		select count(*) into :no_recs from &lib..Abt_x_var where a_no=&save_abt_key;
	%if &no_recs eq 0 %then %do;
		create table work.Abt_x_var as
		select v_no, 'N' as is_selected_flg
		from &out_lib..var_cat
		order by v_no;
	%end;
	%else %do;
		create table work.Abt_x_var as
		select v_no, is_selected_flg
		from &lib..Abt_x_var
		where a_no=&save_abt_key
		order by v_no;
	%end;
	quit;

	/* We are composing a dataset that contains the variables that have been selected for the ABT. */
	/* If first load, load data from SQL */
	%if "&first_load" eq "Y" %then %do; 

		/* Get the data via SQL here. */
		proc sql;
			create table &out_lib..selected_variables as
			select var_cat.v_no, var_short_nm, var_desc, var_category, 
				var_sub_category, var_group, var_nm
			from &out_lib..var_cat left join work.Abt_x_var
			on (var_cat.v_no=Abt_x_var.v_no) 
			where kupcase(is_selected_flg)='Y'
			order by var_cat.v_no;
		quit;

		data _null;
			call symput('first_load', "N");
		run;

	%end;
	
	/* Otherwise: load from save_var_keys */
	%else %do;

		/* Get the data from save_var_keys here */
		data &out_lib..var_selection;
			set &out_lib..var_cat(keep=v_no var_short_nm var_desc var_category 
				var_sub_category var_group var_nm);
			if indexw("&save_var_keys", v_no)>0 then output;
		run;

		proc sort data=&out_lib..var_selection out=work.var_selection_srt;
			by v_no;
		quit;

		data &out_lib..selected_variables;
			set work.var_selection_srt(in=B);
		run;
	%end;

	/* Make the list of variables that has *not* yet been selected, based on the level we are at. */
	%let no_recs=0;
	proc sql noprint;
		select count(*) into :no_recs from &out_lib..selected_variables;
	quit;

	%if &no_recs eq 0 %then %do;
		data &out_lib..available_vars(keep=v_no);
			set work.Abt_x_var;
			if is_selected_flg='N' then output;
		run;
	%end;
	%else %do;
		data &out_lib..available_vars(keep=v_no);
			merge work.Abt_x_var(in=A) &out_lib..selected_variables(in=B);
			by v_no;
			if (A and not B) then output;
		run;
	%end;

	/* Re-sorting the list once we're done. */
	proc sort data=&out_lib..selected_variables;
		by var_category v_no;
	quit;

	/* Get data for the category and available variables */
	%if %str(&var_level) eq %str(CAT) %then %do;
		proc sql noprint;
			/* Data for Variable Category, Sub Category and Group */
			create table &out_lib..var_group as
			select distinct var_cat.var_category as cat
			from &out_lib..var_cat;

			select count(*) into :no_records from &out_lib..var_group;

			/* Get available data for selected ABT sorted by variable number */
			create table &out_lib..abt_avl_vars as
			select var_cat.v_no, var_short_nm, var_desc, var_category, 
				var_sub_category, var_group, var_nm
			from &out_lib..var_cat inner join &out_lib..available_vars
			on (var_cat.v_no=available_vars.v_no) 
			order by var_category, var_cat.v_no;
		quit;
	%end;
	%if %str(&var_level) eq %str(SUBCAT) %then %do;
		proc sql noprint;
			/* Data for Variable Category, Sub Category and Group */
			create table &out_lib..var_group as
			select distinct var_sub_category as cat
			from &out_lib..var_cat
			where ktrim(kleft(kupcase(var_category))) = kupcase("&category")
			order by var_sub_category;

			select count(*) into :no_records from &out_lib..var_group;

			/* Get available data for selected ABT sorted by variable number */
			create table &out_lib..abt_avl_vars as
			select var_cat.v_no, var_short_nm, var_desc, var_category, 
				var_sub_category, var_group, var_nm
			from &out_lib..var_cat inner join &out_lib..available_vars
			on (var_cat.v_no=available_vars.v_no) 
			where ktrim(kleft(kupcase(var_category))) = kupcase("&category")
			order by var_category, var_cat.v_no;
		quit;
	%end;
	%if %str(&var_level) eq %str(GROUP) %then %do;
		proc sql noprint;
			/* Data for Variable Category, Sub Category and Group */
			create table &out_lib..var_group as
			select distinct var_group as cat
			from &out_lib..var_cat
			where ktrim(kleft(kupcase(var_category))) = kupcase("&category") and 
				ktrim(kleft(kupcase(var_sub_category))) = kupcase("&sub_category")
			order by var_group;

			select count(*) into :no_records from &out_lib..var_group;

			/* Get available data for selected ABT sorted by variable number */
			create table &out_lib..abt_avl_vars as
			select var_cat.v_no, var_short_nm, var_desc, var_category, 
				var_sub_category, var_group, var_nm
			from &out_lib..var_cat inner join &out_lib..available_vars
			on (var_cat.v_no=available_vars.v_no) 
			where ktrim(kleft(kupcase(var_category))) = kupcase("&category") and 
				ktrim(kleft(kupcase(var_sub_category))) = kupcase("&sub_category")
			order by var_category, var_cat.v_no;
		quit;
	%end;
	%if %str(&var_level) eq %str(SELGROUP) %then %do;
		proc sql noprint;
			/* Data for Variable Category, Sub Category and Group */
			create table &out_lib..var_group as
			select distinct var_group as cat
			from &out_lib..var_cat
			where ktrim(kleft(kupcase(var_category))) = kupcase("&category") and 
				ktrim(kleft(kupcase(var_sub_category))) = kupcase("&sub_category") and
				ktrim(kleft(kupcase(var_group))) = kupcase("&group")
			order by var_group;

			select count(*) into :no_records from &out_lib..var_group;

			/* Get available data for selected ABT sorted by variable number */
			create table &out_lib..abt_avl_vars as
			select var_cat.v_no, var_short_nm, var_desc, var_category, 
				var_sub_category, var_group, var_nm
			from &out_lib..var_cat inner join &out_lib..available_vars
			on (var_cat.v_no=available_vars.v_no) 
			where ktrim(kleft(kupcase(var_category))) = kupcase("&category") and 
				ktrim(kleft(kupcase(var_sub_category))) = kupcase("&sub_category") and 
				ktrim(kleft(kupcase(var_group))) = kupcase("&group")
			order by var_category, var_cat.v_no;
		quit;
	%end;
%mend get_data;
%get_data;

/* Start printing HTML */
data _NULL_;
	file _webout &webout_options;
	put '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">';
	put '<html xmlns="http://www.w3.org/1999/xhtml"><!-- InstanceBegin template="/Templates/dashboard.dwt" codeOutsideHTMLIsLocked="false" -->';
	put '  <head>';
	put '    <meta http-equiv="content-type" content="text/html;charset=utf-8" />';
	put '    <script type="text/javascript">';
	put '      <!--';

	/* This takes you back to previous wizard pages. */
	put 'function back(page)';
	put '{';
	put '  if(page == 1)';
	put "    form1._program.value=&TEMPLATE_STEP1;";
	put '  else if(page == 2)';
	put "    form1._program.value=&TEMPLATE_STEP2;";
	put '  else if(page == 3)';
	put "    form1._program.value=&TEMPLATE_STEP3;";
	put '  else';
	put "    form1._program.value=&TEMPLATE_STEP4;";
	put '  form1.submit();';
	put '}';

	/* This function is called when the previous button is clicked */
	put 'function previous()';
	put '{';
	put "    form1._program.value=&TEMPLATE_STEP1;";
	put '	 form1.submit()';
	put '}';

	/* This function simply splits one string into five. */
	put '      function getCodeDesc(mdl_val) {';
	put '        var myval=new Array(5)';
	put '        myval=mdl_val.split("#",5)';
	put '        return(myval)';
	put '      }';

	/* This function converts the values in the second list box into a single string of variable keys, suitable for transmission through post variables. */
	put '      function getSelVars(){';
	put '        var abt_sel = ''''';
	put '        for(i = 0; i < form1.selectvars.options.length; i++){';
	put '          value=form1.selectvars.options[i].value';
	put '          valArray=new Array(5)';
	put '          valArray = getCodeDesc(value)';
	put '          abt_sel = abt_sel + " " + valArray[0].replace(/ /, "")';
	put '        }';
	put '        form1.var_keys.value=abt_sel';
	put '      }';

	/* It appears that this function resets the hidden text fields that contain state information for the two lists. */
	put '      function OnChangeCat(){';
	put '        index = document.form1.var_cat.selectedIndex;';
	put '        if (index==0) {';
	put '          if (document.form1.var_level.value=="CAT") {';
	put '            document.form1.category.value = '''';';
	put '            document.form1.sub_category.value = '''';';
	put '            document.form1.group.value = '''';';
	put '          }';
	put '          else if (document.form1.var_level.value=="SUBCAT") {';
	put '            document.form1.sub_category.value = '''';';
	put '            document.form1.group.value = '''';';
	put '          }';
	put '          else if (document.form1.var_level.value=="GROUP") {';
	put '            document.form1.group.value = '''';';
	put '          }';
	put '          for(i = document.form1.available.length - 1; i >= 0; i--)';
	put '            document.form1.available.options[i] = null;';
	put '          for(i = document.form1.selectvars.length - 1; i >= 0; i--)';
	put '            document.form1.selectvars.options[i] = null;';
	put '        }';
	put '        else {';
	put '          value = document.form1.var_cat[index].value;';
	put '          if (document.form1.var_level.value=="CAT") {';
	put '            document.form1.category.value=value';
	put '            document.form1.var_level.value="SUBCAT"';
	put '          }';
	put '          else if (document.form1.var_level.value=="SUBCAT"){';
	put '            document.form1.sub_category.value=value';
	put '            document.form1.var_level.value="GROUP"';
	put '          }';
	put '          else if (document.form1.var_level.value=="GROUP"){';
	put '            document.form1.group.value=value';
	put '            document.form1.var_level.value="SELGROUP"';
	put '          }';
	put '          else if (document.form1.var_level.value=="SELGROUP"){';
	put '			 txt=form1.showcatloc.value;';
	put '			 form1.showcatloc.value=txt.substr(0,txt.lastIndexOf(" > "))';
	put '          }';
	put '		   form1.showcatloc.value = form1.showcatloc.value + '' > '' + value;';
	put '          getSelVars()';
	put "          form1._program.value=&TEMPLATE_STEP2";
	put "		   form1.listopt.value=""&listopt"";"@;
	put '          form1.submit();';
	put '        }';
	put '      }';

	/* This handles returning to a higher variable level. */
	put '      function oneLevelUp(){';
	put '        if (document.form1.var_level.value != "CAT"){';
	put '          if (document.form1.var_level.value == "SUBCAT"){';
	put '            document.form1.var_level.value="CAT"';
	put '            document.form1.category.value=''''';
	put '            document.form1.sub_category.value=''''';
	put '          }';
	put '          else if (document.form1.var_level.value == "GROUP"){';
	put '            document.form1.var_level.value="SUBCAT"';
	put '            document.form1.sub_category.value=''''';
	put '            document.form1.group.value=''''';
	put '          }';
	put '          else if (document.form1.var_level.value == "SELGROUP"){';
	put '            document.form1.var_level.value="GROUP"';
	put '            document.form1.group.value=''''';
	put '          }';
	put '          getSelVars()';
	put '			txt=form1.showcatloc.value;';
	put '			form1.showcatloc.value=txt.substr(0,txt.lastIndexOf(" > "))';
	put "          form1._program.value=&TEMPLATE_STEP2";
	put "		   form1.listopt.value=""&listopt"";"@;
	put '          form1.submit();';
	put '        }';
	put '      }';

	/* This function sets the value in the description box. Straightforward, I see no need to change it. */
	put '      function setDesc(list){';
	put '        index = list.selectedIndex;';
	put '        value = list[index].value;';
	put '        var valArray=new Array(5)';
	put '        valArray = getCodeDesc(value)';
	put '        document.form1.var_desc.value = valArray[1].replace(/<BR>/g, "\n")';
	put '      }';

	/* Comparator. Not sure where it's used. */
	put '      function compareOptionValues(a, b) {';
	put '        var sA = parseInt( a.value, 36 )';
	put '        var sB = parseInt( b.value, 36 )';
	put '        return sA - sB';
	put '      }';

	/* Moves variables from one list to another. */
	put '      function moveVar(srclist, destlist, moveAll){';
	put '        if ( (srclist.selectedIndex == -1) && (moveAll == false) ){';
	put '          return;';
	put '        }';
	put '        var cat_value = document.form1.category.value';
	put '        var subcat_value = document.form1.sub_category.value';
	put '        var group_value = document.form1.group.value';
	put '        var len=destlist.options.length';
	put '        for(i = 0; i <= srclist.options.length; i++){';
	put '          if(srclist.options[i] != null && (srclist.options[i].selected == true || moveAll) ){';
	put '            var valArray=new Array(5)';
	put '            valArray = getCodeDesc(srclist[i].value)';
	put '            var cat = valArray[2].substring(0, valArray[2].lastIndexOf(" "))';
	put '            var subcat = valArray[3].substring(0, valArray[3].lastIndexOf(" "))';
	put '            var grp = valArray[4].substring(0, valArray[4].lastIndexOf(" "))';
	put '            if ( ( ((cat_value == '''') || (cat_value == '' '')) && ((subcat_value == '''') ||';
	put '             (subcat_value == '' '')) && ((group_value == '''') || (group_value == '' '')) ) ||';
	put '		  ( (cat == cat_value) && ((subcat_value == '''') || (subcat_value == '' '')) && ((group_value == '''') || ';
	put '             (group_value == '' '')) ) || ( (cat == cat_value) && (subcat == subcat_value) && ((group_value == '''') ||';
	put '             (group_value == '' '')) ) || ( (cat == cat_value) && (subcat == subcat_value) && (grp == group_value) ) ) {';
	put '              destlist.options[len] = new Option(srclist.options[i].text, srclist.options[i].value)';
	put '              len++';
	put '            }';
	put '          }';
	put '        }';
	put '        for( var i = srclist.options.length - 1; i >= 0; i-- ) {';
	put '          if ( srclist.options[i] != null && ( srclist.options[i].selected == true || moveAll ) ) {';
	put '            srclist.options[i] = null';
	put '          }';
	put '        }';
	put '        document.form1.var_desc.value = ""';
	put '      }';

	put 'function radioclick(lo)';
	put '{';
		put "getSelVars()";
		put 'if (lo=="VN")';
			put 'document.getElementById("listopt").value="1"';
		put 'else';
			put 'document.getElementById("listopt").value="0"';
		put "form1._program.value=&TEMPLATE_STEP2";
		put 'form1.prev_step.value="2";';
		put 'form1.submit();';
	put '}';

	/* Move to the next page. */
	put 'function next()';
	put '{';
	put '	getSelVars()';
	put 'if(form1.var_keys.value=="")';	
	put '{';
	put '	alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp2_alert1.1, noquote))"@;
	put '");';
	put '	return false;';
	put '}';
	put "	form1._program.value = &TEMPLATE_STEP3";
	put '	form1.submit();';
	put '}';

	put 'function restrictnav()';
	put '{';
	put 'alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_restrictnav.1, noquote))"@;
	put '");';
	put 'return;';
	put '}';

	/* This function is called when the cancel button is clicked */
	put 'function cancel()';
	put '{';
	put "	form1._program.value=&TEMPLATE_LIST;";
	put '	form1.submit();';
	put '}';

	put '      //-->';
	put '    </script>';
	 		/*I18N-scnjih-20080429-1519*/
	/*put '    <title>Input Variables</title>';*/
		put '    <title>'@;
		put  "%sysfunc(sasmsg(smd_ds.bismsg,template_step2.sas.1, noquote))"@;
		put '</title>';
		 /*I18N-scnjih-20080429-1519*/
		 
		 
		 /*I18N-scnjih-20080429-1519*/
	/*put '    <!-- InstanceBeginEditable name="doctitle" --><title>Layout</title><!-- InstanceEndEditable -->';*/
		put '    <!-- InstanceBeginEditable name="doctitle" --><title>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,title_of_layout.1, noquote))"@;
		put '</title><!-- InstanceEndEditable -->';
		 /*I18N-scnjih-20080429-1519*/
	put '    <link rel="stylesheet" type="text/css" href="/SASABTFramework/styles/default.css" />';
	put '    <script src="/SASABTFramework/javascript/scripts.js" type="text/javascript"></script>';
	put '    <script src="/SASABTFramework/javascript/buttonMenu.js" type="text/javascript"></script>';
	put '    <script src="/SASABTFramework/javascript/overlib.js" type="text/javascript"></script>';
	put '    <script type="text/javascript" src="/SASABTFramework/javascript/table_controls.js"></script>';
	put '    <script type="text/javascript" src="/SASABTFramework/javascript/boxOver.js"></script>';
	put '  </head>';
	put '  <body>';
	
	put "<form name=""form1"" action=""&_THISSESSION"" method=""post"">";

	/* Input variables contain the state of the two lists. */
	put "      <input type=""hidden"" name=""_program"" value=&TEMPLATE_STEP3>";
	category=symget("category");
	x1='<input type="hidden" name="category" value="'||strip(category)||'">';
	put x1;
	sub_category=symget("sub_category");
	x2='<input type="hidden" name="sub_category" value="'||strip(sub_category)||'">';
	put x2;
	group=symget("group");
	x3='<input type="hidden" name="group" value="'||strip(group)||'">';
	put x3;
	var_level=symget("var_level");
	x4='<input type="hidden" name="var_level" value="'||strip(var_level)||'">';
	put x4;
	first_load=symget("first_load");
	x5='<input type="hidden" name="first_load" value="'||strip(first_load)||'">';
	put x5;

	abt_name=symget("abt_name");
	x6='<input type="hidden" name="abt_name" value="'||strip(abt_name)||'">';
	put x6;

	abt_desc=symget("abt_desc");
	x7='<input type="hidden" name="abt_desc" value="'||strip(abt_desc)||'">';
	put x7;

	purpose_key=symget("purpose_key");
	x8='<input type="hidden" name="purpose_key" value="'||strip(purpose_key)||'">';
	put x8;

	purpose_desc=symget("purpose_desc");
	x9='<input type="hidden" name="purpose_desc" value="'||strip(purpose_desc)||'">';
	put x9;

	prod_key=symget("prod_key");
	x10='<input type="hidden" name="prod_key" value="'||strip(prod_key)||'">';
	put x10;

	prod_desc=symget("prod_desc");
	x11='<input type="hidden" name="prod_desc" value="'||strip(prod_desc)||'">';
	put x11;

	level_key=symget("level_key");
	x12='<input type="hidden" name="level_key" value="'||strip(level_key)||'">';
	put x12;

	level_desc=symget("level_desc");
	x13='<input type="hidden" name="level_desc" value="'||strip(level_desc)||'">';
	put x13;

	outcome_period=symget("outcome_period");
	x14='<input type="hidden" name="outcome_period" value="'||strip(outcome_period)||'">';
	put x14;
	
	showcatloc=symget("showcatloc");
	x15='<input type="hidden" name="showcatloc" value="'||strip(showcatloc)||'">';
	put x15;

	put "      <input type=""hidden"" name=""var_keys"" value="""">";
	put '	   <input type="hidden" name="prev_step" value="2"/>';
	put ' 	   <input type="hidden" name="listopt" id="listopt">';
	
	put '      <div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div>';
	put '      <div id="banback">';

	/* Banner code. */
	put '          <table id="bantabs" border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '            <tr valign="top">';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_home.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tabsellft"><img src="/SASABTFramework/images/tab_upper_left_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tabsellab'><a href='#'>"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_modeling.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabselrgt"><img src="/SASABTFramework/images/tab_upper_right_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scoring.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scheduling.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td width="100%">&nbsp;</td>';
	put '            </tr>';
	put '          </table>';
	put '      </div>';
	put '      <table border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '        <tr>';
	put '          <td id="butbar">';
	put '            <font color="#996600"> <b>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_create_or_edit_template.1, noquote))"@;
	put '</b>';
	put '            <span id="butfill">&nbsp;</span>';
	put '          </td>';
	put '        </tr>';
	put '      </table>';

	/* List on the left side */
	put '      <table border="0" cellpadding="0" cellspacing="0" summary="" width="100%" height="450">';
	put '        <tr valign="top">';
	put '          <td  id="navcel">';
	put '            <div id="navcol">';
	put '              <table border="0" cellspacing="0" summary="" class="mmhide_wizardsteps">';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td><img src="/SASABTFramework/images/AdjustmentComplete.gif"></td>';
	put '					<td>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.details.1, noquote))"@;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td nowrap class="mmhide_wizardstepact"></td>';
	put '                  <td class="mmhide_wizardstepact">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.input_variables.1, noquote))"@;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td><img src="/SASABTFramework/images/blank.gif" width="16"></td>';
	put '                  <td>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.outcome_variable.1, noquote))"@;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td><img src="/SASABTFramework/images/blank.gif" width="16"></td>';
	put '                  <td>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.summary.1, noquote))"@;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td>';
	put '                  </td>';
	put '                  <td><img src="/SASABTFramework/images/blank.gif" width="180" height="1"></td>';
	put '                </tr>';
	put '              </table>';
	put '            </div>';
	put '          </td>';
	put '          <td id="navwdg"><img src="/SASABTFramework/images/blank.gif" name="navwdg" border="0" width="11" height="14" hspace="0" vspace="0" alt="" /></a></td>';
	put '          <td width="100%" id="wizardmain">';
	put '            <!--content comes here-->';
	put '            <div id="pagetitlesection">';
	put '            <div id="pagetitle">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.input_variables.1, noquote))"@;
	put '            </div>';
	put '            <div id="pagesubtitle"><!-- InstanceBeginEditable name="pagesubtitle" -->&nbsp;<!-- InstanceEndEditable --></div>';
	put '            </div>';
	put '            <div class="formfields">';

	/* Here, we have non-changing textboxes that display the name and description. */
	put '              <table class="formfields" cellpadding="4" border="0">';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put '                    &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_name.1, noquote))"@;	
	put ':';
	put '                  </td>';
	put '                  <td>';
	put "                    <input type=""text"" style=""width:200px;"" name=""Name"" value=""&save_abt_name"" Disabled class=""inputtext"">";
	put '                  </td>';
	put '                </tr>';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put '                    &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_description.1, noquote))"@;	
	put ':';
	put '                  </td>';
	put '                  <td>';
	put "                    <input type=""text"" style=""width:200px;"" name=""Description"" value=""&save_abt_desc"" Disabled class=""inputtext"">";
	put '                  </td>';
	put '                </tr>';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put '                    &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_varcat.1, noquote))"@;
	put ':';
	put '                  </td>';
	put '                  <td>';

	/* Generate the dropdown list for variable level. */
	put '                    <select name="var_cat" class="longselect" style="width: 80mm" onChange="javascript:OnChangeCat()">';
	if "&var_level" eq "CAT" then do;
		put '				<option value="None">' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp2_allvars.1, noquote))"@;
		put '</option>';
	end;
	else if "&var_level" eq "SUBCAT" then do;
		put '				<option value="None">'@;
		put "&category"@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.hyphen.1, noquote))"@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp2_allvars.1, noquote))"@;
		put '</option>';
	end;
	else if "&var_level" eq "GROUP" then do;
		put '				<option value="None">'@;
		put "&sub_category"@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.hyphen.1, noquote))"@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp2_allvars.1, noquote))"@;
		put '</option>';
	end;
	else if "&var_level" eq "SELGROUP" then do;
		put '				<option value="None">'@;
		put "&group"@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.hyphen.1, noquote))"@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp2_allvars.1, noquote))"@;
		put '</option>';
	end;
run;

data _NULL_;
	file _webout &webout_options;
	set &out_lib..var_group;
	put '<option value="' @;
	put cat@;
	put '">' @;
	put cat@;
	put '</option>';
run;


data _NULL_;
	file _webout &webout_options;
	put '                    </select>';

	/* This image button takes you one level up in the list. */
	put '                    <a href="javascript:oneLevelUp()"><img src="/SASABTFramework/images/up_one_level.gif" style="border:0"/></a>';
	put '                  </td>';
	put '                </tr>';
	put '				<tr><td></td>';
	put '				<td class=""BreadCrumb"">' @ ;
		 /*I18N-scnjih-20080421-1434*/
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp2_showcatloc.1, noquote))"@;
		 /*I18N-scnjih-20080421-1434*/
	put '</td></tr>';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put '                    &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.input_variables.1, noquote))"@;
	put ':';
	put '                  </td>';
	put '                  <td class="">';
	put '                    <table cellspacing="0" cellpadding="4" border="0" style="width:500px">';

	/* Radio buttons to select display type for variables */
	put '<tr><td><input type=radio name=optvar';
	if "&listopt"="1" then 
		put 'checked=true';
	put 'value = "VN" onclick="radioclick(this.value)"> ' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp2_showvarname.1, noquote))"@;
	put ' </td>';
		put '<td><input type=radio name=optvar';
	if "&listopt"="0" then 
		put 'checked=true'; 
    put 'value = "VSN" onclick="radioclick(this.value)"> ' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp2_showvarshortname.1, noquote))"@;
	put '</td></tr></table>';
	
	put '                    <table cellspacing="0" cellpadding="4" border="0" style="width:500px">';
	put '                      <tr valign="center">';
	put '                        <td>';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp2_available.1, noquote))"@;
	put ':'@;
	put ' <br>';
	put '                          <select multiple size="5" name="available" onchange="setDesc(this)" class="duallistselect" style="width:600px">';

run;

proc sort data=&out_lib..abt_avl_vars out=work.sort_avlvarsby_varnm;
by var_nm;
quit;

proc sort data=&out_lib..abt_avl_vars out=work.sort_avlvarsby_varshortnm;
by var_short_nm;
quit;

/* List items for the first list are generated here. */
%macro displaytype;
%if "&listopt" eq "1" %then %do;
data _NULL_;
	file _webout &webout_options;
	set work.sort_avlvarsby_varnm;
	put '<option value="' @;
	put v_no@;
	put "#"@;
	put var_desc@;
	put "#"@;
	put var_category@;
	put "#"@;
	put var_sub_category@;
	put "#"@;
	put var_group@;
	put '">' @;
	put var_nm@;
	put '</option>';
run;
%end;
%else %do;
data _NULL_;
	file _webout &webout_options;
	set work.sort_avlvarsby_varshortnm;
	put '<option value="' @;
	put v_no@;
	put "#"@;
	put var_desc@;
	put "#"@;
	put var_category@;
	put "#"@;
	put var_sub_category@;
	put "#"@;
	put var_group@;
	put '">' @;
	put var_short_nm@;
	put '</option>';
run;
%end;
%mend displaytype;
%displaytype;

data _NULL_;
	file _webout &webout_options;

	/* Here we generate the buttons for moving items between the lists. */
	put '                          </select>';
	put '                        </td>';
	put '                      </tr>';
	put '                      <tr>';
	put '                        <td align="center">';
	put '                          <table cellspacing="0" cellpadding="4" border="0">';
	put '                            <tr valign="center">';
	put '                              <td>';
	put '                                <a href="javascript:moveVar(form1.available, form1.selectvars, false)"  ><img src="/SASABTFramework/images/ArrowDownAdd.gif" alt="Add" border="0"></a>';
	put '                              </td>';
	put '                              <td>';
	put '                                <a href="javascript:moveVar(form1.available, form1.selectvars, true)"><img src="/SASABTFramework/images/ArrowDownAddAll.gif" alt="Add All" border="0"></a>';
	put '                              </td>';
	put '                              <td>';
	put '                                <a href="javascript:moveVar(form1.selectvars, form1.available, false)"  ><img src="/SASABTFramework/images/ArrowUpRemove.gif" alt="Remove" border="0"></a>';
	put '                              </td>';
	put '                              <td>';
	put '                                <a href="javascript:moveVar(form1.selectvars, form1.available, true)"><img src="/SASABTFramework/images/ArrowUpRemoveAll.gif" alt="Remove All" border="0"></a>';
	put '                              </td>';
	put '                            </tr>';
	put '                          </table>';
	put '                        </td>';
	put '                      </tr>';
	put '                      <tr>';
	put '                        <td>';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp2_selected.1, noquote))"@;
	put ':' @ ;
	put ' <br>';
	put '                          <select multiple size="5" name="selectvars" onchange="setDesc(this)" class="duallistselect" style="width:600px">';

run;

/* List items for the second list are generated here. */
data _NULL_;
	file _webout &webout_options;
	set &out_lib..selected_variables;
	put '<option value="' @;
	put v_no@;
	put "#"@;
	put var_desc@;
	put "#"@;
	put var_category@;
	put "#"@;
	put var_sub_category@;
	put "#"@;
	put var_group@;
	put '">' @;
	if "&listopt"="1" then
		put var_nm@;
	else
		put var_short_nm;
	put '</option>';
run;

data _NULL_;
	file _webout &webout_options;
	put '                          </select>';
	put '                        </td>';
	put '                      </tr>';
	put '                    </table>';
	put '                  </td>';
	put '                </tr>';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put '                    &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_description.1, noquote))"@;
	put ':'@;
	put '                  </td>';
	put '                  <td class="">';
	put '                    <textarea rows=3 style="width:500px;background-color:#FAF8ED" readonly name="var_desc"></textarea>';
	put '                  </td>';
	put '                </tr>';
	put '              </table>';
	put '            </div>';
	put '          </td>';
	put '        </tr>';
	put '      </table>';

	/* Wizard navigation buttons */
	put '      <table border="0" cellpadding="3" cellspacing="0" summary="Action Buttons" id="dialogbuttons" width="100%">';
	put '        <tr>';
	put '          <td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.prevbttn.1, noquote))"@;
	put '" name="Previous" type="button" onclick="previous()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.nextbttn.1, noquote))"@;
	put '" name="Next" type="button" onclick="next()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="30"><img src="/SASABTFramework/images/blank.gif" width="30" height="1">';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="Finish" name="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.finishbttn.1, noquote))"@;
	put '" type="button" Disabled>';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.cancelbttn.1, noquote))"@;
	put '" name="Cancel" type="button" onclick="cancel()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '          </td>';
	put '          <td width="90%">&nbsp';
	put '          </td>';
	put '        </tr>';
	put '      </table>';

	put '      <!--Big table ends here-->';
	put '      <div id="foot">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.copyright_notice.1, noquote))"@;
	put '      </div>';
	put '    </form>';
		
	put '  </body><!-- InstanceEnd -->';
	put '</html>';
run;
