/******************************************************************************************************
       Module:  template_step3

     Function:  This is the third step of the ABT template creation wizard. The outcome variable is chosen here.

      Authors:  BIS Team
         Date:  July 2007
          SAS:  9.1

Datasets used:  The datasets being used in this screen are:
				1. analytic.Outcome_master

******************************************************************************************************/
options nomprint;

/* Global input variables */
%global prev_step var_keys;

/* Here, copy the parameters into the session variables -- only if you are coming from the right page. */
data _null_;
	if "&prev_step" eq "2" then do;
		call symput('save_var_keys', "&var_keys");
	end;
run;

/* Loading macro aliases for the rest of the stored processes */
%select_abt_vars_screen_links;

/* Alias for the back-end library */
%let lib=analytic;

/* Start the session */
%let rc=%sysfunc(stpsrv_session(create));

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;

%let seg_purpose=.;
/*code used for segmentation models*/
proc sql;
select ap_no into :seg_purpose from &lib..abt_purpose where upcase(strip(abt_purpose_desc))='SEGMENTATION MODELS';
quit;

%macro getoutcomedata;
/* Data for Outcome definitions */
%if &seg_purpose NE &save_purpose_key %then %do;
proc sql;
	create table &out_lib..outcome_defns as
	select o_no, outcome_nm, outcome_desc, outcome_type_cd, outcome_defn
	from &lib..outcome_master
	where (ap_no = &save_purpose_key) and (p_no = &save_prod_key) and (l_no = &save_level_key)
	order by outcome_type_cd;
quit;
%end;
%mend getoutcomedata;
%getoutcomedata;

/* Start printing HTML */
data _NULL_;
	file _webout &webout_options;
	put '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">';
	put '<html xmlns="http://www.w3.org/1999/xhtml"><!-- InstanceBegin template="/Templates/dashboard.dwt"';
	put 'codeOutsideHTMLIsLocked="false" -->';
	put '  <head>';
	put '    <meta http-equiv="content-type" content="text/html;charset=utf-8" />';
			 	 /*I18N-scnjih-20080429-1529*/
/*	put '    <title>Outcome Variable</title>';*/
	put '    <title>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,template_step3.sas.1, noquote))"@;
	put '</title>';	
			 	 /*I18N-scnjih-20080429-1529*/
			 	 
			 	  /*I18N-scnjih-20080429-1529*/
	/*put '    <!-- InstanceBeginEditable name="doctitle" --><title>Layout</title><!-- InstanceEndEditable -->';*/
		put '    <!-- InstanceBeginEditable name="doctitle" --><title>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,title_of_layout.1, noquote))"@;
		put '</title><!-- InstanceEndEditable -->';	
	 				/*I18N-scnjih-20080429-1529*/
	put '    <link rel="stylesheet" type="text/css" href="/SASABTFramework/styles/default.css" />';

	/* External scripts */
	put '    <script src="/SASABTFramework/javascript/scripts.js" type="text/javascript"></script>';
	put '    <script src="/SASABTFramework/javascript/buttonMenu.js" type="text/javascript"></script>';
	put '    <script src="/SASABTFramework/javascript/overlib.js" type="text/javascript"></script>';
	put '    <script type="text/javascript" src="/SASABTFramework/javascript/table_controls.js"></script>';
	put '    <script type="text/javascript" src="/SASABTFramework/javascript/boxOver.js"></script>';
	put '    <script type="text/javascript">';
	put '    <!--';

	/* This takes you back to previous wizard pages. */
	put 'function back(page)';
	put '{';
	put '  if(page == 1)';
	put "    form1._program.value=&TEMPLATE_STEP1;";
	put '  else if(page == 2)';
	put "    form1._program.value=&TEMPLATE_STEP2;";
	put '  else if(page == 3)';
	put "    form1._program.value=&TEMPLATE_STEP3;";
	put '  else';
	put "    form1._program.value=&TEMPLATE_STEP4;";
	put '  form1.submit();';
	put '}';

	/* This function is called when the previous button is clicked */
	put 'function previous()';
	put '{';
	put "    form1._program.value=&TEMPLATE_STEP2;";
	put '	 form1.submit()';
	put '}';

	/* This function sets the outcome key to be passed to the next page. */
	put '      function selDefn(key){';
	put '	     form1.out_key.value=key';
	put '	   }';

	/* This takes you to the next wizard step. */
	put '	   function next()';
	put '	   {';
	if &seg_purpose NE &save_purpose_key then do;
		put '	     if((form1.out_key.value=='''') || (form1.out_key.value==''.''))';
		put '	       alert("' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp3_alert1.1, noquote))"@;
		put '")';
		put '	     else';
		put '	     {';
		put "	       form1._program.value=&TEMPLATE_STEP4;";
		put '	       form1.submit();';
		put '	     }';
	end;	
	else do; 
		put "		form1._program.value=&TEMPLATE_STEP4;";
		put '	    form1.submit();';
	end;
	put '	   }';

	put 'function restrictnav()';
	put '{';
	put 'alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_restrictnav.1, noquote))"@;
	put '");';
	put 'return;';
	put '}';

	/* This function is called when the cancel button is clicked */
	put 'function cancel()';
	put '{';
	put "	form1._program.value=&TEMPLATE_LIST;";
	put '	form1.submit();';
	put '}';

	put '	 -->';
	put '	 </script>';
	put '  </head>';

	put '  <body>';
	put "    <form name='form1' action='&_THISSESSION' method='post'>";

	/* These hidden fields store non-textbox form data. */
	out_key=symget("save_out_key");
	x='<input type="hidden" name="out_key" value="'||strip(out_key)||'" />';
	put x;
	put "      <input type='hidden' name='_program' value='&TEMPLATE_STEP4' />";
	put '	   <input type="hidden" name="prev_step" value="3"/>';

	put '      <div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div>';
	put '      <div id="banback">';

	/* Banner code. */
	put '          <table id="bantabs" border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '            <tr valign="top">';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_home.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tabsellft"><img src="/SASABTFramework/images/tab_upper_left_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tabsellab'><a href='#'>"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_modeling.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabselrgt"><img src="/SASABTFramework/images/tab_upper_right_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scoring.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scheduling.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td width="100%">&nbsp;</td>';
	put '            </tr>';
	put '          </table>';
	put '      </div>';
	put '      <table border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '        <tr>';
	put '          <td id="butbar">';
	put '            <font color="#996600"> <b>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_create_or_edit_template.1, noquote))"@;
	put '</b>';
	put '            <span id="butfill">&nbsp;</span>';
	put '          </td>';
	put '        </tr>';
	put '      </table>';


	/* List on the left side */
	put '      <table border="0" cellpadding="0" cellspacing="0" summary="" width="100%" height="500">';
	put '        <tr valign="top">';
	put '          <td  id="navcel">';
	put '            <div id="navcol">';
	put '              <table border="0" cellspacing="0" summary="" class="mmhide_wizardsteps">';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td><img src="/SASABTFramework/images/AdjustmentComplete.gif"></td><td>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.details.1, noquote))"@;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td><img src="/SASABTFramework/images/AdjustmentComplete.gif"></td><td>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.input_variables.1, noquote))"@;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td nowrap class="mmhide_wizardstepact"></td><td class="mmhide_wizardstepact">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.outcome_variable.1, noquote))"@;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td><img src="/SASABTFramework/images/blank.gif" width="16"></td><td>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.summary.1, noquote))"@;
	put '</td>';
	put '                </tr>';
	put '                <tr class="mmhide_wizardstep">';
	put '                  <td></td>';
	put '                  <td><img src="/SASABTFramework/images/blank.gif" width="180" height="1"></td>';
	put '                </tr>';
	put '              </table>';
	put '            </div>';
	put '          </td>';
	put '          <td id="navwdg"><img src="/SASABTFramework/images/blank.gif" name="navwdg" border="0" width="11" height="14" hspace="0" vspace="0" alt="" /></a></td>';
	put '          <td width="100%" id="wizardmain">';
	put '            <!--content comes here-->';
	put '            <div id="pagetitlesection">';
	put '              <div id="pagetitle">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.outcome_variable.1, noquote))"@;
	put '              </div>';
	put '              <div id="pagesubtitle"><!-- InstanceBeginEditable name="pagesubtitle" -->&nbsp;<!-- InstanceEndEditable -->';
	put '              </div>';
	put '            </div>';

	/* Here, we display the name and description of the template. */
	put '            <div class="formfields">';
	put '              <table class="formfields" cellpadding="4" cellpadding="0" border="0" >';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put '                    &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_name.1, noquote))"@;
	put ':';
	put '                  </td>';
	put '                  <td class="">';
	put "                    <input type='text' style=""width:200px;"" name='Name' value='&save_abt_name' Disabled class='inputtext'>";
	put '                  </td>';
	put '                </tr>';
	put '                <tr valign="top">';
	put '                  <td class="formfieldlabel">';
	put '                    &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_description.1, noquote))"@;
	put ':';
	put '                  </td>';
	put '                  <td>';
	put "                    <input type='text' style=""width:200px;"" name='Description' value='&save_abt_desc' Disabled class='inputtext'>";
	put '                  </td>';
	put '                </tr>';
	put '              </table>';
	put '            </div>';
	put '            <div class="tableviewcomposite">';
	put '              <div class="tableheader">';
	put '                <div class="tabletitle">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.outcome_variable.1, noquote))"@;
	put '                </div>';
	put '                <div class="tablecolcount">';
	put '                  &nbsp;';
	put '                </div>';
	put '              </div>';
	put '                <table border="0" cellpadding="0" cellspacing="0" summary="" class="tableview" width="100%">';
run;

%macro printoutcome_head;
%if &seg_purpose NE &save_purpose_key %then %do;	
data _null_;
file _webout &webout_options;

	/* Outcome table headings */
	put '                  <tr valign="top">';
	put '                    <th class="tabletextcol"></th>';
	put '                    <th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp3_outcome_type.1, noquote))"@;
	put '                    </th>';
	put '                    <th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.outcome_variable.1, noquote))"@;
	put '                    </th>';
	put '                    <th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.outcome_desc.1, noquote))"@;
	put '                    </th>';
	put '                    <th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.outcome_defn.1, noquote))"@;
	put '                    </th>';
	put '                  </tr>';
run;
%end;
%else %do;
data _null_;
file _webout &webout_options;
	put '<B>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp3_segmodnooc.1, noquote))"@;
	put '</B>';
run;
%end;
%mend printoutcome_head;
%printoutcome_head;

%macro printoutcome;
%if &seg_purpose NE &save_purpose_key %then %do;		
/* Here, we print the rows for the outcome variables table. */
data _NULL_;
	file _webout &webout_options;
	set &out_lib..outcome_defns;
	by outcome_type_cd;

	/* This alternates the row color. */
	if mod(_N_,2)=0 then do;
		put '<tr class="tableevenrow"> ';
	end;
	else do;
		put '<tr class="tableoddrow"> ';
	end;
	put '<td><div align="center">';
	put '<input type="radio" name="c" value="'@;
	put o_no@;
	put '" OnClick="selDefn('''@;
	put o_no @;
	put ''')"' @;
	if o_no eq "&save_out_key" then put 'checked=checked '@;
	put '></div></td>';
	if first.outcome_type_cd then do;
		put '<td>';
		put outcome_type_cd@;
	end;
	else do;
		put '<td>&nbsp;</td>';
	end;
	put '<td>' @;
	put outcome_nm@;
	put '</td>';
	put '<td>' @;
	put outcome_desc@;
	put '</td>';
	put '<td>' @;
	put outcome_defn@;
	put '</td>';
	put '</tr>';
run;
%end;
%mend printoutcome;
%printoutcome;

data _NULL_;
	file _webout &webout_options;	
	put '                </table>';
	put '              </div>';
	put '            </div>';
	put '          </td>';
	put '        </tr>';
	put '      </table>';

	/* Wizard navigation buttons */
	put '      <table border="0" cellpadding="3" cellspacing="0" summary="Action Buttons" id="dialogbuttons" width="100%">';
	put '        <tr>';
	put '          <td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.prevbttn.1, noquote))"@;
	put '" name="Previous" type="button" onclick="previous()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.nextbttn.1, noquote))"@;
	put '" name="Next" type="button" onclick="next()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="30"><img src="/SASABTFramework/images/blank.gif" width="30" height="1">';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="Finish" name="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.finishbttn.1, noquote))"@;
	put '" type="button" Disabled>';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.cancelbttn.1, noquote))"@;
	put '" name="Cancel" type="button" onclick="cancel()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '          </td>';
	put '          <td width="90%">&nbsp';
	put '          </td>';
	put '        </tr>';
	put '      </table>';

	put '      <!--Big table ends here-->';
	put '      <div id="foot">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.copyright_notice.1, noquote))"@;
	put '      </div>';
	put '    </form>';
		
	put '  </body><!-- InstanceEnd -->';
	put '</html>';
run;
