/******************************************************************************************************
       Module:  template_step4

     Function:  This is the fourth step of the ABT template creation wizard. It acts as a summary page.

      Authors:  BIS Team
         Date:  July 2007
          SAS:  9.1

Datasets used:  The datasets being used in this screen are:
				1. analytic.Var_master
				2. analytic.Outcome_master

******************************************************************************************************/

options nomprint;

/* Global input parameters */
%global out_key prev_step;

/* Alias for the back-end library */
%let lib=analytic;

/* Links specific for the Modeling ABT variables selection screens */
%select_abt_vars_screen_links;

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;

/* Start the session */
%let rc=%sysfunc(stpsrv_session(create));

/* Here, copy the parameters into the session variables -- only if you are coming from the right page. */
data _null_;
	if "&prev_step" eq "3" then do;
		call symput('save_out_key', "&out_key");
	end;
run;

/* Retrieve the details of the outcome variable. */
proc sql;
	create table &out_lib..outcome_defns as
	select o_no, outcome_nm, outcome_desc, outcome_type_cd, outcome_defn
	from &lib..outcome_master
	where (o_no = &save_out_key)
	order by outcome_type_cd;
quit;
/* Initialize with blanks */
%let save_out_name=;
%let save_out_def=;
%let save_out_desc=;

/* Here, store those details in session variables. */
data _null;
	set &out_lib..outcome_defns;
	call symput('save_out_name', outcome_nm);
	call symput('save_out_def', outcome_defn);
	call symput('save_out_desc', outcome_desc);
run;

/* Start printing out HTML. */
data _null_;
	file _webout &webout_options;
	put '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">';
	put '<html xmlns="http://www.w3.org/1999/xhtml"><!-- InstanceBegin template="/Templates/dashboard.dwt"';
	put 'codeOutsideHTMLIsLocked="false" -->';
	put '  <head>';
	put '    <meta http-equiv="content-type" content="text/html;charset=utf-8" />';
	put '    <link rel="stylesheet" type="text/css" href="/SASABTFramework/styles/default.css" />';
	put '    <script type="text/javascript">';
	put '      <!--';

	/* Takes you back to previous wizard pages. */
	put 'function back(page)';
	put '{';
	put '  if(page == 1)';
	put "    form1._program.value=&TEMPLATE_STEP1;";
	put '  else if(page == 2)';
	put "    form1._program.value=&TEMPLATE_STEP2;";
	put '  else if(page == 3)';
	put "    form1._program.value=&TEMPLATE_STEP3;";
	put '  else';
	put "    form1._program.value=&TEMPLATE_STEP4;";
	put '  form1.submit();';
	put '}';
	
	/* This function is called when the previous button is clicked */
	put 'function previous()';
	put '{';
	put "    form1._program.value=&TEMPLATE_STEP3;";
	put '	 form1.submit()';
	put '}';

	put 'function restrictnav()';
	put '{';
	put 'alert("' @ ;
/*	put 'Click cancel and then click the required tab.' @ ;*/
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_restrictnav.1, noquote))"@;
	put '");';
	put 'return;';
	put '}';

	/* This function is called when the cancel button is clicked */
	put 'function cancel()';
	put '{';
	put "	form1._program.value=&TEMPLATE_LIST;";
	put '	form1.submit();';
	put '}';

	/* Takes you to the next step. */
	put 'function finish()';
	put '{';
	put "  form1._program.value=&TEMPLATE_STEP5;";
	put '  form1.submit();';
	put '}';

	put '      -->';
	put '    </script>';
	

	  /*I18N-scnjih-20080429-1533*/
	/*put '    <!-- InstanceBeginEditable name="doctitle" --><title>Layout</title><!-- InstanceEndEditable -->';*/
		put '    <!-- InstanceBeginEditable name="doctitle" --><title>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,title_of_layout.1, noquote))"@;
		put '</title><!-- InstanceEndEditable -->';
	
	 /*I18N-scnjih-20080429-1533*/

	/* External scripts */
	put '    <script src="/SASABTFramework/javascript/scripts.js" type="text/javascript"></script>';
	put '    <script src="/SASABTFramework/javascript/buttonMenu.js" type="text/javascript"></script>';
	put '    <script src="/SASABTFramework/javascript/overlib.js" type="text/javascript"></script>';
	put '    <script type="text/javascript" src="/SASABTFramework/javascript/table_controls.js"></script>';
	put '    <script type="text/javascript" src="/SASABTFramework/javascript/boxOver.js"></script>';
	put '  </head>';
	put '  <body>';
	put "    <form name='form1' action='&_THISSESSION' method='post'>";
	put '      <input type="hidden" name="_program" value="" />';
	put '	<div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div>';
	put '	<div id="banback">';

	/* Banner code. */
	put '          <table id="bantabs" border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '            <tr valign="top">';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_home.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tabsellft"><img src="/SASABTFramework/images/tab_upper_left_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tabsellab'><a href='#'>"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_modeling.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabselrgt"><img src="/SASABTFramework/images/tab_upper_right_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scoring.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "              <td class='mmhide_tablab'><a href='javascript:restrictnav();'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scheduling.1, noquote))"@;
	put '</a></td>';
	put '              <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '              <td width="100%">&nbsp;</td>';
	put '            </tr>';
	put '          </table>';
	put '      </div>';
	put '      <table border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '        <tr>';
	put '          <td id="butbar">';
	put '            <font color="#996600"> <b>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_create_or_edit_template.1, noquote))"@;
	put '</b>';
	put '            <span id="butfill">&nbsp;</span>';
	put '          </td>';
	put '        </tr>';
	put '      </table>';

	/* List on the left hand side */
	put '	<table border="0" cellpadding="0" cellspacing="0" summary="" width="100%" height="500">';
	put '	  <tr valign="top">';
	put '	    <td  id="navcel">';
	put '	      <div id="navcol">';		
	put '	        <table border="0" cellspacing="0" summary="" class="mmhide_wizardsteps">';
	put '	          <tr class="mmhide_wizardstep">';
	put '	            <td><img src="/SASABTFramework/images/AdjustmentComplete.gif"></td>';
	put '	            <td >' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.details.1, noquote))"@;
	put '</td>';
	put '	          </tr>';
	put '	          <tr class="mmhide_wizardstep">';
	put '	            <td><img src="/SASABTFramework/images/AdjustmentComplete.gif"></td>';
	put '	            <td >' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.input_variables.1, noquote))"@;
	put '</td>';
	put '	          </tr>';
	put '	          <tr class="mmhide_wizardstep">';
	put '	            <td><img src="/SASABTFramework/images/AdjustmentComplete.gif"></td>';
	put '	            <td>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.outcome_variable.1, noquote))"@;
	put '</td>';
	put '	          </tr>';
	put '	          <tr class="mmhide_wizardstep">';
	put '	            <td nowrap class="mmhide_wizardstepact"></td>';
	put '	            <td class="mmhide_wizardstepact">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.summary.1, noquote))"@;
	put '</td>';
	put '	          </tr>';
	put '	          <tr class="mmhide_wizardstep">';
	put '	            <td></td>';
	put '	            <td><img src="/SASABTFramework/images/blank.gif" width="180" height="1"></td>';
	put '	          </tr>';
	put '	        </table>';
	put '	      </div>';
	put '	    </td>';
	put '	    <td id="navwdg">';
	put '	      <img src="/SASABTFramework/images/blank.gif" name="navwdg" border="0"';
	put '	       width="11" height="14" hspace="0" vspace="0" alt="" /></a>';
	put '	    </td>';
	put '	    <td width="100%" id="wizardmain">';
	put '	      <!--content comes here-->';
	put '	      <div id="pagetitlesection">';
	put '	        <div id="pagetitle">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.summary.1, noquote))"@;
	put '	        </div>';
	put '	        <div id="pagesubtitle"><!-- InstanceBeginEditable name="pagesubtitle" -->&nbsp;<!-- InstanceEndEditable --></div>';
	put '	      </div>';
	put '	      <div class="formfields">';

	/* Print the template detail */
	put '	        <table class="formfields" cellpadding="4" cellpadding="0" border="0" >';
	put '	          <tr valign="top">';
	put '	            <td class="formfieldlabel">';
	put '	              &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_name.1, noquote))"@;
	put ':';
	put '	            </td>';
	put '	            <td class="">';
	put "	              <input type='text' style=""width:200px;"" name='Name' value='&save_abt_name' Disabled class='inputtext'>";
	put '	            </td>';
	put '	          </tr>';
	put '	          <tr valign="top">';
	put '	            <td class="formfieldlabel">';
	put '	              &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_description.1, noquote))"@;
	put ':';
	put '	            </td>';
	put '	            <td class="">';
	put "	              <input type='text' style=""width:200px;"" name='Description' value='&save_abt_desc' Disabled class='inputtext'>";
	put '	            </td>';
	put '	          </tr>';
	put '	          <tr valign="top">';
	put '	            <td class="formfieldlabel">';
	put '	              &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_purpose.1, noquote))"@;
	put ':';
	put '	            </td>';
	put '	            <td class="">';
	put "	              <input type='text' style=""width:200px;"" name='Purpose' value='&save_purpose_desc' Disabled class='inputtext'>";
	put '	            </td>';
	put '	          </tr>';
	put '	          <tr valign="top">';
	put '	            <td class="formfieldlabel">';
	put '	              &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_level.1, noquote))"@;
	put ':';
	put '	            </td>';
	put '	            <td class="">';
	put "	              <input type='text' style=""width:200px;"" name='Level' value='&save_level_desc' Disabled class='inputtext'>";
	put '	            </td>';
	put '	          </tr>';
	put '	          <tr valign="top">';
	put '	            <td class="formfieldlabel">';
	put '	              &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_prodtype.1, noquote))"@;
	put ':';
	put '	            </td>';
	put '	            <td class="">';
	put "	              <input type='text' style=""width:200px;"" name='Product type' value='&save_prod_desc' Disabled class='inputtext'>";
	put '	            </td>';
	put '	          </tr>';
	put '	          <tr valign="top">';
	put '	            <td class="formfieldlabel">';
	put '	              &nbsp;';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_outcome_period.1, noquote))"@;
	put ':';
	put '	            </td>';
	put '	            <td class="">';
	put "	              <input type='text' style=""width:200px;"" name='Outcome period' value='&save_outcome_period' Disabled class='inputtext'>";
	put '	            </td>';
	put '	          </tr>';
	put '	        </table>';
	put '	      </div>';

	/* Input variable table headings */
	put '	      <div class="tableviewcomposite">';
	put '	        <div class="tableheader">';
	put '	          <div class="tabletitle">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.input_variables.1, noquote))"@;
	put '	          </div>';
	put '	          <div class="tablecolcount">';
	put '	            &nbsp;';
	put '	          </div>';
	put '	        </div>';
	put '	        <table border="0" cellpadding="0" cellspacing="0" summary="" class="tableview" width="100%">';
	put '	          <tr valign="top" class="">';
	put '	            <th class="tabletextcol">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.table_row.1, noquote))"@;
	put '</th>';
	put '	            <th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.table_catg_sub_catg.1, noquote))"@;
	put '	            </th>';
	put '	            <th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.input_variable.1, noquote))"@;
	put '	            </th>';
	put '	            <th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_description.1, noquote))"@;
	put '	            </th>';
	put '	          </tr>';
run;

/* This is where the input variables are printed. */
/* Create a temporary table to hold variable details. */
data &out_lib..var_details;
	set &lib..var_master(keep=v_no var_short_nm var_desc var_category var_sub_category);
	if indexw("&save_var_keys", v_no)>0 then output;
run;

/* Print the table rows using the temporary table */
data _null_;
	set &out_lib..var_details;
	file _webout &webout_options;
	by v_no;
	
	/* This alternates the row color. */
	if mod(_N_,2)=0 then do;
		put '<tr class="tableevenrow"> ';
	end;
	else do;
		put '<tr class="tableoddrow"> ';
	end;
	put '<td class="tablenumcol" width="20">'@;
	put _N_@;
	put '</td>';
	put '<td class="tabletextcol">'@;
	put var_category@;
	put ', '@;
	put var_sub_category@;
	put '</td>';
	put '<td class="tabletextcol">'@;
	put var_short_nm@;
	put '</td>';
	put '<td class="tabletextcol">'@;
	put var_desc@;
	put '</td>';
	put '</tr>';
run;

data _null_;
	file _webout &webout_options;
	put '	        </table>';
	put '	      </div>';
	if "&save_out_name" ne "" then do;
		put '	      <div class="tableviewcomposite">';
		put '	        <div class="tableheader">';
		put '	          <div class="tabletitle">Outcome Variable';
		put '	          </div>';
		put '	          <div class="tablecolcount">';
		put '	            &nbsp;';
		put '	          </div>';
		put '	        </div>';

		/* Outcome variable table headings */
		put '	        <table border="0" cellpadding="0" cellspacing="0" summary="" class="tableview" width="100%">';
		put '	          <tr valign="top" class="">';
		put '	            <th class="tabletextcol">';
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.outcome_variable.1, noquote))"@;
		put '	            </th>';
		put '	            <th class="tabletextcol">';
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.outcome_desc.1, noquote))"@;
		put '	            </th>';
		put '	            <th class="tabletextcol">';
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.outcome_defn.1, noquote))"@;
		put '	            </th>';
		put '	          </tr>';

	/* Outcome variable data row */
		put '	          <tr valign="top" class="tableoddrow">';
		put "	            <td class=""tabletextcol"">&save_out_name</td>";
		put "	            <td class=""tabletextcol"">&save_out_desc</td>";
		put "	            <td class=""tabletextcol"">&save_out_def</td>";
		put '	          </tr>';
		put '	        </table>';
	end;
	put '	      </div>';
	put '	    </td>';
	put '	  </tr>';
	put '	</table>';

	/* Wizard navigation buttons */
	put '      <table border="0" cellpadding="3" cellspacing="0" summary="Action Buttons" id="dialogbuttons" width="100%">';
	put '        <tr>';
	put '          <td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.prevbttn.1, noquote))"@;
	put '" name="Previous" type="button" onclick="previous()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.nextbttn.1, noquote))"@;
	put '" name="Next" type="button" onclick="next()" Disabled>';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="30"><img src="/SASABTFramework/images/blank.gif" width="30" height="1">';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="Finish" name="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.finishbttn.1, noquote))"@;
	put '" type="button" onclick="finish()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '            <td width="40">';
	put '              <table border="0" cellpadding="0" cellspacing="0">';
	put '                <tr>';
	put '                  <td>';
	put '                    <input class="mmhide_btn"style="width:80px;" onmouseover="hov(this,''mmhide_btn mmhide_btnhov'')" onmouseout="hov(this,''mmhide_btn'')" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.cancelbttn.1, noquote))"@;
	put '" name="Cancel" type="button" onclick="cancel()">';
	put '                  </td>';
	put '                  <td></td>';
	put '              </table>';
	put '            </td>';
	put '          </td>';
	put '          <td width="90%">&nbsp';
	put '          </td>';
	put '        </tr>';
	put '      </table>';

	put '      <!--Big table ends here-->';
	put '      <div id="foot">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.copyright_notice.1, noquote))"@;
	put '      </div>';
	put '    </form>';
		
	put '  </body><!-- InstanceEnd -->';
	put '</html>';
run;
