/******************************************************************************************************
       Module:  templates

     Function:  This is the master template list. It allows you create new templates, and edit existing ones.

      Authors:  BIS Team
         Date:  July 2007
          SAS:  9.1

Datasets used:  The datasets being used in this screen are:
				1. analytic.Abt_master
				2. analytic.Abt_purpose
				3. analytic.Abt_product
				4. analytic.Abt_level
				5. analytic.Abt_x_outcome

******************************************************************************************************/

/* No global input parameters. */
%global delflag strabtkey;

/* Alias for the back-end library */
%let lib=analytic;

/* Loading macro aliases for the rest of the stored processes */
%select_abt_vars_screen_links;

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;

%macro deltmps;
%let strabtkey = &strabtkey;
%let c=1;
%let akey = %sysfunc(kscan("&strabtkey",&c," "));
%do %while("&akey" ne "");
	%if "&delflag" eq "Y" and "&akey" ne "" %then %do;
		proc sql;
			update &lib..abt_master 
			set is_deleted = 'Y'
			where a_no=&akey;
		quit;
	%end;
%let c=%eval(&c+1);
%let akey = %sysfunc(kscan("&strabtkey",&c," "));
%end;
%mend;
%deltmps;

/* Here, use a proc sql to retrieve ABT details. */
proc sql;
	/* Retrieve details for each of the templates */
	create table &out_lib..abt_records as
 	select abt_master.a_no, abt_nm, abt_desc, abt_table_nm, abt_master.ap_no, abt_purpose_desc, abt_master.p_no, product_type_desc, abt_master.l_no, level_desc, outcome_period, abt_x_outcome.o_no as out_key
	from &lib..abt_master, &lib..abt_purpose, &lib..abt_product,
	&lib..abt_level, &lib..abt_x_outcome
	where abt_purpose.ap_no = abt_master.ap_no 
	and abt_product.p_no = abt_master.p_no 
	and abt_level.l_no = abt_master.l_no 
	and abt_master.a_no = abt_x_outcome.a_no 
	and abt_master.is_deleted ne 'Y';

	/* This extra proc is required to retrieve data for templates with no product. */
	insert into &out_lib..abt_records 
 	select distinct abt_master.a_no, abt_nm, abt_desc, abt_table_nm, abt_master.ap_no, abt_purpose_desc, ., "n/a", abt_master.l_no, level_desc, outcome_period, abt_x_outcome.o_no as out_key
	from &lib..abt_master, &lib..abt_purpose, &lib..abt_product, &lib..abt_level, &lib..abt_x_outcome
	where abt_purpose.ap_no = abt_master.ap_no 
	and abt_master.p_no = . 
	and abt_level.l_no = abt_master.l_no 
	and abt_master.a_no = abt_x_outcome.a_no 
	and abt_master.is_deleted ne 'Y';
quit;

/* to get the build status of the modeling abts */
proc sql;
create table &out_lib..bldsts as select ast.a_no, ast.status_desc, ast.obs_dt 
from &lib..abt_status ast, &out_lib..abt_records ar
where ast.a_no = ar.a_no;
quit;

proc sql;
create table &out_lib..lnksts as 
select axm.a_no,'linked' as lst, am.model_nm
from &lib..abt_x_model axm, &out_lib..abt_records ar, dim.analytical_model_dim am
where axm.a_no=ar.a_no and IS_SELECTED_FLG='Y' and axm.model_sk=am.model_sk;
quit;

proc sql;
alter table &out_lib..abt_records 
	add status char(50), linked char(10), model_nm char(50), obs_dt num format=date9.;
update &out_lib..abt_records ar set 
status = (select status_desc from &out_lib..bldsts bs where ar.a_no = bs.a_no),
obs_dt = (select obs_dt from &out_lib..bldsts bs where ar.a_no = bs.a_no);
update &out_lib..abt_records ar set
linked = (select lst from &out_lib..lnksts ls where ar.a_no = ls.a_no), 
model_nm = (select model_nm from &out_lib..lnksts ls where ar.a_no = ls.a_no);
quit;

/* Sort the data. */
proc sort data=&out_lib..abt_records out=&out_lib..abt_records;
	by a_no;
run;

%let abtcnt=0;
proc sql;
select count(*) into :abtcnt from &out_lib..abt_records;
quit;

/* Start printing out HTML */
data _null;
	file _webout &webout_options;
	put '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">';
	put '<html xmlns="http://www.w3.org/1999/xhtml"><!-- InstanceBegin template="/Templates/dashboard.dwt" codeOutsideHTMLIsLocked="false" -->';
	put '  <head>';
	put '    <meta http-equiv="content-type" content="text/html;charset=utf-8" />';
		/*I18N-scnjih-20080429-1535*/
	/*put '    <!-- InstanceBeginEditable name="doctitle" --><title>Layout</title><!-- InstanceEndEditable -->';*/
		put '    <!-- InstanceBeginEditable name="doctitle" --><title>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,title_of_layout.1, noquote))"@;
		put '</title><!-- InstanceEndEditable -->';
	
	 /*I18N-scnjih-20080429-1535*/
	
	put '    <link rel="stylesheet" type="text/css" href="/SASABTFramework/styles/default.css" />';

	/* External scripts */
	put '    <script src="/SASABTFramework/javascript/scripts.js" type="text/javascript"></script>';
	put '    <script src="/SASABTFramework/javascript/buttonMenu.js" type="text/javascript"></script>';
	put '    <script src="/SASABTFramework/javascript/overlib.js" type="text/javascript"></script>';
	put '    <script type="text/javascript" src="/SASABTFramework/javascript/table_controls.js"></script>';
	put '    <script type="text/javascript" src="/SASABTFramework/javascript/boxOver.js"></script>';
	put '    <script type="text/javascript">';
	put '    <!--';
	
	put 'function load()';
	put '{';
		put 'document.getElementById("data_capture_prd").style.visibility="hidden"';
	put '}';

	put 'function disable_while_build()';
	put '{';
		put 'form1.bldsts.value=1;';
	put '}';	
		
	/* This function is used to delete existing templates */
	put '	function deltmplt(){';
	put 'var r=confirm("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates_confirm1.1, noquote))"@;
	put '");';
	put 'if (r==false){';
	put '	return;';
	put '}';
	/* if there is only one record then there is no array, just a single checkbox called Sel */
	put '	if(form1.Sel.checked==true)';
	put ' 		form1.strabtkey.value = form1.Sel.value';
	/* if there are more than 1 abt templates,
	   only then an array of checkboxes will be created */
	put '	else if (form1.Sel.length>1)';	
	put '	{';
	put '		for(var i=0; i<form1.Sel.length;i++)';
	put '		 {';
	put '			if(form1.Sel[i].checked==true) ';
	put '				form1.strabtkey.value = form1.strabtkey.value + form1.Sel[i].value';
	put '		 }';
	put '	}';
	put '	form1.delflag.value="Y";';
	put "	form1._program.value=&TEMPLATE_LIST;";
	put '	form1.submit();';
	put '	}';

	/* This function launches the wizard with the specified input data. */
	put '      function edit(abt_key, abt_name, abt_desc, abt_table_name, purpose_key, purpose_desc, prod_key, prod_desc, level_key, level_desc, outcome_period, out_key)';
	put '      {';
	put '        form1.abt_key.value = abt_key;';
	put '        form1.abt_name.value = abt_name;';
	put '        form1.abt_desc.value = abt_desc;';
	put '        form1.abt_table_name.value = abt_table_name;';
	put '        form1.purpose_key.value = purpose_key;';
	put '        form1.purpose_desc.value = purpose_desc;';
	put '        form1.prod_key.value = prod_key;';
	put '        form1.prod_desc.value = prod_desc;';
	put '        form1.level_key.value = level_key;';
	put '        form1.level_desc.value = level_desc;';
	put '        form1.outcome_period.value = outcome_period;';
	put '        form1.out_key.value = out_key;';
	put "		 form1._program.value=&TEMPLATE_STEP1;";
	put '        form1.submit();';
	put '      }';

	put 'javascript:window.history.forward(1);';

	put 'function menu() {';
	put 'var menu = new TableMenu();';
	put 'var c=0;';
	put 'if(!form1.Sel){';
	put 'alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates_alert1.1, noquote))"@;
	put '");';
	put 'return;';
	put '}';
	put 'if (form1.Sel.length>0)';	/* for more than 1 abts */
	put '{';
	put 'for(var i=0;i<form1.Sel.length;i++){';
		put 'if(form1.Sel[i].checked==true)';
		put 'c=c+1;}';
	put '}';

	put 'if (form1.Sel.checked==true)'; /* for exactly 1 abt */
	put 'c=1';

	put 'if (form1.bldsts.value==1)';
	put '{';
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.disabled,"", "' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates_menu_build.1, noquote))"@;
		put '", "javascript:Build()"));';
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.separator));';
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.disabled,"", "' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates_menu_link.1, noquote))"@;
		put '", "javascript:Link()"));';
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.separator));';
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.disabled,"", "' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates_menu_delete, noquote))"@;
		put '", "javascript:deltmplt()"));';
		put 'menu.render();';
		put 'return;';
	put '}';

	put 'if(c==0 || c>1){'; /* Disable the build and link menu options if there are none or more than 1 abts selected */
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.disabled,"", "' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates_menu_build.1, noquote))"@;
		put '", "javascript:Build()"));';
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.separator));';
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.disabled,"", "' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates_menu_link.1, noquote))"@;
		put '", "javascript:Link()"));';
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.separator));';
	put '}';
	put 'else {'; /* Build and link menu options should be enabled only if 1 abt is selected */
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.action,"/SASABTFramework/images/MessageProcess.gif", "' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates_menu_build.1, noquote))"@;
		put '", "javascript:Build()"));';
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.separator));';
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.action,"/SASABTFramework/images/network.gif", "' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates_menu_link.1, noquote))"@;
		put '", "javascript:Link()"));';
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.separator));';
	put '}';
	put 'if(c==0)';
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.disabled,"", "' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates_menu_delete, noquote))"@;
		put '", "javascript:deltmplt()"));';
	put 'else';
		put 'menu.addMenuItem(new MenuItem(MenuItem.prototype.action,"/SASABTFramework/images/DeleteRed.gif", "' @ ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates_menu_delete, noquote))"@;
		put '", "javascript:deltmplt()"));';	
	put 'menu.render();';
	put '}';

	put 'function Build(){';
	put 'if (form1.flag.value==1)';
	put '{';
		put 'document.getElementById("data_capture_prd").style.visibility="visible"';
		put 'form1.flag.value=0;';
	put '}';
	put 'else';
	put '{';
		put 'document.getElementById("data_capture_prd").style.visibility="hidden"';
		put 'form1.flag.value=1;';
	put '}';
  	put '}';

	put 'function linkedmodel(abt_key)';
	put '{';
	put 'form1.abt_key.value = abt_key;';
	put "form1._program.value='&SELECT_MDL_ABT_LINKER';";
	put 'form1.submit();';
	put '}';

	put 'function Startbuild(){';
	put 'if(form1.year.selectedIndex==0 || form1.month_no.selectedIndex==0)';
	put '{';
	put 'alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates_alert2.1, noquote))"@;
	put '");';
	put 'return;';
	put '}';
	put 'if(form1.Sel.checked==true)';
		put 'form1.abt_key.value=form1.Sel.value;';
	put 'else if(form1.Sel.length>1)';
	put '{';
		put 'for(i=0;i<form1.Sel.length;i++){';
		put 'if(form1.Sel[i].checked==true)';
		put '    form1.abt_key.value = form1.Sel[i].value;';
		put '}';
	put '}';
	put "form1._program.value=&BUILD_MDL_ABT;";
	put 'form1.submit();';
	put '}';

	put 'function Link(){';
	put 'if(form1.Sel.checked==true)';
		put 'form1.abt_key.value=form1.Sel.value;';
	put 'else if(form1.Sel.length>1)';
	put '{';
		put 'for(i=0;i<form1.Sel.length;i++){';
		put 'if(form1.Sel[i].checked==true)';
		put '    form1.abt_key.value = form1.Sel[i].value;';
		put '}';
	put '}';
	put "form1._program.value='&SELECT_MDL_ABT_LINKER';";
	put 'form1.submit();';
	put '}';

	put 'function Cancelmdlabt(){';
	put 'document.getElementById("data_capture_prd").style.visibility="hidden"';
	put 'form1.flag.value=1;';
	put '}';

	put 'function seldesel(obj)';
	put '{';
		put 'if(obj.checked==true){';
			put 'for(i=0;i<form1.Sel.length;i++){';
			put 'form1.Sel[i].checked=true;';
			put '}';
			put '}';
		put 'else {';
		put 'for(i=0;i<form1.Sel.length;i++){';
			put 'form1.Sel[i].checked=false;';
			put '}';
			put '}';
	put '}';

	put '    -->';
	put '    </script>';
	put '  </head>';
	put '  <body onload="load()">';
	put '    <div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div>';
	put '    <div id="banback">';

	/* Banner code */
	put '      <table id="bantabs" border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '        <tr valign="top">';
	put '          <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "          <td class='mmhide_tablab'><a href='http://&_SRVNAME:&_SRVPORT/SASStoredProcess/do?_program=SBIP://Foundation/BIS/analytics/explore_abt/explore_abtvars'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_home.1, noquote))"@;
	put '</a></td>';
	put '          <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '          <td class="mmhide_tabsellft"><img src="/SASABTFramework/images/tab_upper_left_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "          <td class='mmhide_tabsellab'><a href='#'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_modeling.1, noquote))"@;
	put '</a></td>';
	put '	       <td class="mmhide_tabselrgt"><img src="/SASABTFramework/images/tab_upper_right_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '	       <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "          <td class='mmhide_tablab'><a href='http://&_SRVNAME:&_SRVPORT/SASStoredProcess/do?_program=SBIP://Foundation/BIS/analytics/scoring/scrabts'>"@; 
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scoring.1, noquote))"@;
	put '</a></td>';
	put '	       <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '	       <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "          <td class='mmhide_tablab'><a href='http://&_SRVNAME:&_SRVPORT/SASStoredProcess/do?_program=SBIP://Foundation/BIS/analytics/scoring/sch_scr_prc'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scheduling.1, noquote))"@;
	put '</a></td>';
	put '	       <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '          <td width="100%">&nbsp;</td>';
	put '        </tr>';
	put '      </table>';
	put '    </div>';
	put '    <table border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '      <tr>';
	put '        <td id="butbar">';
	put '          <span id="butfill">&nbsp;</span>';
	put '        </td>';
	put '        <td id="butbar" align="right">';
	put '          <a href="#"  onClick="javascript:window.print();" >';
	put '          <img src="/SASABTFramework/images/Print.gif" alt="Print" border="0">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.printer_icon.1, noquote))"@;
	put '</a>&nbsp;';
	put '        </td>';
	put '      </tr>';
	put '    </table>';
	put '    <table border="0" cellpadding="12" cellspacing="0" width="100%">';
	put '      <tr>';
	put '        <form method="post" action="/SASStoredProcess/do" name="form1">';

	/* Hidden fields contain the data to be passed to the wizard. */
	put "          <input type='hidden' name='_program' value=/>";
	put '          <input type="hidden" name="abt_key" value="."/>';
	put '          <input type="hidden" name="abt_name" value=""/>';
	put '          <input type="hidden" name="abt_desc" value=""/>';
	put '          <input type="hidden" name="abt_table_name" value=""/>';
	put '          <input type="hidden" name="purpose_key" value="."/>';
	put '          <input type="hidden" name="purpose_desc" value=""/>';
	put '          <input type="hidden" name="prod_key" value="."/>';
	put '          <input type="hidden" name="prod_desc" value=""/>';
	put '          <input type="hidden" name="level_key" value="."/>';
	put '          <input type="hidden" name="level_desc" value=""/>';
	put '          <input type="hidden" name="outcome_period" value=""/>';
	put '          <input type="hidden" name="out_key" value="."/>';
	put '          <input type="hidden" name="prev_step" value="0"/>';
	put '          <input type="hidden" name="first_load" value="Y"/>';
	put '          <input type="hidden" name="delflag" value=""/>';
	put '          <input type="hidden" name="strabtkey" value=""/>';
	put '          <input type="hidden" name="flag" value="1"/>';
	put '          <input type="hidden" name="action" value=""/>';
	put '          <input type="hidden" name="bldsts" value="0"/>';
	put '          <td width="100%" id="main">';
	put '            <div id="mainentity">';

	/* This link launches the wizard for creating a new template. */
	put '	<table>';
	put '   <tr><td></td><td width="100%" align="right"><a href=''javascript:edit(".", "", "", "", ".", "", ".", "", ".", "", ".", ".")''>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.create_template.1, noquote))"@;
	put '</a></td></tr>';
	put '	</table>';
	put '              <div class="tableviewcomposite">';
	put '                <div class="tableheader">';
	put '                  <div class="tabletitle">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates.1, noquote))"@;
	put '                  </div>';
	put '                  <div class="tablecolcount">';
	put '                    &nbsp;';
	put '                  </div>';
	put '                </div>';

	/* Table displaying the templates*/
	put '<table border="0" cellpadding="0" cellspacing="0" summary="" class="tableview" width="100%"><tr valign="top" class="">';

	/* Table headings */
	put '<tr>';
	put '<th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_name.1, noquote))"@;
	put '</th>';
	put '<th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_description.1, noquote))"@;
	put '</th>';
	put '<th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_abt_table_nm.1, noquote))"@;
	put '</th>';
	put '<th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_purpose.1, noquote))"@;
	put '</th>';
	put '<th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_prodtype.1, noquote))"@;
	put '</th>';
	put '<th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_level.1, noquote))"@;
	put '</th>';
	put '<th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_outcome_period.1, noquote))"@;
	put '</th>';
	put '<th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_dateofabt.1, noquote))"@;
	put '</th>';
	put '<th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_buildstatus.1, noquote))"@;
	put '</th>';
	put '<th class="tabletextcol">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.heading_modellinked.1, noquote))"@;
	put '</th>';
	put '<th class="tabletextcol">';
	put '<a href="#" onclick="menu();return false;"><img src="/SASABTFramework/images/ActionMenu.gif" style="border:0"/></a>';
	put '<input type="checkbox" name="selallabt" onclick="seldesel(this);"';
	if &abtcnt <= 1 then 
		put 'disabled>';
	else
		put '>';
	put '</th>';
	put '</tr>';
run;
/* Print the table rows */
data _NULL_;
	file _webout &webout_options;
	set &out_lib..abt_records;

	/* This alternates the row color. */
	if mod(_N_,2)=0 then do;
		put '<tr class="tableevenrow" tr valign="top"> ';
	end;
	else do;
		put '<tr class="tableoddrow" tr valign="top"> ';
	end;
	
	put '<td class="tabletextcol">' @;
	/* This link launches the wizard for editing the template. */
	put '<a href="javascript:edit(' @;
	put a_no @;
	put ', ''' @;
	put abt_nm @;
	put ''', ''' @;
	put abt_desc @;
	put ''', ''' @;
	put abt_table_nm @;
	put ''', ' @;
	put ap_no @;
	put ', ''' @;
	put abt_purpose_desc @;
	put ''', ' @;
	if p_no ne . then 
		put p_no@;
	else 
		put "'.'"@;
	put ', ''' @;
	put product_type_desc @;
	put ''', ' @;
	put l_no @;
	put ', ''' @;
	put level_desc @;
	put ''', ' @;
	put outcome_period @;
	put ', '@;
	if out_key ne . then
		put out_key@;
	else
		put "'.'"@;
	put ')">' @;
	put abt_nm @;
	put '</a></td>';
	put '<td class="tabletextcol">' @;
	put abt_desc@;
	put '</td>';
	put '<td class="tabletextcol">' @;
	put abt_table_nm@;
	put '</td>';
	put '<td class="tabletextcol">' @;
	put abt_purpose_desc@;
	put '</td>';
	put '<td class="tabletextcol">' @;
	put product_type_desc@;
	put '</td>';
	put '<td class="tabletextcol">' @;
	put level_desc@;
	put '</td>';
	put '<td class="tabletextcol">' @;
	put outcome_period@;
	put '</td>';
	put '<td class="tabletextcol">' @;
	put obs_dt@;
	put '</td>';
	put '<td class="tabletextcol">' @;
		 /*I18N-scnjih-20080430-1310*/
	/*if status = 'Building ABT' then do;*/
		if status =  "%sysfunc(sasmsg(smd_ds.bismsg,templates.sas.Month.13, noquote))" then do;	
		 /*I18N-scnjih-20080430-1310*/
		put '<img src="/SASABTFramework/images/MessageProcess.gif">'status @;
		put '<script language="JavaScript">';
		put 'javascript:disable_while_build();';
		put '</script>';
	end;
	else do;
		put status;
	end;
	put '</td>';
	put '<td class="tabletextcol">' @;
	if linked='linked' then do;
		put '<a href="javascript:linkedmodel('@;
		put a_no@;
		put ')">';
		put "<img src=""/SASABTFramework/images/BlueDot.gif"" border=""0""></a>"@;
	end;
	put '</td>';
	/* Check boxes used to select */	
	put '<td class="tabletextcol"><input type="checkbox" name="Sel" id="Sel" value="'@;
	put a_no@; 
	put '"'@;
	put '></td>';
	put '</tr>';
run;

data &out_lib..modyear;
/*I18N-scnhuh-20080429-1733*/
/*   do yr=2005 to 2007       -->     do yr=(year(date())-5) to (year(date())+5)*/
/*do yr=2005 to 2007;*/
do yr=(year(date())-5) to (year(date())+5);
output;
end;
run;
/*I18N-scnhuh-20080429-1733*/

data &out_lib..modmonth;
	 /*I18N-scnjih-20080421-1351*/
/*	chmon='JAN';*/
/*	output;*/
/*	chmon='FEB';*/
/*	output;*/
/*	chmon='MAR';*/
/*	output;*/
/*	chmon='APR';*/
/*	output;*/
/*	chmon='MAY';*/
/*	output;*/
/*	chmon='JUN';*/
/*	output;*/
/*	chmon='JUL';*/
/*	output;*/
/*	chmon='AUG';*/
/*	output;*/
/*	chmon='SEP';*/
/*	output;*/
/*	chmon='OCT';*/
/*	output;*/
/*	chmon='NOV';*/
/*	output;*/
/*	chmon='DEC';*/
/*	output;*/
	chmon= "%sysfunc(sasmsg(smd_ds.bismsg,templates.sas.Month.1, noquote))" ;
	output;
	chmon="%sysfunc(sasmsg(smd_ds.bismsg,templates.sas.Month.2, noquote))";
	output;
	chmon="%sysfunc(sasmsg(smd_ds.bismsg,templates.sas.Month.3, noquote))";
	output;
	chmon="%sysfunc(sasmsg(smd_ds.bismsg,templates.sas.Month.4, noquote))";
	output;
	chmon="%sysfunc(sasmsg(smd_ds.bismsg,templates.sas.Month.5, noquote))";
	output;
	chmon="%sysfunc(sasmsg(smd_ds.bismsg,templates.sas.Month.6, noquote))";
	output;
	chmon="%sysfunc(sasmsg(smd_ds.bismsg,templates.sas.Month.7, noquote))";
	output;
	chmon="%sysfunc(sasmsg(smd_ds.bismsg,templates.sas.Month.8, noquote))";
	output;
	chmon="%sysfunc(sasmsg(smd_ds.bismsg,templates.sas.Month.9, noquote))";
	output;
	chmon="%sysfunc(sasmsg(smd_ds.bismsg,templates.sas.Month.10, noquote))";
	output;
	chmon="%sysfunc(sasmsg(smd_ds.bismsg,templates.sas.Month.11, noquote))";
	output;
	chmon="%sysfunc(sasmsg(smd_ds.bismsg,templates.sas.Month.12, noquote))";
	output;
	 /*I18N-scnjih-20080421-1351*/
run;


/* Finish up. */
data _null_;
file _webout &webout_options;
    put '                </table>';
    put '              </div>';
	put '            </div>';
    put '          </td>';
    put '      </tr>';
	put '    </table>';
	put '    <!--Big table ends here-->';
	
	put '<table id="data_capture_prd" border="0">';
	put '<tr>';
	put '<td>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.templates_data_capture_period.1, noquote))"@;
	put '</td>';
	put '<td><Select name="year">'; 
	put '<option>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.year.1, noquote))"@;
	put '</option>';
run;

data _null_;
file _webout &webout_options;
set &out_lib..modyear;
	put '<option>' @ ;
	put yr @;
	put '</option>' @ ;
run;

data _null_;
file _webout &webout_options;
	put '</Select>';
	put '</td>';
	put '<td><Select name="month_no">'; 
	put '<option>' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.month.1, noquote))"@;
	put '</option>';
run;

data _null_;
file _webout &webout_options;
set &out_lib..modmonth;
	put '<option value="' @ ;
	put _N_ @ ;
	put '">' @ ;
	put chmon;
	put '</option>';
run;
data _null_;
file _webout &webout_options;
	put '</Select>';
	put '</td>';
	put '</tr>';
	put '<tr>'; 
	put '<td><input type="button" name="bldmdlabt" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.buildbttn.1, noquote))"@;
	put '" onclick="Startbuild();"></td>';
	put '<td><input type="button" name="cancelabt" value="' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.cancelbttn.1, noquote))"@;
	put '" onclick="Cancelmdlabt();"></td>';
	put '</tr>';
	put '</table>';	
	put '  <div id="foot">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.copyright_notice.1, noquote))"@;
	put '  </div>';
	put '  </body>';
	put '        </form>';
	put '  <!-- InstanceEnd -->';
	put '</html>';
run;
