/***********************************************************************************************
       Module:  correlation_ccf (Correlation Analysis)

     Function:  This stored process generates the HTML report displaying the 
				correlation analysis statistic and correlation graph for the 
				MODEL TYPE (PD Approvals, PD Ongoing, LGD, CCF), PRODUCT TYPE (Credit Card,
				Mortgage, Loan, Core etc.),TIME and MODEL (CCF MODEL 1) selected in the calling 
				stored process (test_levels).
				If the filter is set to NO the modeling value and the correlation overtime graph
				is displayed.
				By default the filter is set to NO.

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	Stored Process test_levels
				
        Calls:  Calls the following Stored Process    
					1.Reporting		 	(when Reporting link is clicked)
					2.mon_models     	(when Monitoring Models link is clicked)
					3.select_models     (when Select Models link is clicked) 
					4.test_levels    	(when Select Statistic link is clicked)
					5.correlation_ccf	(when the reset button is clicked)
					6.filtering_criteria(when the Filter/Re-Pool button is clicked)

				Calls the following Macros
					1. graph_options macro sets all the graph options and selects the colors
						to be used when rendering the graph.
					2. generate_feed macro for obtaining the required feed.
					3. feed_measure macro for generating the dataset containing the
						statistic values over time.
					4. Corr macro computes correlation between Estimated and Actual CCF.
					5. model_traffic macro for generating the traffic lighting for the
						given measure.
					6. statistic_overtime macro to generate the overtime graph.

Datasets used:  No input datasets required for processing of the stored process
 
        Logic:  1. All inputs to the stored process are accepted as global parameters. 
				2. Standards
					a. 	Naming of data set which are input to and output from macro using
							<prod_type_code><sel_model_key><time_key> Extension as per requirement  
						i.e.		COR           106          1030     pool
							as COR1061030pool.
					b. Setting the default values for statistic, filter, where_measure and
						where_feed. where_feed is passed as parameter(infilter) to the
						generating feed macro, and where_measure is passed as parameter
						to the feed_measure macro.
					c.	Naming the graphs using timestamp and two letters for identifying 
						the graph.
				3. Set all the graph options and select the colors to be used when rendering
					the graph.
				4. Call the macro generate_feed for obtaining the required feed.
				5. Check whether the generate_feed macro generated any error.
					If any error is generated then the same report(correlation_ccf) is called
					with the default criteria.
				6. If there no data, in the case of business filter or dynamic pooling,
					is generated by the generate_feed macro then the same report(correlation_ccf)
					is called with the default criteria.
				7. Call the feed_measure macro for generating the dataset containing the
					statistic values over time.
				8. Call Corr Macro for computing correlation between Estimated and Actual CCF.
				9. Call the model_traffic macro for generating the traffic lighting
					for the given measure.
			   10. Call the statistic_overtime macro to generate the overtime graph.
			   11. Get the pooling technique.
			   12. Generate the HTML using streaming webout.
					a. Provide hidden textboxes for all output parameters so that the values 
						are easily submitted to the next page. 
					b. Provide javascript functions for the links on top of the page
						and for edit and reset buttons.
					c. The modeling value and overtime graph are displayed only if the
						filter is set to NO. When the user clicks the edit button and makes
						some changes in the filter condition then the filter is set to YES,
						and the modeling value and overtime graph is not displayed.
				
   Parameters:
			INPUT 
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD Ongoing,
										LGD, CCF)
		        include_exp_mdl		:   Information to include the expired models for selection of
										model from the traffic light dashboard.
				statistic           :   The default statistic is Correlation Analysis.
				model1				:	The first model if selected (Eg. CCF MODEL 1).		
				model1_key			:	The surrogate key for the first selected model.
				model2				:	The  second model if  selected. (Eg. CCF MODEL 2)
				model2_key			:	The surrogate key for the second selected model.
				sel_model			: 	Model selected on the Measure level dashboard screen.
				sel_model_key		:	Key of the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				filter				:	Used for displaying or hiding the modeling values and
										overtime graph.
				filter_clause		: 	Contains the selected business filter.
		        pd_score 			:	If null then shown as DEFAULT status.
		 	    no_of_quantile      :	The range for dynamic pooling will be decided based on the 
								 	    quantile.Quantile ranges will be calculated based on the 
								 	    SCORE/PD/LGD/CCF of the scoring  population for the
										selected score period  
		  		range_interval      : 	Dynamic pooling based on the range specified.
										E.g. 100, 200 for SCORE and .2, .3 for PD.
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.
				
			OUTPUT
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD Ongoing,
										LGD, CCF)
		        include_exp_mdl		:   Information to include the expired models for selection of
										model from the traffic light dashboard.
				statistic           :   The default statistic is Correlation Analysis.
				model1				:	The first model if selected (Eg. CCF MODEL 1).		
				model1_key			:	The surrogate key for the first selected model.
				model2				:	The  second model if  selected. (Eg. CCF MODEL 2)
				model2_key			:	The surrogate key for the second selected model.
				sel_model			: 	Model selected on the Measure level dashboard screen.
				sel_model_key		:	Key of the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				filter				:	Used for displaying or hiding the modeling values and
										overtime graph.
				filter_clause		: 	Contains the selected business filter.
		        pd_score 			:	If null then shown as DEFAULT status.
		 	    no_of_quantile      :	The range for dynamic pooling will be decided based on the 
								 	    quantile.Quantile ranges will be calculated based on the 
								 	    SCORE/PD/LGD/CCF of the scoring  population for the
										selected score period  
		  		range_interval      : 	Dynamic pooling based on the range specified.
										E.g. 100, 200 for SCORE and .2, .3 for PD.
				called_program		:	Passes the path of the current program(correlation_ccf)
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.

***********************************************************************************************/
goptions reset=all;
options nomprint;

/* Global input parameters that are passed from the calling program*/
%global prod_type_desc prod_type_code model_type_desc model_type_code include_exp_mdl
		model1 model1_key model2 model2_key period time_key filter filter_clause
		statistic pd_score range_interval no_of_quantile prg_name outcome_period elapsed_time
		sel_model sel_model_key format_name;


/* Trimming extra spaces from all the input parameters*/
    %let prod_type_desc=&prod_type_desc;
    %let prod_type_code=&prod_type_code;
    %let model_type_desc=&model_type_desc;
    %let model_type_code=&model_type_code;
    %let model1=&model1;
    %let model1_key=&model1_key;
    %let sel_model=&sel_model;
    %let sel_model_key=&sel_model_key;
    %let period=&period;
    %let time_key=&time_key;
    %let filter_clause=&filter_clause;
    %let pd_score=&pd_score;
    %let prg_name=&prg_name;
    %let outcome_period=&outcome_period;
    %let elapsed_time=&elapsed_time;

/*************/
	%let statistic=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&statistic))))));
/*This macro outputs the format for the stattistics for combination of 
  product type code and the model type code.*/
%format_for_model_product(model_type_code_fm=&model_type_code,prod_type_code_fm=&prod_type_code)
/*This macro chnage the dataset name and hardcode it on the product type*/
%change_dataset_name
/*Assigning standard names for datasets which are input to and ouput from macro using
		<prod_type_code><sel_model_key><time_key> Extension as per requrment  
	i.e.		COR           106          1030     pool
		as COR1061030pool.*/

/* Standard names for datasets that are passed to generate_feed macro*/
%let out_lib=;
%debug_lib_path;
 
%let out_pool=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.cr_pccf))));
%let out_account=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.cr_accf))));
/*************/

/* Standard names for datasets that are passed to feed_measure macro*/
%let in_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.measure_in))));
%let out_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.measure_out))));
/**************/

/* Standard names for datasets that are passed to Corr macro */
%let out_stat_ds=%sysfunc(ktrim(%sysfunc(kleft(&out_lib..&prod_type_code.&sel_model_key.&time_key.corel))));
/*************/

/* Setting values for statistic, filter and where_clauses*/
%let where_feed=;
%let where_measure=;

data _NULL_;

/* Setting the default value for statistic*/
	if ktrim(kleft("&statistic"))="" then
		call symput('statistic',"%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_correlation_analysis.1, noquote))");

/* Setting value for filter depending on whether the filter_clause and pd_score has any
	value set.
		The filter_clause and pd_score value is getting passed from the Filter Screen
		(stored process FilteringCriteria)
		If the filter is NO then the modeling value and the statistic overtime graph
		is displayed else it is not displayed */	
	if ktrim(kleft("&filter_clause"))="" and ktrim(kleft("&pd_score"))="" then
		call symput('filter','NO');
	else
		call symput('filter','YES');

/* Setting the where clause for the feed_measure macro*/
	call symput('where_measure','where ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD="&prod_type_code" and ANALYTICAL_MODEL_DIM.MODEL_SK=&sel_model_key');

/* Setting the where clause for the generate_feed macro depending upon the value of the
		filter_clause*/
	if ktrim(kleft("&filter_clause"))="" then
		call symput('where_feed','where 1');
	else
		call symput('where_feed','where &filter_clause');

run;

/* Assigning standard name for the gifs using timestamp and two characters
	for identifying the graph*/
%let name=;
%let ot_nm=;
data _NULL_;
	name=put(time(),mmss8.1);
	name1=kscan(name,1,":.");
	name2=kscan(name,2,":.");
	name3=kscan(name,3,":.");
	name4="cf"||ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
	name5="ct"||ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
	call symput('name',name4);
	call symput('otnm',name5);
run;

%let graph_name=%sysfunc(ktrim(%sysfunc(kleft(&name))));
%let ot_name=%sysfunc(ktrim(%sysfunc(kleft(&otnm))));
/****************/

/* The graph_options macro sets all the graph options and selects the colors to be used when
	rendering the graph. To access the colors being set in this macro, the respective macro
	variables for the color, color_symbol1, is created.
	This macro only sets the values in the macro variables.

	This macro sets the out path of the gifs to the folder created in the environment which
	will be shared between the server layer and web layer. This is picked up from the macro
	variable CS_REPORT_PATH in the bis_customize_para.sas. */

%let color_symbol1=;
%graph_options;
/**********/

/* Start HTML Screen*/
data _NULL_;
/*I18N-scnhuh-20080418-1540*/
/*add &webout_options*/
	file _webout&webout_options;
/*I18N-scnhuh-20080418-1540*/
	rep="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_correlation_analysis.1, noquote))";
	format rep &format_name..;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" '@;
	put '"http://www.w3.org/TR/html4/loose.dtd"> ';
	put '<html> ';
	put '<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'@;
	put rep @;
	put '</title>';
	put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<style type="text/css"> ';
	put '<!-- ';
	put '.style2 {font-size: small} ';
	put '--> ';
	put '</style> ';

	put '<script>';
	put '<!--';

/* Calls the Reporting stored process if link is clicked */
	put 'function Link1() {';
		put "form1._program.value=&CS_REPORTING";
		put 'form1.submit()';
	put '}';

/* Calls the mon_models stored process if link is clicked */
	put 'function Link2() {';
		put "form1._program.value=&CS_MON_MDL";
		put 'form1.submit()';
	put '}';

/* Calls the select_models stored process if link is clicked */
	put 'function Link3() {';
		put "form1._program.value=&CS_MDL_LVL_DB";
		put 'form1.submit()';
	put '}';

/* Calls the test_levels stored process if link is clicked */
	put 'function Link4() {';
		put "form1._program.value=&CS_MSR_LVL_DB";
		put 'form1.submit()';
	put '}';

/*********************/

/* Calls the filtering_criteria stored process(Filter Screen)
		(this changes the filter_clause and hence the where_feed and filter criteria)*/
	put 'function EditPage() {';
		put 'form1.filter_clause.value=""';
		put "form1._program.value=&CS_FLTR_SCRN";
		put 'form1.submit()';
	put '}';
/*********************/

/* Calls this stored process again after reseting the value of filter_clause to null */
	put 'function ResetPage() {';
		put 'form1.filter_clause.value=""';
		put 'form1.pd_score.value=""';
		put 'form1.range_interval.value=""';
		put 'form1.no_of_quantile.value=""';
		put 'form1.filter.value="NO"';
		put 'form1._program.value="'@;
		put "&prg_name"@;
		put '";';
		put 'form1.submit()';
	put '}';
/*********************/

	/*Function savepage() for saving the page to disk */
	%savepage;
	/*********savepage() ends here*************/

	/*Function printpage() for printing the page to a printer or to a pdf file*/
	%printpage;
	/*********printpage() ends here*************/

	put '//-->';
	put '</script>';

	put '</head> ';
	put '<body>';
	put '<form name="form1" method="post" action="/SASStoredProcess/do">';

/* Hidden textboxes to hold the values for the program name and the output paremeters 
	to pass the values to the next Stored Process called */
	put '<input type="hidden" name="_program" VALUE="';
	put "&prg_name";
	put '">';
	prod_type_desc=symget("prod_type_desc");
	put '<input type="hidden" name="prod_type_desc" value="' @;
	put prod_type_desc;
	put '">';
	prod_type_code=symget("prod_type_code");
	put '<input type="hidden" name="prod_type_code" value="' @;
	put prod_type_code;
	put '">';
	model_type_desc=symget("model_type_desc");
	put '<input type="hidden" name="model_type_desc" value="' @;
	put model_type_desc;
	put '">';
	model_type_code=symget("model_type_code");
	put '<input type="hidden" name="model_type_code" value="' @;
	put model_type_code;
	put '">';
	include_exp_mdl=symget("include_exp_mdl");
	put '<input type="hidden" name="include_exp_mdl" value="' @;
	put include_exp_mdl;
	put '">';
	model1=symget("model1");
	put '<input type="hidden" name="model1" value="' @;
	put model1;
	put '">';
	model1_key=symget("model1_key");
	put '<input type="hidden" name="model1_key" value="' @;
	put model1_key;
	put '">';
	model2=symget("model2");
	put '<input type="hidden" name="model2" value="' @;
	put model2;
	put '">';
	model2_key=symget("model2_key");
	put '<input type="hidden" name="model2_key" value="' @;
	put model2_key;
	put '">';
	sel_model=symget("sel_model");
	put '<input type="hidden" name="sel_model" value="' @;
	put sel_model @;
	put '">';
	sel_model_key=symget("sel_model_key");
	put '<input type="hidden" name="sel_model_key" value="' @;
	put sel_model_key @;
	put '">';
	period=symget("period");
	put '<input type="hidden" name="period" value="' @;
	put period;
	put '">';
	time_key=symget("time_key");
	put '<input type="hidden" name="time_key" value="' @;
	put time_key;
	put '">';
	statistic=symget("statistic");
	put '<input type="hidden" name="statistic" value="' @;
	put statistic;
	put '">';
	filter=symget("filter");
	put '<input type="hidden" name="filter" value="' @;
	put filter;
	put '">';
	filter_clause=symget("filter_clause");
	put '<input type="hidden" name="filter_clause" value="' @;
	put filter_clause;
	put '">';
	pd_score=symget("pd_score");
	put '<input type="hidden" name="pd_score" value="' @;
	put pd_score;
	put '">';
	range_interval=symget("range_interval");
	put '<input type="hidden" name="range_interval" value="' @;
	put range_interval;
	put '">';
	no_of_quantile=symget("no_of_quantile");
	put '<input type="hidden" name="no_of_quantile" value="' @;
	put no_of_quantile;
	put '">';
	prg_name=symget("prg_name");
	put '<input type="hidden" name="prg_name" value="' @;
	put prg_name;
	put '">';
	outcome_period=symget("outcome_period");
	put '<input type="hidden" name="outcome_period" value="' @;
	put outcome_period;
	put '">'; 
	elapsed_time=symget("elapsed_time");
	put '<input type="hidden" name="elapsed_time" value="' @;
	put elapsed_time;
	put '">';
	put '<input type="hidden" name="called_program" value="';
	put "&prg_name";
	put '">';
run;

/*Calls the macro generate_feed for obtaining the required feed by passing
	the following parameters
	1. in_filter		: Where clause (on the basis of the filter clause)
	2. out_lib_nm		: Library name where the output feed will be created. 
	3. out_table_nm_pool: The table name for pool level feed
	4. out_table_nm_acct: The table name for account/application level feed
	5. feed_for			: Possible values are PD, LGD, CCF, APPLPD, APPLLGD. This macro parameter
							decides whether estimated pd/lgd/ccf has to calculated at account 
							level or application level 
	6. pd_score			: Possible values are (Empty), PD, SCORE
          a. (empty)	: The default pooling technique will be used
          b. PD			: If PD then dynamic pooling technique will be used, 
              			  based on PD/LGD/CCF as mentioned in the previous parameter(feed_for) 
          c. SCORE		: If SCORE then dynamic pooling technique will be used,
              				based on SCORE_POINTS. Applicable only if PD or APPLPD value
              				is set in the previous variable (feed_for)
	7. range_interval	: Dynamic pooling based on the range specified. E.g. 100, 200 for
	              			SCORE and .2, .3 for PD. Similar ranges for LGD/CCF
	8. no_of_quantile	: The range for dynamic pooling will be decided based on the quantile.
							Quantile ranges will be calculated based on the SCORE/PD/LGD/CCF 
							of the scoring population for the selected score period
	9. long_run			: Possible values Y/N. Whether the long run calculation is to be
							used to find estimated pd/lgd/ccf
	10. long_run_type	: Possible values are MAX/AVG. Method for calculating the long run
							pd/lgd/ccf  
	11. model_time_key  : Contains the concatenated values of model and time in the
							format _<model_sk>_<time_sk>. This is used to identify
							which fact table should be considered while generating 
							the feed.
*/

%global error_code;
%let error_code=NONE;
%let model_time=_%sysfunc(ktrim(%sysfunc(kleft(&sel_model_key.))))_%sysfunc(ktrim(%sysfunc(kleft(&time_key.))));
%generate_feed(in_filter=&where_feed, out_lib_nm=&out_lib., out_table_nm_pool=&out_pool,
			out_table_nm_acct=&out_account, feed_for=&FEED_FOR_CCF,
			long_run=&LONG_RUN, pd_score=&pd_score, range_interval=&range_interval, 
			no_of_quantile=&no_of_quantile, long_run_type=&LONG_RUN_TYPE,
			model_time_key=&model_time);

/* Checks whether the generate_feed macro generated any error, in the case of business filter
		or dynamic pooling.
	If any error is generated then the ResetPage function defined above is called*/
data _NULL_;
/*I18N-scnhuh-20080418-1540*/
/*add &webout_options*/
	file _webout&webout_options;
/*I18N-scnhuh-20080418-1540*/
	if ktrim(kleft("&error_code")) ne "NONE" and (ktrim(kleft("&filter_clause")) ne "" or ktrim(kleft("&pd_score")) ne "") then do;
		put '<script>';
		put '<!--';
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.alert_error_selec_filter_criteria.1, noquote))"@;
		put '")';
		put 'ResetPage()';
		put '//-->';
		put '</script>';
	end;
run;

/* Checks whether the dataset created in the generate_feed macro, in the case of business
	filter or dynamic pooling has any observations and sets cnt to the number of observations
	in the dataset*/
%let cnt=.;
proc sql noprint;
	select Count(*) into :cnt from &out_lib..&out_pool.;
quit;

/* If there is no observation in the above dataset i.e. cnt=0 then the ResetPage function
	defined above is called */
%let log_name=;
data _NULL_;
/*I18N-scnhuh-20080418-1540*/
/*add &webout_options*/
	file _webout&webout_options;
/*I18N-scnhuh-20080418-1540*/
	if &cnt eq 0 and (trim(left("&filter_clause")) ne "" or trim(left("&pd_score")) ne "") then do;
		put '<script>';
		put '<!--';
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.alert_error_no_data_available.1, noquote))"@;
		put '")';
		put 'ResetPage()';
		put '//-->';
		put '</script>';
	end;
	call symput('log_name',"&CS_DEBUG_PATH./&out_pool."||".log");
run;

%debug_log_file(log_file_nm=&log_name);

%let name_html=;
/* Generates the dataset with measure names for the given model_type_code and the called
	program name(the current stored process correlation_ccf)
	from the measure_dim dataset to be passed as a parameter to the feed_measure macro*/
proc sql noprint;
	create table &out_lib..&in_stat_ot as
	select measure_nm, help_file_nm 
	from dim.measure_dim
	where kupcase(program_nm)=kupcase("&prg_name")
		and kupcase(model_type_cd)=kupcase("&model_type_code");
/*	order by measure_nm;*/
quit;

data _null_;
	set &out_lib..&in_stat_ot;
	call symput('name_html',help_file_nm);
run;

/* Calls the feed_measure macro for generating the dataset containing the statistic values
	over time. The following parameter is passed to this macro:
		1. in_filter			: where clause 
		2. out_lib_nm			: library name from where the input dataset is picked from
								  and where the ouput dataset is stored
		3. in_table_nm			: the input dataset to be passed
		4. out_table_nm_measure	: the output dataset created in the macro*/
%feed_measure(in_filter=&where_measure, out_lib_nm=&out_lib., in_table_nm=&in_stat_ot,
			out_table_nm_measure=&out_stat_ot);

/* Calls Corr Macro for computing correlation between Estimated and Actual CCF.*/
%corr(input_ds=&out_lib..&out_pool.,input_ds_estvar=Estimated_CCF,input_ds_actvar=Actual_CCF,
		output_ds=&out_stat_ds.);

data work.anno; 
	set &out_lib..&out_pool. ;
	retain xsys '1' ysys '1';
	color='black'; line=1; size=1.8;
	function='move'; x=0 ; y=0; output;
	function='draw'; x=100; y=100; output;
run;

/*symbol1 color=&color_symbol1 width=.15 height=2 value=dot;*/

footnote "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.graph_footnote_legend.1, noquote))"
	c=&color_symbol1 "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.graph_footnote_number_of_acct.1, noquote))"; 

/* Code for plotting the graph for correlation */
proc gplot data=&out_lib..&out_pool.;
	axis1 order=0 to 1 by 0.1 label=(a=90 "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.graph_axis1_estimeted_ccf.1, noquote))");
	axis2 order=0 to 1 by 0.1 label=("%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.graph_axis1_realized_ccf.1, noquote))");
	Bubble Estimated_CCF*Actual_CCF=NO_OF_ACC_ACTUAL
		/bcolor=&color_symbol1 haxis=axis2 vaxis=axis1 annotate=work.anno name="&graph_name";
run;
quit;

/* Code to get the Modeling value for statistic*/
%let MDL_MEASURE_VALUE=;
proc sql noprint;
	select Measure_value format = &CS_DEC_FMT. into :MDL_MEASURE_VALUE
	from &out_lib..&out_stat_ot
	where kupcase(dev_flg)="%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.dev_flag_y.1, noquote))";
quit;

/* Code to get the Actual value for statistic*/
%let MEASURE_VALUE=;
proc sql noprint;
	select Measure_value format = &CS_DEC_FMT. into :MEASURE_VALUE
	from &out_stat_ds;
quit;

/* Calls the model_traffic macro to get the traffic lighting for the given value and measure
	The following parameters are passed to this macro
			1. model_cd	: MODEL TYPE (PD Approvals, PD Ongoing, LGD, CCF)
			2. value	: This is the measure_value for the given statistic
			3. ms_name	: This is the measure name(statistic) for which traffic lighting
							is to be done
	This macro returns the color (traffic lighting) which is collected in the macro variable 
	color depending on the bounds(for red and green) provided in the measure_dim dataset*/

%let color=;
%model_traffic(model_cd=&model_type_code,value=&measure_value,ms_name=&statistic, product_type_code=&prod_type_code);
%let color=&color;
/*	Calls statistic_overtime to get the overtime graph.
	The following parameters are passed to this macro
			1. ds		: Input dataset with the data for the	selected measure.
            2. statistic: Name of the measure for which the graph is being generated.
            3. name		: Name to be given to the gif when the graph is generated.*/
%statistic_overtime(&out_lib..&out_stat_ot,&statistic,&ot_name);


/* Macro for getting the Pooling Technique.
	In this macro the following indicates:
			1.pd_score 			: If null then shown  as DEFAULT stautus.
			2.time_key        	: The surrogate key for selected period.
            3.sel_model_key        : The surrogate key for the selected model.
 			4.no_of_quantile    : The range for dynamic pooling will be decided based on
								  the quantile.Quantile ranges will be calculated based
								  on the SCORE/PD/LGD/CCF of the scoring  population
								  for the selected score period.
		    5.range_interval    : Dynamic pooling based on the range specified.
			  						E.g. 100, 200 for SCORE and .2, .3 for PD.	*/
%let pool_tech=;
%let time_period=;
%pool_technique;

%debug_log_web;

/* HTML Screen */
%let view_feed=&out_pool..html;
data _NULL_;
/*I18N-scnhuh-20080418-1540*/
/*add &webout_options*/
	file _webout&webout_options;	
/*I18N-scnhuh-20080418-1540*/
	name_html=symget("name_html");
	rep="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_correlation_analysis.1, noquote))";
	format rep &format_name..;
	put'<script>';
		/**************Help File *********************/
	%helpfile(filename=&name_html);

		/*************feed Table*********************/
	put 'function feed_table(){';
		put'window.open("/SASCSReports/'@; 
		put "&view_feed"@; 
	put '")};';

		/*********************************************/
	put'</script>';

	put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';
	put '<tr> ';
	put '<td align="left"> ';
	put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0"> ';
	put '<tr> ';
	put '<td>';
	put '<table width="100%"  border="0" cellspacing="0" cellpadding="0">';

/* Links on Top of the HTML Page */
  	put '<tr>';
    put '<td><span class="BreadCrumb">';
	put '<a href="javascript:Link1()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.link_reporting.1, noquote))"@;
	put '</a> &gt; '@;
	put '<a href="javascript:Link2()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.link_monitoring_model.1, noquote))"@;
	put '</a> &gt; '@;
	put '<a href="javascript:Link3()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.link_sel_model.1, noquote))"@;
	put '</a> &gt; '@;
	put '<a href="javascript:Link4()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.link_sel_stats.1, noquote))"@;
	put '</a> &gt; '@;
	put '</span><span class="BreadCrumb">'@;
	put rep @;
	put '</span></td>';
/*********/

/* SAS Banner */
    put '<td width="215"><div align="right">'@;
	put '<img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td>';
/**********/

	put '</tr> ';
	put '</table>';
	put '<H2 align="left"><table width="100%"  border="0" cellspacing="0" cellpadding="0"><tr><td>';
	put rep @;
	put '</td>';
	if kupcase(&print) eq 'Y' then do;
		put '<td width=65><div align="center"><span class="LabelFont">';
		put '<a href="javascript:printpage()">';
		put '<img src="/SASCSReports/images/Print.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_print.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&save) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:enregistre()">';
		put '<img src="/SASCSReports/images/SaveFile.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_save.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&help) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:Info()">';
		put '<img src="/SASCSReports/images/Info.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_help.1, noquote))"@;
		put '</div></td>';
	end;
	put '</tr></table></H2>';
	put '</td></tr>';

/* Values of Product_type Period and Model */
	put '<tr> ';
	put '<td align="left"> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.label_model_type.1, noquote))"@;
	put "&model_type_desc"@;
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.label_product_type.1, noquote))"@;
	put "&prod_type_desc"@;
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.label_period.1, noquote))"@;
/*I18N-scnhuh-20080427-1455*/	
/* del one line, add two lines. For displaying in NLS format */	
/*	put "&period" @;*/
		Period_WEBUI=put(input("&period",&CS_TIME_PER_FMT.),&NLDATE_FMT.);
		put Period_WEBUI @;
/*I18N-scnhuh-20080427-1455*/		
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.label_model.1, noquote))"@;
	put "&sel_model"@;
	put '</p>';

/* Pooling Technique */
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.label_pooling_tech.1, noquote))"@;
	put "&pool_tech";
	put '</p>';

/* Target period and elapsed time*/
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.label_outcome_period.1, noquote))"@;
	put "&outcome_period" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.label_months.1, noquote))"@;
	put "&elapsed_time" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.label_month_elapsed.1, noquote))"@;
	put '</p>';

/* Actual value for the statistic with the traffic lighting */
	put '<table  border="0" cellspacing="0" cellpadding="0">';
	put '<tr><td><span class="LabelFont">';
	put rep ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.stats_act_value.1, noquote))"@;
	put "&measure_value"; 
	put '</span></td><td>&nbsp;</td> ';

	put'<td width="25"><div align="center"><span class="LabelFont">'@;
	put '<img src="/SASCSReports/images/' @;
	if "&color"="%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.color_white.1, noquote))" then do;
		put 'spacer.gif"';
	end;
	else do;
		put 'Sphere'@;
		put "&color";
		put '.gif"';
	end;
	put 'width="16" height="16" border="0"></a> </span></div></td>';
	put '<td width="50"><span class="LabelFont"></span></td>';

/* Modeling value for the given statistic.
	This will get displayed only if the filter is set to NO*/
	if upcase("&filter") eq "NO" then do;
		put '<td><span class="LabelFont">';
		put rep ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.stats_mod_value.1, noquote))"@;
		if symexist("MDL_MEASURE_VALUE") eq 0 then 
			put '.' @;
		else 
			put "&MDL_MEASURE_VALUE" @;
		put '</span></td> ';
	end;	
/**************/

    put '</tr></table> ';

	put '<tr>';
	put '<td align="left">';
    put ' <p>';
	put '<H2 align="left">'@;
	put rep @;
	put '</H2></td></tr>';

	put	'<tr><td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
    put '<tr>';
    put '<td width="49%" valign="top"><fieldset>';
    put '<legend><span class="style2">'@;
	put rep @;
	put '</span></legend>';

/* Graph for correlation */
	put '<p><img src="/SASCSReports/'@;
	put "&graph_name";
	put '.gif" width="460" height="200"></p>';
/*******/

	put '</fieldset></td>';
	put '<td width="2%">&nbsp;</td>';

/* Code for displaying overtime graph.
	This will get displayed only if filter is set to NO */
	if upcase("&filter") eq "NO" then do;
        put '<td width="49%" valign="top"><fieldset>';
        put '<legend><span class="style2">';
		put rep  @;
/*		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.stats_over_time.1, noquote))"@;*/
		put '</span></legend>';
	    put '<p><img src="/SASCSReports/'@;
		put "&ot_name";
		put '.gif" width="460" height="200"></p>';
	    put '</fieldset></td>';
	end;
	else do;
		put '<td width="49%" valign="top">';
		put '</td>';
	end;
    put '</tr></table>';

	put '<p>&nbsp;</p></td>';
	put '</tr>';
	put '</table>';
	put '</td></tr>';
	put '<tr>';
    put '<td height="32" bgcolor="#F1EACB">&nbsp;&nbsp;';

/* Filter/Re-Pool and Reset button will get displayed only if the pooling technique
	 is not of clustering type*/
	val=PRXMATCH(kupcase('/cluster/'),kupcase("&pool_tech"));
	if val = 0 then do;
	    put '<INPUT type=button class=mmhide_btn onClick="EditPage()" value="'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.button_filter_repool.1, noquote))"@;
		put '">';
	    put '<INPUT type=button class=mmhide_btn onClick="ResetPage()" value="'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.button_reset.1, noquote))"@;
		put '">';
	end;
	put '<INPUT type=button class=mmhide_btn onClick="feed_table()" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.correlation_lgd.button_view_feed.1, noquote))"@;
	put '">';
   	put '</td></tr>';
	put '</table></form></body></html>';
run;

/******macro feed_table pass parameter  separated by #

		Input parameter 
		1.dt_st =Pass dataset name in string separated by #
		2.dt_nm=pass name u want to give to the table
		3.out_libout library  which is defined above
		        *****************************************************************/

	 /*I18N-scnjih-20080421-1517*/
/*%let dt_nm=Pool Feed;*/
%let dt_nm=%sysfunc(sasmsg(smd_ds.bismsg,Call_feed_table.sas.dt_nm.1, noquote));
	 /*I18N-scnjih-20080421-1517*/
%let dt_st=&out_pool.;
%feed_table(ds=&dt_st,out_lib1=&out_lib,data_name=&dt_nm,name_html=&view_feed);

goptions reset=all;
options nomprint;
