/******************************************************************************************************
       Module:  filtering_criteria

     Function:  This stored process creates the HTML screen which is used to capture the 
				filtering criteria which user may want to provide, say some condition on
				the datasets which are being used in the generate_feed macro, or change
				the range interval or no of quantiles. These filters are then applied to
				the report screen which called the filter screen when 'SUBMIT' button is
				clicked.
				If 'CANCEL' button is clicked then the filters are resetted and the report
				screen comes up with default criteria.

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All Report screen (when the Filter/Repool button is clicked)
        Calls:  The report screen which called this screen.

Datasets used:  No input datasets required for processing of the stored process
 
        Logic:  1. All inputs to the stored process are accepted as global parameters. 
			    2. Access the Star Schema to get all the columns from data_dictionary
					dataset in control library.
				3. Proper validations such as:
					-If either PD/LGD/CCF or SCORE radio button is clicked then the
						values entered in the textbox for range interval and no of quantiles
						should not be less than 0 and should be a number.
						No of qantiles should be between 3 & 100.
				
   Parameters:  INPUT
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
                prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
                model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
                model_type_desc   	:   Analytical Model Type Desc (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
                include_exp_mdl		:   Information to include the expired models for 
										selection of model from the traffic light dashboard.
				statistic           :   Measure name(e.g., Accuracy, Precision, Error Rate,
										Specificity, Sensitivity)
				model1				:	The selected model (Eg. PD MODEL 1).		
				model1_key			:	The surrogate key for the selected model.
				model2				:	The  second model if  selected. (Eg. PD MODEL 2)
				model2_key			:	The surrogate key for the second selected model.
				sel_model			: 	Model selected on the Measure level dashboard screen.
				sel_model_key		:	Key of the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				filter				:	Used for displaying or hiding the modeling values and
										overtime graph.
				filter_clause		: 	Contains the selected business filter.
		        pd_score 			:	If null then shown as DEFAULT status.
		 	    no_of_quantile      :	The range for dynamic pooling will be decided based on the 
								 	    quantile.Quantile ranges will be calculated based on the 
								 	    SCORE/PD/LGD/CCF of the scoring  population for the
										selected score period  
		  		range_interval      : 	Dynamic pooling based on the range specified.
										E.g. 100, 200 for SCORE and .2, .3 for PD.
				called_program		:	Passes the path of the current program(conf_matrix)
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.
				
				OUTPUT
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
                prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
                model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
                model_type_desc   	:   Analytical Model Type Desc (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
                include_exp_mdl		:   Information to include the expired models for 
										selection of model from the traffic light dashboard.
				statistic           :   Measure name(e.g., Accuracy, Precision, Error Rate,
										Specificity, Sensitivity)
				model1				:	The selected model (Eg. PD MODEL 1).		
				model1_key			:	The surrogate key for the selected model.
				model2				:	The  second model if  selected. (Eg. PD MODEL 2)
				model2_key			:	The surrogate key for the second selected model.
				sel_model			: 	Model selected on the Measure level dashboard screen.
				sel_model_key		:	Key of the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				filter				:	Used for displaying or hiding the modeling values and
										overtime graph.
				filter_clause		: 	Contains the selected business filter.
		        pd_score 			:	If null then shown as DEFAULT status.
		 	    no_of_quantile      :	The range for dynamic pooling will be decided based on the 
								 	    quantile.Quantile ranges will be calculated based on the 
								 	    SCORE/PD/LGD/CCF of the scoring  population for the
										selected score period  
		  		range_interval      : 	Dynamic pooling based on the range specified.
										E.g. 100, 200 for SCORE and .2, .3 for PD.
				called_program		:	Passes the path of the current program(conf_matrix)
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.

******************************************************************************************************/
/*This code is Internationalized*/
/*Variables coming from the calling page */
%global prod_type_desc prod_type_code model_type_desc model_type_code include_exp_mdl 
		model1 model1_key model2 model2_key period time_key filter filter_clause
		statistic prg_name outcome_period elapsed_time sel_model sel_model_key
		pd_score range_interval no_of_quantile called_program;
/*End*/

/*Dont touch these variables */
%global dim_table;
%global dim_variable;
%let table_count=0;
%let column_count=0;
%let in_filter = ;
/*End */

%let model_type_code=%sysfunc(ktrim(%sysfunc(kleft(&model_type_code))));

/*This view on control.data_dictionary gives the list of distinct dimension tables, for being
displayed in the combo box */
proc sql;
create view work.tables
as select distinct table_name from control.data_dictionary
order by table_name;
select count(table_name) into :table_count from
work.tables;
quit;
%macro all_scripts;
/*Proc sql for selecting the columns for the selected table*/
proc sql;
create view work.columns
as select table_name, column_name from control.data_dictionary
order by table_name, column_name;

select count(column_name) into :column_count from work.columns;
quit;

/*Data step for assigning the columns to the client array */
data _null_;
file _webout&webout_options;
put '<script language="JavaScript" type="text/JavaScript">';
put "a = new Array(&table_count+1);";
put "b = new Array(&table_count+1);";
put 'function load_array() {';
put "for (var x=0; x < &table_count+1; x++)";
put '{';
put 'a[x] = new Array (50);';
put '}';

run;

data _null_;
file _webout&webout_options;

set work.columns;
retain i 0;
retain j 0;
retain t_name table_name;
/*put t_name;*/

if t_name = table_name then
do;
put "a[" i "][" j "] = """ column_name """;";
j = j+1;
end;
else
do;
i = i+1;
j = 0;

put "a[" i "][" j "] = """ column_name """;";
put "b[" i "] = """ table_name """;";
j = j+1;
end;
t_name = table_name;
/*put "alert( b["i"]);";*/

run;

data _null_;
file _webout&webout_options;
put "return false";
put '}';
run;

data _null_;
file _webout&webout_options;

put 'function dimension_selected(obj_name) {';
/*put 'alert (obj_name.value);';*/

/*put 'alert (document.form1.dim_variable8.options.length)';*/

/*Check for the target object */
put 'var StrLen = String(obj_name.name).length;';
put 'StrVal = String(obj_name.name).substring(StrLen, StrLen - 1);';
put 'StrVal = "dim_variable"+StrVal;';
/*put 'alert (StrVal);';*/

/*Switch statment to check for the corresponding combo box for variables */
put 'switch (StrVal) {';
put 'case "dim_variable1":'; /*Case-1 dim_variable1 */


/*Delete the options if exists */
put "for (var x = document.form1.dim_variable1.length-1; x >= 0 ; x--)";
put "{";
put 'document.form1.dim_variable1.options[x]=null;';
put "}";
/*End of delete option */

	 /*I18N-scnjih-20080429-0924*/
/*put 'document.form1.dim_variable1.options[document.form1.dim_variable1.length]=new Option("NONE","NONE");';*/
put 'document.form1.dim_variable1.options[document.form1.dim_variable1.length]=new Option("'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,filtering_criteria.sas.1, noquote))"@;
put '","NONE");';
 /*I18N-scnjih-20080429-0924*/
/*Call Load arrary function*/
put 'load_array()';
/*End of Call to Load arrary function*/

/*Start creation of the option */
put 'var k=1;';
put "for (k = 1; k < &table_count; k++)";
put '{';
/*put 'alert (b[k]);';*/
put 'if (b[k].replace(/(^ +| +$)/, "") == obj_name.value)';
put 'break;';
put '}';
/*put 'alert(b[k]);';*/

/*put "for (var x = 1; x <= &column_count; x++)";*/
put 'for (var x = 1; x <= 50; x++)';
put '{';
put 'if (a[k][x] == null)';
put 'break;';
put 'document.form1.dim_variable1.options[document.form1.dim_variable1.length]=new Option(a[k][x],a[k][x]);';
put "}";

/*End creation of the option */
put 'break;'; /*Case-1 dim_variable1 */

put 'case "dim_variable2":'; /*Case-2 dim_variable1 */


/*Delete the options if exists */
put "for (var x = document.form1.dim_variable2.length-1; x >= 0 ; x--)";
put "{";
put 'document.form1.dim_variable2.options[x]=null;';
put "}";
/*End of delete option */


	 /*I18N-scnjih-20080429-0924*/
/*put 'document.form1.dim_variable2.options[document.form1.dim_variable2.length]=new Option("NONE","NONE");';*/
put 'document.form1.dim_variable2.options[document.form1.dim_variable2.length]=new Option("'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,filtering_criteria.sas.1, noquote))"@;
put '","NONE");';
 /*I18N-scnjih-20080429-0924*/

/*Call Load arrary function*/
put 'load_array()';
/*End of Call to Load arrary function*/

/*Start creation of the option */
put 'var k=1;';
put "for (k = 1; k < &table_count; k++)";
put '{';
put 'if (b[k].replace(/(^ +| +$)/, "") == obj_name.value)';
put 'break;';
put '}';

/*put "for (var x = 1; x <= &column_count; x++)";*/
put 'for (var x = 1; x <= 50; x++)';
put '{';
put 'if (a[k][x] == null)';
put 'break;';
put 'document.form1.dim_variable2.options[document.form1.dim_variable2.length]=new Option(a[k][x],a[k][x]);';
put "}";

/*End creation of the option */
put 'break;'; /*Case-2 dim_variable1 */


put 'case "dim_variable3":'; /*Case-3 dim_variable1 */


/*Delete the options if exists */
put "for (var x = document.form1.dim_variable3.length-1; x >= 0 ; x--)";
put "{";
put 'document.form1.dim_variable3.options[x]=null;';
put "}";
/*End of delete option */

	 /*I18N-scnjih-20080429-0924*/
/*put 'document.form1.dim_variable3.options[document.form1.dim_variable3.length]=new Option("NONE","NONE");';*/
put 'document.form1.dim_variable3.options[document.form1.dim_variable3.length]=new Option("'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,filtering_criteria.sas.1, noquote))"@;
put '","NONE");';
 /*I18N-scnjih-20080429-0924*/
/*Call Load arrary function*/
put 'load_array()';
/*End of Call to Load arrary function*/

/*Start creation of the option */
put 'var k=1;';
put "for (k = 1; k < &table_count; k++)";
put '{';
put 'if (b[k].replace(/(^ +| +$)/, "") == obj_name.value)';
put 'break;';
put '}';


/*put "for (var x = 1; x <= &column_count; x++)";*/
put 'for (var x = 1; x <= 50; x++)';
put '{';
put 'if (a[k][x] == null)';
put 'break;';
put 'document.form1.dim_variable3.options[document.form1.dim_variable3.length]=new Option(a[k][x],a[k][x]);';
put "}";

/*End creation of the option */
put 'break;'; /*Case-3 dim_variable1 */

put 'case "dim_variable4":'; /*Case-4 dim_variable1 */


/*Delete the options if exists */
put "for (var x = document.form1.dim_variable4.length-1; x >= 0 ; x--)";
put "{";
put 'document.form1.dim_variable4.options[x]=null;';
put "}";
/*End of delete option */

	 /*I18N-scnjih-20080429-0924*/
/*put 'document.form1.dim_variable4.options[document.form1.dim_variable4.length]=new Option("NONE","NONE");';*/
put 'document.form1.dim_variable4.options[document.form1.dim_variable4.length]=new Option("'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,filtering_criteria.sas.1, noquote))"@;
put '","NONE");';
 /*I18N-scnjih-20080429-0924*/
/*Call Load arrary function*/
put 'load_array()';
/*End of Call to Load arrary function*/

/*Start creation of the option */
put 'var k=1;';
put "for (k = 1; k < &table_count; k++)";
put '{';
put 'if (b[k].replace(/(^ +| +$)/, "") == obj_name.value)';
put 'break;';
put '}';


/*put "for (var x = 1; x <= &column_count; x++)";*/
put 'for (var x = 1; x <= 50; x++)';
put '{';
put 'if (a[k][x] == null)';
put 'break;';
put 'document.form1.dim_variable4.options[document.form1.dim_variable4.length]=new Option(a[k][x],a[k][x]);';
put "}";

/*End creation of the option */
put 'break;'; /*Case-4 dim_variable1 */

put 'case "dim_variable5":'; /*Case-5 dim_variable1 */


/*Delete the options if exists */
put "for (var x = document.form1.dim_variable5.length-1; x >= 0 ; x--)";
put "{";
put 'document.form1.dim_variable5.options[x]=null;';
put "}";
/*End of delete option */

	 /*I18N-scnjih-20080429-0924*/
/*put 'document.form1.dim_variable5.options[document.form1.dim_variable5.length]=new Option("NONE","NONE");';*/
put 'document.form1.dim_variable5.options[document.form1.dim_variable5.length]=new Option("'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,filtering_criteria.sas.1, noquote))"@;
put '","NONE");';
 /*I18N-scnjih-20080429-0924*/
/*Call Load arrary function*/
put 'load_array()';
/*End of Call to Load arrary function*/

/*Start creation of the option */
put 'var k=1;';
put "for (k = 1; k < &table_count; k++)";
put '{';
put 'if (b[k].replace(/(^ +| +$)/, "") == obj_name.value)';
put 'break;';
put '}';

/*put "for (var x = 1; x <= &column_count; x++)";*/
put 'for (var x = 1; x <= 50; x++)';
put '{';
put 'if (a[k][x] == null)';
put 'break;';
put 'document.form1.dim_variable5.options[document.form1.dim_variable5.length]=new Option(a[k][x],a[k][x]);';
put "}";

/*End creation of the option */
put 'break;'; /*Case-5 dim_variable1 */

put 'default: alert("'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.alert_no_matching_selection.1, noquote))"@;
put '");';
put '}';
put '}';

put 'var v_counter=1';

put 'function validate_form()';
put '{';

	put 'var query_builder = '' '';';

	put 'for (v_counter=1; v_counter<=5; v_counter++)';
	put '{';

		put 'if (eval("document.form1.dim_table"+v_counter+".value") == ''NONE'')';
			put 'break;';

		put 'if (v_counter > 1)';
			put 'query_builder = query_builder + '' AND '';';

	/*put 'query_builder = query_builder + document.form1.dim_table1.value;';*/

		put 'query_builder = query_builder + '' ('';';
		put 'query_builder = query_builder + eval("document.form1.dim_table"+v_counter+".value");';
		put 'query_builder = query_builder + ''.'';';
		put 'query_builder = query_builder + eval("document.form1.dim_variable"+v_counter+".value");';
		put 'query_builder = query_builder + '' '';';
		put 'query_builder = query_builder + eval("document.form1.dim_operator"+v_counter+".value");';

		put 'if (eval("document.form1.dim_operator"+v_counter+".value") == ''BETWEEN'')';
			put '{';
			put 'query_builder = query_builder + '' '' + eval("document.form1.dim_value_first"+v_counter+".value");';
			put 'query_builder = query_builder + '' AND '' + eval("document.form1.dim_value_second"+v_counter+".value");';
		put '}';
		put 'else';
			put 'query_builder = query_builder + '' '' + eval("document.form1.dim_value_first"+v_counter+".value");';
		put 'query_builder = query_builder + '')''';



	put '}';

	put 'if (query_builder != '' '')';
		put "query_builder = '&in_filter' + query_builder;";
	put 'else';
		put "query_builder = '&in_filter';";

	put 'document.form1.filter_clause.value = query_builder;';

	/*Start the validation code */
	put 'if ((document.form1.pd_score(0).checked) || (document.form1.pd_score(1).checked)){';
		/* If no values is entered or the entered value is not a number then an alert box
			is shown */
		put 'var range=document.form1.range_interval.value';
		put 'var quantile=document.form1.no_of_quantile.value';

		/* If Score range is selected for LGD or CCF model an alert box is shown*/
		put "if ((document.form1.pd_score(1).checked) && (('&model_type_code' == &LGD_MODEL) || ('&model_type_code' == &CCF_MODEL))){";
			put 'alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.alert_score_rng_for_PD_model.1, noquote))"@;
			put '")';
			put 'return false;';
		put '}';

		put 'if (((range == '''') && (quantile ==  '''')) || ((range == ''0'')
				|| (quantile ==  ''0'') || (isNaN(range) || isNaN(quantile))))';
		put '{';
			put 'alert ('''@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.alert_dynamic_pooling_selected_p1.1, noquote))"@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.alert_dynamic_pooling_selected_p2.1, noquote))"@;
			put ');';
			put 'return false;';
		put '}';

		put 'if (range != ""){';
			put 'if (range < 0){';
				put 'alert("'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.alert_range_interval_greater_then_0.1, noquote))"@;
				put '")';
				put 'return false';
			put '}';
		put '}';
		put 'else if (quantile != ""){';
			put 'if (quantile < 3 || quantile > 100){';
				put 'alert("'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.alert_quantile_range_3_100.1, noquote))"@;
				put '")';
				put 'return false';
			put '}';
		put '}';
		put 'else';
			put 'return true;';
	put '}';
	put 'else';
		put 'return true;';
	/*End of validation code */

put '}';

put 'function NoAction(){';
	put 'form1.pd_score(2).checked=true';
	put 'form1.no_of_quantile.value=""';
	put 'form1.range_interval.value=""';
	put 'form1.filter_clause.value=""';
	put 'form1.submit();';
put '}';

put '</script>';
run;

/*End of code for java script */
%mend;

/*End of the view */

/*All macros - Start*/
%macro start_html_macro1;
data _null_;
file _webout&webout_options;
put '<HTML>';
put '<HEAD>';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8">';
/*I18N-scnhuh-20080418-1023*/
put '<title>'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.title_filter_screen.1, noquote))"@;
put '</title>';
/*put "<link href=""/SASCSReports/styles/default.css"" rel=""stylesheet"" type=""text/css"">";*/
put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css">';
put '<style type="text/css">';
put '<!--';
put '.style2 {font-size: small}';
put '-->';
put '/</style>';
run;
%mend;

%macro start_html_macro2;
data _null_;
file _webout&webout_options;
put '</HEAD>';
put '<BODY>';
put "<FORM method=post name='form1' id='form1' 
 action='/SASStoredProcess/do?_program=&called_program'
 onsubmit=""return validate_form();"">";

put '<table width="100%" border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';
put '<tr><td colspan=5><div align="right">';
put '<img src="/SASCSReports/images/CrBanner.gif" width="259" height="29">';
put '</div></td></tr>';

put '<tr>';
put '<td colspan=5><H2 align="left">'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.column_business_filters.1, noquote))"@;
put '</H2></td>';
put '</tr>';
put '<tr >';
put '<td class="LabelFont">'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.column_dimension.1, noquote))"@;
put '</td>';
put '<td class="LabelFont">'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.column_variable.1, noquote))"@;
put '</td>';
put '<td class="LabelFont">'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.column_operator.1, noquote))"@;
put '</td>';
put '<td class="LabelFont">'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.column_parameter1.1, noquote))"@;
put '</td>';
put '<td class="LabelFont">'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.column_parameter2.1, noquote))"@;
put '</td>';
put '</tr>';
run;
%mend;
%macro end_html_macro;
data _null_;
file _webout&webout_options;
put '<tr><td colspan=5>&nbsp;</td></tr>';
put '<tr>';
put '<td colspan=5><H2 align="left">'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.column_pooling_criteria.1, noquote))"@;
put '</H2> </td> ';
put '</tr>';
put '<tr>';
put '<td colspan=1 class="LabelFont">'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.column_range_interval.1, noquote))"@;
put '</td> ';
put '<td colspan=1 class="LabelFont"><INPUT type=text name=''range_interval'' id=''range_interval'' size="15" width="30" ></td> ';
put '</tr>';

put '<tr>';
put '<td class="LabelFont">'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.column_no_quantile.1, noquote))"@;
put '</td> ';
put '<td class="LabelFont"><INPUT type=text name=''no_of_quantile'' id=''no_of_quantile'' size="15" width="30" ></td> ';
put '</tr>';

/*The code to keep track of the global variables as hidden */
put "<tr><td colspan=5>
<INPUT type=hidden name='filter_clause' id='filter_clause' size=15 width=30 ></td></tr>";

put "<tr><td colspan=5>&nbsp;
<INPUT type=hidden name='prod_type_desc' id='prod_type_desc' value='&prod_type_desc' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='prod_type_code' id='prod_type_code' value='&prod_type_code' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='model_type_code' id='model_type_code' value='&model_type_code' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='model_type_desc' id='model_type_desc' value='&model_type_desc' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='include_exp_mdl' id='include_exp_mdl' value='&include_exp_mdl' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='model1' id='model1' value='&model1' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='model2' id='model2' value='&model2' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='model1_key' id='model1_key' value='&model1_key' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='model2_key' id='model2_key' value='&model2_key' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='period' id='period' value='&period' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='time_key' id='time_key' value='&time_key' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='statistic' id='statistic' value='&statistic' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='prg_name' id='prg_name' value='&prg_name' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='outcome_period' id='outcome_period' value='&outcome_period' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='elapsed_time' id='elapsed_time' value='&elapsed_time' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='sel_model' id='sel_model' value='&sel_model' size=15 width=30 ></td></tr>";
put "<tr><td colspan=5>
<INPUT type=hidden name='sel_model_key' id='sel_model_key' value='&sel_model_key' size=15 width=30 ></td></tr>";

put "<tr><td colspan=5>
<INPUT type=hidden name='filter' id='filter' value='&filter' size=15 width=30 ></td></tr>";

/*End of code to keep track of the global variables */

put '<tr>';
put '<td class="LabelFont"><input name="pd_score" type="radio" value="PD" >'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.radio_pd_lgd_ccf.1, noquote))"@;
put '</td> ';
put '</tr>';

put '<tr>';
put '<td class="LabelFont"><input name="pd_score" type="radio" value="SCORE" >'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.radio_score_pd.1, noquote))"@;
put '</td> ';
put '</tr>';

put '<tr>';
put '<td class="LabelFont"><input name="pd_score" type="radio" value="" checked>'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.radio_none.1, noquote))"@;
put '</td> ';
put '</tr>';

put '<tr><td colspan=5>&nbsp;</td></tr>';

put '<tr>';
put '<td colspan=5 height="32" bgcolor="#F1EACB"> <input type="submit" class=mmhide_btn value="'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.button_submit.1, noquote))"@;
put '">';
put '<input type="button" class=mmhide_btn value="'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,crs.filtering_criteria.button_cancle.1, noquote))"@;
put '" onClick="javascript:NoAction()"></td>';
put '</tr>';
put '</table>';
put '</FORM>';
put '</BODY>';
put '</HTML>';
run;
%mend;

%macro repeat_for_each_table;
data _null_;
/*Variables
dim_data: local variable used within this data step */

file _webout&webout_options;
set work.tables end=L; /*end=L for identifying the last record being processed*/
j = &i;

/*If the table is selected in the previous step, then display the same table */

dim_table_val='<option value='''||ktrim(kleft(table_name))||'''>'||ktrim(kleft(table_name))||'</option>';

/* If this is the first observation */
if _N_ = 1 then
do;
put '<tr>';
put '<td>';
dim_table="""dim_table"||ktrim(kleft(j))||"""";
put '<SELECT name=' dim_table ' id=' dim_table ' size="1" width="30" style="width: 80mm"  OnChange="dimension_selected(this)">';
	 /*I18N-scnjih-20080421-1439*/
/*put '<OPTION value="NONE">NONE</OPTION>';*/
put '<OPTION value="NONE">'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,filtering_criteria.sas.1, noquote))"@;
put '</OPTION>';
	 /*I18N-scnjih-20080421-1439*/
end;
/*If neither the first or last observation then */
else if L = 1 then
do;
put dim_table_val;
put '</SELECT>';
put '</td>';
dim_variable="""dim_variable"||ktrim(kleft(j))||"""";
put '<td><SELECT name=' dim_variable ' id=' dim_variable ' size="1" width="30" style="width: 80mm">';
	 /*I18N-scnjih-20080421-1439*/
/*put '<OPTION value="NONE">NONE</OPTION>';*/
put '<OPTION value="NONE">'@;
put  "%sysfunc(sasmsg(smd_ds.bismsg,filtering_criteria.sas.2, noquote))"@;
put '</OPTION>';
	 /*I18N-scnjih-20080421-1439*/
put '</td>';

put '</td>';
dim_operator="""dim_operator"||ktrim(kleft(j))||"""";
put '<td><SELECT name=' dim_operator ' id=' dim_operator ' size="1" width="30"  >';
put '<OPTION value=">"> > </OPTION>';
put '<OPTION value="<"> < </OPTION>';
put '<OPTION value="<>"> <> </OPTION>';
put '<OPTION value="="> = </OPTION>';
	 /*I18N-scnjih-20080421-1439*/
/*put '<OPTION value="BETWEEN"> BETWEEN </OPTION>';*/
/*put '<OPTION value="IN"> IN </OPTION>';*/
put '<OPTION value="BETWEEN">'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,filtering_criteria.sas.3, noquote))"@;
put ' </OPTION>';
put '<OPTION value="IN">'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,filtering_criteria.sas.4, noquote))"@;
put '</OPTION>';
	 /*I18N-scnjih-20080421-1439*/
put '</SELECT>';
put '</td>';
dim_value_first="""dim_value_first"||ktrim(kleft(j))||"""";
put '<td><INPUT type=text name=' dim_value_first ' id=' dim_value_first ' size="15" width="30"  >';
put '</td>';

dim_value_second="""dim_value_second"||ktrim(kleft(j))||"""";
put '<td><INPUT type=text name=' dim_value_second ' id=' dim_value_second ' size="15" width="30" >';
put '</td>';

put '</tr>';
end;
if _N_>=1 and not L then put dim_table_val;
run;
%mend;


%macro decission_macro;
%let i = 1;
/*%do %while (&i <= &table_count);*/
%do %while (&i <= 5);

%repeat_for_each_table;
%let i= &i+1;
%end;
%mend;

/*All macros - End*/

/* Data step for displaying the combo box */
%start_html_macro1;
%all_scripts;
%start_html_macro2;
%decission_macro;
%end_html_macro;
