/******************************************************************************************************
       Module:  measure_config

     Function:  This stored process provides a configuration screen for editing the level,
				sequence no, etc. in dim.Measure_dim dataset.

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	NA
        Calls:  measure_config (when edit or update or cancel button is clicked)

Datasets used:  No input datasets required for processing of the stored process
 
        Logic:  1. All inputs to the stored process are accepted as global parameters. 
			    2. Access the Star Schema to get all the columns from data_dictionary
					dataset in control library.
				3. If Edit button is clicked then the details of the selected measure
					is shown, which can then be modified. After modifying if Update
					button is clicked then the dim.measure_dim dataset is updated
					with the modified data for the selected measure.
					If there is any error while updating the table then an appropriate
					alert box is shown and the default screen comes up.
					If cancel button is clicked then the default screen is shown
					without updating the dataset.
				4. Proper validation such as:
					-If Edit button is clicked and then another measure is selected,
						without clicking update or cancel then an alert box is shown
						saying 'Click on Update or Cancel before selecting another measure'
						is displayed.
				
   Parameters:  INPUT
                model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
				msr_key				:	The measure_sk of the selected measure.
				level				:	The level of the selected measure.
				seq					:	The sequence number of the selected measure.
				prog_nm				:	The program name of the selected measure.
				b_red				:	The bound_red value of the selected measure.
				b_green				:	The bound_green value of the selected measure.
				perf_action			:	If perf_action is 0 then the screen without edit
										details is shown.
										If perf_action is 1 then the Edit details are shown
										(i.e. the value of level, sequence etc can be modified)
										If perf_action is 2 then the measure_dim dataset in dim
										library is updated for the selected measure.
				
				OUTPUT 
                model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
				msr_key				:	The measure_sk of the selected measure.
				level				:	The level of the selected measure.
				seq					:	The sequence number of the selected measure.
				prog_nm				:	The program name of the selected measure.
				b_red				:	The bound_red value of the selected measure.
				b_green				:	The bound_green value of the selected measure.
				perf_action			:	If perf_action is 0 then the screen without edit
										details is shown.
										If perf_action is 1 then the Edit details are shown
										(i.e. the value of level, sequence etc can be modified)
										If perf_action is 2 then the measure_dim dataset in dim
										library is updated for the selected measure.
				product_type_code	: 
******************************************************************************************************/
/*This code is Internationalized*/
%global model_type_code msr_key level seq prog_nm b_red b_green perf_action product_type_code;
/*This code is Internationalized*/
/* 	Action 0: No
	Action 1: Edit
	Action 2: Update
*/
 
option mlogic mprint;
%macro check_macro_variable;  
%if &msr_key. ne   %then 
	%let msr_key=%sysfunc(ktrim(%sysfunc(kleft(&msr_key))));  
%if %str("&model_type_code") ne %str("") %then
	%let model_type_code=%sysfunc(ktrim(%sysfunc(kleft(&model_type_code))));
/*New addition in for product type code*/
	%put product_type_code=&product_type_code;
%if %str("&product_type_code") ne %str("") %then
	%let product_type_code=%sysfunc(ktrim(%sysfunc(kleft(&product_type_code))));
/**/
	%put level=&level*;
%if  %str(&level)  ne   %then
	%let level=%sysfunc(ktrim(%sysfunc(kleft(&level))));
	%put seq=&seq*;
%if  %str(&seq)  ne  %then
	%let seq=%sysfunc(ktrim(%sysfunc(kleft(&seq))));
%if  %str(&b_red)ne   %then
	%let b_red=%sysfunc(ktrim(%sysfunc(kleft(&b_red))));
%if  %str(&b_green) ne  %then
	%let b_green=%sysfunc(ktrim(%sysfunc(kleft(&b_green))));
%if %str(&perf_action) ne  %then
	%let perf_action=%sysfunc(ktrim(%sysfunc(kleft(&perf_action))));
/*%let radiochange=%trim(%left(&radiochange));*/
/*%let msr_key=;*/
%mend;
%check_macro_variable;

/* Setting default values for any required parameters */
data _null_;
	if "&model_type_code"="" then call symput('model_type_code',&PD_APP_MODEL);
/*	if  "&radiochange"="" then call symput('radiochange',0);*/
	if "&msr_key"="" then call symput('perf_action',0);
run;

proc sql;
	create table work.measure as
	select * from dim.measure_dim
	where model_type_cd = "&model_type_code"
	      and PRODUCT_TYPE_CD="&product_type_code"
	order by seq_no;
quit;

data _NULL_;
	set work.measure;
	if _N_ = 1 and &perf_action = 0 then call symput('msr_key',measure_sk);
run;

%macro edit_update_config;
%if &product_type_code ne "" %then 
%do; 
	%if &perf_action=0  %then %do;
		/* No Action */
		data _null_;
			file _webout&webout_options;
			put '<tr><td>&nbsp</td></tr> ';
			put '          <tr bgcolor="#FAF8ED">';
			put '            <td bgcolor="#F1EACB">&nbsp;&nbsp;';
			put '                <INPUT type=submit class=mmhide_btn onClick="javascript:EditAction()" value="'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.button_edit.1, noquote))"@;
			put '">';
			put '            </td>';
			put '          </tr>';
		run;
	%end;
	%else %if &perf_action=1 %then %do;
		/* Action = Edit */
		proc sql noprint;
			create table work.edit_measure as 
			select * from dim.measure_dim
			where model_type_cd = "&model_type_code" and measure_sk=&msr_key 
			and PRODUCT_TYPE_CD="&product_type_code";

			create table work.levels as
			select distinct level_desc from dim.measure_dim
			where model_type_cd = "&model_type_code" and PRODUCT_TYPE_CD="&product_type_code";

			select length(program_nm)+1 into :prog_size from work.edit_measure;

			select level_desc into :level from work.edit_measure;
		quit;
 
		data _null_;
			file _webout&webout_options;
			set work.edit_measure;
			put '<tr><td align="left"><H2 align="left">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.column_edit_msr_dtl.1, noquote))"@;
			put '</H2></td></tr> ';
			put '<tr><td valign="top"><table width="100%" border="0" cellpadding="3" cellspacing="0">';
			put '<tr><td class="LabelFont">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.column_msr_nm.1, noquote))"@;
			put '</td><td class="LabelFont">'; 
			put measure_nm;
			put '</td></tr> ';
		run;

		data _null_;
			if "&model_type_code" ne &MIP_MODEL then do;
				file _webout&webout_options;
				set work.levels end=last;
				if _N_=1 then do;
					put '<tr><td width="15%" class="LabelFont">'@;
					put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.column_level.1, noquote))"@;
					put '</td>';
					put '<td><select name=select>';
				end;
				put '<option value="'@;
				put level_desc@;
				put '"'@;
				if "&level"=level_desc then put ' selected'@;
				put '>'@;
				put level_desc@;
				put '</option>';
				if last then do;
					put'</select></td></tr> ';
				end;
			end;
		run;
		
		data _null_;
			file _webout&webout_options;
			set work.edit_measure;
			put '<tr><td class="LabelFont">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.column_seq_no.1, noquote))"@;
			put '</td>'; 
			put '<td><input name=seq_no type=text value='@;
			put seq_no@;
			put '></td></tr> ';
			put '<tr><td class="LabelFont">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.column_prog_link.1, noquote))"@;
			put '</td>'; 
			put '<td><input name=prog_name type=text size=';
			put "&prog_size"@; 
			put ' value='@;
			put program_nm@;
			put '></td></tr> ';
			put '<tr><td class="LabelFont">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.column_bound_red.1, noquote))"@;
			put '</td>'; 
			put '<td><input name=bound_red type=text value='@;
			put bound_red@;
			put '></td></tr> ';
			put '<tr><td class="LabelFont">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.column_bound_green.1, noquote))"@;
			put '</td>'; 
			put '<td><input name=bound_green type=text value='@;
			put bound_green@;
			put '></td></tr> ';
			put '</table></td></tr>';
			put '<tr><td>&nbsp</td></tr> ';
			put '          <tr bgcolor="#FAF8ED">';
			put '            <td bgcolor="#F1EACB">&nbsp;&nbsp;';
			put '                <INPUT type=button class=mmhide_btn onClick="javascript:UpdateAction()" value="'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.button_update.1, noquote))"@;
			put '">';
			put '                <INPUT type=button class=mmhide_btn onClick="javascript:NoAction()" value="'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.button_cancel.1, noquote))"@;
			put '">';
			put '            </td>';
			put '          </tr>';
		run;
	%end;
	%else %if &perf_action=2 %then %do;
		%let error_code=NONE;

		data _NULL_;
		name=put(time(),mmss8.1);
		put name=;
		name1=kscan(name,1,":.");
		name2=kscan(name,2,":.");
		name3=kscan(name,3,":."); 
		name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
		call symput('log_name',"Data/bisdata/error/msr_&model_type_code._&msr_key."||ktrim(kleft(name4))||".log");
		run;

		%put NOTE: Sending log messages to :&log_name;

		proc printto log="&log_name";
		quit;
		/*End proc printto */

		/* Action = Update */
		%if %quote(%'&model_type_code%') = &MIP_MODEL %then %do;
			proc sql;
				update dim.measure_dim 
				set seq_no=&seq_no, program_nm="&prog_nm", 
					bound_red=&b_red, bound_green=&b_green
				where model_type_cd="&model_type_code" and measure_sk=&msr_key 
								and PRODUCT_TYPE_CD="&product_type_code";
			quit;
		%end;
		%else %do;
			proc sql;
				update dim.measure_dim 
				set level_desc="&level", seq_no=&seq_no, program_nm="&prog_nm", 
					bound_red=&b_red, bound_green=&b_green
				where model_type_cd="&model_type_code" and measure_sk=&msr_key 
							and PRODUCT_TYPE_CD="&product_type_code";
			quit;
		%end;

		/*Code to check for errors.
		Possibly error will happen only if the filter condition is not properly passed. 
		In this case, return to the calling program with error_code=ERROR
		*/
		%if &sqlrc = 8 %then %do;
			%let error_code = ERROR;
	/*		%RETURN;*/
		%end;
		/*End of code to check errors */

		/*Proc printto will reset the log redirection */
		proc printto;
		quit;

		%put NOTE: Resetting log to _webout&webout_options;
		/*End of proc printto */
		%put error=&error_code;

		/* If update is successful, alert success, reset variables and generate report with No Action
			If update is not successful, alert error message and generate report with Edit Action. */
		data _null_;
			file _webout&webout_options;
			if &perf_action=2 then do;
				put '<script>';
				put '<!--';
				if ktrim(kleft("&error_code"))="NONE" then do;
					put 'alert("'@;
					put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.alert_update_sucessful.1, noquote))"@;
					put '")';
					put 'form1.msr_key.value=""';
					put 'form1.level.value=""';
					put 'form1.seq.value=""';
					put 'form1.prog_nm.value=""';
					put 'form1.b_red.value=""';
					put 'form1.b_green.value=""';
					put 'NoAction()';
				end;
				else do;
					put 'alert("'@;
					put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.alert_update_parameter_failed.1, noquote))"@;
					put '")';
					put 'EditAction()';
				end;
				put '//-->';
				put '</script>';
			end;
		run;
	%end;
%end;
%mend edit_update_config;

data _null_;
	file _webout&webout_options;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" ';
	put '"http://www.w3.org/TR/html4/loose.dtd"> ';
	put '<html> ';
	put '<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.title_filter_screen.1, noquote))"@;
	put '</title> ';
	put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<style type="text/css"> ';
	put '<!-- ';
	put '.style2 {color: #990000} ';
	put 'body { ';
	put '	background-color: #FAF8ED; ';
	put '} ';
	put '--> ';
	put '</style> ';

	put '<script language="JavaScript" type="text/JavaScript"> ';
	put '<!-- ';

	/* Calls the Reporting stored process if link is clicked */
	put 'function Link1() {';
		put "form1._program.value=&CS_REPORTING";
		put 'form1.submit()';
	put '}';
	
	put 'function load()';
	put '{';
		put 'form1.ProductType.disabled=false;';
	put '}';

	put 'function setType(val) {';
			put 'form1.product_type_code.value=""';
			put 'form1.model_type_code.value=val;';
 			put 'form1.ProductType.select_prd="select_prd";';
			put 'form1.perf_action.value="0"';
			put 'form1.ProductType.options[0].selected = true';
			put 'form1.ProductType.disabled=true;';
			put 'form1.submit();';
		put '};';

	put 'function PrdType(DrpDwn) {';
			put 'form1.product_type_code.value=DrpDwn;';
			put 'form1.perf_action.value="0"';
			put 'form1.submit();';
	put '}';
	put 'function setMsr(val) {';
		if &perf_action = 0 then do;
			put 'form1.msr_key.value=val';
		end;
		else do;
			put 'alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.alert_click_update_cancel.1, noquote))"@;
			put '")';
			put 'form1.submit();';
		end;
	put '}';

	put 'function EditAction() {';
		if "&product_type_code" eq "" then 
		do;
			put 'form1.perf_action.value="0"'; 
			put 'form1.submit();';
		end;
		else
		do;
			put 'form1.perf_action.value="1"';  
			put 'form1.submit();';
		end;
	put '}';

	put 'function NoAction() {';
		put 'form1.msr_key.value=""';
		put 'form1.perf_action.value="0"';
		put 'form1.submit();';
	put '}';

	put 'function UpdateAction() {';
		if "&model_type_code" = &MIP_MODEL then
			put 'form1.level.value=""';
		else
		put 'form1.level.value=form1.select(form1.select.selectedIndex).value';
		put 'form1.seq.value=form1.seq_no.value';
		put 'form1.prog_nm.value=form1.prog_name.value';
		put 'form1.b_red.value=form1.bound_red.value';
		put 'form1.b_green.value=form1.bound_green.value';
		put 'form1.perf_action.value="2"';
		put 'form1.submit();';
	put '}';

	put '//-->';
	put	'</script> ';

	put '</head> ';

	put '<body onload="load();"> ';
	put '<form name="form1" method="post" action="/SASStoredProcess/do">';

	/* Hidden textboxes to hold the values for the program name and the output paremeters */
	put "<input type='hidden' name='_program' VALUE=&CS_MSR_CONFIG>";
	model_type_code=symget("model_type_code");
	put '<input type="hidden" name="model_type_code" value="' @;
	put model_type_code;
	put '">';
  	product_type_code=symget("product_type_code");
	put '<input type="hidden" name="product_type_code" value="' @;
	put product_type_code;
	put '">';
	msr_key=symget("msr_key");
	put '<input type="hidden" name="msr_key" value="' @;
	put msr_key;
	put '">';
	level=symget("level");
	put '<input type="hidden" name="level" value="' @;
	put level;
	put '">';
	seq=symget("seq");
	put '<input type="hidden" name="seq" value="' @;
	put seq;
	put '">';
	prog_nm=symget("prog_nm");
	put '<input type="hidden" name="prog_nm" value="' @;
	put prog_nm;
	put '">';
	b_red=symget("b_red");
	put '<input type="hidden" name="b_red" value="' @;
	put b_red;
	put '">';
	b_green=symget("b_green");
	put '<input type="hidden" name="b_green" value="' @;
	put b_green;
	put '">';
	perf_action=symget("perf_action");
	put '<input type="hidden" name="perf_action" value="' @;
	put perf_action;
	put '">';
/*	radiochange=symget("radiochange");*/
/*	put '<input type="hidden" name="radiochange" value="' @;*/
/*	put radiochange;*/
/*	put '">';*/

	put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED"> ';
	put '<tr> ';
	put '<td align="left"> ';
	put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0"> ';
	put '<tr> ';
	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
	put '		  <tr> ';

/*  put '<td><span class="BreadCrumb">';*/
/*	put '<a href="javascript:Link1()">Reporting </a> &gt; '@;*/
/*	put '</span><span class="BreadCrumb">Measure Configuration</span></td>';*/
	put '<td>&nbsp;</td>';

	put '		<td width="259"><div align="right"><img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td> ';
	put '		  </tr> ';
	put '			</table> ';
	put '		  <tr> ';
	put '<td align="left"><H2 align="left">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.title_test_stats_config.1, noquote))"@;
	put '</H2></td></tr> ';
	put '          <tr>';
	put '            <td valign="top">';
	put '              <p class="LabelFont">';
	put '                <input name="radio" type="radio" value='@;put"&PD_APP_MODEL"@;
	if "&model_type_code" = &PD_APP_MODEL then put 'checked=checked '@;
	put 'onClick="javascript:setType(this.value)">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.drp_dwn_model_risk_based_approv.1, noquote))"@;
	put '</p>';
	put '              <p class="LabelFont">';
	put '                <input name="radio" type="radio" value='@;put"&PD_ONG_MODEL"@;
	if "&model_type_code" = &PD_ONG_MODEL then put 'checked=checked '@;
	put 'onClick="javascript:setType(this.value)">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.drp_dwn_model_ongoing_risk_mngmt.1, noquote))"@;
	put '</p>';
	put '              <p class="LabelFont">';
	put '                <input name="radio" type="radio" value='@;put"&LGD_MODEL"@;
	if "&model_type_code" = &LGD_MODEL then put 'checked=checked '@;
	put 'onClick="javascript:setType(this.value)">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.drp_dwn_model_loss_given_default.1, noquote))"@;
	put '</p>';
	put '              <p class="LabelFont">';
	put '                <input name="radio" type="radio" value='@;put"&CCF_MODEL"@;
	if "&model_type_code" = &CCF_MODEL then put 'checked=checked '@;
	put 'onClick="javascript:setType(this.value)">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.drp_dwn_model_credit_conv_factor.1, noquote))"@;
	put '</p>';
	put '              <p class="LabelFont">';
	put '                <input name="radio" type="radio" value='@;put"&MIP_MODEL"@;
	if "&model_type_code" = &MIP_MODEL then put 'checked=checked '@;
	put 'onClick="javascript:setType(this.value)">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.drp_dwn_model_inputs.1, noquote))"@;
	put '</p>';
/*	put '<tr><td>&nbsp</td></tr> ';*/ 
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.drp_dwn_name_prd_typ_cd.1, noquote))"@;
/*	put '<select name="ProductType">';*/
	put '<select name="ProductType" onchange="PrdType(this.value)">';
data _null_;
file _webout&webout_options;
	   if "&model_type_code" eq &CCF_MODEL  then
		do;
				put '<option value=""'@; 
				put 'selected="selected"'@;
				put'>'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.drp_dwn_sel_prd_type.1, noquote))"@;
				put '</option>';
				put '<option value='@;
				put"&CCD_PRD_TYPE"@;
				if "&product_type_code" =&CCD_PRD_TYPE then put 'selected="selected"'@;
				put'>'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.drp_dwn_credit_card.1, noquote))"@;
				put'</option>';
		end;
		else 
		do;
			put '<option value=""'@; 
			put '>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.drp_dwn_sel_prd_type.1, noquote))"@;
			put '</option>';
			put '<option value='@;
			put"&MTG_PRD_TYPE"@;
			if "&product_type_code" =&MTG_PRD_TYPE then put 'selected="selected"'@;
			put'>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.drp_dwn_mortgage.1, noquote))"@;
			put '</option>';
			put '<option value='@;
			put"&CCD_PRD_TYPE"@;
			if "&product_type_code" =&CCD_PRD_TYPE then put 'selected="selected"'@;
			put'>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.drp_dwn_credit_card.1, noquote))"@;
			put '</option>';
			put '<option value='@;
			put"&COR_PRD_TYPE"@;
			if "&product_type_code" =&COR_PRD_TYPE then put 'selected="selected"'@;
			put'>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.drp_dwn_core_banking.1, noquote))"@;
			put '</option>';
			put '<option value='@;
			put"&LON_PRD_TYPE"@;
			if "&product_type_code" =&LON_PRD_TYPE then put 'selected="selected"'@;
			put'>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.drp_dwn_loan.1, noquote))"@;
			put '</option></p>';
		end;
/*	end;*/
	put '</select>';
	put'</td></tr>'; 
  /*Note for selecting report*/
	put '<tr><td>';
	put '<p class=NoteFont>'@;
	put '<strong>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.note_notes.1, noquote))"@;
	put '</strong><br>';
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.note_notes_part1_p1.1, noquote))"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.note_notes_part1_p2.1, noquote))"@;
	put '<br>';
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.note_notes_part2_p1.1, noquote))"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.note_notes_part2_p2.1, noquote))"@;
	put  '</p>';
	put '</td></tr>';
  /*********/

	put '<tr><td> ';
	put '<table width="100%" border="0" cellpadding="0" cellspacing="0" bgcolor="#7F9DB9" class="tableborder"> ';
	put '<tr> ';
	put '<td valign="top"><table width="100%" border="0" cellpadding="3" cellspacing="0"> ';
	put '<tr bgcolor="#FFFFFF"> ';
	put '<td class="HZtableborder"><div align="center">&nbsp</div></td> ';
	if "&model_type_code" ne &MIP_MODEL then 
		do;
			put '<td class="HZtableborder">';
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.column_level.1, noquote))"@;
			put '</td> ';
		end;
	put '<td class="HZtableborder">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.column_msr_nm.1, noquote))"@;
	put '</td> ';
	put '<td class="HZtableborder"><div align="right">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.column_seq_no.1, noquote))"@;
	put '</div></td> ';
	put '<td class="HZtableborder">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.column_prog_link.1, noquote))"@;
	put '</td> ';
	put '<td class="HZtableborder"><div align="right">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.column_bound_red.1, noquote))"@;
	put '</div></td> ';
	put '<td class="HZtableborder"><div align="right">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_config.column_bound_green.1, noquote))"@;
	put '</div></td> ';
	put '</tr> ';
if  "&product_type_code"  eq "" then
do;
	put '</table></td>'; 
	put '</tr>'; 
	put '</table></td>'; 
	put '</tr>';
end;
run;
data _null_;
if  "&product_type_code"  ne "" then
do;
		file _webout&webout_options;
		set work.measure end=last;
		if mod(_N_,2)=0 then do;
			put '<tr bgcolor="#F4F4F2"> ';
			put '<td bgcolor="#F4F4F2" class="Font12px"> ';
		end;
		else do;
			put '<tr bgcolor="#FFFFFF"> ';
			put '<td class="LabelFont"> ';
		end;
		put '<div align="center">';
		put '<input type="radio" name="select_msr" ' @;
		put 'value="' @;
		put measure_sk @;
		put '" OnClick="javascript:setMsr(this.value)"'@;
		if "&msr_key" eq measure_sk then put 'checked=checked '@;
		else if _N_ = 1 and &perf_action = 0 then do;
			put 'checked=checked'@;
 
		end;
		put '></div></td>';
		if "&model_type_code" ne &MIP_MODEL then do;
			put '<td class="verttebleborder">'@;
			put level_desc @;
			put '</td> ';
		end;
		put '<td class="verttebleborder">'@;
		put measure_nm @;
		put '</td> ';
		put '<td class="verttebleborder"><div align="right">'@;
		put seq_no @;
		put '</div></td> ';
		put '<td class="verttebleborder">'@;
		put program_nm @;
		put '</td> ';
		put '<td class="verttebleborder"><div align="right">'@;
		put bound_red @;
		put '</div></td> ';
		put '<td class="verttebleborder"><div align="right">'@;
		put bound_green @;
		put '</div></td> ';
		put '</tr> ';
		if last then do;
			put '</table></td> ';
			put '</tr> ';
			put '</table></td> ';
			put '</tr> ';
		end;
  
end;
run;

%edit_update_config;

data _null_;
	file _webout&webout_options;
	put '</table> ';
	put '</td> ';
	put '</tr> ';
	put '</table> ';
	put '</body> ';
	put '</html> ';
run;
