/******************************************************************************************************
       Module:  create_tree

     Function:  This stored process creates an HTML screen where the parameter categories
				are shown in a tree structure with the hierarchy as given in the
				Parameter_category dataset in customisableparameters library.

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	parameter_conf
        Calls:  update_parameter(when any of the links is clicked)

Datasets used:  No input datasets required for processing of the stored process
 
        Logic:  1. Access the Star Schema to get the data from the parameter tables.
				2. tree_items.js script file is created in the CS_REPORT_PATH/script
					folder, which contains the link to the update_parameter stored process
					and the category code for which it is to be called, when the any of
					branch in the tree structure is clicked.
				3. The tree function in the tree.js file is called to create a tree structure
					for the parameters categories with the hierarchy as given in the
					Parameter_category dataset in customisableparameters library.
				
   Parameters:  NA

******************************************************************************************************/
/*This code is Internationalized*/
%let update_parameter=SBIP://Foundation/BIS/conf/update_parameter;

proc sql;
	create table work.para_cat as
	select * from custpara.parameter_category left join custpara.parameter_x_category
	on (parameter_category.category_cd=parameter_x_category.category_cd);
quit;

proc sql;
	create table work.para_cat1 as
	select * from work.para_cat left join custpara.parameter
	on (para_cat.parameter_no=parameter.parameter_no);
quit;

%let js_path=%sysfunc(kscan(&CONF_REPORT_PATH,1,%str(%')));
%let js_path = "&js_path.script/tree_items.js";
/*%let js_path="../BISConfiguration/script/tree_items.js";  */
%macro tree_cr(category=,level=);
/*	%put BEGIN-------------------------------- cat=&category;*/
/*	%put LEVEL-------------------------------- &level;*/
	%let level=%eval(&level+1);
	%local cat;
	proc sql noprint;
		select count(distinct category_cd) into :no
		from work.para_cat1 where kupcase(parent_category_cd) = kupcase("&category");
	quit;

	%if &no>0 %then %do;
		proc sql noprint;
			select distinct( ktrim(kleft(category_cd))) into :cat separated by '#'
			from work.para_cat1
			where kupcase(parent_category_cd) = kupcase("&category");
		quit;
		
		%local cnt;
		%let cnt=1;
		%let token=%sysfunc(kscan(&cat,&cnt,#));
		%do %while (&token ne %str());
			proc sql noprint;
				select parameter_no into :para_no
				from work.para_cat1
				where kupcase(parent_category_cd) = kupcase("&category");
			quit;
			%let para_no=%sysfunc(ktrim(%sysfunc(kleft(&para_no))));
			%put token=&token;
			%put para_no=&para_no;
				data _null_;
/*I18N-scnhuh-20080418-1555*/
/*add &webout_options*/				
					file &js_path &webout_options mod LRECL=500;
/*I18N-scnhuh-20080418-1555*/
					do i = 1 to &level;
						put ' '@;
					end;
					put '['''@;
					put "&token" @;
					%if &para_no eq . %then %do;
						put "', 'http://&_SRVNAME:&_SRVPORT/SASStoredProcess/do?"@;
						put '&_program='@;
						put "&update_parameter"@;
						put ''', ';
					%end;
					%else %do;
						put "', 'http://&_SRVNAME:&_SRVPORT/SASStoredProcess/do?"@;
						put '&_program='@;
						put "&update_parameter"@;
						put '&category_cd='@;
/*						put "&token" @;*/
						/*following 2 lines are internationalized*/
						catcd_temp=strip(urlencode(unicodec("&token",'utf8')));
						put catcd_temp@;
						put ''', ';
					%end;
			%tree_cr(category=&token,level=&level);
				data _null_;
/*I18N-scnhuh-20080418-1555*/
/*add &webout_options*/				
					file &js_path &webout_options mod lrecl=500;
/*I18N-scnhuh-20080418-1555*/
					do i = 1 to &level;
						put ' '@;
					end;
					put '],'@;
			%let cnt=%eval(&cnt+1);
			%let token=%sysfunc(kscan(&cat,&cnt,#));
		%end;
		%if &cnt>1 %then %do;	
			run;
		%end;
/*	%put END-------------------------------- cat=&category;*/
/*	%put LEVEL-------------------------------- &level;*/
	%end;
%mend tree_cr;	


proc sql noprint;
	select ktrim(kleft(category_cd)) into :cat
	from work.para_cat1
	where upcase(parent_category_cd) ="%sysfunc(sasmsg(smd_ds.bismsg,crs.create_tree.sas.parent_category.1, noquote))";
quit;

%let cat=%sysfunc(ktrim(%sysfunc(kleft(&cat))));

data _null_;
/*I18N-scnhuh-20080418-1555*/
/*add &webout_options*/				
	file &js_path &webout_options;
/*I18N-scnhuh-20080418-1555*/
	put 'var TREE_ITEMS = [';
	put '['''@;
	put "&cat" @;
	put "', 'http://&_SRVNAME:&_SRVPORT/SASStoredProcess/do?"@;
	put '&_program='@;
	put "&update_parameter"@;
	put ''', ';
run;

%let level=0;
%tree_cr(category=&cat,level=&level);

data _null_;
/*I18N-scnhuh-20080418-1555*/
/*add &webout_options*/				
	file &js_path &webout_options mod LRECL=500;
/*I18N-scnhuh-20080418-1555*/
	put ']';
	put '];';
run;


data _NULL_;
	file _webout &webout_options;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"';
	put '"http://www.w3.org/TR/html4/loose.dtd">';
	put '<html>';
	put '<head>';
	put '<meta name="description" content="Free Cross Browser Javascript DHTML Tree Menu Navigation"> ';
	put '<meta name="keywords" content="JavaScript tree menu, DHTML tree menu, client side tree menu,' @;
	put 'table of contents, site map, web authoring, scripting, freeware, download, shareware,' @;
	put 'free software, DHTML, Free Tree Menu, site, navigation, html, web, netscape,explorer,'@;
	put 'IE, opera, DOM, control, cross browser, support, frames, target, download">';
	put '<meta name="robots" content="index,follow"> ';
	put '<title>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_tree.title.1, noquote))"@;
	put'</title>';
	put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css">';
	put '<link href="/SASBISConfiguration/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<style type="text/css">';
	put '<!--';
	put '.style2 {color: #990000}';
	put 'body {';
	put '	background-color: #FAF8ED;';
	put '}';
	put '-->';
	put '</style>';
	put '</head> ';
	put '<body bottommargin="0" topmargin="0" leftmargin="0" rightmargin="0" marginheight="0" marginwidth="0" bgcolor="white"> ';
	put '<script language="JavaScript" src="/SASBISConfiguration/script/tree.js"></script> ';
	put '<script language="JavaScript" src="/SASBISConfiguration/script/tree_items.js"></script> ';
	put '<script language="JavaScript" src="/SASBISConfiguration/script/tree_tpl.js"></script> ';

	put '<table cellpadding="5" cellspacing="0" cellpadding="10" border="0" width="100%"> ';
	put '<tr> ';
	put '	<td class="LabelFont"> ';
	put '	<script language="JavaScript"> ';
	put '	<!--// ';
	put '		new tree (TREE_ITEMS,TREE_TPL); ';
	put '	//--> ';
	put '	</script> ';
	put '	</td> ';
	put '</tr> ';
	put '</table> ';
	put '</body> ';
	put '</html> ';
run;
