
/********************************************************************************************
       Module:  Model Attribute by Event

     Function:  This stored process generates the HTML report displaying the
				weight of evidence table for the Variable selected in the calling stored process
				stored process (model_in_var).

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	Stored Process model_attrib_event
				
        Calls:  Calls  the following Stored Process
					1. Reporting	  	 (when Reporting link is clicked)
					2. mon_model_inputs	 (when Monitoring Model Inputs link is clicked)
					3. model_in_var    	 (when Select Variable link is clicked)

				Calls the following Macros
					1. generate_feed_mip macro for obtaining the required feed.
					2. CreateTable macro for creating the cumulative and Proportion 
					   table with the out table of generate_feed_mip macro.
					3. graph_line_bar macro for generating the graph.
					4. draw_table macro for drawing the output table.

Datasets used:  No input datasets required for processing of the stored process
 
        Logic:  1. All inputs to the stored process are accepted as global parameters.
				2. Standards
					a. Naming of data set which are input to and output from macro using
						<prod_type_code><model_key><time_key>Extension as per requirement
						i.e.		MTG           100          1036     pool
							as MTG1001036pool.
					b. Setting the default values for where_measure, where_feed and
						feed_for. where_feed and feed_for is passed as parameter(infilter
						& feed_for) to the generate_feed_mip macro, and where_measure is 
						passed as parameter to the feed_measure_mip macro.
					c.	Naming the graphs using timestamp and two letters for  
						identifying the graph.
				3. Call the macro generate_feed_mip for obtaining the required feed.
				4. calls the CreateTable macro for creating the cumulative and Proportion 
					   table with the out table of generate_feed_mip macro.
				5. Call the  graph_line_bar macro for generating the graph.
			    6. draw_table macro for drawing the output table.
			    7. Generate the HTML using streaming webout.
					a. Provide hidden textboxes for all output parameters so that the 
						values are easily submitted to the next page. 
					b. Provide javascript functions for the links on top of the page
						and for edit and reset buttons.
				
   Parameters:
			INPUT 
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals,
										PD Ongoing, LGD, CCF)
		        model_measure_type	:   Model type code (MIP) for referring the models
										for model input reports in measure_dim.
				statistic           :   Measure name(Information Value and Other Statistics)
				model				:	The selected model (e.g., PD MODEL 1).		
				model_key			:	The surrogate key for the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				variable			:	The selected variable (e.g., Variable 1)
				variable_key		: 	The surrogate key for selected variable (e.g., 1)
                table				: 	The table which is to be ploted, the name for that data
										set is given.
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.
				
			OUTPUT
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals,
										PD Ongoing, LGD, CCF)
		        model_measure_type	:   Model type code (MIP) for referring the models
										for model input reports in measure_dim.
				statistic           :   Measure name(Information Value and Other Statistics)
				model				:	The selected model (e.g. PD MODEL 1).		
				model_key			:	The surrogate key for the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				variable			:	The selected variable (Eg. Variable 1)
				variable_key		: 	The surrogate key for selected variable (Eg. 1)
                table				: 	The table which is to be ploted, the name for that data
										set is given.
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.
********************************************************************************************/
/* Global variable declaration */
goptions reset=all;
options nomprint;

/* Global variable declaration */
%global ds_nme prod_type_desc prod_type_code model_type_code model_measure_type model model_key
		period time_key variable variable_key statistic table prg_name 
		outcome_period elapsed_time model_type_desc  variable;
goptions reset=all;
/**********Initially default value of table is taken for cumulative plot***************/
data _null_;
	if "&table"="" then call symput('table','Attrib_cumm');
run;

/* Trimming extra spaces from all the input parameters*/
option mlogic mprint;
%macro macro_val_check;
%if "&prod_type_desc" ne "" %then
%let prod_type_desc=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&prod_type_desc))))));
%if "&prod_type_code" ne "" %then
%let prod_type_code=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code))));
%if "&model_type_code" ne "" %then
%let model_type_code=%sysfunc(ktrim(%sysfunc(kleft(&model_type_code))));
%if "&model_measure_type" ne "" %then
%let model_measure_type=%sysfunc(ktrim(%sysfunc(kleft(&model_measure_type))));
%if "&model" ne "" %then
%let model=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&model))))));
%if "&model_key" ne "" %then
%let model_key=%sysfunc(ktrim(%sysfunc(kleft(&model_key))));
%if "&period" ne "" %then
%let period=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&period))))));
%if "&time_key" ne "" %then
%let time_key=%sysfunc(ktrim(%sysfunc(kleft(&time_key))));
%if "&variable" ne "" %then
%let variable=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&variable))))));
%if "&variable_key" ne "" %then
%let variable_key=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&variable_key))))));
%if "&statistic" ne "" %then
%let statistic=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&statistic))))));
%if "&prg_name" ne "" %then
%let prg_name=%str(%sysfunc(ktrim(%sysfunc(kleft(&prg_name)))));
%if "&variable" ne "" %then
%let variable=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&variable))))));
%if "&model_type_desc" ne "" %then
%let model_type_desc=%str(%sysfunc(ktrim(%sysfunc(kleft(&model_type_desc)))));
%if "&outcome_period" ne "" %then
%let outcome_period=%str(%sysfunc(ktrim(%sysfunc(kleft(&outcome_period)))));
%if "&elapsed_time" ne "" %then
%let elapsed_time=%str(%sysfunc(ktrim(%sysfunc(kleft(&elapsed_time)))));
/*************/
%mend;
%macro_val_check
%let ds_nme=%sysfunc(ktrim(%sysfunc(kleft(&table))));

%let out_lib=;
%debug_lib_path;

%let out_mip=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&model_key.&time_key.pool))));
%let out_acc_mip=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&model_key.&time_key.account))));
%let in_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&model_key.&time_key.sei_in))));
%let gname=;
%let data_set=%sysfunc(ktrim(%sysfunc(kleft(&table))));

/* Creation of where_clauses */
%let where_feed=;
%let where_measure=;
data _null_;
call symput('where_measure','where ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD="&prod_type_code" and ANALYTICAL_MODEL_DIM.MODEL_SK=&model_key and SCORE_CARD_VARIABLE_FACT.VARIABLE_SK=&variable_key');

/* Setting the feed_for depending on the analytical model type.
	This is passed as parameter to generate_feed_mip */
	if ktrim(kleft("&model_type_code"))=&PD_APP_MODEL then
    	call symput('feed_for',"&FEED_FOR_APPLPD");
	else if ktrim(kleft("&model_type_code"))=&PD_ONG_MODEL then
	    call symput('feed_for',"&FEED_FOR_PD");
	else if ktrim(kleft("&model_type_code"))=&LGD_MODEL then
        call symput('feed_for',"&FEED_FOR_LGD");
	else if ktrim(kleft("&model_type_code"))=&LGD_APP_MODEL then
        call symput('feed_for',"&FEED_FOR_APPLLGD");
	else if ktrim(kleft("&model_type_code"))=&CCF_MODEL then
        call symput('feed_for',"&FEED_FOR_CCF");

/* Setting the where clause for the feed_measure_mip macro */
	call symput('where_measure','where ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD="&prod_type_code" and ANALYTICAL_MODEL_DIM.MODEL_SK=&model_key and SCORE_CARD_VARIABLE_FACT.VARIABLE_SK=&variable_key');

/* Setting the where clause for the generate_feed_mip macro */
	call symput('where_feed','1');
run;
/******************/

/* All graph options */
    /* Setting the graph name */
    /* Calling graph_options macro */
data _NULL_;
	name=put(time(),mmss8.1);
	name1=kscan(name,1,":.");
	name2=kscan(name,2,":.");
	name3=kscan(name,3,":.");
	name4="me"||ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
	call symput('gname1',name4);
run;
%let name2=%sysfunc(ktrim(%sysfunc(kleft(&gname1))));

data _null_;
file _webout&webout_options;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"';
	put '"http://www.w3.org/TR/html4/loose.dtd">';
	put '<html>';
	put '<head>';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8">';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'; 
	put "&statistic" @;
	put'</title>'@;
	put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css">';
	put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css">';
	put '<style type="text/css">';
	put '<!--';
	put '.style2 {font-size: small}';
	put '-->';
	put '</style>';
	put '<script language="JavaScript" type="text/JavaScript">';
	/*Checking for missing global parameters*/
		if "&prod_type_desc" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_prod_type_desc.1, noquote))"@;
		put'");';
	end;
	else if "&prod_type_code" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_prod_type_desc.1, noquote))"@;
		put '");';
	end;
	else if "&model_type_code" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_model_type_cd.1, noquote))"@;
		put '");';
	end;
	else if "&sel_model" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_select_model.1, noquote))"@;
		put '");';
	end;
	else if "&sel_model_key" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_select_model_key.1, noquote))"@;
		put '");';
	end;
	else if "&period" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_period.1, noquote))"@;
		put '");';
	end;
	else if "&time_key" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_time_key.1, noquote))"@;
		put '");';
	end;

/* Calls the Reporting stored process if link is clicked */
	put 'function Link1() {';
		put "form1._program.value=&CS_REPORTING";
		put 'form1.submit()';
	put '}';

/* Calls the mon_model_inputs stored process if link is clicked */
	put 'function Link2() {';
		put "form1._program.value=&CS_MON_MDL_IP";
		put 'form1.submit()';
	put '}';

/* Calls the model_in_var stored process if link is clicked */
	put 'function Link3() {';
		put "form1._program.value=&CS_VAR_LVL_DB";
		put 'form1.submit()';
	put '}';
/*********************/

	/*Function savepage() for saving the page to disk */
	%savepage;
	/*********savepage() ends here*************/

	/*Function printpage() for printing the page to a printer or to a pdf file*/
	%printpage;
	/*********printpage() ends here*************/

	put 'function assign_to_dist(val){';
		put 'form1.table.value=val';
		put 'form1.submit()';
	put '}';

	put '</script>';
	put '</head>';

	put '<body><form name="form1" method="post" action="/SASStoredProcess/do">';
	put '<input type="hidden" name="_program" VALUE="'@;
	put "&prg_name"@;
	put '">';

/* Hidden textboxes to hold the values for the program name and the output paremeters 
	to pass the values to the next Stored Process called */
	prod_type_desc=symget("prod_type_desc");
	put '<input type="hidden" name="prod_type_desc" value="' @;
	put prod_type_desc;
	put '">';
	prod_type_code=symget("prod_type_code");
	put '<input type="hidden" name="prod_type_code" value="' @;
	put prod_type_code;
	put '">';
	model_type_code=symget("model_type_code");
	put '<input type="hidden" name="model_type_code" value="' @;
	put model_type_code;
	put '">';
	model_measure_type=symget("model_measure_type");
	put '<input type="hidden" name="model_measure_type" value="' @;
	put model_measure_type;
	put '">';
	model=symget("model");
	put '<input type="hidden" name="model" value="' @;
	put model;
	put '">';
	model_key=symget("model_key");
	put '<input type="hidden" name="model_key" value="' @;
	put model_key;
	put '">';
	period=symget("period");
	put '<input type="hidden" name="period" value="' @;
	put period;
	put '">';
	time_key=symget("time_key");
	put '<input type="hidden" name="time_key" value="' @;
	put time_key;
	put '">';
	variable=symget("variable");
	put '<input type="hidden" name="variable" value="' @;
	put variable;
	put '">';
	variable_key=symget("variable_key");
	put '<input type="hidden" name="variable_key" value="' @;
	put variable_key;
	put '">';
	statistic=symget("statistic");
	put '<input type="hidden" name="statistic" value="' @;
	put statistic;
	put '">';
	table=symget("table");
	put '<input type="hidden" name="table" value="' @;
	put table;
	put '">';

	prg_name=symget("prg_name");
	put '<input type="hidden" name="prg_name" value="' @;
	put prg_name;
	put '">';

	outcome_period=symget("outcome_period");
	put '<input type="hidden" name="outcome_period" value="' @;
	put outcome_period;
	put '">'; 
	elapsed_time=symget("elapsed_time");
	put '<input type="hidden" name="elapsed_time" value="' @;
	put elapsed_time;
	put '">';

	model_type_desc=symget("model_type_desc");
	put '<input type="hidden" name="model_type_desc" value="' @;
	put model_type_desc;
	put '">';
	variable=symget("variable");
	put '<input type="hidden" name="variable" value="' @;
	put variable;
	put '">';
run;

/*Calls the macro generate_feed_mip for obtaining the required feed by passing
	the following parameters
	1. in_filter		: Where clause
	2. out_lib_nm		: Library name where the output feed will be created. 
	3. out_table_nm_pool: The table name for pool level feed
	4. out_table_nm_acct: The table name for account/application level feed
	5. feed_for			: Possible values are PD, LGD, CCF, APPLPD, APPLLGD. This macro
							parameter decides whether estimated pd/lgd/ccf has to calculated 
							at account level or application level 
	6. var				: variable_key that is passed from the calling stored process
							(model_in_var)
	7. model_time_key  	: Contains the concatenated values of model and time in the
							format _<model_sk>_<time_sk>. This is used to identify
							which fact table should be considered while generating 
							the feed.
	8. product_type_code	: This is the selected product type code (E.G. MTG, LON).
*/
option mprint nomlogic;
%let model_time=_%sysfunc(ktrim(%sysfunc(kleft(&model_key.))))_%sysfunc(ktrim(%sysfunc(kleft(&time_key.))));
%generate_feed_mip(in_filter=&where_feed, out_lib_nm=&out_lib, out_table_nm_pool=&out_mip, 
					out_table_nm_acct=&out_acc_mip, feed_for=&feed_for, var=&variable_key,
					model_time_key=&model_time, product_type_code=&prod_type_code);

%let log_name=;
data _NULL_;
	call symput('log_name',"&CS_DEBUG_PATH./&out_mip."||".log");
run;

%debug_log_file(log_file_nm=&log_name);

/*%let out_acc_mip=Test_out_account;*/
%macro createtable(ds=, attrib_nm=, col_id=,col_act=, col_dev=,label=,act_prop=,dev_prop=,cl_nm=,out_lib1=);
%let sqlstr=; 
%let token=;

data _null_;
	call symput ('b',count("&attrib_nm","#"));	
run;

%let end=%eval(&b+1);

%do i = 1 %to &end;

	%let token =  %sysfunc(kscan(&attrib_nm,&i,#));
	data &out_lib.._&token;
		set &ds;
		where &cl_nm=&token;
	run;

	proc sort data=&out_lib.._&token out=&out_lib.._&token._1;
		by &col_id;
	quit;

	proc transpose data=&out_lib.._&token._1 
		out=&out_lib.._&token._3;
		id  &cl_nm;
		by  &col_id;
		run;
	quit;

	data &out_lib.._&token._4;
		set &out_lib.._&token._3;
		if kupcase(_NAME_)=kupcase("&col_act") or kupcase(_NAME_)=kupcase("&col_dev")	;
	

	run;

   data &out_lib.._&token._5;
		 set &out_lib.._&token._3;
	if 	kupcase(_NAME_)=kupcase("&act_prop") or kupcase(_NAME_)=kupcase("&dev_prop");

	run;

%end;
data &out_lib..final_1;
	set &out_lib.._&token._5;
run;
data &out_lib..final;
	set &out_lib.._&token._4;
run;

%do for_merge_cnt = 1 %to &end;
	%let token =%sysfunc(kscan(&attrib_nm,&for_merge_cnt,#));
	%put _&token;
	data &out_lib..final;
	   merge &out_lib..final &out_lib.._&token._4;
	   by &col_id;
	run;
		data &out_lib..final_1;
	   merge &out_lib..final_1 &out_lib.._&token._5;
	   by &col_id;
	run;

%end;

%let datstep=%str(data &out_lib..attrib; merge );
%let datstep1=%str(data &out_lib..attrib_propt; merge );

%do i = 1 %to 2;
	%if &i=1 %then %do;
		%let col=NO_OF_ACC_ACT1;
		%let col1=Actual;
		%let suffix=act;
	%end;
	%else %do;
		%let col1=development;
		%let col=NO_OF_ACC_DEV1;
		%let suffix=dev;
	%end;
	%let sqlstr=create table &out_lib..graph_&suffix as select &col_id, ;
	%let sqlstr_prop=create table &out_lib..graphprop_&suffix as select &col_id, ;

	%do for_merge_cnt = 1 %to &end;
		%let token =%sysfunc(kscan(&attrib_nm,&for_merge_cnt,#));
		%put count=&for_merge_cnt b=&end;

		%if &for_merge_cnt ne &end %then %do;
			%let sqlstr=%str(&sqlstr)%str( )%str(_&token as _&token.&suffix,);
			%let sqlstr_prop=%str(&sqlstr_prop)%str( )%str(_&token as _&token.&suffix,);
		%end;

		%else %do;
			%let sqlstr=%str(&sqlstr)%str( )%str(_&token as _&token.&suffix from &out_lib..final where kupcase(_NAME_)=kupcase("&col"));
			%let sqlstr_prop=%str(&sqlstr_prop)%str( )%str(_&token as _&token.&suffix from &out_lib..final_1 where kupcase(_NAME_)=kupcase("&col1"));
		%end;
	%end;

	%let sqlstr = %str(proc sql;) &sqlstr%str(;) %str(quit;);
	%let sqlstr_prop= %str(proc sql;) &sqlstr_prop%str(;) %str(quit;);

	&sqlstr;
	&sqlstr_prop;

	%let datstep=%sysfunc(ktrim(%sysfunc(kleft(&datstep)))) %str(&out_lib..graph_&suffix);
	%let datstep1=%sysfunc(ktrim(%sysfunc(kleft(&datstep1)))) %str(&out_lib..graphprop_&suffix);

%end;

%let datstep=%sysfunc(ktrim(%sysfunc(kleft(&datstep))))%str(;) %str(by &col_id;) %str(run;);
%let datstep1=%sysfunc(ktrim(%sysfunc(kleft(&datstep1))))%str(;) %str(by &col_id;) %str(run;);	
	
&datstep;
&datstep1;



/* Cumulative  & Proportion Tables */
%let cumm1=;
%let cumm2=;
%let prop1=;
%do for_cummulative_cnt= 1 %to &end;
	%let token =%sysfunc(kscan(&attrib_nm,&for_cummulative_cnt,#));
	%let label_cl=%sysfunc(kscan(&label,&for_cummulative_cnt,#));

	%do i=1 %to 2;
		%if &i=1 %then %do;
			%let col=&col_act;
			%let suffix=act;
			 /*I18N-scnjih-20080424-1453*/
			/*%let lbl=Actual;*/
			%let lbl=%sysfunc(sasmsg(smd_ds.bismsg,model_attrib_event.sas.5, noquote));
			/*I18N-scnjih-20080424-1453*/
		%end;
		%else %do;
			%let col=&col_dev;
			%let suffix=dev;
			 /*I18N-scnjih-20080424-1453*/
				/*%let lbl=Development;*/
			%let lbl=%sysfunc(sasmsg(smd_ds.bismsg,model_attrib_event.sas.6, noquote));
			/*I18N-scnjih-20080424-1453*/
		%end;
/*	 	%let cumm1=%str(&cumm1) %str(_&token.&suffix._cum=_&token.&suffix;);*/
		%let cumm1=%str(&cumm1) %str(label _&token.&suffix=&label_cl.(&lbl););
		%let cumm2=%str(&cumm2) %str(format )%str(_&token.&suffix. percent6.2 ;);
		%let cumm2=%str(&cumm2) %str(label _&token.&suffix.=&label_cl.(&lbl););
/*		%let cumm1=%str(&cumm1) %str(drop _&token.&suffix;);*/
		%let prop1=%str(&prop1) %str(_&token.&suffix.1=_&token.&suffix.;);
 		%let prop1=%str(&prop1) %str(format )%str(_&token.&suffix.1 percent6.2 ;);
		%let prop1=%str(&prop1) %str(label _&token.&suffix.1=&label_cl(&lbl););
		%let prop1=%str(&prop1) %str(drop _&token.&suffix.;);
	%end;
%end;
%let cumm2=%str(&cumm2) ;
%let sqlstr_cum = %str(data &out_lib..attrib_cumm1; set &out_lib..attrib end=last;) &cumm1 %str( run;);
%let sqlstr_prop = %str(data &out_lib..attrib_prop; set &out_lib..attrib_propt;) &prop1 %str( run;);
%let sqlstr_for =%str(data &out_lib..attrib_cumm;  set &out_lib..attrib ; )&cumm2 %str( run;);
&sqlstr_cum;	/****Here we create a data step where we do cumulating**/ 
&sqlstr_prop;  /** and proportion for the development and actual account in to **/
&sqlstr_for;				/** variable "sqlstr_cum" and "sqlstr_prop" ****/


%mend;

proc sql noprint;
	select distinct(VARIABLE_GROUP_NO)
	into :attrib_nm  separated by "#" from &out_lib..&out_acc_mip ;
quit;

proc sql noprint;
	select distinct(ATTR_NAME)
	into :attrib_lbl  separated by "#" from &out_lib..&out_acc_mip ;
quit;
data &out_lib..&out_acc_mip.1;
set &out_lib..&out_acc_mip;
run;

/*******relacing missing values by zero (0)************/
proc sql noprint;
	update  &out_lib..&out_acc_mip.1 set NO_OF_EVENTS_ACTUAL=0
	where NO_OF_EVENTS_ACTUAL is null  ;
	update &out_lib..&out_acc_mip.1  set  NO_OF_ACC_ACTUAL=0 
	where   NO_OF_ACC_ACTUAL is null;
quit;
/********************/

proc sql noprint ;
create table &out_lib..temp as select  	Max(FROM_SCORE) as FROM_SCORE ,
								sum(NO_OF_EVENTS_ACTUAL) as sum_Act,
								sum(NO_OF_EVENTS_DEV) as sum_Dev
from &out_lib..&out_acc_mip.1
group by FROM_SCORE;
quit;


proc sql noprint;
create table &out_lib..temp1 as select*, o.NO_OF_EVENTS_ACTUAL/t.sum_Act as Actual ,
							o.NO_OF_EVENTS_DEV/t.sum_Dev as development
from &out_lib..temp t, &out_lib..&out_acc_mip.1 o
where t.FROM_SCORE=o.FROM_SCORE;
quit;

/*******relacing missing values by zero (0)************/
proc sql noprint;
	update  &out_lib..temp1 set Actual=0
	where Actual is null  ;
	update &out_lib..temp1  set  development=0 
	where   development is null;
quit;
/********************/

data &out_lib..temp2;
set &out_lib..temp1;
drop sum_Act sum_Dev;
run;

proc sort data=&out_lib..temp2 out=&out_lib..temp2;
	by FROM_SCORE;
run;

data &out_lib..temp;
	set &out_lib..temp2;
	by FROM_SCORE;

if first.FROM_SCORE then  do;
		NO_OF_ACC_DEV1=0;
		NO_OF_ACC_ACT1=0;
end;   
	NO_OF_ACC_ACT1+Actual;
	NO_OF_ACC_DEV1+development;

run;

/****Macro create table parameter Passed
						1.ds=it is the dataset which is generated from 
							  macro generate_feed_mip.
					    2.atb_nm=This is a variable which contains the name of attribute
								 in the dataset which is out table of feed
					    3.col_id=Required for transposing the values inside the macro
						4.col_act=This is actual value colom of the dataset passed
					    5.col_dev=This is development value colom of the dataset passed 
					      **********/
%createtable(ds=&out_lib..temp, attrib_nm=&attrib_nm, col_id=%str(FROM_SCORE), 
col_act=%str(NO_OF_ACC_ACT1), col_dev=%str(NO_OF_ACC_DEV1),label=&attrib_lbl,
act_prop=%str(Actual),dev_prop=%str(development),cl_nm=%str(VARIABLE_GROUP_NO),out_lib1=&out_lib.);

%let name_html=;
/* Generates the dataset with measure names for the given model_type_cd and the called
	program name(the current stored process info_val)
	from the measure_dim dataset to be passed as a parameter to the feed_measure_mip macro*/
proc sql;
	create table &out_lib..&in_stat_ot as
	select measure_nm, help_file_nm, monotonic() as tot_count 
	from dim.measure_dim
	where kupcase(program_nm)=kupcase("&prg_name")
			and kupcase(model_type_cd)=kupcase("&model_measure_type");
/*	order by measure_nm;*/
quit;

data _null_;
	set &out_lib..&in_stat_ot;
	call symput('name_html',help_file_nm);
run;

proc sql noprint;
	create table &out_lib..atrrib_prop_tbl as
	select *
	from &out_lib..&out_acc_mip.1  left outer join &out_lib..Attrib_cumm 
	on (Attrib_cumm.FROM_SCORE=&out_acc_mip.1.FROM_SCORE);
quit;


/***********Selecting values for from score and score range******************/
Proc sql noprint;
	create table merge_range as 
	select Max(FROM_SCORE) as FROM_SCORE, Max(SCORE_RANGE) as SCORE_RANGE
	from &out_lib..&out_acc_mip.1
	group by FROM_SCORE;
quit; 

/***********To show the score range and giving label to score range******************/
data &out_lib..attrib_cumm;
	merge  merge_range &out_lib..attrib_cumm;
	by FROM_SCORE;
	 /*I18N-scnjih-20080423-1714*/
	/*label SCORE_RANGE='Score Range';*/
	/*label FROM_SCORE='From Score';*/
		label SCORE_RANGE="%sysfunc( sasmsg(smd_ds.bismsg,model_attrib_event.sas.1, noquote))";
		label FROM_SCORE="%sysfunc( sasmsg(smd_ds.bismsg,model_attrib_event.sas.2, noquote))";
	 /*I18N-scnjih-20080423-1714*/
run;

/***********To show the score range and giving label to score range******************/
data  &out_lib..attrib_prop;
	merge  merge_range &out_lib..attrib_prop;
	by FROM_SCORE;
		 /*I18N-scnjih-20080423-1714*/
	/*label SCORE_RANGE='Score Range';*/
	/*label FROM_SCORE='From Score';*/
		label SCORE_RANGE="%sysfunc( sasmsg(smd_ds.bismsg,model_attrib_event.sas.3, noquote))";
		label FROM_SCORE="%sysfunc( sasmsg(smd_ds.bismsg,model_attrib_event.sas.4, noquote))";
		 /*I18N-scnjih-20080423-1714*/
run;

proc sql noprint;
	select name 
	into :col_name separated by ","
	from sashelp.vcolumn
	where libname=kUPCASE("&out_lib.") and memname=kUPCASE("&ds_nme"); 
quit;

%let cl_names=%nrquote(&col_name);
%let cl_labels=%str();



%macro graph_line_bar(ds=,sub_grp=,V_bar=,line=,sumvar=,grup_nm=);

/*****************************replace code*****************************************************************/
data &out_lib..Temp_test1;
set &out_lib..temp;
	keep FROM_SCORE ATTR_NAME NO_OF_ACC_DEV1 Actual VARIABLE_GROUP_NO;
run;


data &out_lib..Temp_test3 ;
	set &out_lib..Temp_test1;
	NO_OF_ACC_DEV2=NO_OF_ACC_DEV1;
	keep  FROM_SCORE ATTR_NAME NO_OF_ACC_DEV2 VARIABLE_GROUP_NO;
run;

proc sort data=&out_lib..Temp_test3;
	by ATTR_NAME ;
run;
data &out_lib..Temp_test2;
	set &out_lib..Temp_test3;
	retain NO_OF_ACC_DEV2 0;
	by ATTR_NAME ;
	if first.ATTR_NAME then	NO_OF_ACC_DEV2=0;
	NO_OF_ACC_DEV2+NO_OF_ACC_DEV1;	
run;




proc sort  data=&out_lib..Temp_test2 out=&out_lib..Temp_test3;
	by   ATTR_NAME  ;
run;

data &out_lib..out_account1;
	set &out_lib..Temp_test3;
run;

data &out_lib..Temp_test4;
	set &out_lib..Temp_test1;
	keep FROM_SCORE ATTR_NAME Actual;
run;

proc sort  data=&out_lib..Temp_test4 out=&out_lib..Temp_test5;
	by   ATTR_NAME  FROM_SCORE;
run;

/*****************************replace code*****************************************************************/

proc sql noprint ;/******We take minimum value of from score to get the plot drawn from initial point**/ 
	select min(FROM_SCORE) into :first_obs
	from &out_lib..out_account1;
quit;

proc sql noprint;
	select max(VARIABLE_GROUP_NO) into: max_no
	from &out_lib..Temp_test3;
quit;

proc sql noprint;
	select distinct(ATTR_NAME)
	into :atb_lbl  separated by "#" from &ds;
quit;



%let color=;/*********Here we create dynamic color variable selection making them
								global variabels**********/
%do i=1 %to &max_no ;
        %let color=%str(&color)%str(color_symbol&i.);
%end;

%global &color;
%graph_options;



goptions xpixels= 1000 ypixels=700 htitle=5 htext=2;

%let strcol=;
%let footnote=;
%let pattern=;
%let color=;
%do i=1 %to &max_no ;
	%let atb_lbl1 =%scan(&atb_lbl,&i,#);
    %let strcol=%str(&strcol)%str( if  VARIABLE_GROUP_NO="&i")
		 %sysfunc(ktrim(%sysfunc(kleft(then color=))))%str("&&color_symbol&i")%str(;);
		%let footnote=%str(&footnote)%str(footnote)%eval(&i+1)%str(   c=)%str("&&color_symbol&i")%str( ___ )%str(c=black  )%str(&atb_lbl1 )%str(;);
%end; 

	 /*I18N-scnjih-20080425-1331*/
/*%let footnote=%str(footnote1  Legend:  ;)%str(&footnote)%str(;);*/
/*%let footnote3=%str("Bar represents Actual samples and  Line represents Development samples")%str(;);*/

%let footnote=%str(footnote1 )%sysfunc(sasmsg(smd_ds.bismsg,model_attrib_event.sas.8, noquote))%str(:  ;)%str(&footnote)%str(;);
%let footnote3=%sysfunc(sasmsg(smd_ds.bismsg,model_attrib_event.sas.9, noquote))%str(;);
	 /*I18N-scnjih-20080425-1331*/
proc sql noprint;
	create table &out_lib..anno1 as 
	select * ,1 as fakeby
	from &out_lib..out_account1 order by  ATTR_NAME ,FROM_SCORE;
quit;

data &out_lib..anno1; 
	length function color  $8 text $30;
	retain xsys ysys '2' color 'black' when 'a' size 4 ;
	set &out_lib..anno1 end=last; by fakeby;

&strcol;
	
if FROM_SCORE=&first_obs   then function='move'; else function='draw';

	midpoint=FROM_SCORE; y=NO_OF_ACC_DEV2 ; output;
	function='symbol';
	text='dot';size=.5; 
	midpoint=FROM_SCORE; y=NO_OF_ACC_DEV2; output;
run;

&footnote;/****This select values for  the colors and labels for footnote 
 							come from above do loop*********/
 footnote%eval(&max_no+3) &footnote3;

 ODS LISTING CLOSE;
 axis1  minor=none label=(angle=90)label=(a=90 "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.graph_axis1.1, noquote))");
 axis2  label=( "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.graph_axis2.1, noquote))");
 axis3   minor=none label=none ;


%do i=1 %to &max_no ;
	%let pattern=%str(pattern&i)%str(  v=s c=)%str(&&color_symbol&i)%str(;);
	&pattern;
%end; 

 proc gchart data=&out_lib..Temp_test4 anno=&out_lib..anno1;
  vbar FROM_SCORE		
	  	/  axis=axis1 maxis=axis2 coutline=black 
     autoref clipref cref=white width=5 space=6
     sumvar=Actual discrete
     nolegend
     des="" name="&name2"
     subgroup=ATTR_NAME;      
 	run;
 quit;



 ODS HTML CLOSE;
 ODS LISTING;
%mend;

/****Macro graph_line_bar parameter Passed
				1.Input Dataset which is ouput of feed
				2.Subgroup the values for which we want to do group ( for e.g. Attribute  name).
				3.Vertical bar which we see on graph.It is values for y axis
				4.Line which is to cumulated and to be drawn over bar.
				5.Sumvar values to be stack for the vertical bar graph.
				6.Group number to be values Corresponding to score range.
					                            *******************************************/

%graph_line_bar(ds=&out_lib..&out_acc_mip.1,sub_grp=ATTR_NAME,V_bar=FROM_SCORE,line=No_of_Acc_Dev,sumvar=NO_OF_ACC_ACTUAL,grup_nm=VARIABLE_GROUP_NO );

%debug_log_web;

%let view_feed=&out_mip..html;
data _null_;
	file _webout&webout_options;

	name_html=symget("name_html");
	put'<script>';
		/**************Help File *********************/
	%helpfile(filename=&name_html);

		/*************feed Table*********************/
	put 'function feed_table(){';
		put'window.open("/SASCSReports/'@; 
		put "&view_feed"@; 
	put '")};';
			
		/*********************************************/
	put'</script>';
	
	put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';
	put '<tr>';
	put '<td align="left">';
	put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0">';
	put '<tr>';
	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';
	put '<td><span class="BreadCrumb">'@;
	put '<a href="javascript:Link1()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.linnk_reporting.1, noquote))"@;
	put '</a> &gt; ';
	put '<a href="javascript:Link2()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.linnk_mon_model_input.1, noquote))"@;
	put '</a> &gt; ';
	put '<a href="javascript:Link3()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.linnk_sel_var.1, noquote))"@;
	put '</a> &gt;'@;
	put '</span><span class="BreadCrumb">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.linnk_model_attrib_event.1, noquote))"@;
	put '</span></td> ';
	/* To display SAS credit scoring as heading */
	put '<td width="215"><div align="right"><img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td>';
	put '</tr>';
	/* Heading ends */
	put '</table><H2 align="left"><table width="100%"  border="0" cellspacing="0" cellpadding="0"><tr><td>';
	put "&statistic" @;
	put '</td>';
	if kupcase(&print) eq 'Y' then do;
		put '<td width=65><div align="center"><span class="LabelFont">';
		put '<a href="javascript:printpage()">';
		put '<img src="/SASCSReports/images/Print.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_print.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&save) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:enregistre()">';
		put '<img src="/SASCSReports/images/SaveFile.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_save.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&help) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:Info()">';
		put '<img src="/SASCSReports/images/Info.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_help.1, noquote))"@;
		put '</div></td>';
	end;
	put '</tr></table></H2>';
	put '</td></tr>';

	put '<tr>';
	put '<td align="left">';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_model_type.1, noquote))"@;
	put "&model_type_desc"@;
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_product_type.1, noquote))"@;
	put "&prod_type_desc";
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_period.1, noquote))"@;
/*I18N-scnhuh-20080427-1455*/	
/* del one line, add two lines. For displaying in NLS format */	
/*	put "&period" @;*/
		Period_WEBUI=put(input("&period",&CS_TIME_PER_FMT.),&NLDATE_FMT.);
		put Period_WEBUI @;
/*I18N-scnhuh-20080427-1455*/		
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_model.1, noquote))"@;
	put "&model";
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_variable.1, noquote))"@;
	put "&variable";
	put '</p> ';
	/* Target period and elapsed time*/
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_outcome_period.1, noquote))"@;
	put "&outcome_period" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_months.1, noquote))"@;
	put "&elapsed_time" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_month_elapsed.1, noquote))"@;
	put '</p>';

	/* Number of months of Historic data */
	if kupcase("&model_type_code") eq kupcase(&PD_APP_MODEL.) then do;
		put '<p class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pd_stored_proc_hist.label_historic_data.1, noquote))"@;
		if kupcase("&prod_type_code") eq kupcase(&MTG_PRD_TYPE.) then do;
			put "&PDA_MTG_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&LON_PRD_TYPE.) then do;
			put "&PDA_LON_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&COR_PRD_TYPE.) then do;
			put "&PDA_COR_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&CCD_PRD_TYPE.) then do;
			put "&PDA_CCD_HIST" @;
		end;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pd_stored_proc_month.label_months.1, noquote))"@;
		put '</p>';
	end;

	put '<table width="100%"   border="0" cellspacing="0" cellpadding="0">';
	put '<p class="LabelFont">&nbsp;</p><fieldset>';
	put '<legend><span class="style2"></span></legend>';
			/*****HERE YOU CAN PUT NAME FOR RADIO BUTTON********/						
	put '<p class="style2">';
	put '<input name="radiobutton" type="radio" value="Attrib_prop" onClick="javascript:assign_to_dist(this.value)"'@;

	if "&table" eq "Attrib_prop" then do;
		put ' checked="checked"'@;
	end;

	put ' >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.radio_nm_attrib_event_score.1, noquote))"@;
	put '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; '; 
	put '<input name="radiobutton" type="radio" value="Attrib_cumm" onClick="javascript:assign_to_dist(this.value)"'@; 

	 if "&table" eq "Attrib_cumm" then do;
		put ' checked="checked"'@;
	end;

	put ' >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.radio_nm_attrib_cumm_event_score.1, noquote))"@;
	put'</p>';
	put '</fieldset>';
	put '</td>';
	put '</tr>';
	put '<p>&nbsp;&nbsp;</p>';
run;

/***Macro Draw table 
1.Input datas set
2.column name of passed data set,this is defined above as col_name where name of column 
  are provide this is  compulsary to be given by the user while defining col_names;
3.column lables of the datset ,this is defined as col_lables above this feild might be 
  empty for in that case  column lables should be there in the dataset	 	 
********************************/


%put ****************************&cl_names;
%draw_table(ds=&out_lib..&ds_nme., col_names=&cl_names., col_labels=&cl_labels.);


data _null_;
file _webout&webout_options;
	put '<p class=NoteFont>'@;
	put '<strong>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.note_note.1, noquote))"@;
	put ':</strong>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.note_note.1, noquote))"@;
	put '</p>';
	put '<tr>';
	put '<td width="50"><span class="LabelFont"></span></td>';
	put '</tr>';
	put '</table>';
	put '<tr>';
	put '<td align="left">';
	put '<p>';
	put '<H2 align="left">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.lable_attribute.1, noquote))"@;

		if  "&table" eq "Attrib_prop" then do;
			put '   ';
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.lable_event_rate_by_score.1, noquote))"@;
			put'</H2>';
		end;

		if "&table" eq "Attrib_cumm" then do;
			put '   ';
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.lable_cumm_event_rate_by_score.1, noquote))"@;
			put'</H2>';
		end;

	put '</td>';
	put '</tr>';
	put '<tr><td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';
	put '<td width="49%" valign="top"><fieldset>';
	put '<legend><span class="style2"></span></legend>';
					
	put '<p><img src="/SASCSReports/'@;
	put "&name2";
	put '.gif" width="1000" height="700"> </p>';

	put '</fieldset></td>';
	put '<td width="2%">&nbsp;</td>';
	put '<td width="49%" valign="top">';

	put '</td>';
	put '</tr>';

	put '</tr> ';
	put '</table>';
	put '</td> ';
	put '</tr> ';
	put '<tr> ';
	put '<td height="32" bgcolor="#F1EACB">&nbsp;&nbsp;';
	put '<INPUT type=button class=mmhide_btn onClick="feed_table()" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.button_view_feed.1, noquote))"@;
	put '">';
	put '</td> ';
	put '</tr> ';
	put '</table> ';
	put '</form> ';
	put '</body> ';
	put '</html> ';
run;
/*******relacing missing values by zero (0)************/
proc sql noprint;
	update  &out_lib..&out_acc_mip.1 set NO_OF_ACC_ACTUAL=0
	where NO_OF_EVENTS_ACTUAL is null  ;
	update &out_lib..&out_acc_mip.1  set  NO_OF_EVENTS_ACTUAL=0 
	where   NO_OF_EVENTS_ACTUAL is null;
	update &out_lib..&out_acc_mip.1  set  NO_OF_ACC_DEV=0 
	where   NO_OF_ACC_DEV is null;
	update &out_lib..&out_acc_mip.1  set  NO_OF_EVENTS_DEV=0 
	where   NO_OF_EVENTS_DEV is null;
quit;
/********************/
/******macro feed_table pass parameter  separated by #

		Input parameter 
		1.dt_st =Pass dataset name in string separated by #
		2.dt_nm=pass name u want to give to the table
		3.out_libout library  which is defined above
		        *****************************************************************/


 /*I18N-scnjih-20080424-1509*/
/*%let dt_nm=Attribute Feed;*/
%let dt_nm=%sysfunc(sasmsg(smd_ds.bismsg,model_attrib_event.sas.7, noquote));
 /*I18N-scnjih-20080424-1509*/
%let dt_st=&out_acc_mip.1;
%feed_table(ds=&dt_st,out_lib1=&out_lib,data_name=&dt_nm,name_html=&view_feed);

goptions reset=all;
options nomprint;
