/*********************************************************************************************
	   Module:  BNT_Traffic

	 Function:  This stored process generates an HTML report displaying the 
				traffic lighting for Binomial, Normal and Traffic lighting test.

	  Authors:  BIS Team
		 Date:  05 April 2006
		  SAS:  9.1
	Called-by:  Stored Process test_levels

		Calls:  Calls the following Stored Process    
 				1.Reporting		  	(when Reporting link is clicked)
 				2.mon_models     	(when Monitoring Models link is clicked)
 				3.select_models     (when Select Models link is clicked) 
 				4.test_levels    	(when Select Statistic link is clicked)
 				5.bnt_traffic		(when the reset button is clicked)
 				6.filtering_criteria(when the Filter/Re-Pool button is clicked)

				Calls the following Macros
 				1. graph_options macro sets all the graph options and selects the colors
     				to be used when rendering the graph.
 				2. generate_feed macro for obtaining the required feed.
 				3. feed_measure macro which makes data for the overtime graphs
 				4. binomial macro for preparing data for display.
 				5. normal macro for preparing data for display.
 				6. traffic_light macro for preparing data for display.
				7. savepage				
				8. helpfile
				9. printpage
				10. pool_technique
				11. debug macros
          
Datasets used:  No input datasets required for processing of the stored process

		Logic:
				1. All inputs to the stored process are accepted as global parameters. 
				2. Standards
 					a. Naming of data set which are input to and output from macro using
         <prod_type_code><sel_model_key><time_key> Extension as per requirement  
     i.e.		MTG           100          1036     pool
         			as MTG1001036pool.
 					b. Setting the default values for feed_pd and where_feed to be 
						passed as parameter(infilter) to the generating feed macro.
 					c.	Naming the graphs using timestamp and two letters for identifying 
     					the graph.
				3. Set all the graph options and select the colors to be used when 
					rendering the graph.
				4. Call the macro generate_feed for obtaining the required feed.
				5. Check whether the generate_feed macro generated any error.
 					If any error is generated then the same report(bnt_traffic) is called
 					with the default criteria.
				6. If there no data, in the case of business filter or dynamic pooling,
 					is generated by the generate_feed macro then the same report
					(bnt_traffic) is called with the default criteria.
				7. Call the binomial, normal and traffic_light macro for preparing data 
 					for display.
				8. Get the pooling technique.
				9  Generate the HTML using streaming webout.
 					a. Provide hidden textboxes for all output parameters so that the 
						values are easily submitted to the next page. 
 					b. Provide javascript functions for the links on top of the page
     					and for edit and reset buttons.

   Parameters: 
				INPUT 
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
				      					Mortgage, Loan, Core)
				prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
				model_type_code   	:   Analytical Model Type Code (e.g., PD 
										Approvals, PD Ongoing, LGD, CCF)
				include_exp_mdl		:   Information to include the expired models for
										selection of model from the traffic light 
										dashboard.
				statistic           :   Statistic name (Kolmogorov-Smirnov Statistic).
				model1				:	The first model if selected (Eg. PD MODEL 1).		
				model1_key			:	The surrogate key for the first selected model.
				model2				:	The  second model if  selected. (Eg. PD MODEL 2)
				model2_key			:	The surrogate key for the second selected model.
				sel_model			: 	Model selected on the Measure level dashboard screen.
				sel_model_key		:	Key of the selected model.
				period				:	The selected period (month and year)
										(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				filter				:	Used for displaying or hiding the modeling 
										values and overtime graph.(Not used in this 
										report)
				filter_clause		: 	Contains the selected business filter.
				pd_score 			:	If null then shown  as DEFAULT stautus.
				no_of_quantile      :	The range for dynamic pooling will be decided
										based on the quantile.Quantile ranges will be 
										calculated based on the SCORE/PD/LGD/CCF of 
										the scoring  population for the selected 
										score period  
				range_interval      : 	Dynamic pooling based on the range specified.
				      					E.g. 100, 200 for SCORE and .2, .3 for PD.
				prg_name			:	The program name, for calling the report, 
										which is picked from program_nm column of 
										dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.

				OUTPUT
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
				      					Mortgage, Loan, Core)
				prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
				model_type_code   	:   Analytical Model Type Code (e.g., PD 
										Approvals, PD Ongoing, LGD, CCF)
				include_exp_mdl		:   Information to include the expired models for
										selection of model from the traffic light 
										dashboard.
				statistic           :   Statistic name (Kolmogorov-Smirnov Statistic).
				model1				:	The first model if selected (Eg. PD MODEL 1).		
				model1_key			:	The surrogate key for the first selected model.
				model2				:	The  second model if  selected. (Eg. PD MODEL 2)
				model2_key			:	The surrogate key for the second selected model.
				sel_model			: 	Model selected on the Measure level dashboard screen.
				sel_model_key		:	Key of the selected model.
				period				:	The selected period (month and year)
										(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				filter				:	Used for displaying or hiding the modeling 
										values and overtime graph.(Not used in this 
										report)
				filter_clause		: 	Contains the selected business filter.
				pd_score 			:	If null then shown  as DEFAULT stautus.
				no_of_quantile      :	The range for dynamic pooling will be decided
										based on the quantile.Quantile ranges will be 
										calculated based on the SCORE/PD/LGD/CCF of 
										the scoring  population for the selected 
										score period  
				range_interval      : 	Dynamic pooling based on the range specified.
				      					E.g. 100, 200 for SCORE and .2, .3 for PD.
				called_program		:	Passes the path of the current program(conf_matrix)
				prg_name			:	The program name, for calling the report, 
										which is picked from program_nm column of 
										dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.
         
***********************************************************************************************/
goptions reset=all;
options nomprint;

/* Global variable declaration */
%global prod_type_desc prod_type_code model_type_code include_exp_mdl model1 model1_key model2 
	model2_key period time_key filter filter_clause statistic pd_score range_interval 
	no_of_quantile prg_name outcome_period elapsed_time model_type_desc
	sel_model sel_model_key format_name;

option mlogic mprint;

	%let prod_type_desc=&prod_type_desc;
	%let prod_type_code=&prod_type_code;
	%let model_type_desc=&model_type_desc;
	%let model_type_code=&model_type_code;
	%let model1=&model1;
	%let model1_key=&model1_key;
	%let sel_model=&sel_model;
	%let sel_model_key=&sel_model_key;
	%let period=&period;
	%let time_key=&time_key;
	%let filter=&filter;
	%let filter_clause=&filter_clause;
	%let pd_score=&pd_score;
	%let prg_name=&prg_name;
	%let outcome_period=&outcome_period;
	%let elapsed_time=&elapsed_time;
/*Assigning standard names for datasets which are input to and ouput from macro using
		<prod_type_code><sel_model_key><time_key> Extension as per requrment  
	i.e.		COR           106          1030     pool
		as COR1061030pool.*/
%let out_lib=;
%debug_lib_path;


/*This macro outputs the format for the stattistics for combination of 
  product type code and the model type code.*/
%format_for_model_product(model_type_code_fm=&model_type_code,prod_type_code_fm=&prod_type_code)
/*This macro chnage the dataset name and hardcode it on the product type*/
%change_dataset_name

%let out_pool=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.pool))));
%let out_pool_bt=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.pool))));
%let out_account=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.account))));

/*Used in calls to feed measure, data preparation and the 3 stat macros*/
%let out_data_prep=%sysfunc(ktrim(%sysfunc(kleft(&out_lib..&prod_type_code.&sel_model_key.&time_key.data_prep))));
%let out_graph_ds=%sysfunc(ktrim(%sysfunc(kleft(&out_lib..&prod_type_code.&sel_model_key.&time_key.ar_graph))));
%let out_stat_ds=%sysfunc(ktrim(%sysfunc(kleft(&out_lib..&prod_type_code.&sel_model_key.&time_key.ar_stat))));
%let out_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.ar_ot))));
%let in_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.ar_in))));

/* Setting values for the feed_pd and where_clause*/
%let where_feed=;
%let where_normal=;
%let where_measure=;
%let feed_pd=;

/*The data _null_ step below is to perform checking and initialize the required variables*/
data _null_;
/* Setting the feed_pd depending on whether its an application model or not.
	This is passed as parameter to generate_feed */
	if ktrim(kleft("&model_type_code"))=&PD_APP_MODEL then
		call symput('feed_pd',"&FEED_FOR_APPLPD");
    else
        call symput('feed_pd',"&FEED_FOR_PD");

/* Setting the default value for statistic*/
	if ktrim(kleft("&statistic"))="" then
   		call symput('statistic',"%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_binimial_test.1, noquote))");

/* Setting value for filter depending on whether the filter_clause and pd_score has any
	value set.
		The filter_clause and pd_score value is getting passed from the Filter Screen
		(stored process FilteringCriteria)
		If the filter is NO then the modeling value and the statistic overtime graph
		is displayed else it is not displayed */	
	if ktrim(kleft("&filter_clause"))="" and ktrim(kleft("&pd_score"))=""  then
		call symput('filter','NO');
    else
		call symput('filter','YES');

/* Setting the where clause for the feed_measure macro*/
	call symput('where_measure','where ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD="&prod_type_code" 
		and ANALYTICAL_MODEL_DIM.MODEL_SK=&sel_model_key');

/* Setting the where clause for the generate_feed macro depending upon the value of the
		filter_clause */
	if ktrim(kleft("&filter_clause"))="" then do;
		call symput('where_normal','where 1');
		call symput('where_feed','where 1');
	end;
	else do;
		call symput('where_normal','where &filter_clause');
		call symput('where_feed','where &filter_clause');
	end;
run;

/*The data _NULL_ step below is to produce the first part of the HTML which also includes 
the javascript blocks*/
data _NULL_;
	file _webout&webout_options;
	rep="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_binimial_test.1, noquote))";
	format rep &format_name..;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" '@;
	put '"http://www.w3.org/TR/html4/loose.dtd"> ';
	put '<html> ';
	put '<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'@;
	put  rep @;
	put '</title>';
	put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<style type="text/css"> ';
	put '<!-- ';
	put '.style2 {font-size: small} ';
	put '--> ';
	put '</style> ';

/**************************Javascript Starts here ****************************************/
	put '<script>';
	put '<!--';

	/*Checking for missing global parameters*/
	if "&prod_type_desc" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_prod_type_desc.1, noquote))"@;
		put'");';
	end;
	else if "&prod_type_code" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_prod_type_desc.1, noquote))"@;
		put '");';
	end;
	else if "&model_type_code" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_model_type_cd.1, noquote))"@;
		put '");';
	end;
	else if "&sel_model" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_select_model.1, noquote))"@;
		put '");';
	end;
	else if "&sel_model_key" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_select_model_key.1, noquote))"@;
		put '");';
	end;
	else if "&period" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_period.1, noquote))"@;
		put '");';
	end;
	else if "&time_key" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_time_key.1, noquote))"@;
		put '");';
	end;
	/******************/

	/*Functions for the links on top of the html page*/

/* Calls the Reporting stored process if link is clicked */
	put 'function Link1() {';
		put "form1._program.value=&CS_REPORTING";
		put 'form1.submit()';
	put '}';

/* Calls the mon_models stored process if link is clicked */
	put 'function Link2() {';
		put "form1._program.value=&CS_MON_MDL";
		put 'form1.submit()';
	put '}';

/* Calls the select_models stored process if link is clicked */
	put 'function Link3() {';
		put "form1._program.value=&CS_MDL_LVL_DB";
		put 'form1.submit()';
	put '}';

/* Calls the test_levels stored process if link is clicked */
	put 'function Link4() {';
		put "form1._program.value=&CS_MSR_LVL_DB";
		put 'form1.submit()';
	put '}';
	/*********************/

	/*Function EditPage() for calling the Filter Screen
		(this changes the filter_clause and hence the where_feed)*/
	put 'function EditPage() {';
		put 'form1.filter_clause.value=""';
		put "form1._program.value=&CS_FLTR_SCRN";
		put 'form1.submit()';
	put '}';
	/*********EditPage() ends here**************/

	/*Function ResetPage() for reseting the value of filter_clause to null*/
	put 'function ResetPage() {';
		put 'form1.filter_clause.value=""';
		put 'form1.pd_score.value=""';
		put 'form1.range_interval.value=""';
		put 'form1.no_of_quantile.value=""';
		put 'form1.filter.value="NO"';
		put 'form1._program.value="'@;
		put "&prg_name"@;
		put '";';
		put 'form1.submit()';
	put '}';
	/*********ResetPage() ends here*************/

	/*Function savepage() for saving the page to disk */
	%savepage;
	/*********savepage() ends here*************/

	/*Function printpage() for printing the page to a printer or to a pdf file*/
	%printpage;
	/*********printpage() ends here*************/

	put '//-->';
	put '</script>';

/**************************Javascript Ends here ****************************************/

	put '</head> ';
	put '<body>';
	put '<form name="form1" method="post" action="/SASStoredProcess/do">';

	/* Stores the values of all the global variables in hidden textboxes
	This is done to pass the values to the next Stored Process */
	put '<input type="hidden" name="_program" VALUE="';
	put "&prg_name";
	put '">';
	prod_type_desc=symget("prod_type_desc");
	put '<input type="hidden" name="prod_type_desc" value="' @;
	put prod_type_desc;
	put '">';
	prod_type_code=symget("prod_type_code");
	put '<input type="hidden" name="prod_type_code" value="' @;
	put prod_type_code;
	put '">';
	model_type_code=symget("model_type_code");
	put '<input type="hidden" name="model_type_code" value="' @;
	put model_type_code;
	put '">';
	include_exp_mdl=symget("include_exp_mdl");
	put '<input type="hidden" name="include_exp_mdl" value="' @;
	put include_exp_mdl;
	put '">';
	model1=symget("model1");
	put '<input type="hidden" name="model1" value="' @;
	put model1;
	put '">';
	model1_key=symget("model1_key");
	put '<input type="hidden" name="model1_key" value="' @;
	put model1_key;
	put '">';
	model2=symget("model2");
	put '<input type="hidden" name="model2" value="' @;
	put model2;
	put '">';
	model2_key=symget("model2_key");
	put '<input type="hidden" name="model2_key" value="' @;
	put model2_key;
	put '">';
	sel_model=symget("sel_model");
	put '<input type="hidden" name="sel_model" value="' @;
	put sel_model @;
	put '">';
	sel_model_key=symget("sel_model_key");
	put '<input type="hidden" name="sel_model_key" value="' @;
	put sel_model_key @;
	put '">';
	period=symget("period");
	put '<input type="hidden" name="period" value="' @;
	put period;
	put '">';
	time_key=symget("time_key");
	put '<input type="hidden" name="time_key" value="' @;
	put time_key;
	put '">';
	statistic=symget("statistic");
	put '<input type="hidden" name="statistic" value="'@;
	put statistic;
	put '">';
	filter=symget("filter");
	put '<input type="hidden" name="filter" value="'@;
	put filter;
	put '">';
	filter_clause=symget("filter_clause");
	put '<input type="hidden" name="filter_clause" value="'@;
	put filter_clause;
	put '">';

	pd_score=symget("pd_score");
	put '<input type="hidden" name="pd_score" value="' @;
	put pd_score;
	put '">';
	range_interval=symget("range_interval");
	put '<input type="hidden" name="range_interval" value="' @;
	put range_interval;
	put '">';
	no_of_quantile=symget("no_of_quantile");
	put '<input type="hidden" name="no_of_quantile" value="' @;
	put no_of_quantile;
	put '">';
	prg_name=symget("prg_name");
	put '<input type="hidden" name="prg_name" value="' @;
	put prg_name;
	put '">';

	model_type_desc=symget("model_type_desc");
	put '<input type="hidden" name="model_type_desc" value="' @;
	put model_type_desc;
	put '">';
		
	outcome_period=symget("outcome_period");
	put '<input type="hidden" name="outcome_period" value="' @;
	put outcome_period;
	put '">';

	elapsed_time=symget("elapsed_time");
	put '<input type="hidden" name="elapsed_time" value="' @;
	put  elapsed_time;
	put '">';

	put '<input type="hidden" name="called_program" value="';
	put "&prg_name";
	put '">';
	/**********************/
run;

/*Calls the macro generate_feed for obtaining the required feed by passing
	the following parameters
	1. in_filter		: Where clause (on the basis of the filter clause)
	2. out_lib_nm		: Library name where the output feed will be created. 
	3. out_table_nm_pool: The table name for pool level feed
	4. out_table_nm_acct: The table name for account/application level feed
	5. feed_for			: Possible values are PD, LGD, CCF, APPLPD, APPLLGD. This macro parameter
							decides whether estimated pd/lgd/ccf has to calculated at account 
							level or application level 
	6. pd_score			: Possible values are (Empty), PD, SCORE
          a. (empty)	: The default pooling technique will be used
          b. PD			: If PD then dynamic pooling technique will be used, 
              			  based on PD/LGD/CCF as mentioned in the previous parameter(feed_for) 
          c. SCORE		: If SCORE then dynamic pooling technique will be used,
              				based on SCORE_POINTS. Applicable only if PD or APPLPD value
              				is set in the previous variable (feed_for)
	7. range_interval	: Dynamic pooling based on the range specified. E.g. 100, 200 for
	              			SCORE and .2, .3 for PD. Similar ranges for LGD/CCF
	8. no_of_quantile	: The range for dynamic pooling will be decided based on the quantile.
							Quantile ranges will be calculated based on the SCORE/PD/LGD/CCF 
							of the scoring population for the selected score period
	9. long_run			: Possible values Y/N. Whether the long run calculation is to be
							used to find estimated pd/lgd/ccf
	10. long_run_type	: Possible values are MAX/AVG. Method for calculating the long run
							pd/lgd/ccf  
	11. model_time_key  : Contains the concatenated values of model and time in the
							format _<model_sk>_<time_sk>. This is used to identify
							which fact table should be considered while generating 
							the feed.
	12. product_type_code	: This is the selected product type code (E.G. MTG, LON).
*/
%global error_code;
%let error_code=NONE;
/*the call below is for both binomial and traffic light test since data is only for a specific
	  period*/
%let model_time=_%sysfunc(ktrim(%sysfunc(kleft(&sel_model_key.))))_%sysfunc(ktrim(%sysfunc(kleft(&time_key.))));
%generate_feed(in_filter=&where_feed, out_lib_nm=&out_lib., 
      out_table_nm_pool=&out_pool._bt, out_table_nm_acct=&out_account, 
	  feed_for=&feed_pd, long_run=&LONG_RUN, pd_score=&pd_score, 
	  range_interval=&range_interval, no_of_quantile=&no_of_quantile, 
	  long_run_type=&LONG_RUN_TYPE, model_time_key=&model_time,product_type_code=&prod_type_code);

/*generate feed macros creates data feeds for further processing
the call below is for normal test. The feed is called in a loop for the
selected number of years. */
%let time_list=.;
proc sql noprint;
	select distinct score_time_sk into :time_list separated by '#' 
	from fact.model_measure_fact
	where score_time_sk<&time_key and model_sk=&sel_model_key 
	and kupcase(dev_flg)="%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.dev_flag_n.1, noquote))"
	order by score_time_sk descending;
quit;
%let time_list=%sysfunc(ktrim(%sysfunc(kleft(&time_list))));

%macro generate_feed_normal;
	data &out_lib..normal_feed;
		set &out_lib..&out_pool._bt;
	run;

	%if &time_list ne %str(.) %then %do;
		%let cnt=1;
		%let token=;
		%let token=%sysfunc(kscan(&time_list,&cnt,#));
		%do %while (&cnt<&CS_NORMAL_SCR_DT and &token ne %str());
			%let model_time=_%sysfunc(ktrim(%sysfunc(kleft(&sel_model_key.))))_%sysfunc(ktrim(%sysfunc(kleft(&token.))));

			%generate_feed(in_filter=&where_normal, out_lib_nm=&out_lib., 
			      out_table_nm_pool=&out_pool, out_table_nm_acct=&out_account, 
				  feed_for=&feed_pd, long_run=&LONG_RUN,pd_score=&pd_score, 
				  range_interval=&range_interval, no_of_quantile=&no_of_quantile, 
				  long_run_type=&LONG_RUN_TYPE, model_time_key=&model_time);
			
			proc append data=&out_lib..&out_pool base=&out_lib..normal_feed force;
			quit;
			%let cnt=%eval(&cnt+1);
			%let token=;
			%let token=%sysfunc(kscan(&time_list,&cnt,#));
		%end;
	%end;
%mend generate_feed_normal;
%generate_feed_normal;

/* Checks whether the generate_feed macro generated any error.
	If any error is generated then the ResetPage function defined above is called*/
data _NULL_;
	file _webout&webout_options;
	if ktrim(kleft("&error_code")) ne "NONE" and (ktrim(kleft("&filter_clause")) ne "" or ktrim(kleft("&pd_score")) ne "") then do;
		put '<script>';
		put '<!--';
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_selec_filter_criteria.1, noquote))"@;
		put '")';
		put 'ResetPage()';
		put '//-->';
		put '</script>';
	end;
run;

/* Checks whether the dataset created in the generate_feed macro has any observations
			and sets cnt to the number of observations in the dataset*/
%let cnt=.;
proc sql noprint;
      select Count(*) into :cnt from &out_lib..&out_pool._bt;
quit;

/* If there is no observation in the above dataset i.e. cnt=0 then the ResetPage function
	defined above is called */
%let log_name=;
data _NULL_;
	file _webout&webout_options;
	if &cnt eq 0 and (ktrim(kleft("&filter_clause")) ne "" or ktrim(kleft("&pd_score")) ne "") then do;
		put '<script>';
		put '<!--';
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_no_data_available.1, noquote))"@;
		put '")';
		put 'ResetPage()';
		put '//-->';
		put '</script>';
	end;
	call symput('log_name',"&CS_DEBUG_PATH./&out_pool."||".log");
run;

/******ERROR TO GET LOG IN THE Specified LIBNAME*************/
%debug_log_file(log_file_nm=&log_name);

%let name_html=;
proc sql;
	create table &out_lib..&in_stat_ot as
	select help_file_nm
	from dim.measure_dim 
	where kupcase(program_nm)=kupcase("&prg_name")
		and kupcase(model_type_cd)=kupcase("&model_type_code");
/*	order by measure_nm;*/
quit;

data _null_;
	set &out_lib..&in_stat_ot;
	call symput('name_html',help_file_nm);
run;

/*Macro for binomial test*/

%binomial(input_ds=&out_lib..&out_pool._bt, output_ds=&out_lib..binomial, msr_nm=&statistic, model_type=&model_type_code);

/*Macro for traffic lighting test*/
%traffic_light(input_ds=&out_lib..&out_pool._bt, output_ds=&out_lib..trafficlights, msr_nm=%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.macro_traffic_light_test_para.1, noquote)), model_type=&model_type_code);

/*Macro for normal test*/
%normal(input_ds=&out_lib..normal_feed,output_ds=&out_lib..normal,msr_nm=%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.macro_normal_para.1, noquote)),model_type=&model_type_code);

data work.bin;
set &out_lib..binomial (rename=(traffic=Btraffic));
run;

data work.nor;
set &out_lib..normal (rename=(traffic=Ntraffic));
run;

data work.trfc;
set &out_lib..trafficlights (rename=(traffic=Ttraffic));
run;

/*Sorting before the merge occurs*/
proc sort data=work.bin out=work.binsort ;
by pool_seq;
run;

proc sort data=work.nor out=work.normalsort ;
by pool_seq;
run;

proc sort data=work.trfc out=work.trafficsort ;
by pool_seq;
run;

/*Merger all the sorted data sets*/
data &out_lib..traffic_merged;
merge work.binsort work.normalsort work.trafficsort;
by pool_seq;
drop diff stdev bucket no_of_ac a_gb avgpd nondef;
if BTraffic = '' then BTraffic = "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.colour_white.1, noquote))";
if TTraffic = '' then TTraffic = "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.colour_white.1, noquote))";
if NTraffic = '' then NTraffic = "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.colour_white.1, noquote))";
run;

/* Macro for getting the Pooling Technique.
	In this macro the following indicates:
			1.pd_score 			: If null then shown  as DEFAULT stautus.
			2.time_key        	: The surrogate key for selected period.
            3.sel_model_key        : The surrogate key for the selected model.
 			4.no_of_quantile    : The range for dynamic pooling will be decided based on
								  the quantile.Quantile ranges will be calculated based
								  on the SCORE/PD/LGD/CCF of the scoring  population
								  for the selected score period.
		    5.range_interval    : Dynamic pooling based on the range specified.
			  						E.g. 100, 200 for SCORE and .2, .3 for PD.	*/
%let pool_tech=;
%pool_technique;
%let pool_tech=&pool_tech;
%debug_log_web;
%let view_feed=&out_pool..html;
/* All data _null_ statements to create the html */
 
data _null_;
	file _webout&webout_options;
/*	rep="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_binimial_test.1, noquote))";*/
	rep="&statistic.";
	format rep &format_name.. ;
	put'<script>';
		/**************Help File *********************/
	%helpfile(filename=&name_html);

		/*************feed Table*********************/
	put 'function feed_table(){';
		put'window.open("/SASCSReports/'@; 
		put "&view_feed"@; 
	put '")};';
			
		/*********************************************/
	put'</script>';

	put '  <table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';
	/* To display SAS credit scoring as heading */
	put '<tr>';
	put '<td align="left">';
	put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0">';
	put '<tr>';
	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';
	put '<td><span class="BreadCrumb">'; 
	put '<a href="javascript:Link1()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.link_reporting.1, noquote))"@;
	put '</a> &gt;<a href="javascript:Link2()" >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.link_monitoring_model.1, noquote))"@;
	put '</a> &gt; <a href="javascript:Link3()" >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.link_sel_model.1, noquote))"@;
	put '</a> &gt; <a href="javascript:Link4()" >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.link_sel_stats.1, noquote))"@;
	put '</a> &gt;';
	put '</span><span class="BreadCrumb">'@;
	put rep;
	put '</span></td>';
	put '<td width="215"><div align="right"><img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td>';
	put '</tr></table>';

	/* Heading ends */
	put '<H2 align="left"><table width="100%"  border="0" cellspacing="0" cellpadding="0"><tr><td>';
/*	put 'Binomial, Normal and Traffic Light Tests'@;*/
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.link_BNT_test.1, noquote))"@;
	put'</td>';
	if kupcase(&print) eq 'Y' then do;
		put '<td width=65><div align="center"><span class="LabelFont">';
		put '<a href="javascript:printpage()">';
		put '<img src="/SASCSReports/images/Print.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_print.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&save) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:enregistre()">';
		put '<img src="/SASCSReports/images/SaveFile.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_save.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&help) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:Info()">';
		put '<img src="/SASCSReports/images/Info.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_help.1, noquote))"@;
		put '</div></td>';
	end;
	put '</tr></table></H2>';
	put '</td></tr>';

	put '<tr>';
	put '<td align="left">';

	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_model_type.1, noquote))"@;
	put "&model_type_desc"@;
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_product_type.1, noquote))"@;
	put "&prod_type_desc" @;
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_period.1, noquote))"@;
/*I18N-scnhuh-20080427-1455*/	
/* del one line, add two lines. For displaying in NLS format */	
/*	put "&period" @;*/
		Period_WEBUI=put(input("&period",&CS_TIME_PER_FMT.),&NLDATE_FMT.);
		put Period_WEBUI @;
/*I18N-scnhuh-20080427-1455*/		
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_model.1, noquote))"@;
	put "&sel_model" @;
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_pooling_tech.1, noquote))"@;
	put "&pool_tech";
	put '</p>';
	/* Target period and elapsed time*/
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_outcome_period.1, noquote))"@;
	put "&outcome_period" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_months.1, noquote))"@;
	put "&elapsed_time" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_month_elapsed.1, noquote))"@;
	put '</p>';

	/* Number of months of Historic data */
	if kupcase("&model_type_code") eq kupcase(&PD_APP_MODEL.) then do;
		put '<p class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pd_stored_proc_hist.label_historic_data.1, noquote))"@;
		if kupcase("&prod_type_code") eq kupcase(&MTG_PRD_TYPE.) then do;
			put "&PDA_MTG_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&LON_PRD_TYPE.) then do;
			put "&PDA_LON_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&COR_PRD_TYPE.) then do;
			put "&PDA_COR_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&CCD_PRD_TYPE.) then do;
			put "&PDA_CCD_HIST" @;
		end;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pd_stored_proc_month.label_months.1, noquote))"@;
		put '</p>';
	end;

	put '<br>';
run;

/*the table is displayed using the data _null_ step below.*/
data _NULL_;
format ND &CS_DEC_FMT. BCLD &CS_DEC_FMT. BCHD &CS_DEC_FMT. NCLD &CS_DEC_FMT. NCHD &CS_DEC_FMT.
TCLD &CS_DEC_FMT. TCHD &CS_DEC_FMT.;
	file _webout&webout_options;
	set &out_lib..traffic_merged end=last;
	BCLD = BClow;
	BCHD = BChigh;
	NCLD = NClow;
	NCHD = NChigh;
	TCLD = TClow;
	TCHD = TChigh; 
	ND = Zcalc;
	/*heading for the table columns are displayed using the following if block*/
	if _N_=1 then do;
		put '<table width="60%" border="0" cellpadding="0" cellspacing="0" bgcolor="#FFFFFF" class="tableborder"> ';
		put '<tr> ';
		put '<td valign="top"><table width="100%" border="0" cellpadding="3" cellspacing="0"> ';
		put '<tr> ';
		put '<td align="right" class="cornerborderTop">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_pool_seq.1, noquote))"@;
		put'</td>';
		put '<td align="center" class="cornerborderTop">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_binomial.1, noquote))"@;
		put'</td>';
		put '<td align="center" class="cornerborderTop">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_normal.1, noquote))"@;
		put'</td>';
		put '<td align="center" class="HrzBorderTop">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_traffic.1, noquote))"@;
		put'</td>';

		put '<tr><td align="left" class="cornerborder">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_critical_limits.1, noquote))"@;
		put '</td>';
		put '<td class="cornerborder"><table width="100%" border="0" cellspacing="0" cellpadding="0"> ';
		put '<tr> ';
		put '<span class="LabelFont"><td width="10%">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td>';
		put '<span class="LabelFont"><td width="30%"><div align="right">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_stats.1, noquote))"@;
		put '</div></td>';
		put '<span class="LabelFont"><td width="30%"><div align="right">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_clow.1, noquote))"@;
		put '</div></td>';
		put '<span class="LabelFont"><td width="30%"><div align="right">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_chigh.1, noquote))"@;
		put'</div></td>';
		put '</td></span></tr></table>';

		put '<td class="cornerborder"><table width="100%" border="0" cellspacing="0" cellpadding="0"> ';
		put '<span class="LabelFont"><td width="10%">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td>';
		put '<span class="LabelFont"><td width="30%"><div align="right">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_stats.1, noquote))"@;
		put '</div></td>';
		put '<span class="LabelFont"><td width="30%"><div align="right">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_clow.1, noquote))"@;
		put '</div></td>';
		put '<span class="LabelFont"><td width="30%"><div align="right">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_chigh.1, noquote))"@;
		put'</div></td>';
		put '</td></span></tr></table>';

		put '<td class="cornerborder"><table width="100%" border="0" cellspacing="0" cellpadding="0"> ';
		put '<span class="LabelFont"><td width="10%">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td>';
		put '<span class="LabelFont"><td width="30%"><div align="right">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_stats.1, noquote))"@;
		put '</div></td>';
		put '<span class="LabelFont"><td width="30%"><div align="right">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_clow.1, noquote))"@;
		put '</div></td>';
		put '<span class="LabelFont"><td width="30%"><div align="right">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.label_chigh.1, noquote))"@;		
		put'</div></td>';
		put '</td></span></tr></table>';
		
		put '</tr>';
	end;

	put '<tr><td align="right" class="cornerborder">';
	put pool_seq;
	put '</td>';
	put '<td class="cornerborder"><table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
	put '<tr> ';
	put '<span class="LabelFont"><td width="10%">'@;
	if kupcase(BTraffic) = kupcase("%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.colour_white.1, noquote))") then do;
		put '<img src="/SASCSReports/images/spacer' @;
	end;
	else do;
		put '<img src="/SASCSReports/images/Sphere' @;
		put BTraffic;
	end;
	put '.gif" width="16" height="16" border="0"></td>';
	put '<td class="textlink" width="30%"><div align="right">';
	put No_Of_Actual_Bads;
	put'</div></td></span>';
	put '<td class="textlink" width="30%"><div align="right">';
	put BCLD;
	put'</div></td></span>';
	put '<td class="textlink" width="30%"><div align="right">';
	put BCHD;
	put'</div></td></span></tr></table>';

	put '<td class="cornerborder"><table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
	put '<tr> ';
	put '<span class="LabelFont"><td width="10%">'@;
	if kupcase(NTraffic) = kupcase("White") then do;
		put '<img src="/SASCSReports/images/spacer' @;
	end;
	else do;
		put '<img src="/SASCSReports/images/Sphere' @;
		put NTraffic;
	end;
	put '.gif" width="16" height="16" border="0"></td>';
	put '<td class="textlink" width="30%"><div align="right">';
	put ND;
	put'</div></td></span>';
	put '<td class="textlink" width="30%"><div align="right">';
	put NCLD;
	put'</div></td></span>';
	put '<td class="textlink" width="30%"><div align="right">';
	put NCHD;
	put'</div></td></span></tr></table>';

	put '<td class="HrzBorder"><table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
	put '<tr> ';
	put '<span class="LabelFont"><td width="10%">'@;
	if kupcase(TTraffic) = kupcase("White") then do;
		put '<img src="/SASCSReports/images/spacer' @;
	end;
	else do;
		put '<img src="/SASCSReports/images/Sphere' @;
		put TTraffic;
	end;
	put '.gif" width="16" height="16" border="0"></td>';
	put '<td class="textlink" width="30%"><div align="right">';
	put No_Of_Actual_Bads;
	put'</div></td></span>';
	put '<td class="textlink" width="30%"><div align="right">';
	put TCLD;
	put'</div></td></span>';
	put '<td class="textlink" width="30%"><div align="right">';
	put TCHD;
	put'</div></td></span></tr></table>';

	put '</tr>';
	if last then do;
		put '</tr>';
		put '</table>';
		put'</tr></table>';
		put '<p class=NoteFont>'@;
		put '<strong>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.note_note.1, noquote))"@;
		put '</strong>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.bnt_traffic.note_note1.1, noquote))"@;
		put '</p>';
		put '<p>&nbsp;</p>';
		put'</td>';
		put '</td>';
		put '</tr>';
		put '<tr>'@;
		put '<td height="32" bgcolor="#F1EACB">&nbsp;&nbsp;';
		val=PRXMATCH(kupcase('/cluster/'),kupcase("&pool_tech"));
		if val = 0 then do;
			put '<INPUT type=button class=mmhide_btn onClick=EditPage() value="'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.button_filter_repool.1, noquote))"@;
			put '">';
			put '<INPUT type=button class=mmhide_btn onClick=ResetPage() value="'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.button_reset.1, noquote))"@;
			put'">';
		end;
		put '<INPUT type=button class=mmhide_btn onClick="feed_table()" value="'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.button_view_feed.1, noquote))"@;
		put '">';
		put '</td>';
		put '</tr>';
		put '</table>';
		put '</form>';
		put '</body>';
		put '</html>';
	end;	
run;

/******macro feed_table pass parameter  separated by #

		Input parameter 
		1.dt_st =Pass dataset name in string separated by #
		2.dt_nm=pass name u want to give to the table
		3.out_libout library  which is defined above
		        *****************************************************************/

	 /*I18N-scnjih-20080424-1458*/
/*%let dt_nm=%str(Binomial, Traffic Light Test Feed#Normal Test Feed);*/
	%let dt_nm=%sysfunc(sasmsg(smd_ds.bismsg,bnt_traffic.sas.1, noquote))#%sysfunc(sasmsg(smd_ds.bismsg,bnt_traffic.sas.2, noquote));
	 /*I18N-scnjih-20080424-1458*/
data &out_lib..&out_pool._bt_1; 
set &out_lib..&out_pool._bt;
SCORE_POINTS=round(SCORE_POINTS);
run;
data &out_lib..normal_feed_1; 
set &out_lib..normal_feed;
SCORE_POINTS=round(SCORE_POINTS);
run;

%let dt_st=%str(&out_pool._bt_1#normal_feed_1);
%feed_table(ds=&dt_st,out_lib1=&out_lib,data_name=&dt_nm,name_html=&view_feed);
goptions reset=all;
options nomprint;
