
/*********************************************************************************************
       Module:  Score Validation

     Function:  This stored process creates the HTML screen which is used to capture the information
				regarding the MODEL TYPE (PD Approvals, PD Ongoing, LGD, CCF), PRODUCT TYPE (Credit Card,
				Mortgage, Loan, Core etc.) for generating the validation  graph and display table for
				that  validation.

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1

    Called-by:	1. Static HTML screen Reporting.htm available in the virtual folder 
					/SASCSReports as part of the regular flow.
				2. From any model monitoring report screen as part of the links provided on 
				   the page for navigation.

        Calls:  Stored Process 
			1.Reporting		    (Reporting )
			2.mon_models        (Monitoring Models)  
			3.select_models     (Select Models) 
			4.test_levels       (Select Statistic)
			5.Score validation  (calls the same reports on click of reset button)
			6.filtering_criteria(when the Filter/Re-Pool button is clicked)
			7.Call to macro 				           
					a.	feed_measure  used to generate dataset for statistic overtime.
					b.	Validation_input,Distance_Stats,interpolationare used to generate the 
						dataset for different statistic 
					c.	Model traffic macro is used to generate the color for the particular 
						model code  eg. PDA  of a statistic.Input dataset required should have 
						different statistic name and value. Output value will be the color for 
						the modeling value.
					d.	Statistic overtime macro plots the statistic value. Input to this 
						macro are Output of feed_mesure macro, statistic name  and the 
						graph name(on which the gif will be created )
					e.  Draw table macro used to generate table in html;

Datasets used:  No Input dataset used.
 
        Logic:  1. All inputs to the stored process are accepted as global parameters. 
				2.	Standards followed across all reports.
					a.	Naming of data set which are input  to macro using using 
							<prod_type_code><sel_model_key><time_key> Extension as per requrment  
						eg.		Cor           106          1030     pool
							as Cor1061030pool.
					b.	Naming the graphs using timestamp and two letters for id for your graph.
					c.	Polling technique is used as variable pool_tech this is generated from a macro 
						pool_technique.			

			3.	Creating HTML 
				          
				a.	Validation for the different parameter which is to be passed to this  stored     process .
				b.	Function JavaScript for links to be provided on top of report , and the Function onchange for the combo box.
				c.	Hidden text box are made to collect different parameter. which will get submitted  to called store process on submit function.       
				d.  Modeling and Actual values are shown for diffrent distance statisctic.
				e.  Drawing table for difffrent distance statistic.
				f.	On filter condition as 'NO'the statistic overtime graph will be displayed .
				
   Parameters:  Parameters:  INPUT (From Report Screen when link is used for navigation):
			INPUT 
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD Ongoing,
										LGD, CCF)
		        include_exp_mdl		:   Information to include the expired models for selection of
										model from the traffic light dashboard.
				statistic           :   Measure name(e.g., Accuracy, Precision, Error Rate,
										Specificity, Sensitivity)
				model1				:	The first model if selected (Eg. PD MODEL 1).		
				model1_key			:	The surrogate key for the first selected model.
				model2				:	The  second model if  selected. (Eg. PD MODEL 2)
				model2_key			:	The surrogate key for the second selected model.
				sel_model			: 	Model selected on the Measure level dashboard screen.
				sel_model_key		:	Key of the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				filter				:	Used for displaying or hiding the modeling values and
										overtime graph.
				filter_clause		: 	Contains the selected business filter.
		        pd_score 			:	If null then shown  as DEFAULT stautus.
		 	    no_of_quantile      :	The range for dynamic pooling will be decided based on the 
								 	    quantile.Quantile ranges will be calculated based on the 
								 	    SCORE/PD/LGD/CCF of the scoring  population for the
										selected score period  
		  		range_interval      : 	Dynamic pooling based on the range specified.
										E.g. 100, 200 for SCORE and .2, .3 for PD.
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.
				
			OUTPUT
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD Ongoing,
										LGD, CCF)
		        include_exp_mdl		:   Information to include the expired models for selection of
										model from the traffic light dashboard.
				statistic           :   Measure name(e.g., Accuracy, Precision, Error Rate,
										Specificity, Sensitivity)
				model1				:	The first model if selected (Eg. PD MODEL 1).		
				model1_key			:	The surrogate key for the first selected model.
				model2				:	The  second model if  selected. (Eg. PD MODEL 2)
				model2_key			:	The surrogate key for the second selected model.
				sel_model			: 	Model selected on the Measure level dashboard screen.
				sel_model_key		:	Key of the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				filter				:	Used for displaying or hiding the modeling values and
										overtime graph.
				filter_clause		: 	Contains the selected business filter.
		        pd_score 			:	If null then shown  as DEFAULT stautus.
		 	    no_of_quantile      :	The range for dynamic pooling will be decided based on the 
								 	    quantile.Quantile ranges will be calculated based on the 
								 	    SCORE/PD/LGD/CCF of the scoring  population for the
										selected score period  
		  		range_interval      : 	Dynamic pooling based on the range specified.
										E.g. 100, 200 for SCORE and .2, .3 for PD.
				called_program		:	Passes the path of the current program(conf_matrix)
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.
*****************************************************************************************/
goptions reset=all;
options nomprint;

/* Global variables */
%global prod_type_desc prod_type_code model_type_code model1 model1_key model2 model2_key 
		period time_key filter filter_clause statistic pd_score range_interval no_of_quantile 
		statistic include_exp_mdl prg_name model_type_desc outcome_period elapsed_time
		sel_model sel_model_key format_name;

option mlogic mprint;
/* Begin-Used for calling all macros */

    %let prod_type_desc=&prod_type_desc;
    %let prod_type_code=&prod_type_code;
    %let model_type_code=&model_type_code;
    %let model1=&model1;
    %let model1_key=&model1_key;
    %let model2=&model2;
    %let model2_key=&model2_key;
    %let sel_model=&sel_model;
    %let sel_model_key=&sel_model_key;
    %let period=&period;
    %let time_key=&time_key;
    %let filter=&filter;
    %let filter_clause=&filter_clause;
    %let pd_score=&pd_score;
    %let prg_name=&prg_name;
    %let model_type_desc=&model_type_desc;
    %let outcome_period=&outcome_period;
    %let elapsed_time=&elapsed_time;

/*over time*/                 
%let cl_names=%str(measure_nm,measure_value,grade);

/*I18N-scnjih-20080505-1444*/
/*%let cl_labels=%str(Measure Name, Measure Value, Validation Score);*/
%let cl_labels=%sysfunc(sasmsg(smd_ds.bismsg,score_validation.sas.1,noquote))%str(,)%sysfunc(sasmsg(smd_ds.bismsg,score_validation.sas.2,noquote))%str(,)%sysfunc(sasmsg(smd_ds.bismsg,score_validation.sas.3,noquote));
/*I18N-scnjih-20080505-1444*/

/*This macro outputs the format for the stattistics for combination of 
  product type code and the model type code.*/
%format_for_model_product(model_type_code_fm=&model_type_code,prod_type_code_fm=&prod_type_code)
/*This macro chnage the dataset name and hardcode it on the product type*/
%change_dataset_name

/**************************************values for micro required****************************/
%let ot_name=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.ar_ot))));


%let out_lib=;
%debug_lib_path;
/**********************/
%let out_pool=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.pool))));
%let out_account=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.account))));
%let out_data_prep=%sysfunc(ktrim(%sysfunc(kleft(&out_lib..&prod_type_code.&sel_model_key.&time_key.data_prep))));
%let out_graph_ds=%sysfunc(ktrim(%sysfunc(kleft(&out_lib..&prod_type_code.&sel_model_key.&time_key.ar_graph))));
%let out_stat_ds=%sysfunc(ktrim(%sysfunc(kleft(&out_lib..&prod_type_code.&sel_model_key.&time_key.ar_stat))));

/* Standard names for datasets that are passed to feed_measure macro*/
%let out_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.ar_ot))));
%let in_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.ar_in))));
/**************************************************************/
%let where_feed=;                       
%let where_measure=;            
%let avg_valid_scr= ;


/******TO DO STATISTICS REQUIRED*********/



data _NULL_;
   if ktrim(kleft("&statistic"))="" then
            	call symput('statistic',"%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_validation_Score.1, noquote))");
/* Setting value for filter depending on whether the filter_clause and pd_score has any
	value set.
		The filter_clause and pd_score value is getting passed from the Filter Screen
		(stored process FilteringCriteria)
		If the filter is NO then the modeling value and the statistic overtime graph
		is displayed else it is not displayed */	
 if ktrim(kleft("&filter_clause"))="" and ktrim(kleft("&pd_score"))=""  then
                call symput('filter','NO');
else
				call symput('filter','YES');
/* Setting the feed_pd depending on whether its an application model or not.
	This is passed as parameter to generate_feed */
if ktrim(kleft("&model_type_code"))=&PD_APP_MODEL then
	            call symput('feed_pd',"&FEED_FOR_APPLPD");
	else
	            call symput('feed_pd',"&FEED_FOR_PD"); 

/* Setting the where clause for the feed_measure macro*/
call symput('where_measure','where ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD="&prod_type_code" 
							and ANALYTICAL_MODEL_DIM.MODEL_SK=&sel_model_key');

 /* Setting the where clause for the generate_feed macro depending upon the value of the
		filter_clause*/
	if ktrim(kleft("&filter_clause"))="" then
		call symput('where_feed','where 1');
	else
		call symput('where_feed','where &filter_clause');
run;


/*******Setting the graph name by timestamp**************************/
data _null_;
	name=put(time(),mmss8.1);
	name1=kscan(name,1,":.");
	name2=kscan(name,2,":.");
	name3=kscan(name,3,":.");
	name4="sv"||ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
	call symput('name',name4);
run;

%let graph_name=%sysfunc(ktrim(%sysfunc(kleft(&name))));

/********GOPTION SPECIFICATION****no input required It give the graphics option for ploting the graph*
here thwo color_symbol are used as  there is only two colors in graph*******************/
%let color_symbol1=;
%let color_symbol2=;
%graph_options;

data _null_;
	file _webout&webout_options;
	rep="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_validation_Score.1, noquote))";
	format rep &format_name..;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" ';
	put '"http://www.w3.org/TR/html4/loose.dtd"> ';
	put '<html> ';
	put '<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'@;
	put rep @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.score_validation.stats_val_score_report.1, noquote))" @;
	put '</title> ';
	put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<style type="text/css"> ';
	put '<!-- ';
	put '.style2 {font-size: small} ';
	put '--> ';
	put '</style> ';
	put'<script language="JavaScript" type="text/JavaScript"> ';
	/*	put'<!-- ';*/
		/*Checking for missing global parameters*/
			/*Checking for missing global parameters*/
	if "&prod_type_desc" eq %str("") then 
	 do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.crs.stability_index_lgd.alert_error_put_prod_type_desc.1, noquote))"@;
		put '");';
	end;
	else if "&prod_type_code" eq %str("") then 
	 do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.crs.stability_index_lgd.alert_error_put_prod_type_desc.1, noquote))"@;
		put '");';
	end;
	else if "&model_type_code" eq %str("") then 
	 do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.crs.stability_index_lgd.alert_error_put_model_type_cd.1, noquote))"@;
		put '");';
	end;
	else if "&sel_model" eq %str("") then 
	 do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.crs.stability_index_lgd.alert_error_put_select_model.1, noquote))"@;
		put '");';
	end;
	else if "&sel_model_key" eq %str("") then 
     do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.crs.stability_index_lgd.alert_error_put_select_model_key.1, noquote))"@;
		put '");';
	 end;
	else if "&period" eq %str("") then 
	 do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.crs.stability_index_lgd.alert_error_put_period.1, noquote))"@;
		put '");';
	 end;
	else if "&time_key" eq %str("") then 
	  do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.crs.stability_index_lgd.alert_error_put_time_key.1, noquote))"@;
		put '");';
	 end;
	/******************/
	put 'function Link1() {';
		put "form1._program.value=&CS_REPORTING";
		put 'form1.submit()';
	put '}';

	put 'function Link2() {';
		put "form1._program.value=&CS_MON_MDL";
		put 'form1.submit()';
	put '}';

	put 'function Link3() {';
		put "form1._program.value=&CS_MDL_LVL_DB";
		put 'form1.submit()';
	put '}';

	put 'function Link4() {';
		put "form1._program.value=&CS_MSR_LVL_DB";
		put 'form1.submit()';
	put '}';

    put 'function ResetPage() {';
	    put 'form1.filter_clause.value=""';
	    put 'form1.pd_score.value=""';
	    put 'form1.range_interval.value=""';
	    put 'form1.no_of_quantile.value=""';
	    put 'form1.filter.value="NO"';
		put 'form1._program.value="'@;
		put "&prg_name"@;
		put '";';
	    put 'form1.submit()';
    put '}'; 

/* Call the filter screen stored process */
	put 'function EditPage() {';
		put "form1._program.value=&CS_FLTR_SCRN";
		put 'form1.submit();';
	put '}';

	/*Function savepage() for saving the page to disk */
	%savepage;
	/*********savepage() ends here*************/

	/*Function printpage() for printing the page to a printer or to a pdf file*/
	%printpage;
	/*********printpage() ends here*************/

	put	'</script> ';
	put '</head> ';
	/************HIDDEN TEXT BOXEX WHERE GLOBAL PARAMETER ARE PASSED***********************/
	put	'<body><form name="form1" method="post" ACTION="/SASStoredProcess/do"> ';
	put '<input type="hidden" name="_program" VALUE="'@;
	put "&prg_name"@;
	put '">';

	prod_type_desc=symget("prod_type_desc");
		put '<input type="hidden" name="prod_type_desc" value="' @;
	put prod_type_desc;
		put '">';
	prod_type_code=symget("prod_type_code");
	put '<input type="hidden" name="prod_type_code" value="' @;
	put prod_type_code;
	put '">';
	model_type_code=symget("model_type_code");
	put '<input type="hidden" name="model_type_code" value="' @;
	put model_type_code;
	put '">';
	model1=symget("model1");
	put '<input type="hidden" name="model1" value="' @;
	put model1;
	put '">';
	model1_key=symget("model1_key");
	put '<input type="hidden" name="model1_key" value="' @;
	put model1_key;
	put '">';
	model2=symget("model2");
	put '<input type="hidden" name="model2" value="' @;
	put model2;
	put '">';

	model2_key=symget("model2_key");
	put '<input type="hidden" name="model2_key" value="' @;
	put model2_key;
	put '">';

	sel_model=symget("sel_model");
	put '<input type="hidden" name="sel_model" value="' @;
	put sel_model @;
	put '">';
	sel_model_key=symget("sel_model_key");
	put '<input type="hidden" name="sel_model_key" value="' @;
	put sel_model_key @;
	put '">';
	period=symget("period");
	put '<input type="hidden" name="period" value="' @;
	put period;
	put '">';

	time_key=symget("time_key");
	put '<input type="hidden" name="time_key" value="' @;
	put time_key;
	put '">';

	%put"&period";

	statistic=symget("statistic");
	put '<input type="hidden" name="statistic" value="'@;
	put statistic;
	put '">';
	filter=symget("filter");
	put '<input type="hidden" name="filter" value="'@;
	put filter;
	put '">';
	filter_clause=symget("filter_clause");
	put '<input type="hidden" name="filter_clause" value="'@;
	put filter_clause;
	put '">';

	pd_score=symget("pd_score");
	put '<input type="hidden" name="pd_score" value="' @;
	put pd_score;
	put '">';

	range_interval=symget("range_interval");
	put '<input type="hidden" name="range_interval" value="' @;
	put range_interval;
	put '">';

	no_of_quantile=symget("no_of_quantile");
	put '<input type="hidden" name="no_of_quantile" value="' @;
	put no_of_quantile;
	put '">';

	include_exp_mdl=symget("include_exp_mdl");
	put '<input type="hidden" name="include_exp_mdl" value="' @;
	put include_exp_mdl;
	put '">';

	prg_name=symget("prg_name");
	put '<input type="hidden" name="prg_name" value="' @;
	put prg_name;
	put '">';

	model_type_desc=symget("model_type_desc");
	put '<input type="hidden" name="model_type_desc" value="' @;
	put model_type_desc;
	put '">';

	outcome_period=symget("outcome_period");
	put '<input type="hidden" name="outcome_period" value="' @;
	put outcome_period;
	put '">';

	elapsed_time=symget("elapsed_time");
	put '<input type="hidden" name="elapsed_time" value="' @;
	put  elapsed_time;
	put '">';

	put '<input type="hidden" name="called_program" value="';
	put "&prg_name";
	put '">';
run;

/******** Thses values are used for alert if  no   data set is availabel i.e. out put of 
          feed mesure macro**********/
%global error_code;
%let error_code=NONE;
	/************ Macro generate_feed parameter passed
	in_filter				: Where clause (inclusive of the keyword where),
	out_lib_nm				: Library name where the output feed will be created. 
	out_table_nm_pool		: The table name for pool level feed
	out_table_nm_acct		: The table name for account/application level feed
	feed_for				: Possible values are PD, LGD, CCF, APPLPD, APPLLGD. This macro 
							  parameter decides whether estimated pd/lgd/ccf has to calculated 
							  at account level or application level
	pd_score				: Possible values are (Empty), PD, SCORE
	(empty)					: The default pooling technique will be used
	PD						: If PD then dynamic pooling technique will be used, 
							  based on PD/LGD/CCF as mentioned in the previous parameter 
								(feed_for) 
	SCORE					: If SCORE then dynamic pooling technique will be used,
							  based on SCORE_POINTS. Applicable only if PD or APPLPD value 
							  is set in the previous variable (feed_for)
	range_interval			: Dynamic pooling based on the range specified. E.g. 100, 200 for 
							  SCORE	and .2, .3 for PD. Similar ranges for LGD/CCF
	no_of_quantile			: The range for dynamic pooling will be decided based on the 
							  quantile.Quantile ranges will be calculated based on the 
							  SCORE/PD/LGD/CCF of  the scoring population for the selected 
								score period
	long_run				: Possible values Y/N. Whether the long run calculation is to be used 
							  to find estimated pd/lgd/ccf
	long_run_type			: Possible values are MAX/AVG. Method for calculating the long run 
							  pd/lgd/ccf macro_call example,
	model_time_key		:	This is the combination of  selected model and selected 
								time for that model (E.G. 100_1025 , 103_1027).
	product_type_code	: 	This is the selected product type code (E.G. MTG, LON).*/
%let model_time=_%sysfunc(ktrim(%sysfunc(kleft(&sel_model_key.))))_%sysfunc(ktrim(%sysfunc(kleft(&time_key.))));
%generate_feed(in_filter=&where_feed, out_lib_nm=&out_lib., 
	out_table_nm_pool=&out_pool, out_table_nm_acct=&out_account, feed_for=&feed_pd, long_run=&LONG_RUN,
	pd_score=&pd_score, range_interval=&range_interval, no_of_quantile=&no_of_quantile,
	long_run_type=&LONG_RUN_TYPE, model_time_key=&model_time, product_type_code=&prod_type_code);

/* Checks whether the generate_feed macro generated any error.
	If any error is generated then the ResetPage function defined above is called*/

data _NULL_;
	file _webout&webout_options;
	if ktrim(kleft("&error_code")) ne "NONE" and (ktrim(kleft("&filter_clause")) ne "" or ktrim(kleft("&pd_score")) ne "") then do;

		put '<script>';
		put '<!--';
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.alert_error_selec_filter_criteria.1, noquote))"@;
		put '")';
		put 'ResetPage()';
		put '//-->';
		put '</script>';
	end;
run;
/* Checks whether the dataset created in the generate_feed macro has any observations
			and sets cnt to the number of observations in the dataset*/

%let cnt=.;
proc sql noprint;
	select Count(*) into :cnt from &out_lib..&out_pool.;
quit;

%let log_name=;
data _NULL_;
      file _webout&webout_options;
if &cnt eq 0 and (ktrim(kleft("&filter_clause")) ne "" or ktrim(kleft("&pd_score")) ne "") then do;

            put '<script>';
            put '<!--';
			put 'alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.alert_error_no_data_available.1, noquote))"@;
			put '")';
            put 'ResetPage()';
            put '//-->';
            put '</script>';
    end;
	call symput('log_name',"&CS_DEBUG_PATH./&out_pool."||".log");
run;
/******ERROR TO GET LOG IN THE Specified LIBNAME*************/
%debug_log_file(log_file_nm=&log_name);

%let name_html=;
/* Data creation for measure_nm in a dataset and call for feed_measure values are taken on 
	model type code and program_nm*/

proc sql;
	create table &out_lib..&in_stat_ot as
	select measure_nm,help_file_nm
	from dim.measure_dim
	where kupcase(program_nm)=kupcase("&prg_name") 
	and model_type_cd="&model_type_code"
	order by measure_nm;
quit;
data _null_;
	set &out_lib..&in_stat_ot;
	call symput('name_html',help_file_nm);
run;
/******feed_measure required 
	   1.where condition on basis of filter clause
       2.out_lib=output liberary usually work (this could be changed) 
	   3.Input dataset as standard dataset defined above  
	   4.output dataset(required for statistic overtime graph)**********************/
%feed_measure(in_filter=&where_measure,out_lib_nm=&out_lib,in_table_nm=&in_stat_ot, out_table_nm_measure=&out_stat_ot);
/************************chek for the reoprt libname****************************************/

/* Creation of all graphs and call to overtime macro */
/*******PASSING DATA SET NAME, STATISTICS AND GRAPH NAME OVERTIME GRAPH This value will be 
     passed from Feed_measure macro output as 1.dataset 2.statistic 3.graphname******/
%statistic_overtime(&out_lib..&out_stat_ot,&statistic,&graph_name);


/******validation for distatnt statistic are passed in the dats set then ouput is taken
  		Distance_stats pool datset name as defined above according to statndards  is passed 
                                        ********************************/
%validation_input(input_ds=control.validation_grade,output_ds=&out_lib..validationscore);



/*****MACRO Distance_Stats parameter passed
	1. Input : Dataset with  values and name of distance statistics  
	2. Output: Tbale will have distance statistic 
		(PH ((1-PH) Statistic), D (D Statistic) etc.)**/

%distance_stats(input=&out_lib..&out_pool., diststat=&out_lib..Diststat);
 



/*****Data set to be passed will be 
1.output of Distance_Stats macro 
2.ouput of Validation_input macro 
3.Here we will get the outdatas set*******************************************************/
%interpolation(input_ds=&out_lib..Diststat,validation_score=&out_lib..validationscore,output_ds=&out_lib..val_scr);

%let min_val max_val;
proc sql ;
select max(Grade) format=&CS_DEC_FMT., min(Grade) format=&CS_DEC_FMT. into :max_val , :min_val
from &out_lib..val_scr;
quit;
/* Data creation for measure_nm in a dataset and call for feed_measure values are 
	taken on model type code and program_nm where dev_flag(Development flag) is Y (yes) */
proc sql noprint;
	select Measure_value format =&CS_DEC_FMT. into :MDL_MEASURE_VALUE
	from &out_lib..&out_stat_ot
	where upcase(dev_flg)="%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.dev_flag_y.1, noquote))"
	order by Measure_nm;
quit;

proc sql noprint;
select avg(grade) format=&CS_DEC_FMT. into :avg_valid_scr from &out_lib..val_scr;
quit;
 


data &out_lib..val_scr1;
	length measure_nm $100 ;
	format Measure_nm &format_name..;
	format measure_value &CS_DEC_FMT.;
	set &out_lib..val_scr (rename=(col1=measure_value));
 run;


/****************Model traffic (used to take a single color as output) 
1. Model type code (Eg. CCF LGD)
2. Value(Eg.0.123 etc) which will be generated from val_scr dataset 
   which is out dataset of macro interpolation.
3. Name of statistic(Eg.Information Value Statistic), 
   here color is taken on the basis of value , statistic and model_type_code
   this macro gives out single color on the basis of parameter passed***********************/
%let color=;
%model_traffic (model_cd=&model_type_code, value=&avg_valid_scr, ms_name=&statistic, product_type_code=&prod_type_code);
%let color=&color;
/***********Macro Pool_technique parameter passed
			1.pd_score 			:	If null then shown  as DEFAULT stautus.
			2.time_key        	:	The surrogate key for selected period.
            3.sel_model_key        :	The surrogate key for the selected model.
 			4.no_of_quantile    :	The range for dynamic pooling will be decided based on the 
								 	quantile.Quantile ranges will be calculated based on the 
								 	SCORE/PD/LGD/CCF of the scoring  population for the selected 
								 	score period  
		    5.range_interval    : 	Dynamic pooling based on the range specified. E.g. 100, 200 
			  						for SCORE and .2, .3 for PD.			
         ********************************************************************************/
%let pool_tech=;
%let time_period=;
%pool_technique;

%debug_log_web;
%let view_feed=&out_pool..html;
/************************HTML FRONT END START ***********************************/
data _null_;
file _webout&webout_options;
	name_html=symget("name_html");
	rep="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_validation_Score.1, noquote))";
	format rep &format_name..;
	put'<script>';
		/**************Help File *********************/
	%helpfile(filename=&name_html);

		/*************feed Table*********************/
	put 'function feed_table(){';
		put'window.open("/SASCSReports/'@; 
		put "&view_feed"@; 
	put '")};';
	
		/*********************************************/
	put'</script>';
	put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED"> ';
	put '<tr> ';
	put '<td align="left"> ';
	put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0"> ';
	put '<tr> ';
	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '<tr> ';

		/*Links on Top of the HTML Page*/
	put '<td><span class="BreadCrumb">'@;
	put '<a href="javascript:Link1()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.link_reporting.1, noquote))"@;
	put '</a> &gt;<a href="javascript:Link2()" >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.link_monitoring_model.1, noquote))"@;
	put '</a> &gt; <a href="javascript:Link3()" >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.link_sel_model.1, noquote))"@;
	put '</a> &gt; <a href="javascript:Link4()" >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.link_sel_stats.1, noquote))"@;
	put '</a> &gt;';
	put'</span><span class="BreadCrumb">'@;
/*	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.score_validation.stats_val_score.1, noquote))"@;*/
	put rep @;
	put'</span></td>';
  /******************* **********/

	put '<td width="215"><div align="right"><img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td> ';
	put '</tr> ';   
	put '</table><H2 align="left"><table width="100%"  border="0" cellspacing="0" cellpadding="0"><tr><td>';
	put rep @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.score_validation.stats_val_score_report.1, noquote))"@;
	put'</td>';
	if kupcase(&print) eq 'Y' then do;
		put '<td width=65><div align="center"><span class="LabelFont">';
		put '<a href="javascript:printpage()">';
		put '<img src="/SASCSReports/images/Print.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_print.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&save) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:enregistre()">';
		put '<img src="/SASCSReports/images/SaveFile.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_save.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&help) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:Info()">';
		put '<img src="/SASCSReports/images/Info.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_help.1, noquote))"@;
		put '</div></td>';
	end;
	put '</tr></table></H2>';
	put '</td></tr>';

	put '<tr> ';
	put '<td align="left"> ';
	put '			  <p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.label_model_type.1, noquote))"@;
	put "&model_type_desc";
	put' </p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.label_product_type.1, noquote))"@;
	put "&prod_type_desc";
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.label_period.1, noquote))"@;
/*I18N-scnhuh-20080427-1455*/	
/* del one line, add two lines. For displaying in NLS format */	
/*	put "&period" @;*/
		Period_WEBUI=put(input("&period",&CS_TIME_PER_FMT.),&NLDATE_FMT.);
		put Period_WEBUI @;
/*I18N-scnhuh-20080427-1455*/		
	put '</p>';
	put '			  <p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.label_model.1, noquote))"@;
	put"&sel_model";
	put '</p> ';
	put '			  <p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.label_pooling_tech.1, noquote))"@;
	put"&pool_tech";
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.label_outcome_period.1, noquote))"@;
	put "&outcome_period" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.label_months.1, noquote))"@;
	put "&elapsed_time" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.label_month_elapsed.1, noquote))"@;
	put '</p>';

	/* Number of months of Historic data */
	if kupcase("&model_type_code") eq kupcase(&PD_APP_MODEL.) then do;
		put '<p class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pd_stored_proc_hist.label_historic_data.1, noquote))"@;
		if upcase("&prod_type_code") eq upcase(&MTG_PRD_TYPE.) then do;
			put "&PDA_MTG_HIST" @;
		end;
		if upcase("&prod_type_code") eq upcase(&LON_PRD_TYPE.) then do;
			put "&PDA_LON_HIST" @;
		end;
		if upcase("&prod_type_code") eq upcase(&COR_PRD_TYPE.) then do;
			put "&PDA_COR_HIST" @;
		end;
		if upcase("&prod_type_code") eq upcase(&CCD_PRD_TYPE.) then do;
			put "&PDA_CCD_HIST" @;
		end;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pd_stored_proc_month.label_months.1, noquote))"@;
		put '</p>';
	end;

	put '<table  border="0" cellspacing="0" cellpadding="0"> ';
	put '<tr> ';
	put '<td><span class="LabelFont">' @;
	put rep @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.score_validation.actual_val.1, noquote))"@;
	put "&avg_valid_scr" @;
	put '       ('@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.score_validation.maximum_val.1, noquote))"@;
	put': ';
	put "&max_val";
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.score_validation.minimum_val.1, noquote))"@;
	put': ';
	put "&min_val" ;
	put')';
	put '</span></td><td>&nbsp;</td> ';
	put'<td width="25"><div align="center"><span class="LabelFont"><img src="/SASCSReports/images/';
			if "&color"="%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.color_white.1, noquote))" then do;
				put 'spacer.gif"';
			end;
			else do;
				put 'Sphere'@;
				put "&color";
				put'.gif"';
			end;
			put 'width="16" height="16" border="0"></a> </span></div></td> ';
	put '<td width="50"><span class="LabelFont"></span></td> ';

/* Modeling value for the given statistic.
	This will get displayed only if the filter is set to NO*/

	if kupcase("&filter") eq "NO" then do;
	    put '<td><span class="LabelFont">';
	    put rep ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.score_validation.modeling_val.1, noquote))"@;
		put': '; 
	    put "&mdl_measure_value"; 
	    put '</span></td> ';
	end;  

	put '</tr> ';
	put '<td>&nbsp;</td> ';
	put '</table>			 ';
	put '			  <p class="LabelFont">&nbsp;</p> ';
run;


/***Macro Draw table 
1.Input datas set
2.column name of passed data set,this is defined above as col_name where name of column 
  are provide this is  compulsary to be given by the user while defining col_names;
3.column lables of the datset ,this is defined as col_lables above this feild might be 
  empty for in that case  column lables should be there in the dataset	 	 
********************************/
%draw_table(ds=&out_lib..val_scr1,col_names=&cl_names,col_labels=&cl_labels);
/********************************************************************************/


data _null_;
	file _webout&webout_options;
	rep="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_validation_Score.1, noquote))";
	format rep &format_name..;
	put '</td> ';
	put '</tr> ';

	/* Code for displaying overtime graph.
		This will get displayed only if filter is set to NO */
	if kupcase("&filter") eq "NO" then do;
		put '<tr> ';
		put '<td align="left"> ';
		put '<p> ';
		put '<H2 align="left">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.score_validation.graph_nm.1, noquote))"@;
		put '</H2> ';
		put '</p>';
		put '</td> ';
		put '</tr> ';
		put '<tr><td><table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
		put '</tr> ';
		put '<td width="49%" valign="top"><fieldset> ';
		put '<legend><span class="style2">';
		put rep @;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.score_validation.stats_overtime.1, noquote))"@;
		put': ';
		put '</span></legend> ';
		put '<p><img border="0" src="/SASCSReports/';
		put "&graph_name";
		put '.gif"'; 
		put ' width="460" height="200"></p> ';
		put  '</fieldset></td> ';
		put '<td width="49%" valign="top">';
		put '</td> ';
	end;
	else do;
	 	put '<tr><td><table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
		put '</tr> ';
		put '<td width="49%" valign="top">';
		put '</td> ';
  	end;
	put '</tr></table>';
	put '<p>&nbsp;</p></td>';
	put '</tr> ';
	put '</table> ';
	put '<p>&nbsp;</p></td> ';
	put '		  </tr> ';
	put '<tr> ';
	put '<td height="32" bgcolor="#F1EACB">&nbsp;&nbsp;';

	/* Edit and Reset button will get displayed only if the pooling technique
		 is not of clustering type*/
	val=PRXMATCH(kupcase('/cluster/'),kupcase("&pool_tech"));
	if val = 0 then do;
		put '<INPUT type=button class=mmhide_btn onClick="EditPage()" value="'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.button_filter_repool.1, noquote))"@;
		put'">';
		put '<INPUT type=button class=mmhide_btn onClick="ResetPage()" value="'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.button_reset.1, noquote))"@;
		put'">';
	end;
	put '<INPUT type="button" class=mmhide_btn value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.stability_index_lgd.button_view_feed.1, noquote))"@;
	put'" onClick="feed_table()">';
	put '</td>';
	put '</tr>';
	put '</table> ';
	put '</form> ';
	put '</body> ';
	put '</html> ';
run;
/******************************HTML UI END HERE ***************************************/
/******macro feed_table pass parameter  separated by #

		Input parameter 
		1.dt_st =Pass dataset name in string separated by #
		2.dt_nm=pass name u want to give to the table
		3.out_libout library  which is defined above
		        *****************************************************************/

	 /*I18N-scnjih-20080421-1517*/
/*%let dt_nm=Pool Feed;*/
%let dt_nm=%sysfunc(sasmsg(smd_ds.bismsg,Call_feed_table.sas.dt_nm.1, noquote));
data &out_lib..&out_pool._1; 
set &out_lib..&out_pool.;
SCORE_POINTS=round(SCORE_POINTS);
run;

/*I18N-scnjih-20080424-0928*/
%let dt_st=&out_pool._1;
%feed_table(ds=&dt_st,out_lib1=&out_lib,data_name=&dt_nm,name_html=&view_feed);

goptions reset=all;
options nomprint;
