/******************************************************************************************************
       Module:  create_master_scale

     Function:  To create a new master scale

      Authors:  BIS Team
         Date:  14 May 2007
          SAS:  9.1
    Called-by:	pool_main
        Calls:  select_master_scale

Datasets used:  1. pool.master_scale_defn: Retrieves the defn of existing master scale and saves the defn
					for new master scales in this dataset

        Logic:  1. The user may select an existing master scale which will be displayed on the screen
				2. If an existing master scale defn exists the user may edit the defn by editing the
					information in a row of the defn or by deleting one row or deleting all rows in the
					defn or by adding a new row to the definition.
				3. The user may also use any of the above mentioned actions to create a new master
					scale defn
				4. Clicking save saves the new or edited master scale defn displayed on screen.
				5. The available actions are:
						N: None.
						M: New MS & MS Details
						R: Add Row
						D: Delete Row
						X: Delete All Rows
						E: Edit Row
						U: Update Row
						A: Add RG info
						S: Save

   Parameters:  ms_no 		: The unique identifier of an existing master scale
   				ms_nm		: The name for an existing or new master scale
				action 		: Screen action code
				grade		: The grade code assigned to the record in the master scale
				grade_name	: The grade name assigned to the record in the master scale
				pd			: The pd value assigned to the record in the master scale
				ms_seq		: The unique identifier of a record in an existing master scale
				first_load	: Specifies that the screen is being displayed for the first time for a
								selected master scale.

 ******************************************************************************************************/
/*This code is Internationalized*/
options nomprint;

/* Global Input Parameters */
%global ms_no ms_nm action grade grade_name pd ms_seq first_load;

%let lib=pool;

/* Setting default values for any required parameters */
data _null_;
	if "&action"="" then call symput('action','N');
	if "&ms_no"="" then call symput('ms_no','.');
	if "first_load"="" then call symput('first_load', 'Y');
run;

/* Trimming extra spaces for all input paremeters */
%macro check_macro_variable;
%if "&ms_no" ne "" %then
	%let ms_no=%sysfunc(ktrim(%sysfunc(kleft(&ms_no))));
%if "&ms_nm" ne "" %then
	%let ms_nm=%sysfunc(ktrim(%sysfunc(kleft(&ms_nm))));
%if "&grade" ne "" %then
	%let grade=%sysfunc(ktrim(%sysfunc(kleft(&grade))));
%if "&grade_name" ne "" %then
	%let grade_name=%sysfunc(ktrim(%sysfunc(kleft(&grade_name))));
%if "&pd" ne "" %then
	%let pd=%sysfunc(ktrim(%sysfunc(kleft(&pd))));
%if "&ms_seq" ne "" %then
	%let ms_seq=%sysfunc(ktrim(%sysfunc(kleft(&ms_seq))));
%if "&first_load" ne "" %then
	%let first_load=%sysfunc(ktrim(%sysfunc(kleft(&first_load))));
	/**/
%mend;
%check_macro_variable;

/* Links specific for the Master Scale screens */
%let CREATE_MS='SBIP://Foundation/BIS/pool/create_master_scale';
%let SELECT_MS='SBIP://Foundation/BIS/pool/select_master_scale';

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;

%macro add_scheme;
/*Code to remove the doubble quotes or single quotes if present*/
			%let grade_c1=%index(&grade,%str(%'));
			%let grade_c2=%index(&grade,%str(%"));

			%let grade_name_c1=%index(&grade_name,%str(%'));
			%let grade_name_c2=%index(&grade_name,%str(%"));


			data _null_;
			%if %str(&grade_c1) ne %str(0) %then %do;
				x=compress(&grade,"'");
				call symput('grade',x);
			%end;
			%else %if %str(&grade_c2) ne %str(0) %then %do;
				x=compress(&grade,'"');
				call symput('grade',x);
			%end;
			%if %str(&grade_name_c1) ne %str(0) %then %do;
				x=compress(&grade_name,"'");
				call symput('grade_name',x);
			%end;
			%else %if %str(&grade_name_c2) ne %str(0) %then %do;
				x=compress(&grade_name,'"');
				call symput('grade_name',x);
			%end;			
			
			run;
/**************************************/


	%if %str(&action) = %str(N) %then %do;
		/* No Action */
/*		proc sql;*/
/*			create table &lib..ms_details as*/
/*			select ms_seq_no, ms_rating_grade_cd, ms_grade_name, ms_grade_pd_no*/
/*			from &lib..master_scale_defn*/
/*			where master_scale_no=&ms_no;*/
/*		quit;*/
		proc sql;
			drop table &lib..ms_details;
		quit;

		data _null_;
			file _webout&webout_options;
			put '        </table>';
			put '		<tr><td>&nbsp;</td></tr>';
			put '		<tr> ';
			put '			<td height="32" bgcolor="#F1EACB">&nbsp; ';
			put '				<input type="button" name="Submit5" value="'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.button_new_master_scale.1, noquote))"@;
			put'" class="mmhide_btn" onClick="javascript:newMS()" />';
			put '			</td> ';
			put '		</tr> ';
		run;
	%end;
	%else %if %str(&action) = %str(M) or %str(&action) = %str(R) or
		%str(&action) = %str(A) or %str(&action) = %str(E) or
		%str(&action) = %str(U) %then %do;
		/* Action = New MS / MS Details / Add Row / Add RG info / Edit Row / Update Row */

		%if %str(%sysfunc(kupcase(&first_load))) = %str(Y) %then %do;
			proc sql;
				create table &lib..ms_details as
				select ms_seq_no, ms_rating_grade_cd, ms_grade_name, ms_grade_pd_no
				from &lib..master_scale_defn
				where master_scale_no=&ms_no;
			quit;
		%end;

		%if %str(&action) = %str(A) %then %do;
			/* Only for Add RG info */
			%let error_code=NONE;

			/*Proc printto will redirect the log to the directory
			"Data/bisdata/error". */
			%global log_name;
			data _NULL_;
			name=put(time(),mmss8.1);
			name1=kscan(name,1,":.");
			name2=kscan(name,2,":.");
			name3=kscan(name,3,":.");
			name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
			call symput('log_name',"Data/bisdata/log/create_ms_"||ktrim(kleft(name4))||".log");
			run;

			%put NOTE: Sending log messages to :&log_name;

			proc printto log="&log_name";
			quit;

			%let seq=0;
			proc sql noprint;
				select max(ms_seq_no) into :seq
				from &lib..ms_details;

				%if %str(%sysfunc(ktrim(%sysfunc(kleft(&seq)))))= %str(.) %then %let seq=1;
				%else %let seq=%eval(&seq+1);

				insert into &lib..ms_details
					(ms_seq_no, ms_rating_grade_cd, ms_grade_name, ms_grade_pd_no)
				values(&seq, "&grade", "&grade_name", &pd);
			quit;
			%if &sqlrc > 4 %then %do;
				%let error_code = ERROR;
			%end;

			/*Proc printto will reset the log redirection */
			proc printto;
			quit;

			%put NOTE: Resetting log to _webout&webout_options;;
			/*End of proc printto */

			/* Show the relevant messages on the screen */
			data _null_;
				file _webout&webout_options;
				put '<script language="JavaScript" type="text/JavaScript"> ';
				put '<!-- ';
			%if %str(&error_code) eq %str(ERROR) %then %do;
				put '	alert("'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_data_not_added_p1.1, noquote))"@;
				put "&log_name"@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_data_not_added_p2.1, noquote))"@;
				put'")';
			%end;
				put '	cancelRow()';
				put '//-->';
				put	'</script> ';
			run;
		%end;
		%else %if %str(&action) = %str(U) %then %do;
			/* Only for Update RG info */
			%let error_code=NONE;

			/*Proc printto will redirect the log to the directory
			"Data/bisdata/error". */
			%global log_name;
			data _NULL_;
			name=put(time(),mmss8.1);
			name1=kscan(name,1,":.");
			name2=kscan(name,2,":.");
			name3=kscan(name,3,":.");
			name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
			call symput('log_name',"Data/bisdata/log/create_ms_"||ktrim(kleft(name4))||".log");
			run;

			%put NOTE: Sending log messages to :&log_name;

			proc printto log="&log_name";
			quit;

			%let seq=0;
			
			proc sql noprint;
				update &lib..ms_details set ms_rating_grade_cd="&grade",
					ms_grade_name="&grade_name", ms_grade_pd_no=&pd
				where ms_seq_no=&ms_seq;
			quit;
			%if &sqlrc > 4 %then %do;
				%let error_code = ERROR;
			%end;

			/*Proc printto will reset the log redirection */
			proc printto;
			quit;

			%put NOTE: Resetting log to _webout&webout_options;
			/*End of proc printto */

			/* Show the relevant messages on the screen */
			data _null_;
				file _webout&webout_options;
				put '<script language="JavaScript" type="text/JavaScript"> ';
				put '<!-- ';
			%if %str(&error_code) eq %str(ERROR) %then %do;
				put '	alert("'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_data_not_updated_p1.1, noquote))"@;
				put "&log_name"@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_data_not_updated_p2.1, noquote))"@;
				put'")';
			%end;
				put '	cancelRow()';
				put '//-->';
				put	'</script> ';
			run;
		%end;

		/* This part is common to all */
		data _null_;
			file _webout&webout_options;
			put '				</table>';
			put '			</tr></td>';
			put '		</table>';
			put '		</td></tr>';
			put '		<tr><td>&nbsp;</td></tr>';
			put '		<tr>';
			put '			<td><table width="60%" border="0" cellpadding="0" cellspacing="0" bgcolor="#7F9DB9" class="tableborder">';
			put '          		<tr>';
			put '            		<td valign="top"><table width="100%" border="0" cellpadding="3" cellspacing="0">';
			put '                		<tr bgcolor="#FFFFFF">';
		    put '              	   			<td width="15" align="center" class="HZtableborder">';
				/*<!-- slide down content goes here -->*/
			put '								<div id="dhtmlgoodies_slidedown">';
			put '								<div id="dhtmlgoodies_control"><a href="#" onclick="slidedown_showHide();return false;"><img src="/SASCSPooling/images/ActionMenu.gif" style="border:0"/></a>
			</div>';
			put '								<div id="dhtmlgoodies_contentBox">';
			put '									<div id="dhtmlgoodies_content">';
			put '									<table width="100%" border="1" class="tableborder" cellpadding="3" cellspacing="0">';
			put '										<tr><td>';
			put '										<table width="100%" border="0" cellpadding="3" cellspacing="0">';
			put '										<tr>';
			put '											<td width=5% align="center">';
			put '												<input type="radio" name="action_radio" value="R"></td>';
			put '											<td width=35% align="left">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.radio_add_row.1, noquote))"@;
			put'</td>';
			put '										</tr>';

			put '										<tr>';
			put '											<td width=5% align="center">';
			put '												<input type="radio" name="action_radio" value="E"></td>';
			put '											<td width=35% align="left">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.radio_edit_Row.1, noquote))"@;
			put'</td>';
			put '										</tr>';

			put '										<tr>';
			put '											<td width=5% align="center">';
			put '												<input type="radio" name="action_radio" value="D"></td>';
			put '											<td width=35% align="left">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.radio_delete_row.1, noquote))"@;
			put'</td>';
			put '										</tr>';

			put '										<tr>';
			put '											<td width=5% align="center">';
			put '												<input type="radio" name="action_radio" value="X"></td>';
			put '											<td width=35% align="left">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.radio_delete_all_row.1, noquote))"@;
			put'</td>';
			put '										</tr>';
			put '										</table>';

			put '										<table width="100%" border="0" cellpadding="3" cellspacing="0">';
			put '										<tr>';
			put '											<td align="left">&nbsp;';
			put '												<INPUT type=button class=mmhide_btn onClick="javascript:OK()" value="'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.button_ok.1, noquote))"@;
			put'">';
			put '												<INPUT type=button class=mmhide_btn onclick="slidedown_showHide();return false;" value="'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.button_cancel.1, noquote))"@;
			put'"></td>';
			put '										</tr>';
			put '										</table>';
			put '										<tr><td>';
			put '									</table>';
			put '									</div>';
			put '								</div>';
			put '								</div>';
				/*		<!-- End slide down content -->*/
			put '							</td>';
			put '                  			<td class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.column_rating_grade.1, noquote))"@;
			put '</td>';
			put '                  			<td class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.column_rating_grade_name.1, noquote))"@;
			put ' </td>';
			put '                  			<td class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.column_pd.1, noquote))"@;
			put'</td>';
			put '                		</tr>';
		run;

		data _NULL_;
			file _webout&webout_options;
			set &lib..ms_details;
			if  mod(_N_,2)=0 then
				put '                		<tr bgcolor="#F4F4F2">';
			else
				put '                		<tr bgcolor="#FFFFFF">';
		    put '              	   			<td width="15" class="LabelFont"><div align="center">'@;
		    put '<input type="radio" name="checkbox" value="'@;
			put ms_seq_no@;
			put '" onClick="javascript:setMS(this.value)" />'@;
		    put '							</div></td>';
			put '              	   			<td class="verttebleborder">' @;
			put ms_rating_grade_cd@;
			put '</td>';
			put '              	   			<td class="verttebleborder">' @;
			put ms_grade_name@;
			put '</td>';
			put '              	   			<td class="verttebleborder">' @;
			put ms_grade_pd_no@;
			put '</td>';
			put '                		</tr>';
		run;

		data _NULL_;
			file _webout&webout_options;
			put '            		</table></td>';
			put '          		</tr>';
			put '			</table>';
			put '			<tr><td>&nbsp;</td></tr>';
		run;

		%put ******Action=&action***********;

		%if %str(&action) = %str(M) %then %do;
			/* Only for New MS / MS Details */
			data _null_;
				file _webout&webout_options;
				put '			<tr><td>&nbsp;</td></tr>';
				put '			<tr> ';
				put '				<td height="32" bgcolor="#F1EACB">&nbsp; ';
				put '					<input type="button" name="Submit5" value="'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.button_save.1, noquote))"@;
				put '" class="mmhide_btn" onClick="javascript:Save()" />';
				put '					<input type="button" name="Submit5" value="'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.button_cancel.1, noquote))"@;
				put '" class="mmhide_btn" onClick="javascript:Cancel()" />';
				put '				</td> ';
				put '			</tr> ';
			run;
		%end;
		%else %if %str(&action) = %str(R) %then %do;
			/* Only for Add Row */
			data _null_;
				file _webout&webout_options;
				put '			<tr>';
				put '				<td>';
				put '					<H2 align="left">';
				put '						<table width="100%" border="0" cellspacing="0" cellpadding="0">';
				put '							<tr><td>'@;
 				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.rating_grade_inf.1, noquote))"@;
				put '</td>';
				put '							</tr>';
				put '						</table>';
				put '					</H2>';
				put '				</td>';
				put '			</tr>';

				put '		<tr>';
				put '			<td><table width="60%" border="0" cellpadding="3" cellspacing="0">';
				put '          		<tr>';
				put '					<td class="LabelFont" width="25%">'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.rating_grade.1, noquote))"@;
				put '</td>';
				put '					<td class="LabelFont">';
				put '						<input type="text" size="45" name="grade" value="">';
				put '					</td>';
				put '				</tr>';
				put '          		<tr>';
				put '					<td class="LabelFont">'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.rating_grade_nm.1, noquote))"@;
				put '</td>';
				put '					<td class="LabelFont">';
				put '						<input type="text" size="45" name="grade_name" value="">';
				put '					</td>';
				put '				</tr>';
				put '          		<tr>';
				put '					<td class="LabelFont">'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.pd.1, noquote))"@;
				put'</td>';
				put '					<td class="LabelFont">';
				put '						<input type="text" size="45" name="pd" value="">';
				put '					</td>';
				put '				</tr>';
				put '			</table></td>';
				put '			<tr><td>&nbsp;</td></tr>';
				put '			<tr> ';
				put '				<td height="32" bgcolor="#F1EACB">&nbsp; ';
				put '					<input type="button" name="Submit5" value="'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.button_add.1, noquote))"@;
				put '" class="mmhide_btn" onClick="javascript:Add()" />';
				put '					<input type="button" name="Submit5" value="'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.button_cancel.1, noquote))"@;
				put '" class="mmhide_btn" onClick="javascript:cancelRow()" />';
				put '				</td> ';
				put '			</tr> ';

			run;
		%end;
		%else %if %str(&action) = %str(E) %then %do;
			/* Only for Edit Row */
			/* Get information to edit */
			/* To edit a row in a master scale, read from temp table pool.ms_details */
			proc sql noprint;
				select ms_rating_grade_cd, ms_grade_name, ms_grade_pd_no
					into :rg_cd, :rg_nm, :rg_pd
				from &lib..ms_details
				where ms_seq_no=&ms_seq;
			quit;

			%let rg_cd=%sysfunc(ktrim(%sysfunc(kleft(&rg_cd))));
			%let rg_nm=%sysfunc(ktrim(%sysfunc(kleft(&rg_nm))));
			%let rg_pd=%sysfunc(ktrim(%sysfunc(kleft(&rg_pd))));

			data _null_;
				file _webout&webout_options;
				put '			<tr>';
				put '				<td>';
				put '					<H2 align="left">';
				put '						<table width="100%" border="0" cellspacing="0" cellpadding="0">';
				put '							<tr><td>'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.rating_grade_inf.1, noquote))"@;
				put'</td>';
				put '							</tr>';
				put '						</table>';
				put '					</H2>';
				put '				</td>';
				put '			</tr>';

				put '		<tr>';
				put '			<td><table width="60%" border="0" cellpadding="3" cellspacing="0">';
				put '          		<tr>';
				put '					<td class="LabelFont" width="15%">'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.column_rating_grade.1, noquote))"@;
				put '</td>';
				put '					<td class="LabelFont">';
				put '						<input type="text" size="45" name="grade" value="'@;
				put "&rg_cd"@;
				put '">'@;
				put '					</td>';
				put '				</tr>';
				put '          		<tr>';
				put '					<td class="LabelFont" width="15%">'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.column_rating_grade_name.1, noquote))"@;
				put '</td>';
				put '					<td class="LabelFont">';
				put '						<input type="text" size="45" name="grade_name" value="'@;
				put "&rg_nm"@;
				put '">'@;
				put '					</td>';
				put '				</tr>';
				put '          		<tr>';
				put '					<td class="LabelFont" width="15%">'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.column_pd.1, noquote))"@;
				put '</td>';
				put '					<td class="LabelFont">';
				put '						<input type="text" size="45" name="pd" value="'@;
				put "&rg_pd"@;
				put '">'@;
				put '					</td>';
				put '				</tr>';
				put '			</table></td>';
				put '			<tr><td>&nbsp;</td></tr>';
				put '			<tr> ';
				put '				<td height="32" bgcolor="#F1EACB">&nbsp; ';
				put '					<input type="button" name="Submit5" value="'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.button_update.1, noquote))"@;
				put'" class="mmhide_btn" onClick="javascript:updateRow()" />';
				put '					<input type="button" name="Submit5" value="'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.button_cancel.1, noquote))"@;
				put'" class="mmhide_btn" onClick="javascript:cancelRow()" />';
				put '				</td> ';
				put '			</tr> ';

			run;
		%end;
	%end;
	%else %if %str(&action) = %str(D) %then %do;
		/* Action = Delete Row */
		%let error_code=NONE;

		/*Proc printto will redirect the log to the directory
		"Data/bisdata/error". */
		%global log_name;
		data _NULL_;
		name=put(time(),mmss8.1);
		name1=kscan(name,1,":.");
		name2=kscan(name,2,":.");
		name3=kscan(name,3,":.");
		name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
		call symput('log_name',"Data/bisdata/log/create_ms_"||ktrim(kleft(name4))||".log");
		run;

		%put NOTE: Sending log messages to :&log_name;

		proc printto log="&log_name";
		quit;

		proc sql noprint;
			delete from &lib..ms_details where ms_seq_no = &ms_seq;
		quit;
		%if &sqlrc > 4 %then %do;
			%let error_code = ERROR;
		%end;

		/*Proc printto will reset the log redirection */
		proc printto;
		quit;

		%put NOTE: Resetting log to _webout&webout_options;;
		/*End of proc printto */

		/* Show the relevant messages on the screen */
		data _null_;
			file _webout&webout_options;
			put '<script language="JavaScript" type="text/JavaScript"> ';
			put '<!-- ';
		%if %str(&error_code) eq %str(ERROR) %then %do;
			put '	alert("'@;
			put  "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_data_not_deleted_p1.1, noquote))"@;
			put "&log_name"@;
			put  "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_data_not_deleted_p2.1, noquote))"@;
			put '")';
		%end;
			put 'cancelRow()';
			put '//-->';
			put	'</script> ';
		run;
	%end;
	%else %if %str(&action) = %str(X) %then %do;
		/* Action = Delete All Rows */
		%let error_code=NONE;

		/*Proc printto will redirect the log to the directory
		"Data/bisdata/error". */
		%global log_name;
		data _NULL_;
		name=put(time(),mmss8.1);
		name1=kscan(name,1,":.");
		name2=kscan(name,2,":.");
		name3=kscan(name,3,":.");
		name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
		call symput('log_name',"Data/bisdata/log/create_ms_"||ktrim(kleft(name4))||".log");
		run;

		%put NOTE: Sending log messages to :&log_name;

		proc printto log="&log_name";
		quit;

		proc sql noprint;
			delete from &lib..ms_details;
		quit;
		%if &sqlrc > 4 %then %do;
			%let error_code = ERROR;
		%end;

		/*Proc printto will reset the log redirection */
		proc printto;
		quit;

		%put NOTE: Resetting log to _webout&webout_options;;
		/*End of proc printto */

		/* Show the relevant messages on the screen */
		data _null_;
			file _webout&webout_options;
			put '<script language="JavaScript" type="text/JavaScript"> ';
			put '<!-- ';
		%if %str(&error_code) eq %str(ERROR) %then %do;
			put '	alert("'@;
			put  "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_data_not_deleted_p1.1, noquote))"@;
			put "&log_name"@;
			put  "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_data_not_deleted_p2.1, noquote))"@;
			put '")';
		%end;
			put 'cancelRow()';
			put '//-->';
			put	'</script> ';
		run;
	%end;
	%else %if %str(&action) = %str(S) %then %do;
		/* Action = Save */
		%let error_code=NONE;

		/*Proc printto will redirect the log to the directory
		"Data/bisdata/error". */
		%global log_name;
		data _NULL_;
		name=put(time(),mmss8.1);
		name1=kscan(name,1,":.");
		name2=kscan(name,2,":.");
		name3=kscan(name,3,":.");
		name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
		call symput('log_name',"Data/bisdata/log/create_ms_"||ktrim(kleft(name4))||".log");
		run;

		%put NOTE: Sending log messages to :&log_name;

		proc printto log="&log_name";
		quit;

		/* If ms_no = missing, then it is a new master scale
				Check if scale name exists
				Get highest master scale no
				Append new rows to master_scale_defn
		   If ms_no has a value, then it is an existing master scale
				Delete rows for master_scale_no=ms_no
				Append new rows to master_scale_defn
		*/
		%if &ms_no eq . %then %do;
			/* New Master Scale */
			/* Check if scale name exists */
			%let cnt=0;
			proc sql noprint;
				select count(*) into :cnt
				from &lib..master_scale_defn
				where master_scale_name="&ms_nm";
			quit;
			%if &sqlrc > 4 or &cnt > 0 %then %do;
				/* If exists then give name error */
				%let error_code = ERRORNM;
			%end;
			%else %do;
				/* Continue with creating dataset to append */
				%let seq=0;
				proc sql noprint;
					select max(master_scale_no) into :seq
					from &lib..master_scale_defn;
				quit;
				%if &sqlrc > 4 %then %do;
					/* Error */
					%let error_code = ERROR;
				%end;
				%else %do;
					/* Continue with creating dataset to append */
					%if %str(%sysfunc(ktrim(%sysfunc(kleft(&seq)))))= %str(.) %then %let seq=1;
					%else %let seq=%eval(&seq+1);

					/* Create dataset to append */
					data &out_lib..temp_ms_defn;
						set &lib..ms_details;
						master_scale_no=&seq;
						master_scale_name="&ms_nm";
					run;
				%end;
			%end;
		%end;
		%else %if &ms_no > 0 %then %do;
			/* Existing Master Scale */
			proc sql;
				create table &lib..master_scale_defn as
				select *
				from &lib..master_scale_defn
				where master_scale_no ne &ms_no;
			quit;
			%if &sqlrc > 4 %then %do;
				/* Error */
				%let error_code = ERROR;
			%end;
			%else %do;
				/* Create dataset to append */
				data &out_lib..temp_ms_defn;
					set &lib..ms_details;
					master_scale_no=&ms_no;
					master_scale_name="&ms_nm";
				run;
			%end;
		%end;

		%if %str(&error_code) eq %str(NONE) %then %do;
			/* Append the rows */
			proc append data=&out_lib..temp_ms_defn base=&lib..master_scale_defn force;
			quit;
		%end;

		/*Proc printto will reset the log redirection */
		proc printto;
		quit;

		%put NOTE: Resetting log to _webout&webout_options;;
		/*End of proc printto */

		/* Show the relevant messages on the screen */
		data _null_;
			file _webout&webout_options;
			put '<script language="JavaScript" type="text/JavaScript"> ';
			put '<!-- ';
		%if %str(&error_code) eq %str(ERRORNM) %then %do;
			put '	alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_master_scale_p1.1, noquote))"@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_master_scale_p2.1, noquote))"@;
			put '")';
			put '	cancelRow()';
		%end;
		%else %if %str(&error_code) eq %str(ERROR) %then %do;
			put '	alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_grade_data_p1.1, noquote))"@;
			put "&log_name"@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_grade_data_p2.1, noquote))"@;
			put '")';
			put '	cancelRow()';
		%end;
		%else %if %str(&error_code) eq %str(NONE) %then %do;
			put '	alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_master_scale_data_saved.1, noquote))"@;
			put '")';
			put '	form1.first_load.value=''Y''';
			put '	Cancel()';
		%end;
			put '//-->';
			put	'</script> ';
		run;
	%end;

%mend add_scheme;

/* Start HTML Screen */
data _null_;
	file _webout&webout_options;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" ';
	put '"http://www.w3.org/TR/html4/loose.dtd"> ';
	put '<html> ';
	put '<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.title_pooling.1, noquote))"@;
	put'</title> ';
	put '<link href="/SASCSPooling/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<style type="text/css">';
	put '<!--';
	put 'body {';
	put '	background-color: #FAF8ED;';
	put '}';
	put '-->';
	put '</style>';

	put '	<style type="text/css"> ';
	put '	#dhtmlgoodies_contentBox{ ';
	put '		border:1px solid #7F9DB9; ';
	put '		height:0px; ';
	put '		visibility:hidden; ';
	put '		position:absolute; ';
	put '		background-color:#FAF8ED; ';
	put '		overflow:hidden; ';
	put '		padding:2px; ';
	put '		width:150px; ';
	put '	} ';
	put '	#dhtmlgoodies_content{ ';
	put '		position:relative;		 ';
	put '		font-family: Trebuchet MS ';
	put '		width:100%; ';
/*	put '		font-size:0.8em; ';*/
	put '	} ';
	put '	#dhtmlgoodies_slidedown{ ';
	put '		position:relative; ';
	put '		width:20px; ';
	put '	} ';
	put '	</style> ';

	put '<script language="JavaScript" src="/SASCSPooling/script/action_menu.js"></script>';
	put '<script language="JavaScript" type="text/JavaScript"> ';
	put '<!-- ';

	put 'function Select(){';
	put "	form1._program.value=&SELECT_MS";
	put '	form1.submit();';
	put '}';

	put 'function setMSName() {';
	put '	form1.ms_no.value=''''';
	put '	form1.ms_nm.value=form1.ms_name.value';
	put '}';

	put 'function setMS(val) {';
	put '	form1.ms_seq.value=val';
	put '}';

	put 'function newMS() {';
	put '	form1.first_load.value=''Y''';
	put '	form1.ms_no.value=''''';
	put '	form1.ms_nm.value=''''';
	put "	form1._program.value=&CREATE_MS";
	put '	form1.action.value="M"';
	put '	form1.submit();';
	put '}';

	put 'function addRow() {';
	put "	form1._program.value=&CREATE_MS";
	put '	form1.action.value="R"';
	put '	form1.submit();';
	put '}';

	put 'function editRow() {';
	put '	if ((form1.ms_seq.value == '''') || (form1.ms_seq.value == '' '')) {';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_select_row_edit.1, noquote))"@;
	put'")';
	put '		slidedown_showHide();';
	put '	}';
	put '	else {';
	put "		form1._program.value=&CREATE_MS";
	put '		form1.action.value="E"';
	put '		form1.submit();';
	put '	}';
	put '}';

	put 'function updateRow() {';
	put "	form1.ms_seq.value=&ms_seq";
	put "	form1._program.value=&CREATE_MS";
	put '	form1.action.value="U"';
	put '	form1.submit();';
	put '}';

	put 'function deleteRow() {';
	put '	if ((form1.ms_seq.value == '''') || (form1.ms_seq.value == '' '')) {';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_select_row_delete.1, noquote))"@;
	put '")';
	put '		slidedown_showHide();';
	put '	}';
	put '	else {';
	put "		form1._program.value=&CREATE_MS";
	put '		form1.action.value="D"';
	put '		form1.submit();';
	put '	}';
	put '}';

	put 'function deleteAllRows() {';
	put "	form1._program.value=&CREATE_MS";
	put '	form1.action.value="X"';
	put '	form1.submit();';
	put '}';

	put 'function Add() {';
	put "	form1._program.value=&CREATE_MS";
	put '	form1.action.value="A"';
	put '	form1.submit();';
	put '}';

	put 'function cancelRow() {';
	put '	form1.action.value="M"';
	put "	form1._program.value=&CREATE_MS;";
	put '	form1.submit()';
	put '}';

	put 'function OK() {';
	put '	for(var i=0; i<form1.action_radio.length; i++){';
	put '		if(form1.action_radio[i].checked == true){';
	put '			val = form1.action_radio[i].value';
	put '			if(val == "R") addRow()';
	put '			else if(val == "D") deleteRow()';
	put '			else if(val == "E") editRow()';
	put '			else if(val == "X") deleteAllRows()';
	put '		}';
	put '	}';
	put '}';

	put 'function Cancel() {';
	put '	form1.ms_no.value=''''';
	put '	form1.ms_nm.value=''''';
	put '	form1.action.value=''N''';
	put "	form1._program.value=&CREATE_MS;";
	put '	form1.submit()';
	put '}';

	put 'function Save() {';
	put '	if ((form1.ms_nm.value == '''') || (form1.ms_nm.value == '' '')) {';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.alert_master_scale_name_save.1, noquote))"@;
	put '")';
	put '	}';
	put '	else {';
	put '		form1.action.value="S"';
	put "		form1._program.value=&CREATE_MS;";
	put '		form1.submit()';
	put '	}';
	put '}';

	put '//-->';
	put	'</script> ';
	put '</head>';

	put '<body>';
	put '<form name="form1" method="post" ACTION="/SASStoredProcess/do"> ';

	/* Hidden textboxes to hold the values for the program name and the output paremeters */
	put '<input type="hidden" name="_program" VALUE="">';
	ms_no=symget("ms_no");
	x='<input type="hidden" name="ms_no" value="'||strip(ms_no)||'">';
	put x;
	ms_nm=symget("ms_nm");
	x='<input type="hidden" name="ms_nm" value="'||strip(ms_nm)||'">';
	put x;
	ms_seq=symget("ms_seq");
	x='<input type="hidden" name="ms_seq" value="'||strip(ms_seq)||'">';
	put x;
	put '<input type="hidden" name="action" value="N">';
	put '<input type="hidden" name="first_load" value="N">';
	/**/
run;

data _null_;
	file _webout&webout_options;
	put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED"> ';
	put '	<tr> ';
	put '		<td align="left"> ';
	put '		<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0"> ';
	put '			<tr> ';
	put '				<td>';
	put '				<table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
	put '					<tr> ';

	/* Navigational Links */
	put '						<td><span class="BreadCrumb">&nbsp;</td>';
	put '						<td align="right"><img src="/SASCSPooling/images/CrBanner.gif" width="259" height="29"></td> ';
	put '					</tr>';
	put '				</table>';
	put '				</td>';
	put '			</tr>';
	put '			<tr>';
	put '				<td>';

	/* Main Body */
	put '					<H2 align="left">';
	put '						<table width="100%" border="0" cellspacing="0" cellpadding="0">';
	put '							<tr><td>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.create_master_scale.1, noquote))"@;
	put '</td>';
	put '							</tr>';
	put '						</table>';
	put '					</H2>';
	put '				</td>';
	put '			</tr>';
	put '			<tr><td>';
	put '				<table width="100%" border="0" cellspacing="0" cellpadding="5">';
	put '					<tr><td class="LabelFont" width="20%">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.create_master_scale_name.1, noquote))"@;
	put '</td>';
	put '					<td class="LabelFont">';
	put '						<input type="text" size="45" name="ms_name" value="'@;
	put "&ms_nm"@;
	put '" maxLength="40" OnChange="javascript:setMSName()">';
	put '						<INPUT type=button class=mmhide_btn onClick="javascript:Select()" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.create_master_scale.button_select.1, noquote))"@;
	put'"></p>';
	put '					</td></tr>';
run;

%add_scheme;

data _NULL_;
	file _webout&webout_options;
	put '	</tr>';
	put '</table>';
	put '</body>';
	put '</html>';
run;

