/******************************************************************************************************
       Module:  select_master_scale

     Function:  Displays the existing master scales and allows the user to select a master scale

      Authors:  BIS Team
         Date:  14 May 2007
          SAS:  9.1
    Called-by:	create_master_scale
        Calls:  create_master_scale

Datasets used:  pool.master_scale_defn
 
        Logic:  Displays the master scales available in pool.master_scale_defn and allows the user to
				select one. The master scale identifier for the selected master scale is passed to the
				create_master_scale screen.
				
   Parameters:  NA

******************************************************************************************************/
/*This code is Internationalized*/
options nomprint;

%let lib=pool;

/* Links specific for the Master Scale screens */
%let CREATE_MS='SBIP://Foundation/BIS/pool/create_master_scale';

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;

proc sql noprint;
	select count(*) into :cnt 
	from &lib..master_scale_defn;

	create table &out_lib..ms_names as
	select distinct master_scale_no, master_scale_name 
	from &lib..master_scale_defn;
quit;

data _null_;
	file _webout&webout_options;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"';
	put '"http://www.w3.org/TR/html4/loose.dtd">';
	put '<html xmlns="http://www.w3.org/1999/xhtml>';
	put '<head>';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put '<title></title>';
	put '<link href="/SASCSPooling/styles/default.css" rel="stylesheet" type="text/css">';

	put '<style type="text/css">';
	put '<!-- ';
	put 'body {';
	put '	background-color: #FAF8ED;';
	put '}';
	put '--> ';
	put '</style> ';

	put '<script language="JavaScript" type="text/JavaScript"> ';
	put '<!-- ';

	/* For all dropdowns and model_types, the value holds the information such as 
	prod_type_cd:prod_type_desc. Hence depending on the selected index in the dropdown, 
	the code and descriptions have to extracted. This function does the job of extracting 
	the codes and descriptions. */
	put 'function getCodeDesc(mdl_val,mdl_key,mdl_name) {';
	put '	var len=mdl_val.length';
	put '	var indx=mdl_val.indexOf(":")';
	put '	var key_end=indx-1';
	put '	var nm_st=indx+1';
	put '	var nm_len=len-nm_st';
	put '	var key=mdl_val.substr(0,key_end)';
	put '	var nm=mdl_val.substr(nm_st,nm_len)';
	put '	mdl_key.value=key';
	put '	mdl_name.value=nm';
	put '}';
	/**/

	put 'function selectMS(val) {';
	put '	getCodeDesc(val, form1.ms_no, form1.ms_nm)';
	put '}';

	put 'function Select() {';
	put '	if((form1.ms_no.value=='''') || (form1.ms_nm.value=='''')) {';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_master_scale.alert_sel_master_scale.1, noquote))"@;
	put '")';
	put '	}';
	put '	else {';
	put '		form1.action.value=''M''';
	put '		form1.first_load.value=''Y''';
	put "		form1._program.value=&CREATE_MS;";
	put '		form1.submit()';		
	put '	}';
	put '}';

	put 'function Cancel() {';
	put '	form1.ms_no.value=''''';
	put '	form1.ms_nm.value=''''';
	put '	form1.action.value=''N''';
	put "	form1._program.value=&CREATE_MS;";
	put '	form1.submit()';
	put '}';

	put '//-->';
	put	'</script> ';
	put '</head>';

	put '<body>';
	put '<form name="form1" method="post" ACTION="/SASStoredProcess/do"> ';

	/* Hidden textboxes to hold the values for the program name and the output paremeters */
	put '<input type="hidden" name="_program" VALUE="">';
	put '<input type="hidden" name="ms_no" value="">';
	put '<input type="hidden" name="ms_nm" value="">';
	put '<input type="hidden" name="action" value="">';
	put '<input type="hidden" name="first_load" value="">';
	/**/

	put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';
	put '<tr>';
	put '<td align="left">';
	put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0">';
	put '<tr>';
	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';

	/* Navigational Links */
	put '<td>&nbsp;</td>'; 
	put '<td align="right"><img src="/SASCSPooling/images/CrBanner.gif" width="259" height="29"></td> ';
	put '</tr></table>';
	put '</td></tr>';
	/**/

	/* Main Body */
	put '<tr><td>';
	put '<H2 align="left"><table width="100%" border="0" cellspacing="0" cellpadding="0">';
	put '<tr><td>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_master_scale.master Scales.1, noquote))"@;
	put'</td></tr>';
	put '</table></H2>';
	put '</td></tr>';
	put '<tr><td>';
	put '<table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
	
	if ktrim(kleft("&cnt")) eq "0" then do;
		put '<tr><td>&nbsp;</td></tr>';
		put '<tr><td class="LabelFont">';
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_master_scale.not_defn_mstr_scl.1, noquote))";
	end;
run;

data _null_;
	file _webout&webout_options;
	set &out_lib..ms_names;
	put '<tr><td class="LabelFont"><input type="radio" name="ms" value="'@;
	ms_no=strip(master_scale_no);
	put ms_no@;
	put ':'@; 
	ms_nm=strip(master_scale_name);
	put ms_nm@;
	put '"'@;
	put ' onClick="javascript:selectMS(this.value)"'@;
	put '>'@;
	put ms_nm@;
	put '</td></tr>';
run;

data _null_;
	file _webout&webout_options;
	put '<tr><td>&nbsp;</td></tr>';
	put '</table>';
	put '</td></tr>';
	put '<tr>';
	put '<td height="32" bgcolor="#F1EACB">&nbsp;&nbsp;';
	put '<INPUT type=button class=mmhide_btn onClick="javascript:Select()" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_master_scale.button_select.1, noquote))"@;
	put '" align="left">';
	put '<INPUT type=button class=mmhide_btn onClick="javascript:Cancel()" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_master_scale.button_cancel.1, noquote))"@;
	put'" align="left">';
	put '</td>';
	put '</tr>';
	put '</table>';
	put '</td></tr></table>';
	put '</form>';
	put '</body>';
	put '</html>';
run;

