/******************************************************************************************************
       Module:  view_scheme

     Function:  Displays the details of the selected pool scheme

      Authors:  BIS Team
         Date:  14 May 2007
          SAS:  9.1
    Called-by:	build_scheme_score_pool
				build_scheme_pd_pool
				build_scheme_pd_lgd_pool
				build_scheme_pd_lgd_ccf_pool
				build_scheme_rating_pool
        Calls:  

Datasets used:  pool.pool_scheme_defn
 
        Logic:  Displays the pool scheme definition for the selected pool_scheme
				
   Parameters:  scheme_no	: The unique identifier of the pool scheme to be displayed

******************************************************************************************************/
/*This code is Internationalized*/
options nomprint;
/* Global Input Parameters */
%global scheme_no;

%let lib=pool;

/* Trimming extra spaces for all input paremeters */
%macro check_variable;
%let scheme_no=%str(%sysfunc(ktrim(%sysfunc(kleft(&scheme_no)))));
%mend;
%check_variable;
/**/

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;

proc sql;
	create table &out_lib..scheme_details as
	select * 
	from &lib..pool_scheme_defn
	where pool_scheme_no=&scheme_no;

	create table &out_lib..scheme_details1 as
	select scheme_details.*, b.model_nm as pd_model_nm, c.model_nm as lgd_model_nm, 
		d.model_nm as ccf_model_nm, e.model_nm as seg_model_nm
	from &out_lib..scheme_details left join dim.analytical_model_dim as b
	on(scheme_details.pd_model_rk = b.model_rk and b.valid_end_dttm = &valid_high_dttm)
	left join dim.analytical_model_dim as c
	on(scheme_details.lgd_model_rk = c.model_rk and c.valid_end_dttm = &valid_high_dttm)
	left join dim.analytical_model_dim as d
	on(scheme_details.ccf_model_rk = d.model_rk and d.valid_end_dttm = &valid_high_dttm)
	left join dim.analytical_model_dim as e
	on(scheme_details.seg_model_rk = e.model_rk and e.valid_end_dttm = &valid_high_dttm);
quit;

data _null_;
	file _webout&webout_options;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" ';
	put '"http://www.w3.org/TR/html4/loose.dtd"> ';
	put '<html> ';
	put '<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.title_pooling.1, noquote))"@;	
	put'</title> ';
	put '<link href="/SASCSPooling/styles/default.css" rel="stylesheet" type="text/css"> ';

	put '<style type="text/css">';
	put '<!--';
	put 'body {';
	put '	background-color: #FAF8ED;';
	put '}';
	put '-->';
	put '</style>';

	put '<script language="JavaScript" type="text/JavaScript"> ';
	put '<!-- ';

	put 'function closeWindow(){';
	put '	window.close()';
	put '}';

	put '//-->';
	put	'</script> ';
	put '</head>';

	put '<body>';
	put '<form name="form1" method="post" ACTION="/SASStoredProcess/do"> ';

	put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';
	put '<tr>';
	put '<td align="left">';
	put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0">';
	put '<tr>';
	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';

	/* Navigational Links */
	put '<td>&nbsp;</td>'; 
	put '<td align="right"><img src="/SASCSPooling/images/CrBanner.gif" width="259" height="29"></td> ';
	put '</tr></table>';
	put '</td></tr>';
	/**/

	/* Main Body */
	put '<tr><td>';
	put '<H2 align="left"><table width="100%" border="0" cellspacing="0" cellpadding="0">';
	put '<tr><td>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.title_view_sch_detl.1, noquote))"@;
	put '</td></tr>';
	put '</table></H2>';
	put '</td></tr>';
	put '<tr><td>';
	put '<table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
run;

data _null_;
	file _webout&webout_options;
	set &out_lib..scheme_details1;
	put '	<tr>';
	put '	<td class="LabelFont" width="15%">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.title_scheme_name.1, noquote))"@;
	put '</td>';
	put '	<td class="LabelFont">'@;
	put pool_scheme_name@;
	put '</td>';	
	put '	</tr>';

	scheme_type_nm=put(pool_scheme_type_cd, $poolschm.);
	put '	<tr>';
	put '	<td class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.title_scheme_type.1, noquote))"@;
	put'</td>';
	put '	<td class="LabelFont">'@;
	put scheme_type_nm@;
	put '</td>';	
	put '	</tr>';

	put '<tr><td>&nbsp;</td></tr>';

/*	put '	<tr>';*/
/*	put '	<td class="LabelFont">Model Name:</td>';*/
/*	put '	<td class="LabelFont">'@;*/
/*	put model_nm@;*/
/*	put '</td>';	*/
/*	put '	</tr>';*/
/**/
/*	put '<tr><td>&nbsp;</td></tr>';*/

	if strip(pool_scheme_type_cd) eq &SEGMENT_TYPE then do;
		desc_seg=put(seg_method_type_cd, $poolasgn.);
		put '	<tr>';
		put '	<td class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.column_seg_name.1, noquote))"@;
		put '</td>';
		put '	<td class="LabelFont">'@;
		put desc_seg@; 
		put '</td>';
		put '	</tr>';

		put '	<tr>';
		put '	<td class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.column_seg_mdl_name.1, noquote))"@;
		put '</td>';
		put '	<td class="LabelFont">'@;
		if seg_model_nm ne "" then put seg_model_nm@;
		else 
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.condition_none.1, noquote))"@;
		put '</td>';	
		put '	</tr>';
	end;
	else do;
		desc_pd=put(pd_method_type_cd, $poolasgn.);
		put '	<tr>';
		put '	<td class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.column_pd_method.1, noquote))"@;
		put '</td>';
		put '	<td class="LabelFont">'@;
		put desc_pd@;
		put '</td>';	
		put '	</tr>';

		put '	<tr>';
		put '	<td class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.column_pd_model_name.1, noquote))"@;
		put '</td>';
		put '	<td class="LabelFont">'@;
		put pd_model_nm@;
		put '</td>';	
		put '	</tr>';

		put '<tr><td>&nbsp;</td></tr>';

		desc_lgd=put(lgd_method_type_cd, $poolasgn.);
		put '	<tr>';
		put '	<td class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.column_lgd_method.1, noquote))"@;
		put '</td>';
		put '	<td class="LabelFont">'@;
		put desc_lgd@;
		put '</td>';
		put '	</tr>';

		put '	<tr>';
		put '	<td class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.column_lgd_model_name.1, noquote))"@;
		put '</td>';
		put '	<td class="LabelFont">'@;
		if lgd_model_nm ne "" then put lgd_model_nm@;
		else 
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.condition_none.1, noquote))"@;
		put '</td>';	
		put '	</tr>';

		put '<tr><td>&nbsp;</td></tr>';

		desc_ccf=put(ccf_method_type_cd, $poolasgn.);
		put '	<tr>';
		put '	<td class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.column_ccf_method.1, noquote))"@;
		put '</td>';
		put '	<td class="LabelFont">'@;
		put desc_ccf@; 
		put '</td>';
		put '	</tr>';

		put '	<tr>';
		put '	<td class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.column_ccf_model_name.1, noquote))"@;
		put '</td>';
		put '	<td class="LabelFont">'@;
		if ccf_model_nm ne "" then put ccf_model_nm@;
		else 
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.condition_none.1, noquote))"@;
		put '</td>';	
		put '	</tr>';
	end;

	put '<tr><td>&nbsp;</td></tr>';

	word_dt=put(obs_dt,ddmmyy10.);
	put '	<tr>';
	put '	<td class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.column_dt_of_abt.1, noquote))"@;
	put '</td>';
	put '	<td class="LabelFont">'@;
	put word_dt@;
	put '</td>';	
	put '	</tr>';
	put '	<tr>';
	put '	<td class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.column_status.1, noquote))"@;
	put '</td>';
	put '	<td class="LabelFont">'@;
	put status_desc@;
	put '</td>';	
	put '	</tr>';
run;

data _null_;
	file _webout&webout_options;
	put '<tr><td>&nbsp;</td></tr>';
	put '</table>';
	put '</td></tr>';
	put '<tr>';
	put '<td height="32" bgcolor="#F1EACB">&nbsp;&nbsp;';
	put '<INPUT type=button class=mmhide_btn onClick="javascript:closeWindow()" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.view_scheme.button_close_window.1, noquote))"@;
	put '" align="left">';
	put '</td>';
	put '</tr>';
	put '</table>';
	put '</td></tr></table>';
	put '</form>';
	put '</body>';
	put '</html>';
run;

